/*==============================================================================
|                               SAS SCENARIO FILE
|
| PRODUCT: SAS Anti-Money Laundering
| SYSTEM:  UNIX/WINDOWS
================================================================================
| NAME:            | SAS10080
|                  |
| CATEGORY:        | Watch List Entities
|                  |
| SEVERITY:        | Scenario
|                  |
| FREQUENCY:       | Weekly
|                  |
| DURATION:        | 1 day
|                  |
| SUBJECT:         | Customer
|                  |
| PREP FILE:       | Not Applicable
|                  |
| HEADER FILE:     | party_watchlist_header
|                  |
| TRIGGER:         | No
|                  |
| DAYS CONSIDERED: | Not Applicable
================================================================================

SHORT DESCRIPTION
-----------------
Non-Terrorist on Watch List

DESCRIPTION
-----------
A customer is designated on a watch list but is not considered a terrorist.

BUSINESS NOTES
--------------
This scenario compares all customers to the entity watch list table.

The scenario first checks for a match on exact name or a match on name match
code. If a match is found on either exact name or name match code then the
scenario checks additional match components for potential matches.

For individuals the scenario checks for matches on country, state/province and
city match codes, as well as exact matches for birth date or birth year, tax id
and citizenship.

For organizations the scenario checks for matches on country, state/province and
city match codes, as well as exact matches for tax id and country of business.

A match is found if a customer is not designated as a terrorist in the entity
watch list table and the minimum number of conditions to match for the entity
is met. Note: this scenario requires that match codes are built for both the
customer table and the entity watch list table.

TECHNICAL NOTES
---------------
The system parameter WATCH_LIST_PROCESSING_ METHOD is set in AUTOEXEC.SAS. It
determines whether the watch list array is stored in memory or in external hash
tables. This parameter should be set to HASH_ARRAY (the default) for 64-bit
environments and INDEX_ARRAY for 32-bit Windows environments.

MESSAGE
-------
%let r10080_threshold_message=%str("Non-Terrorist = #1; Match Count = #2;
Matches = #3; #4; WL ID = #5; WL Name = #6");

SAMPLE MESSAGE
--------------
Non-Terrorist = INDIVIDUAL; Match Count = 5; Matches = JAMES SCHIANO;
Match Code Name-Country-State-City-Citizenship; WL ID = 140176; WL Name = WCHK


================================================================================
PARAMETERS

Name                              Type                Default Value
---------------------------------|-------------------|--------------------------
 p10080_min_ind_match_count      | Numeric Constant  | 3
 p10080_min_org_match_count      | Numeric Constant  | 2

Descriptions
------------
- p10080_min_ind_match_count
Minimum number of conditions to match for individuals

- p10080_min_org_match_count
Minimum number of conditions to match for organizations

================================================================================

================================================================================
Copyright (c) 2012-2013 by SAS Institute Inc., Cary, NC 27513 USA
- All rights reserved
==============================================================================*/

format
   p10080_match_condition_01
   p10080_match_condition_02
   p10080_match_condition_03
   p10080_match_condition_04
   p10080_match_condition_05
   p10080_match_condition_06
   p10080_match_condition_07
   p10080_match_condition_08
   p10080_match_condition_09
   p10080_match_condition_10 $50.
   p10080_all_matches $500.
;

%macro aml_initialize_match_flags;
  p10080_match_condition_01=' ';    /* Name      */
  p10080_match_condition_02=' ';    /* Country   */
  p10080_match_condition_03=' ';    /* State     */
  p10080_match_condition_04=' ';    /* City      */
  p10080_match_condition_05=' ';    /* Birth Date/Year */
  p10080_match_condition_06=' ';    /* Tax ID */
  p10080_match_condition_07=' ';    /* Country of Citizenship Code */
  p10080_match_condition_08=' ';    /* Org Country of Business Code */
  p10080_match_condition_09=' ';    /* Full address */
  p10080_match_condition_10=' ';    /* Address */
  p10080_all_matches=' ';           /* All matches */

  p10080_match_01=0;                 /* Name      */
  p10080_match_02=0;                 /* Country   */
  p10080_match_03=0;                 /* State     */
  p10080_match_04=0;                 /* City      */
  p10080_match_05=0;                 /* Birth Date/Year */
  p10080_match_06=0;                 /* Tax ID */
  p10080_match_07=0;                 /* Country of Citizenship Code */
  p10080_match_08=0;                 /* Org Country of Business Code */
  p10080_match_09=0;                 /* Full address */
  p10080_match_10=0;                 /* Address */
  p10080_match_count=0;              /* Match Count */
%mend aml_initialize_match_flags;


%macro aml_address_check;
  /* CHECK FULL ADDRESS MATCH */
  if lengthn(kcompress(_match_code_full_address{i},'$')) ne 0 then do;
     if match_code_street_address  eq _match_code_full_address{i} or
        match_code_mailing_address eq _match_code_full_address{i} then do;
        p10080_match_09=1;
        p10080_match_condition_09=&r10080_match_09_value_01;
     end;
  end;

  /* CHECK COUNTRY MATCH */
  if lengthn(kcompress(_match_code_country{i},'$')) ne 0 then do;
     if match_code_street_country  eq _match_code_country{i} or
        match_code_mailing_country eq _match_code_country{i} then do;
        /* COUNTRY MATCH */
        p10080_match_02=1;
        p10080_match_condition_02=&r10080_match_02_value_01;
     end;
  end;

  /* CHECK STATE/PROVINCE MATCH */
  if lengthn(kcompress(_match_code_state{i},'$')) ne 0 and p10080_match_02 eq 1 then do;
     if match_code_street_state  eq _match_code_state{i} or
        match_code_mailing_state eq _match_code_state{i} then do;
        /* STATE/PROVINCE MATCH */
        p10080_match_03=1;
        p10080_match_condition_03=&r10080_match_03_value_01;
     end;
  end;

  /* CHECK CITY MATCH */
  if lengthn(kcompress(_match_code_city{i},'$')) ne 0 and p10080_match_02 eq 1 then do;
     if match_code_street_city  eq _match_code_city{i} or
        match_code_mailing_city eq _match_code_city{i} then do;
        /* CITY MATCH */
        p10080_match_04=1;
        p10080_match_condition_04=&r10080_match_04_value_01;
     end;
  end;

  /* CHECK ADDRESS MATCH */
  if lengthn(kcompress(_match_code_addr_lines{i},'$')) ne 0 and p10080_match_02 eq 1 then do;
     if match_code_street_addr_lines  eq _match_code_addr_lines{i} or
        match_code_mailing_addr_lines eq _match_code_addr_lines{i} then do;
        /* ADDRESS MATCH */
        p10080_match_10=1;
        p10080_match_condition_10=&r10080_match_10_value_01;
     end;
  end;
%mend aml_address_check;


%macro aml_birth_check;
  if not missing(party_date_of_birth) then do;
     if not missing(_date_of_birth{i}) then do;
        if datepart(party_date_of_birth) eq datepart(_date_of_birth{i}) then do;
           /* DATE_OF_BIRTH MATCH */
           p10080_match_05=1;
           p10080_match_condition_05=&r10080_match_05_value_01;
        end;
     end;
     if not missing(_year_of_birth{i}) and p10080_match_05 ne 1 then do;
        if year(datepart(party_date_of_birth)) eq _year_of_birth{i} then do;
          /* BIRTH_YEAR MATCH */
           p10080_match_05=1;
           p10080_match_condition_05=&r10080_match_05_value_02;
        end;
     end;
  end;
%mend aml_birth_check;


%macro aml_tax_id_check;
  if not missing(party_tax_id) then do;
     if not missing(_tax_id{i}) then do;
        if kstrip(kcompress(kcompress(party_tax_id,"-"))) eq kstrip(_tax_id{i}) then do;
           /* TAX_ID MATCH */
           p10080_match_06=1;
           p10080_match_condition_06=&r10080_match_06_value_01;
        end;
     end;
  end;
%mend aml_tax_id_check;


%macro aml_citizenship_check;
  if not missing(citizenship_country_code) then do;
     if not missing(_citizenship_country_code{i}) then do;
        if upcase(kstrip(citizenship_country_code)) eq upcase(kstrip(_citizenship_country_code{i})) then do;
           /* CITIZENSHIP MATCH */
           p10080_match_07=1;
           p10080_match_condition_07=&r10080_match_07_value_01;
        end;
     end;
  end;
%mend aml_citizenship_check;


%macro aml_process_match;
  if (upcase(party_type_desc) eq 'INDIVIDUAL' and p10080_match_count ge &p10080_min_ind_match_count) or
     (upcase(party_type_desc) eq 'ORGANIZATION' and p10080_match_count ge &p10080_min_org_match_count) then do;

     primary_entity_number=party_number;

     p10080_all_matches=kstrip(catx("-",p10080_match_condition_01,
                                       p10080_match_condition_02,
                                       p10080_match_condition_03,
                                       p10080_match_condition_04,
                                       p10080_match_condition_05,
                                       p10080_match_condition_06,
                                       p10080_match_condition_07,
                                       p10080_match_condition_08,
                                       p10080_match_condition_09,
                                       p10080_match_condition_10));

     actual_values_text=tranwrd(&r10080_threshold_message,'#1',kstrip(party_type_desc));
     actual_values_text=tranwrd(actual_values_text,       '#2',kstrip(party_name));
     actual_values_text=tranwrd(actual_values_text,       '#3',kstrip(p10080_all_matches));
     actual_values_text=tranwrd(actual_values_text,       '#4',kstrip(_entity_watch_list_number{i}));
     actual_values_text=tranwrd(actual_values_text,       '#5',kstrip(_watch_list_name{i}));

     ewln=_entity_watch_list_number(i);

     rc = ptyewl.check();
     if (rc ne 0) then
     do; /* new party/entity watch list number combo so output */
         /* and add to hash */
        output &alert_fname;
        rc =ptyewl.add();
     end;

     alert_fired = 1;

  end;
%mend aml_process_match;


entity_watch_list_number_prev='';
flag=0;
alert_fired = 0;


/**************/
/* INDIVIDUAL */
/**************/
if upcase(party_type_desc) eq 'INDIVIDUAL' then do;

   /*--------------------------
    * Matches = None --> EXIT
    *-------------------------*/
   if rc_ind_n ne 0 and rc_ind_m ne 0 then
      goto &sysmacroname.;

   last_name=upcase(compbl(kstrip(party_last_name)));
   match_code_individual=kstrip(match_code_individual_r);

   /*---------------------------------------------*/
   /* Matches = LAST_NAME + MATCH_CODE_INDIVIDUAL */
   /*---------------------------------------------*/
   if rc_ind_n eq 0 and rc_ind_m eq 0 then do;

       do until (_iorc_ eq %sysrc(_dsenom));

         if flag eq 1 then
            last_name=input('0000'x,$10.);

         set stg_wtch.wl_ind_name key=last_name;

         if _iorc_ eq 0 then do;

            %aml_initialize_match_flags;
            i=index_counter;

            if upcase(_category_desc{i}) eq 'TERRORISM' then
               continue;

            /* Check full name match */
            if upcase(compbl(kstrip(party_name))) eq upcase(compbl(kstrip(_entity_name{i})))
               or
               ( upcase(compbl(kstrip(party_first_name))) eq upcase(compbl(kstrip(_first_name{i}))) and
                 upcase(compbl(kstrip(party_middle_name))) eq upcase(compbl(kstrip(_middle_name{i}))) )
            then do;

               /* Match on FULL NAME */
               p10080_match_01=1;
               p10080_match_condition_01=&r10080_match_01_value_01;

               %aml_address_check;
               %aml_birth_check;
               %aml_citizenship_check;
               %aml_tax_id_check;

               p10080_match_count=sum(p10080_match_01,
                                      p10080_match_02,
                                      p10080_match_03,
                                      p10080_match_04,
                                      p10080_match_05,
                                      p10080_match_06,
                                      p10080_match_07,
                                      p10080_match_09,
                                      p10080_match_10);

               if p10080_match_01 eq 1 and p10080_match_count ge &p10080_min_ind_match_count then do;

                  if upcase(compbl(kstrip(_entity_watch_list_number{i}))) ne entity_watch_list_number_prev then do;
                     %aml_process_match;
                     entity_watch_list_number_prev=upcase(compbl(kstrip(_entity_watch_list_number{i})));
                  end;
                  else
                     continue;
               end;

            end;
            else do;
               /* Check match code individual match */
               if match_code_individual eq _match_code_individual{i} then do;

                  /* Match on MATCH_CODE_INDIVIDUAL */
                  p10080_match_01=1;
                  p10080_match_condition_01=&r10080_match_01_value_02;

                  %aml_address_check;
                  %aml_birth_check;
                  %aml_citizenship_check;
                  %aml_tax_id_check;

                  p10080_match_count=sum(p10080_match_01,
                                         p10080_match_02,
                                         p10080_match_03,
                                         p10080_match_04,
                                         p10080_match_05,
                                         p10080_match_06,
                                         p10080_match_07,
                                         p10080_match_09,
                                         p10080_match_10);

                  if p10080_match_01 eq 1 and p10080_match_count ge &p10080_min_ind_match_count then do;

                     if upcase(compbl(kstrip(_entity_watch_list_number{i}))) ne entity_watch_list_number_prev then do;
                        %aml_process_match;
                        entity_watch_list_number_prev=upcase(compbl(kstrip(_entity_watch_list_number{i})));
                     end;
                     else
                        continue;
                  end;
               end;
            end;
         end;
         else do;
            _error_=0;
            if not flag then do;
               flag=1;
               _iorc_=0;
            end;
         end;
      end;
   end;
   
   /*---------------------*/
   /* Matches = LAST_NAME */
   /*---------------------*/
   if rc_ind_n eq 0 and rc_ind_m ne 0 then do;

       do until (_iorc_ eq %sysrc(_dsenom));

         if flag eq 1 then
            last_name=input('0000'x,$10.);

         set stg_wtch.wl_ind_name key=last_name;

         if _iorc_ eq 0 then do;

            %aml_initialize_match_flags;
            i=index_counter;

            if upcase(_category_desc{i}) eq 'TERRORISM' then
               continue;

            /* Check last name match */
            if upcase(compbl(kstrip(party_name))) eq upcase(compbl(kstrip(_entity_name{i})))
               or
               ( upcase(compbl(kstrip(party_first_name))) eq upcase(compbl(kstrip(_first_name{i}))) and
                 upcase(compbl(kstrip(party_middle_name))) eq upcase(compbl(kstrip(_middle_name{i}))) )
            then do;

               /* Match on FULL NAME */
               p10080_match_01=1;
               p10080_match_condition_01=&r10080_match_01_value_01;

               %aml_address_check;
               %aml_birth_check;
               %aml_citizenship_check;
               %aml_tax_id_check;

               p10080_match_count=sum(p10080_match_01,
                                      p10080_match_02,
                                      p10080_match_03,
                                      p10080_match_04,
                                      p10080_match_05,
                                      p10080_match_06,
                                      p10080_match_07,
                                      p10080_match_09,
                                      p10080_match_10);

               if p10080_match_01 eq 1 and p10080_match_count ge &p10080_min_ind_match_count then do;

                  if upcase(compbl(kstrip(_entity_watch_list_number{i}))) ne entity_watch_list_number_prev then do;
                     %aml_process_match;
                     entity_watch_list_number_prev=upcase(compbl(kstrip(_entity_watch_list_number{i})));
                  end;
                  else
                     continue;
               end;
            end;
         end;
         else do;
            _error_=0;
            if not flag then do;
               flag=1;
               _iorc_=0;
            end;
         end;
      end;
   end;

   /*---------------------------------*/
   /* Matches = MATCH_CODE_INDIVIDUAL */
   /*---------------------------------*/

   /* alert_fired commented out due to S:7613232992 */
   /* alert_fired was used to output one alert per party but the requirement is */
   /* one alert per party per entity watch list number (as long as there are */
   /* supporting secondary matches) */

   if (rc_ind_n ne 0 and rc_ind_m eq 0) or
      (rc_ind_n eq 0 and rc_ind_m eq 0 /* and alert_fired eq 0 */) then do;

      flag = 0;

      do until (_iorc_ eq %sysrc(_dsenom));

         if flag eq 1 then
            match_code_individual=input('0000'x,$10.);

         set stg_wtch.wl_ind_match key=match_code_individual;

         if _iorc_ eq 0 then do;

            %aml_initialize_match_flags;
            i=index_counter;

            if upcase(_category_desc{i}) eq 'TERRORISM' then
               continue;

            /* Check match code individual match */
            if match_code_individual eq _match_code_individual{i} then do;

               /* Match on MATCH_CODE_INDIVIDUAL */
               p10080_match_01=1;
               p10080_match_condition_01=&r10080_match_01_value_03;

               %aml_address_check;
               %aml_birth_check;
               %aml_citizenship_check;
               %aml_tax_id_check;

               p10080_match_count=sum(p10080_match_01,
                                      p10080_match_02,
                                      p10080_match_03,
                                      p10080_match_04,
                                      p10080_match_05,
                                      p10080_match_06,
                                      p10080_match_07,
                                      p10080_match_09,
                                      p10080_match_10);

               if p10080_match_01 eq 1 and p10080_match_count ge &p10080_min_ind_match_count then do;

                  if upcase(compbl(kstrip(_entity_watch_list_number{i}))) ne entity_watch_list_number_prev then do;
                     %aml_process_match;
                     entity_watch_list_number_prev=upcase(compbl(kstrip(_entity_watch_list_number{i})));
                  end;
                  else
                     continue;
               end;
            end;
         end;
         else do;
            _error_=0;
            if not flag then do;
               flag=1;
               _iorc_=0;
            end;
         end;
      end;
   end;
end; /* END INDIVIDUAL */


/****************/
/* ORGANIZATION */
/****************/
if upcase(party_type_desc) eq 'ORGANIZATION' then do;

   /*--------------------------
    * Matches = None --> EXIT
    *-------------------------*/
   if rc_org_n ne 0 and rc_org_m ne 0 then
      goto &sysmacroname.;

   entity_name=upcase(compbl(kstrip(party_name)));
   match_code_organization=kstrip(match_code_organization_r);

   /*-------------------------------------------------------*/
   /* Matches = ORGANIZATION_NAME + MATCH_CODE_ORGANIZATION */
   /*-------------------------------------------------------*/
   if rc_org_n eq 0 and rc_org_m eq 0 then do;

      do until (_iorc_ eq %sysrc(_dsenom));

         if flag eq 1 then
            entity_name=input('0000'x,$10.);

         set stg_wtch.wl_org_name key=entity_name;

         if _iorc_ eq 0 then do;

            %aml_initialize_match_flags;
            i=index_counter;

            if upcase(_category_desc{i}) eq 'TERRORISM' then
               continue;

            /* Check organization name match */
            if upcase(compbl(kstrip(party_name))) eq upcase(compbl(kstrip(_entity_name{i}))) then do;

               /* Match on ORGANIZATION NAME */
               p10080_match_01=1;
               p10080_match_condition_01=&r10080_match_01_value_01;

               %aml_address_check;
               %aml_tax_id_check;

               p10080_match_count=sum(p10080_match_01,
                                      p10080_match_02,
                                      p10080_match_03,
                                      p10080_match_04,
                                      p10080_match_06,
                                      p10080_match_08,
                                      p10080_match_09,
                                      p10080_match_10);

               if p10080_match_01 eq 1 and p10080_match_count ge &p10080_min_org_match_count then do;

                  if upcase(compbl(kstrip(_entity_watch_list_number{i}))) ne entity_watch_list_number_prev then do;
                     %aml_process_match;
                     entity_watch_list_number_prev=upcase(compbl(kstrip(_entity_watch_list_number{i})));
                  end;
                  else
                     continue;
               end;
            end;
            else do;

               /* Check match code organization match */
               if match_code_organization eq _match_code_organization{i} then do;

                  /* MATCH_CODE_ORGANIZATION MATCH */
                  p10080_match_01=1;
                  p10080_match_condition_01=&r10080_match_01_value_03;

                  %aml_address_check;
                  %aml_tax_id_check;

                  p10080_match_count=sum(p10080_match_01,
                                         p10080_match_02,
                                         p10080_match_03,
                                         p10080_match_04,
                                         p10080_match_06,
                                         p10080_match_08,
                                         p10080_match_09,
                                         p10080_match_10);

                  if p10080_match_01 eq 1 and p10080_match_count ge &p10080_min_org_match_count then do;

                     if upcase(compbl(kstrip(_entity_watch_list_number{i}))) ne entity_watch_list_number_prev then do;
                        %aml_process_match;
                        entity_watch_list_number_prev=upcase(compbl(kstrip(_entity_watch_list_number{i})));
                     end;
                     else
                        continue;
                  end;
               end;
            end;
         end;
         else do;
            _error_=0;
            if not flag then do;
               flag=1;
               _iorc_=0;
            end;
         end;
      end;
   end;

   /*-----------------------------*/
   /* Matches = ORGANIZATION_NAME */
   /*-----------------------------*/
   if rc_org_n eq 0 and rc_org_m ne 0 then do;

      do until (_iorc_ eq %sysrc(_dsenom));

         if flag eq 1 then
            entity_name=input('0000'x,$10.);

         set stg_wtch.wl_org_name key=entity_name;

         if _iorc_ eq 0 then do;

            %aml_initialize_match_flags;
            i=index_counter;

            if upcase(_category_desc{i}) eq 'TERRORISM' then
               continue;

            /* Check organization name match */
            if upcase(compbl(kstrip(party_name))) eq upcase(compbl(kstrip(_entity_name{i}))) then do;

               /* Match on ORGANIZATION NAME */
               p10080_match_01=1;
               p10080_match_condition_01=&r10080_match_01_value_01;

               %aml_address_check;
               %aml_tax_id_check;

               p10080_match_count=sum(p10080_match_01,
                                      p10080_match_02,
                                      p10080_match_03,
                                      p10080_match_04,
                                      p10080_match_06,
                                      p10080_match_08,
                                      p10080_match_09,
                                      p10080_match_10);

               if p10080_match_01 eq 1 and p10080_match_count ge &p10080_min_org_match_count then do;

                  if upcase(compbl(kstrip(_entity_watch_list_number{i}))) ne entity_watch_list_number_prev then do;
                     %aml_process_match;
                     entity_watch_list_number_prev=upcase(compbl(kstrip(_entity_watch_list_number{i})));
                  end;
                  else
                     continue;
               end;
            end;
         end;
         else do;
            _error_=0;
            if not flag then do;
               flag=1;
               _iorc_=0;
            end;
         end;
      end;
   end;
   
   /*-----------------------------------*/
   /* Matches = MATCH_CODE_ORGANIZATION */
   /*-----------------------------------*/
   /* alert_fired commented out due to S:7613232992 */
   /* alert_fired was used to output one alert per party but the requirement is */
   /* one alert per party per entity watch list number (as long as there are */
   /* supporting secondary matches) */

   if (rc_org_n ne 0 and rc_org_m eq 0) or
      (rc_org_n eq 0 and rc_org_m eq 0 /* and alert_fired eq 0 */) then do;

      flag = 0;

      do until (_iorc_ eq %sysrc(_dsenom));

         if flag eq 1 then
            match_code_organization=input('0000'x,$10.);

         set stg_wtch.wl_org_match key=match_code_organization;

         if _iorc_ eq 0 then do;

            %aml_initialize_match_flags;
            i=index_counter;

            if upcase(_category_desc{i}) eq 'TERRORISM' then
               continue;

            /* Check match code organization match */
            if match_code_organization eq _match_code_organization{i} then do;

               /* Match on MATCH_CODE_ORGANIZATION */
               p10080_match_01=1;
               p10080_match_condition_01=&r10080_match_01_value_03;

               %aml_address_check;
               %aml_tax_id_check;

               p10080_match_count=sum(p10080_match_01,
                                      p10080_match_02,
                                      p10080_match_03,
                                      p10080_match_04,
                                      p10080_match_06,
                                      p10080_match_08,
                                      p10080_match_09,
                                      p10080_match_10);

               if p10080_match_01 eq 1 and p10080_match_count ge &p10080_min_org_match_count then do;

                  if upcase(compbl(kstrip(_entity_watch_list_number{i}))) ne entity_watch_list_number_prev then do;
                     %aml_process_match;
                     entity_watch_list_number_prev=upcase(compbl(kstrip(_entity_watch_list_number{i})));
                  end;
                  else
                     continue;
               end;
            end;
         end;
         else do;
            _error_=0;
            if not flag then do;
               flag=1;
               _iorc_=0;
            end;
         end;
      end;
   end;
end; /* END ORGANIZATION */


/* EXIT */
&sysmacroname.:;

/* ========================================================================== */
/* END SCENARIO - SAS10080                                                    */
/* ========================================================================== */
