/******************************************************************************/
/*                  S A S   S A M P L E   L I B R A R Y                       */
/*                                                                            */
/*    NAME: fcf_risk_class_list_extract.sas                                   */
/*   TITLE: fcf_risk_class_list_extract                                       */
/* PRODUCT: SAS Anti-Money Laundering                                         */
/*  SYSTEM: UNIX/WINDOWS                                                      */
/******************************************************************************/
/* ************************************************************************** */
/*  Copyright (c) 2016 by SAS Institute Inc., Cary, NC 27513 USA              */
/*  ---All Rights Reserved.                                                   */
/* ************************************************************************** */
/* USAGE EXAMPLES:
/* %fcf_risk_class_list_extract;
/*----------------------------------------------------------------------------*/
/* COMMENTS:
/*---------------------------------------------------------
 *  Host and Site specific customizations may be REQUIRED
 *---------------------------------------------------------*/
%macro fcf_risk_class_list_extract;
   /*----------------------------------------------------------------------------*/ 
   /* Configurable macro variables 
   /* - FCF_CONFIG_LOCALE_OPT: macro variable to override FCF_CONFIG_LOCALE.
   /*----------------------------------------------------------------------------*/ 

    %let FCF_CONFIG_LOCALE_OPT = %sysfunc(sasmsg(sashelp.fcflocale,&fcf_config_locale, N));

   /*----------------------------------------------------------------------------*/
   /* Set error code to 0 and message to blank
   /*----------------------------------------------------------------------------*/
    %let trans_rc = 0;
    %let _fcfmsg_=;

   /*--------------------------------------------------------------------------*/
   /* BEGIN RISK CLASSIFIER EXTRACT
   /*--------------------------------------------------------------------------*/

   /*--------------------------------------------------------------------------*/
   /*      Get risk classifiers by risk category 
   /*--------------------------------------------------------------------------*/
    %if %sysfunc(exist(&seg_kc_libname..fsk_risk_classifier_category)) and 
        %sysfunc(exist(&seg_kc_libname..fsk_risk_classifier)) %then %do;
      proc sql noprint;
         create table risk_classifier_report_data as 
         select
            cc.risk_classifier_category_name ,  
            cc.risk_classifier_category_desc ,
            rc.risk_classifier_name ,  
            rc.risk_classifier_short_desc ,
            rc.risk_classifier_desc ,
            rc.risk_classifier_type_code ,
            rc.risk_classifier_type_code as TYPE_DESC, 
            rc.active_ind ,
            rc.weight ,
            rc.source_table ,  
            rc.source_column , 
            rc.source_value , 
            rc.classifier_fact_column,
            rc.operator_desc ,  
            rc.classifier_threshold , 
            datepart(rc.create_date)  as CREATED FORMAT WORDDATE20.,
            rc.create_user_id ,   
            rc.version_number
         from  &seg_kc_libname..fsk_risk_classifier_category  as cc ,
               &seg_kc_libname..fsk_risk_classifier as rc
         where cc.risk_classifier_category_id = rc.risk_classifier_category_id 
            and cc.logical_delete_ind = 'N'    
            and rc.logical_delete_ind = 'N'     
         order by cc.risk_classifier_category_name , cc.risk_classifier_category_desc ;
      quit;

      %fcf_rcset(&sqlrc);
      %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
          %let _fcfmsg_=ERROR: Unable create fcf_rpt.risk_classifier_report_data.;
           %fcf_put_error;
           %goto MACRO_END;
      %end;
    %end;
    %else %do;
        %let trans_rc = 900;
        %let _fcfmsg_ =ERROR: Required &seg_kc_libname..fsk_risk_classifier_category or &seg_kc_libname..fsk_risk_classifier table not found, processing will end;  
        %fcf_put_error;
        %goto MACRO_END;
    %end;

   /*----------------------------------------------------------------------------*/
   /* Build dynamic in clause for display data retrieval.
   /*----------------------------------------------------------------------------*/

        PROC SQL noprint;
            select "'" || TYPE_DESC || "'" into :typeDescInClauseCond separated by ", " from
            (select distinct TYPE_DESC from risk_classifier_report_data);
        quit;


        %fcf_rcset(&sqlrc);
        %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
            %let _fcfmsg_=ERROR: Unable to build sql clause, processing will end.;
            %fcf_put_error;
            %goto MACRO_END;
        %end;

   /*----------------------------------------------------------------------------*/
   /* Get long display values for TYPE_DESC
   /*----------------------------------------------------------------------------*/

   %if %sysfunc(exist(&seg_kc_libname..FSK_LOV)) %then %do;
    proc sql;
        create table TYPE_DESC_DISPLAY as
             select distinct LOV_TYPE_CODE as value_cd, LOV_TYPE_DESC as value_desc from &seg_kc_libname..FSK_LOV
                where LOV_TYPE_NAME = 'CLASSIFIER_TYPE' and
                      LOV_LANGUAGE_DESC = "&fcf_config_locale_opt" and
                      VALUE_CD IN (&typeDescInClauseCond)
             ;
    quit;

    %fcf_rcset(&sqlrc);
    %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
        %let _fcfmsg_=ERROR: Unable to create table TYPE_DESC_DISPLAY, processing will end;
        %fcf_put_error;
        %goto MACRO_END;
    %end;
   /*----------------------------------------------------------------------------*/
   /* Verify at least one type desc display code returned.
   /*----------------------------------------------------------------------------*/
    %let dsid = %sysfunc(open(TYPE_DESC_DISPLAY));
    %if %sysfunc(attrn(&dsid, nlobs)) > 0 %then %do;
        %let rc = %sysfunc(close(&dsid));
   /*----------------------------------------------------------------------------*/
   /* Update TYPE_DESC 
   /*----------------------------------------------------------------------------*/
        %fcf_update_display_data(tabName=risk_classifier_report_data,
            LUTAB=TYPE_DESC_DISPLAY,
            existCol=TYPE_DESC,
            LUKey=VALUE_CD,
            LUVal=VALUE_DESC
            );
    %end;
    %else %do;
      %let trans_rc = 909;
      %let _fcfmsg_ = ERROR: No Entity Level Display Codes returned.;  
      %fcf_put_error;
      %goto MACRO_END;
    %end; 
  %end; 
  %else %do;
          %let _fcfmsg_ = WARNNG: &seg_kc_libname..FSK_lov table not found codes will be displayed in report.;  
          %fcf_put_error;
  %end;

        proc sql noprint;
         create table fcf_rpt.risk_classifier_report_data as 
         select
            risk_classifier_category_name ,  
            risk_classifier_category_desc ,
            risk_classifier_name ,  
            risk_classifier_short_desc ,
            risk_classifier_desc ,
            risk_classifier_type_code ,
            type_desc, 
            active_ind ,
            weight ,
            source_table ,  
            source_column , 
            source_value , 
            classifier_fact_column,
            operator_desc ,  
            classifier_threshold , 
            created,
            create_user_id ,   
            version_number
         from  risk_classifier_report_data     
         order by risk_classifier_category_name , risk_classifier_category_desc ;
      quit;

   /*----------------------------------------------------------------------------*/
   /* END RISK CLASSIFIER EXTRACT
   /*----------------------------------------------------------------------------*/

   /*----------------------------------------------------------------------------*/
   /* BEGIN LIST CATEGORY EXTRACT
   /*----------------------------------------------------------------------------*/

   /*----------------------------------------------------------------------------*/
   /*      Get list by list category  
   /*----------------------------------------------------------------------------*/
    %if %sysfunc(exist(&seg_kc_libname..fsk_list_category)) and 
        %sysfunc(exist(&seg_kc_libname..fsk_list)) %then %do;
       proc sql noprint;
       create table fcf_rpt.list_report_data as 
       select lc.list_category_name ,  
              lc.list_category_desc ,
              rl.list_name ,  
              rl.list_desc ,  
              rl.validation_type_code , 
              datepart(rl.create_date) as CREATED FORMAT WORDDATE20.,  
              rl.create_user_id 
         from  &seg_kc_libname..fsk_list_category  as lc ,
               &seg_kc_libname..fsk_list as rl
         where lc.list_category_id = rl.list_category_id  
            and lc.logical_delete_ind = 'N'    
            and rl.logical_delete_ind = 'N'    
         order by lc.list_category_name, lc.list_category_desc, rl.list_name;
      quit;

      %fcf_rcset(&sqlrc);
      %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
          %let _fcfmsg_=ERROR: Unable create fcf_rpt.list_report_data.;
           %fcf_put_error;
           %goto MACRO_END;
      %end;
    %end;
    %else %do;
        %let trans_rc = 900;
        %let _fcfmsg_ =ERROR: Required &seg_kc_libname..fsk_list_category or &seg_kc_libname..fsk_list table not found, processing will end;  
        %fcf_put_error;
        %goto MACRO_END;
    %end;
   /*----------------------------------------------------------------------------*/
   /* END LIST CATEGORY EXTRACT 
   /*----------------------------------------------------------------------------*/

%MACRO_END:

%if &trans_rc in (3 5 900 909) %then
     %fcf_execute_macro(fcf_error);
%else %do;
     %fcf_execute_macro(fcf_success);
%end;

%mend fcf_risk_class_list_extract;

