/******************************************************************************/
/*                  S A S   S A M P L E   L I B R A R Y                       */
/*                                                                            */
/*    NAME: fcf_scenario_administration_extract.sas                           */
/*   TITLE: fcf_scenario_administration_extract                               */
/* PRODUCT: SAS Anti-Money Laundering                                         */
/*  SYSTEM: UNIX/WINDOWS                                                      */
/******************************************************************************/
/* ************************************************************************** */
/*  Copyright (c) 2016 by SAS Institute Inc., Cary, NC 27513 USA              */
/*  ---All Rights Reserved.                                                   */
/* ************************************************************************** */
/* USAGE EXAMPLES:
/* %fcf_scenario_admin_extract;
/*----------------------------------------------------------------------------*/
/* COMMENTS:
/*---------------------------------------------------------
 *  Host and Site specific customizations may be REQUIRED
 *---------------------------------------------------------*/
%macro fcf_scenario_admin_extract;

   /*----------------------------------------------------------------------------*/ 
   /* Configurable macro variables 
   /* - FCF_CONFIG_LOCALE_OPT: macro variable to override FCF_CONFIG_LOCALE.
   /* - add: display text for scenario change history - addtions.
   /* - delete: display text for scenario change history - deletions.
   /* - change: display text for scenario change history - changes.
   /* - format: display text for scenario change history - format.
   /* - value: display text for scenario change history - value.
   /* - desc: display text for scenario change history - description.
   /*----------------------------------------------------------------------------*/

    %let FCF_CONFIG_LOCALE_OPT = %sysfunc(sasmsg(sashelp.fcflocale,&fcf_config_locale, N));
    %let add = Addition;
    %let delete = Deletion; 
    %let change = Change;
    %let format = Format;
    %let value = Value;
    %let desc = Description;


   /*----------------------------------------------------------------------------*/
   /* Set error code to 0 and message to blank
   /*----------------------------------------------------------------------------*/
    %let trans_rc = 0;
    %let _fcfmsg_=;

   /*----------------------------------------------------------------------------*/
   /* BEGIN ACTIVE HEADER EXTRACT
   /*----------------------------------------------------------------------------*/

   /*----------------------------------------------------------------------------*/
   /* Retrieve all active headers from &seg_kc_libname..FSK_HEADER
   /*----------------------------------------------------------------------------*/
    %if %sysfunc(exist(&seg_kc_libname..FSK_HEADER)) %then %do;
        PROC SQL;
         connect to &dbflavor as &dbflavor (authdomain="&segkcAuthDomain."
                                                     &segKCDBConnOpts);
            CREATE TABLE WORK.HEADER_SELECT AS
                SELECT a.HEADER_ID            FORMAT=best32.,
                    a.HEADER_NAME             ,
                    a.HEADER_DESCRIPTION      ,
                    a.ENTITY_LEVEL_CODE       ,
                    a.DENORM_TABLE_NAME       ,
                    a.ALERT_TABLE_NAME        ,
                    a.HEADER_AUTOGEN_IND      ,
                    a.HEADER_LOCATION_DESC    ,
                    a.SOURCE_TYPE_DESC        ,
                    CASE
                    WHEN a.HEADER_ID < -1 THEN
                    'VSD' 
                    ELSE
                    'AML'
                    END as HEADER_SOURCE      ,
                    a.CREATE_USER_ID          ,
                    a.CREATE_DATE             FORMAT=nldatm.,
                    a.LSTUPDATE_USER_ID       ,
                    a.LSTUPDATE_DATE          FORMAT=nldatm.,
                    a.HEADER_HOST_DESC        ,
                    a.LOGICAL_DELETE_IND
                FROM  &seg_kc_libname..FSK_HEADER AS a
                    WHERE  (a.HEADER_ID > 0 OR a.HEADER_ID < -1) AND
                        a.LOGICAL_DELETE_IND = 'N'
                    ORDER BY a.HEADER_ID, a.CREATE_DATE;
           disconnect from &dbflavor;
        QUIT;
    %end;
    %else %do;
        %let trans_rc = 900;
        %let _fcfmsg_ =ERROR: seg_kc.FSK_HEADER table not found, processing will end;  
        %fcf_put_error;
        %goto MACRO_END;
    %end;
   /*----------------------------------------------------------------------------*/
   /* Verify at least one active header returned.
   /*----------------------------------------------------------------------------*/
    %let dsid = %sysfunc(open(HEADER_SELECT));
    %if %sysfunc(attrn(&dsid, nlobs)) > 0 %then %do;
        %let rc = %sysfunc(close(&dsid));
   /*----------------------------------------------------------------------------*/
   /* Build dynamic in clause for display data retrieval.
   /*----------------------------------------------------------------------------*/
        PROC SQL noprint;
            select "'" || ENTITY_LEVEL_CODE || "'" into :entityInClauseCond separated by ", " from
            (select distinct ENTITY_LEVEL_CODE from HEADER_SELECT);
        quit;

        %fcf_rcset(&sqlrc);
        %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
            %let _fcfmsg_=ERROR: Unable to build sql clause, processing will end.;
            %fcf_put_error;
            %goto MACRO_END;
        %end;
   %end;
   %else %do;
      %let trans_rc = 909;
      %let _fcfmsg_ = ERROR: No active headers returned.;  
      %fcf_put_error;
      %goto MACRO_END;
   %end;
   /*----------------------------------------------------------------------------*/
   /* Get long display values for ENTITY_LEVEL_CODE
   /*----------------------------------------------------------------------------*/
    proc sql;
        create table ENTITY_LEVEL_CODE_DISPLAY as
            select distinct LOV_TYPE_CODE as value_cd, LOV_TYPE_DESC as value_desc from DB_KC.FSK_LOV
                where LOV_TYPE_NAME = 'RT_ENTITY_LEVEL' and
                      LOV_LANGUAGE_DESC = "&fcf_config_locale_opt" and
                      VALUE_CD IN (&entityInClauseCond);
    quit;

    %fcf_rcset(&sqlrc);
    %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
        %let _fcfmsg_=ERROR: Unable to create table ENTITY_LEVEL_CODE_DISPLAY, processing will end;
        %fcf_put_error;
        %goto MACRO_END;
    %end;
   /*----------------------------------------------------------------------------*/
   /* Verify at least one entity level display code returned.
   /*----------------------------------------------------------------------------*/
    %let dsid = %sysfunc(open(ENTITY_LEVEL_CODE_DISPLAY));
    %if %sysfunc(attrn(&dsid, nlobs)) > 0 %then %do;
        %let rc = %sysfunc(close(&dsid));
   /*----------------------------------------------------------------------------*/
   /* Update ENTITY_LEVEL_CODE  
   /*----------------------------------------------------------------------------*/
        %fcf_update_display_data(tabName=header_select,
            LUTAB=ENTITY_LEVEL_CODE_DISPLAY,
            existCol=ENTITY_LEVEL_CODE,
            LUKey=VALUE_CD,
            LUVal=VALUE_DESC
            );
    %end;
    %else %do;
      %let trans_rc = 909;
      %let _fcfmsg_ = ERROR: No Entity Level Display Codes returned.;  
      %fcf_put_error;
      %goto MACRO_END;
    %end; 

   /*----------------------------------------------------------------------------*/
   /* Summarize element records for each header
   /*----------------------------------------------------------------------------- */
    PROC SQL;
       connect to &dbflavor as &dbflavor (authdomain="&segkcAuthDomain."
                                          &segKCDBConnOpts);
        CREATE TABLE WORK.ELEMENT_SUMMARY AS
            SELECT FSK_HEADER.HEADER_ID                     FORMAT=best32.,
                FSK_HEADER.HEADER_DESCRIPTION           FORMAT=$255.,
                (COUNT(FSK_HEADER_ELEMENT.ELEMENT_NAME)) AS HEADER_ELEMENT_COUNT 
            FROM      &seg_kc_libname..FSK_HEADER AS FSK_HEADER
                LEFT JOIN
                    &seg_kc_libname..FSK_HEADER_ELEMENT AS FSK_HEADER_ELEMENT
                    ON (FSK_HEADER.HEADER_ID = FSK_HEADER_ELEMENT.HEADER_ID)
                WHERE (FSK_HEADER.HEADER_ID > 0 OR FSK_HEADER.HEADER_ID < -1)  AND
                    FSK_HEADER.LOGICAL_DELETE_IND = 'N'
                GROUP BY FSK_HEADER.HEADER_ID, FSK_HEADER.HEADER_DESCRIPTION
                    ORDER BY FSK_HEADER.HEADER_ID, FSK_HEADER.HEADER_DESCRIPTION;
       disconnect from &dbflavor;
    QUIT;

    %fcf_rcset(&sqlrc);
    %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
        %let _fcfmsg_=ERROR: Unable to create ELEMENT_SUMMARY;
        %fcf_put_error;
        %goto MACRO_END;
    %end;

   /*----------------------------------------------------------------------------
   /* Join Element records to active headers
   /*----------------------------------------------------------------------------- */
    proc sql;
        create table WORK.HEADER_ELEMENTS_COUNT as
            select a.HEADER_ID            ,
                a.HEADER_NAME             ,
                a.HEADER_DESCRIPTION      ,
                a.ENTITY_LEVEL_CODE       ,
                a.DENORM_TABLE_NAME       ,
                a.ALERT_TABLE_NAME        ,
                a.HEADER_AUTOGEN_IND      ,
                a.HEADER_LOCATION_DESC    ,
                a.SOURCE_TYPE_DESC        ,
                a.HEADER_SOURCE       ,
                a.CREATE_USER_ID          ,
                a.CREATE_DATE             ,
                a.LSTUPDATE_USER_ID       ,
                a.LSTUPDATE_DATE          ,
                a.HEADER_HOST_DESC        ,
                a.LOGICAL_DELETE_IND      ,
                b.Header_element_count
            from WORK.HEADER_SELECT as a left join WORK.ELEMENT_SUMMARY as b
            on a.HEADER_ID = b.HEADER_ID
               order by HEADER_NAME;
    quit;

    %fcf_rcset(&sqlrc);
    %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
        %let _fcfmsg_=ERROR: Unable to append header elements count to active headers.;
        %fcf_put_error;
        %goto MACRO_END;
    %end;

   /*----------------------------------------------------------------------------
   /* Create Element table for all active header elements
   /*----------------------------------------------------------------------------- */

    PROC SQL;
    connect to &dbflavor as &dbflavor (authdomain="&segkcAuthDomain."
                                       &segKCDBConnOpts);
        CREATE TABLE WORK.SELECT_ACTIVE_ELEMENTS  AS
            SELECT a.HEADER_ID          FORMAT=best32.,
                a.ELEMENT_NAME              ,
                a.ELEMENT_TYPE_CODE         ,
                a.ELEMENT_FORMAT_CODE       ,
                a.ELEMENT_LABEL_DESC        ,
                a.ELEMENT_USAGE_DESC
            FROM &seg_kc_libname..FSK_HEADER_ELEMENT AS a
                ORDER BY a.HEADER_ID,
                    a.ELEMENT_USAGE_DESC,
                    a.ELEMENT_NAME;
    disconnect from &dbflavor;
    QUIT;
    
    %fcf_rcset(&sqlrc);
    %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
        %let _fcfmsg_=ERROR: Unable to create active elements table.;
        %fcf_put_error;
        %goto MACRO_END;
    %end;

   /*----------------------------------------------------------------------------*/
   /* Verify at least one element returned.
   /*----------------------------------------------------------------------------*/
    %let dsid = %sysfunc(open(SELECT_ACTIVE_ELEMENTS));
    %if %sysfunc(attrn(&dsid, nlobs)) lt 1 %then %do;
       %let trans_rc = 909;
       %let _fcfmsg_ = ERROR: No Elements returned.;  
       %fcf_put_error;
       %goto MACRO_END;
    %end;
    %let rc = %sysfunc(close(&dsid));
    
   /*----------------------------------------------------------------------------
   /* Join Element information to active headers
   /*----------------------------------------------------------------------------- */
    proc sql;
        create table FCF_RPT.ACTIVE_HEADERS_DATA as
            select a.HEADER_ID            ,
                a.HEADER_NAME             ,
                a.HEADER_DESCRIPTION      ,
                a.ENTITY_LEVEL_CODE       ,
                a.DENORM_TABLE_NAME       ,
                a.ALERT_TABLE_NAME        ,
                a.HEADER_AUTOGEN_IND      ,
                a.HEADER_LOCATION_DESC    ,
                a.SOURCE_TYPE_DESC        ,
                a.HEADER_SOURCE       ,
                a.CREATE_USER_ID          ,
                a.CREATE_DATE             ,
                a.LSTUPDATE_USER_ID       ,
                a.LSTUPDATE_DATE          ,
                a.HEADER_HOST_DESC        ,
                a.LOGICAL_DELETE_IND      ,
                a.HEADER_ELEMENT_COUNT    ,
                b.ELEMENT_NAME            ,
                b.ELEMENT_TYPE_CODE       ,
                b.ELEMENT_FORMAT_CODE     ,
                b.ELEMENT_LABEL_DESC      ,
                b.ELEMENT_USAGE_DESC      
            from WORK.HEADER_ELEMENTS_COUNT as a left join WORK.SELECT_ACTIVE_ELEMENTS as b
            on a.HEADER_ID = b.HEADER_ID
                    order by HEADER_ID;
    quit;
    %fcf_rcset(&sqlrc);
    %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
       %let _fcfmsg_=ERROR: Unable to join elements information to active header data.;
       %fcf_put_error;
       %goto MACRO_END;
    %end;
   /*----------------------------------------------------------------------------*/
   /* END ACTIVE HEADER EXTRACT
   /*----------------------------------------------------------------------------*/

   /*----------------------------------------------------------------------------*/
   /* BEGIN SCENARIOS AND RISK FACTORS EXTRACT
   /*----------------------------------------------------------------------------*/

   /*----------------------------------------------------------------------------*/
   /*  Select most recent version of scenarios
   /*----------------------------------------------------------------------------*/
   %if %sysfunc(exist(&seg_kc_libname..FSK_SCENARIO)) %then %do;
    PROC SQL;
    connect to &dbflavor as &dbflavor (authdomain="&segkcAuthDomain."
                                       &segKCDBConnOpts);
      CREATE TABLE WORK.SELECT_SCENARIOS AS SELECT
       a.SCENARIO_ID                         FORMAT=best32.,
       a.HEADER_ID                           FORMAT=best32.,
       a.SCENARIO_NAME                       ,
       a.SCENARIO_SHORT_DESCRIPTION          ,
       a.SCENARIO_DESCRIPTION                ,
       a.SCENARIO_CODE_LOCATION_DESC         ,
       a.SCENARIO_CATEGORY_CODE              ,
       a.PRODUCT_TYPE_CODE                   ,
       a.SCENARIO_STATUS_CODE                ,
       a.CURRENT_IND                         ,
       a.DFLT_SUPPRESS_DURATION_COUNT        ,
       a.SCENARIO_DURATION_COUNT             ,
       a.MONEY_LAUNDERING_BAYES_WEIGHT       ,
       a.TERROR_FINANCING_BAYES_WEIGHT       ,
       a.EXECUTION_PROBABILITY_RATE          ,
       a.RISK_FACTOR_IND                     ,
       a.CREATE_DATE                         FORMAT=NLDATM.,
       a.CREATE_USER_ID                      ,
       a.END_DATE                            FORMAT=NLDATM.,
       a.END_USER_ID                         ,
       a.VERSION_NUMBER                      ,
       a.LOGICAL_DELETE_IND                  ,
       a.SCENARIO_RUN_FREQUENCY_CODE         ,
       a.ROUTING_GROUP_ID                    ,
       a.ROUTING_USER_LONG_ID                
    FROM &seg_kc_libname..FSK_SCENARIO AS a
    WHERE a.SCENARIO_ID > -1
    GROUP BY a.SCENARIO_NAME
    HAVING a.VERSION_NUMBER = MAX(a.VERSION_NUMBER)
    ORDER BY a.SCENARIO_STATUS_CODE, a.SCENARIO_NAME;
    disconnect from &dbflavor;
    QUIT;
    %fcf_rcset(&sqlrc);
    %put transaction return code post fcf_reset: &trans_rc;
    %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
            %put SQL RETURN CODE: &sqlrc;
            %let _fcfmsg_=ERROR: Unable to to retrieve data from seg_kc.FSK_SCENARIO, processing will end;
            %fcf_put_error;
            %goto MACRO_END;
        %end;
    %end;
    %else %do;
        %let trans_rc = 900;
        %let _fcfmsg_ =ERROR: seg_kc.FSK_SCENARIO table not found, processing will end;  
        %fcf_put_error;
        %goto MACRO_END;
    %end;
   /*----------------------------------------------------------------------------*/
   /* Build dynamic in clause for display data retrieval.
   /*----------------------------------------------------------------------------*/
     PROC SQL noprint;
       select "'" || STRIP(SCENARIO_STATUS_CODE) || "'" into :scnStatCDInClauseCond separated by ", " from
       (select distinct SCENARIO_STATUS_CODE from WORK.SELECT_SCENARIOS);
     quit;

   /*----------------------------------------------------------------------------*/
   /* Get long display values for SCENARIO_STATUS_CODE
   /*----------------------------------------------------------------------------*/
    proc sql;
        create table SCENARIO_STATUS_CODE_DISPLAY as
            select distinct LOV_TYPE_CODE as value_cd, LOV_TYPE_DESC as value_desc from DB_KC.FSK_LOV
                where LOV_TYPE_NAME = 'SCENARIO_STATUS' and
                      LOV_LANGUAGE_DESC = "&fcf_config_locale_opt" and
                      VALUE_CD IN (&scnStatCDInClauseCond);
    quit;
    %fcf_rcset(&sqlrc);
    %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
        %let _fcfmsg_=ERROR: Unable to create table Scenario Status Code Display, processing will end;
        %fcf_put_error;
        %goto MACRO_END;
    %end;
   /*----------------------------------------------------------------------------*/
   /* Verify at least one SCENARIO_STATUS_CODE Display returned.
   /*----------------------------------------------------------------------------*/
    %let dsid = %sysfunc(open(SCENARIO_STATUS_CODE_DISPLAY));
    %if %sysfunc(attrn(&dsid, nlobs)) > 0 %then %do;
        %let rc = %sysfunc(close(&dsid));
   /*----------------------------------------------------------------------------*/
   /* Update SCENARIO_STATUS_CODE  
   /*----------------------------------------------------------------------------*/
        %fcf_update_display_data(tabName=SELECT_SCENARIOS,
            LUTAB=SCENARIO_STATUS_CODE_DISPLAY,
            existCol=SCENARIO_STATUS_CODE,
            LUKey=VALUE_CD,
            LUVal=VALUE_DESC
            );
   %end;
   %else %do;
      %let trans_rc = 909;
      %let _fcfmsg_ = ERROR: No Scenario Status Display Codes returned.;  
      %fcf_put_error;
      %goto MACRO_END;
   %end; 
   /*----------------------------------------------------------------------------*/
   /* Build dynamic in clause for display data retrieval. 
   /*----------------------------------------------------------------------------*/
   PROC SQL noprint;
     select "'" || STRIP(SCENARIO_CATEGORY_CODE) || "'" into :scnCatCDInClauseCond separated by ", " from
     (select distinct SCENARIO_CATEGORY_CODE from WORK.SELECT_SCENARIOS);
   quit;

   /*----------------------------------------------------------------------------*/
   /* Get long display values for SCENARIO_CATEGORY_CODE
   /*----------------------------------------------------------------------------*/
    proc sql;
        create table SCENARIO_CATEGORY_CODE_DISPLAY as
            select distinct LOV_TYPE_CODE as value_cd, LOV_TYPE_DESC as value_desc from DB_KC.FSK_LOV
                where LOV_TYPE_NAME = 'SCENARIO_CATEGORY' and
                      LOV_LANGUAGE_DESC = "&fcf_config_locale_opt" and
                      VALUE_CD IN (&scnCatCDInClauseCond);
    quit;

    %fcf_rcset(&sqlrc);
    %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
        %let _fcfmsg_=ERROR: Unable to create table Scenario Category Code Display, processing will end;
        %fcf_put_error;
        %goto MACRO_END;
    %end;
   /*----------------------------------------------------------------------------*/
   /* Verify at least one SCENARIO_CATEGORY_CODE display code returned.
   /*----------------------------------------------------------------------------*/
    %let dsid = %sysfunc(open(SCENARIO_CATEGORY_CODE_DISPLAY));
    %if %sysfunc(attrn(&dsid, nlobs)) > 0 %then %do;
        %let rc = %sysfunc(close(&dsid));
   /*----------------------------------------------------------------------------*/
   /* Update SCENARIO_CATEGORY_CODE  
   /*----------------------------------------------------------------------------*/
        %fcf_update_display_data(tabName=SELECT_SCENARIOS,
            LUTAB=SCENARIO_CATEGORY_CODE_DISPLAY,
            existCol=SCENARIO_CATEGORY_CODE,
            LUKey=VALUE_CD,
            LUVal=VALUE_DESC
            );
    %end;
    %else %do;
        %let trans_rc = 909;
        %let _fcfmsg_ = ERROR: No Scenario Category Display Codes returned.;  
        %fcf_put_error;
        %goto MACRO_END;
    %end; 
   /*----------------------------------------------------------------------------*/
   /* Build dynamic in clause for display data retrieval. 
   /*----------------------------------------------------------------------------*/
    PROC SQL noprint;
         select "'" || STRIP(SCENARIO_RUN_FREQUENCY_CODE) || "'" into :scnFrqCDInClauseCond separated by ", " from
           (select distinct SCENARIO_RUN_FREQUENCY_CODE from WORK.SELECT_SCENARIOS);
    quit;

   /*----------------------------------------------------------------------------*/
   /* Get long display values for SCENARIO_RUN_FREQUENCY_CODE
   /*----------------------------------------------------------------------------*/
    proc sql;
         create table SCENARIO_RUN_FRQ_CODE_DISPLAY as
            select distinct LOV_TYPE_CODE as value_cd, LOV_TYPE_DESC as value_desc from DB_KC.FSK_LOV
                where LOV_TYPE_NAME = 'SCENARIO_FREQUENCY' and
                      LOV_LANGUAGE_DESC = "&fcf_config_locale_opt" and
                      VALUE_CD IN (&scnFrqCDInClauseCond);
    quit;
    %fcf_rcset(&sqlrc);
    %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
        %let _fcfmsg_=ERROR: Unable to create table Scenario Category Code Display, processing will end;
        %fcf_put_error;
        %goto MACRO_END;
    %end;
   /*----------------------------------------------------------------------------*/
   /* Verify at least one SCENARIO_RUN_FREQUENCY_CODE display code returned.
   /*----------------------------------------------------------------------------*/
    %let dsid = %sysfunc(open(SCENARIO_RUN_FRQ_CODE_DISPLAY));
    %if %sysfunc(attrn(&dsid, nlobs)) > 0 %then %do;
        %let rc = %sysfunc(close(&dsid));
   /*----------------------------------------------------------------------------*/
   /* Update SCENARIO_RUN_FREQUENCY_CODE  
   /*----------------------------------------------------------------------------*/
        %fcf_update_display_data(tabName=SELECT_SCENARIOS,
            LUTAB=SCENARIO_RUN_FRQ_CODE_DISPLAY,
            existCol=SCENARIO_RUN_FREQUENCY_CODE,
            LUKey=VALUE_CD,
            LUVal=VALUE_DESC
            );
    %end;
    %else %do;
       %let trans_rc = 909;
       %let _fcfmsg_ = ERROR: No Scenario Run Frequency Display Codes returned.;  
       %fcf_put_error;
       %goto MACRO_END;
    %end; 

   /*--------------------------------------------------------------
   /*  Get number of scenario parms associated with current scenarios
   /*--------------------------------------------------------------*/
    PROC SQL;
      connect to &dbflavor as &dbflavor (authdomain="&segkcAuthDomain."
                                     &segKCDBConnOpts);
         CREATE TABLE WORK.NUMBER_SCENARIO_PARAMETERS AS
         SELECT b.SCENARIO_ID FORMAT=best32.,
             (COUNT(a.PARM_NAME)) AS NUMBER_OF_PARAMETERS 
         FROM &seg_kc_libname..FSK_SCENARIO_PARAMETER AS a
              RIGHT JOIN work.select_scenarios AS b
         ON (a.SCENARIO_ID = b.SCENARIO_ID)
         GROUP BY a.SCENARIO_ID
         ORDER BY b.SCENARIO_ID;
      disconnect from &dbflavor;
    QUIT;

    %fcf_rcset(&sqlrc);
    %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
         %let _fcfmsg_=ERROR: Unable to derive scenario paramenter information from seg_kc.FSK_SCENARIO, processing will end;
         %fcf_put_error;
         %goto MACRO_END;
    %end;

   /*----------------------------------------------------------------------------*/
   /* Verify at least one paramenter returned.
   /*----------------------------------------------------------------------------*/
    %let dsid = %sysfunc(open(NUMBER_SCENARIO_PARAMETERS));
    %if %sysfunc(attrn(&dsid, nlobs)) < 1 %then %do;
          %let trans_rc = 909;
          %let _fcfmsg_ = ERROR: No Parameters returned.;  
          %fcf_put_error;
          %goto MACRO_END;            
    %end;
    %let rc = %sysfunc(close(&dsid));
   /*---------------------------------------------------------
   /* Put number of parms associated current scenarios in table
   /*-----------------------------------------------------------*/
    PROC SQL;
     CREATE TABLE WORK.SCENARIOS_NUMBER_PARMS_DATA AS SELECT
        a.SCENARIO_ID                       FORMAT=best32.,
        a.HEADER_ID                         FORMAT=best32.,
        a.SCENARIO_NAME                     ,
        a.SCENARIO_SHORT_DESCRIPTION        ,
        a.SCENARIO_DESCRIPTION              ,
        a.SCENARIO_CODE_LOCATION_DESC       ,
        a.scenario_category_code            ,
        a.PRODUCT_TYPE_CODE                 ,
        a.SCENARIO_STATUS_CODE              ,
        a.CURRENT_IND                       ,
        a.DFLT_SUPPRESS_DURATION_COUNT      ,
        a.SCENARIO_DURATION_COUNT           ,
        a.MONEY_LAUNDERING_BAYES_WEIGHT     ,
        a.TERROR_FINANCING_BAYES_WEIGHT     ,
        a.EXECUTION_PROBABILITY_RATE        ,
        a.RISK_FACTOR_IND                   ,
        a.CREATE_DATE                       FORMAT=NLDATM.,
        a.CREATE_USER_ID                    ,
        a.END_DATE                          FORMAT=NLDATM.,
        a.END_USER_ID                       ,
        a.VERSION_NUMBER                    ,
        a.LOGICAL_DELETE_IND                ,
        a.SCENARIO_RUN_FREQUENCY_CODE       ,
        a.ROUTING_GROUP_ID                  ,
        a.ROUTING_USER_LONG_ID              ,  
        b.NUMBER_OF_PARAMETERS              
     FROM work.select_scenarios AS a
        INNER JOIN work.number_scenario_parameters AS b
            ON (a.SCENARIO_ID = b.SCENARIO_ID);
     QUIT;
     %fcf_rcset(&sqlrc);
     %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
         %let _fcfmsg_=ERROR: Unable to append number pf parameters to selected scenarios, processing will end;
         %fcf_put_error;
         %goto MACRO_END;
     %end;
   /*-------------------------------------------------------------------*/
   /*  Create scenario info to scenario parameters
   /*-------------------------------------------------------------------*/
    PROC SQL;
    CREATE TABLE WORK.SCENARIO_PARMS AS
    SELECT  a.SCENARIO_ID                   FORMAT=best32. ,
            a.PARM_NAME                     ,
            a.PARM_VALUE                    ,
            a.PARM_TYPE_DESC                ,
            a.PARM_DESC                      
     FROM &seg_kc_libname..FSK_SCENARIO_PARAMETER AS a
        INNER JOIN WORK.SCENARIOS_NUMBER_PARMS_DATA AS b
    ON (a.SCENARIO_ID = b.SCENARIO_ID)
    order by SCENARIO_ID, PARM_NAME  ;
    QUIT;

    %fcf_rcset(&sqlrc);
    %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
        %let _fcfmsg_=ERROR: Unable to append number pf parameters to selected scenarios, processing will end;
        %fcf_put_error;
        %goto MACRO_END;
    %end;

   /*----------------------------------------------------------------------------*/
   /* Joine all scenario data to Header Extract data 
   /*----------------------------------------------------------------------------*/
    PROC SQL;
       create table FCF_RPT.SCENARIOS_AND_RISK_DATA as
       select a.HEADER_ID                     ,
        a.HEADER_NAME                         ,
        a.HEADER_DESCRIPTION                  ,
        b.SCENARIO_ID                                 FORMAT=best32.,
        b.SCENARIO_NAME                       ,
        b.SCENARIO_SHORT_DESCRIPTION          ,
        b.SCENARIO_DESCRIPTION                ,
        b.SCENARIO_CODE_LOCATION_DESC         ,
        b.SCENARIO_CATEGORY_CODE              ,
        b.PRODUCT_TYPE_CODE                   ,
        b.SCENARIO_STATUS_CODE                ,
        b.CURRENT_IND                         ,
        b.DFLT_SUPPRESS_DURATION_COUNT        ,
        b.SCENARIO_DURATION_COUNT             ,
        b.MONEY_LAUNDERING_BAYES_WEIGHT       ,
        b.TERROR_FINANCING_BAYES_WEIGHT       ,
        b.EXECUTION_PROBABILITY_RATE          ,
        b.RISK_FACTOR_IND                     ,
        b.CREATE_DATE as CREATE_DATE_SCENARIO        FORMAT=NLDATM.,
        b.CREATE_USER_ID as CREATE_USER_ID_SCENARIO                ,
        b.END_DATE as END_DATE_SCENARIO              FORMAT=NLDATM.,
        b.END_USER_ID as END_USER_ID_SCENARIO ,
        b.VERSION_NUMBER                      ,
        b.LOGICAL_DELETE_IND as LOGICAL_DELETE_IND_SCENARIO        ,
        b.NUMBER_OF_PARAMETERS                ,
        b.SCENARIO_RUN_FREQUENCY_CODE         ,
        b.ROUTING_GROUP_ID                    ,
        b.ROUTING_USER_LONG_ID                ,
        c.PARM_NAME                           ,
        c.PARM_VALUE                          ,
        c.PARM_TYPE_DESC                      ,
        c.PARM_DESC                     
        from &seg_kc_libname..FSK_HEADER a, WORK.SCENARIOS_NUMBER_PARMS_DATA b,
             WORK.SCENARIO_PARMS c
        where a.HEADER_ID = b.HEADER_ID and 
              b.SCENARIO_ID = c.SCENARIO_ID;
        quit;

       %fcf_rcset(&sqlrc);
       %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
           %let _fcfmsg_=ERROR: Unable to merge header and scenario data.;
           %fcf_put_error;
           %goto MACRO_END;
       %end;
   /*----------------------------------------------------------------------------*/
   /* END SCENARIOS AND RISK FACTORS EXTRACT
   /*----------------------------------------------------------------------------*/
   /*----------------------------------------------------------------------------*/
   /* BEGIN SCENARIOS AUDIT EXTRACT
   /*----------------------------------------------------------------------------*/
   /*----------------------------------------------------------------------------*/
   /* CREATE DUMMY FILE FOR APPENDING
   /*----------------------------------------------------------------------------*/
     data work.changed_records;
        attrib
            SCENARIO_NAME           format=$35.
            PARAMETER_TYPE          format=$20.
            PARAMETER               format=$35.
            ATTRIBUTE               format=$35.
            ORIGINAL_VALUE          format=$1024.
            UPDATED_VALUE           format=$1024.
            USER                    format=$340.
            CHANGE_DATE             format=DATETIME20.0
            UPDATED_VERSION         format=6.0
            SORT_KEY                format=8.
            ;
           SCENARIO_NAME   = ' ';
           PARAMETER_TYPE  = ' ';
           PARAMETER  = ' ';
           ORIGINAL_VALUE   = ' ';
           UPDATED_VALUE  = ' ';
           USER   = ' ';
           CHANGE_DATE    = 0  ;
           UPDATED_VERSION =  0 ;
           SORT_KEY     = -1;
           stop;
           RUN;
   /*-------------------------------------------------------------------
   /* GET UPDATED SCENARIOS
   /*------------------------------------------------------------------- */
     proc sql; 
       connect to &dbflavor as &dbflavor (authdomain="&segkcAuthDomain."
                                     &segKCDBConnOpts);
       create table updated_scenarios as
       select SCENARIO_ID,
            HEADER_ID,
            SCENARIO_NAME,
            SCENARIO_SHORT_DESCRIPTION,
            SCENARIO_DESCRIPTION,
            SCENARIO_CATEGORY_CODE,
            SCENARIO_CODE_LOCATION_DESC,
            PRODUCT_TYPE_CODE,
            SCENARIO_STATUS_CODE,
            CURRENT_IND,
            DFLT_SUPPRESS_DURATION_COUNT,
            SCENARIO_DURATION_COUNT,
            MONEY_LAUNDERING_BAYES_WEIGHT,
            TERROR_FINANCING_BAYES_WEIGHT,
            EXECUTION_PROBABILITY_RATE,
            RISK_FACTOR_IND,
            CREATE_DATE,
            CREATE_USER_ID,
            END_DATE,
            LSTUPDATE_USER_ID as END_USER_ID label='END_USER_ID',
            VERSION_NUMBER,
            LOGICAL_DELETE_IND,
            ROUTING_GROUP_ID,
            ORDER_IN_HEADER,
            ALERT_TYPE_CD,
            ALERT_CATEGORY_CD,
            ALERT_SUBCATEGORY_CD,
            ROUTING_USER_LONG_ID,
            LSTUPDATE_DATE,
            SCENARIO_TYPE_CODE,
            SCENARIO_RUN_FREQUENCY_CODE,
            SAVE_TRIG_TRANS_IND,
            SKIP_IF_NO_TRANS_CURR_DAY_IND,
            MIN(VERSION_NUMBER) as min_version
      from  &seg_kc_libname..fsk_scenario 
      where scenario_id ^=-1 
      group by scenario_name
      having count(VERSION_NUMBER) > 1
      order by scenario_name
      ;
     disconnect from &dbflavor;
     quit;
 
     %fcf_rcset(&sqlrc);
     %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
         %let _fcfmsg_=ERROR: Unable to create ELEMENT_SUMMARY;
         %fcf_put_error;
         %goto MACRO_END;
     %end;

   /*----------------------------------------------------------------------------*/
   /* Verify at least one updated scenario returned.
   /*----------------------------------------------------------------------------*/
     %let dsid = %sysfunc(open(updated_scenarios));
     %if %sysfunc(attrn(&dsid, nlobs)) lt 1 %then %do;
        %let trans_rc = 700;
        %let _fcfmsg_ = Warning: No scenario changes found. Empty Report table will be created.;  
        %fcf_put_error;
        data FCF_RPT.SCENARIO_CHANGE_HISTORY_DATA;
            set work.changed_records;
        run;
        %let rc = %sysfunc(close(&dsid));
        %goto MACRO_END;
     %end;
     %let rc = %sysfunc(close(&dsid));


   /*--------------------------------------------------------------------*/
   /* GET SCENARIO NAMES OF CHANGED SCENARIOS
   /*--------------------------------------------------------------------*/
     PROC SQL;
     CREATE TABLE WORK.DISTINCT_NAMES AS
         SELECT distinct SCENARIO_NAME, min(LSTUPDATE_DATE) format Datetime20. as min_date 
         FROM work.updated_scenarios 
         group by SCENARIO_NAME
         ORDER BY SCENARIO_NAME;
     QUIT;

     %fcf_rcset(&sqlrc);
      %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
          %let _fcfmsg_=ERROR: Unable to create DISTINCT_NAMES table from WORK.UPDATED_SCENARIOS;
          %fcf_put_error;
          %goto MACRO_END;
      %end;
   /*-------------------------------------------------------------------*/
   /* SELECT ORGINALS OF CHANGED SCENARIOS (version = 1 )
   /*-------------------------------------------------------------------*/
     proc sql;
     connect to &dbflavor as &dbflavor (authdomain="&segkcAuthDomain."
                                     &segKCDBConnOpts);
     create table WORK.VERSION_ONE as
         SELECT a.SCENARIO_ID,
                a.HEADER_ID,
                a.SCENARIO_NAME,
                a.SCENARIO_SHORT_DESCRIPTION,
                a.SCENARIO_DESCRIPTION,
                a.SCENARIO_CATEGORY_CODE,
                a.SCENARIO_CODE_LOCATION_DESC,
                a.PRODUCT_TYPE_CODE,
                a.SCENARIO_STATUS_CODE,
                a.CURRENT_IND,
                a.DFLT_SUPPRESS_DURATION_COUNT,
                a.SCENARIO_DURATION_COUNT,
                a.MONEY_LAUNDERING_BAYES_WEIGHT,
                a.TERROR_FINANCING_BAYES_WEIGHT,
                a.EXECUTION_PROBABILITY_RATE,
                a.RISK_FACTOR_IND,
                a.CREATE_DATE,
                a.CREATE_USER_ID,
                a.END_DATE,
                a.LSTUPDATE_USER_ID as END_USER_ID label='END_USER_ID',
                a.VERSION_NUMBER,
                a.LOGICAL_DELETE_IND,
                a.ROUTING_GROUP_ID,
                a.ORDER_IN_HEADER,
                a.ALERT_TYPE_CD,
                a.ALERT_CATEGORY_CD,
                a.ALERT_SUBCATEGORY_CD,
                a.ROUTING_USER_LONG_ID,
                a.LSTUPDATE_DATE,
                a.SCENARIO_TYPE_CODE,
                a.SCENARIO_RUN_FREQUENCY_CODE,
                a.SAVE_TRIG_TRANS_IND,
                a.SKIP_IF_NO_TRANS_CURR_DAY_IND
         from &seg_kc_libname..FSK_SCENARIO as a
         INNER JOIN WORK.DISTINCT_NAMES AS b 
              ON (a.SCENARIO_NAME = b.SCENARIO_NAME and 
                  a.LSTUPDATE_DATE = b.min_date)
      where a.scenario_id ^=-1 
      GROUP BY a.SCENARIO_NAME;
      disconnect from &dbflavor;
      quit;

      %fcf_rcset(&sqlrc);
      %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
           %let _fcfmsg_=ERROR: Unable to create VERSION_ONE table from SEG_KC.FSK_SCENARIO, WORK.DISTINCT_NAMES;
           %fcf_put_error;
           %goto MACRO_END;
      %end;

   /*-------------------------------------------------------------------*/
   /* APPEND ORIGINAL TO CHANGED
   /*-------------------------------------------------------------------*/

     PROC SQL;
     CREATE TABLE WORK.all_updated_scenarios AS
         SELECT * FROM WORK.UPDATED_SCENARIOS
            OUTER UNION CORR
         SELECT * FROM WORK.VERSION_ONE
     order by scenario_name, LSTUPDATE_DATE ;
     QUIT;

     %fcf_rcset(&sqlrc);
     %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
          %let _fcfmsg_=ERROR: Unable append original scearios to changed.;
          %fcf_put_error;
          %goto MACRO_END;
     %end;
   /*----------------------------------------------------------------------*
   /* Version number has changed meaning with introductio of ECM  
   /*  need to derive new temp sequential version number
   /*---------------------------------------------------------------------*/
      data WORK.all_updated_scenarios (drop=org_version)
           WORK.org_version_info (keep=scenario_name version_number org_version);
      set WORK.all_updated_scenarios (rename=(version_number=org_version));
      by scenario_name;
      retain version_number;
      if first.scenario_name then do;
         version_number = 0;
      end;
      version_number+1;
      run;

   /*-------------------------------------------------------------------*/
   /* SORT 
   /*-------------------------------------------------------------------*/
    PROC SORT DATA=WORK.ALL_UPDATED_SCENARIOS
          OUT=WORK.ALL_UPDATED_SCENARIOS_SORTED;
          BY SCENARIO_NAME VERSION_NUMBER;
    RUN;

   /*-------------------------------------------------------------------*/
   /*   CREATE MACRO VARIABLE LISTS AND COUNTS
   /*-------------------------------------------------------------------*/

    %global scenario_list scenario_id_list version_number_list header_id_list scenario_count;

    PROC SQL noprint;
    SELECT a.SCENARIO_NAME,
            max(a.scenario_id) ,
            max(a.version_number) ,
            max(a.header_id)
            INTO :scenario_list separated by ',' ,
            :scenario_id_list separated by ',' ,
            :version_number_list separated by ','   ,
            :header_id_list separated by ','
        FROM WORK.ALL_UPDATED_SCENARIOS_SORTED AS a
        GROUP BY a.SCENARIO_NAME
        ORDER BY a.SCENARIO_NAME;
    QUIT;

    %fcf_rcset(&sqlrc);
    %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
         %let _fcfmsg_=ERROR: Unable create global macro variables from ALL_UPDATED_SCENARIOS_SORTED.;
         %fcf_put_error;
         %goto MACRO_END;
    %end;

    PROC SQL noprint;
    SELECT count( distinct a.SCENARIO_NAME)
        INTO :scenario_count
        FROM WORK.ALL_UPDATED_SCENARIOS_SORTED AS a;
    QUIT;

    %fcf_rcset(&sqlrc);
    %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
         %let _fcfmsg_=ERROR: Unable create distinct scenario_count from ALL_UPDATED_SCENARIOS_SORTED.;
         %fcf_put_error;
         %goto MACRO_END;
    %end;

   /*-------------------------------------------------------------------*/
   /* Translaste Codes to display values via formats 
   /*-------------------------------------------------------------------*/

    Data WORK.ALL_UPDATED_SCENARIOS_LABELED;
    set WORK.ALL_UPDATED_SCENARIOS_SORTED ;
    KEEP
        SCENARIO_SHORT_DESCRIPTION
        SCENARIO_DESCRIPTION
        SCENARIO_CODE_LOCATION_DESC
        SCENARIO_CATEGORY_CODE
        PRODUCT_TYPE_CODE
        SCENARIO_STATUS_CODE
        SCENARIO_RUN_FREQUENCY_CODE
        CURRENT_IND
        ROUTING_USER_LONG_ID
        DFLT_SUPPRESS_DURATION_COUNT
        SCENARIO_DURATION_COUNT
        MONEY_LAUNDERING_BAYES_WEIGHT
        TERROR_FINANCING_BAYES_WEIGHT
        EXECUTION_PROBABILITY_RATE
        RISK_FACTOR_IND
        LOGICAL_DELETE_IND
        ROUTING_GROUP_ID
        END_DATE
        END_USER_ID
        SCENARIO_NAME
        VERSION_NUMBER
        CREATE_DATE
        CREATE_USER_ID 
        LSTUPDATE_DATE;

    RUN;

   /*----------------------------------------------------------------------------*/
   /* Build dynamic in clause for display data retrieval. 
   /*----------------------------------------------------------------------------*/
    PROC SQL noprint;
         select "'" || STRIP(SCENARIO_CATEGORY_CODE) || "'" into :scnCatCDInClauseCond separated by ", " from
           (select distinct SCENARIO_CATEGORY_CODE from WORK.ALL_UPDATED_SCENARIOS_LABELED);
    quit;

   /*----------------------------------------------------------------------------*/
   /* Get long display values for SCENARIO_CATEGORY_CODE
   /*----------------------------------------------------------------------------*/
    proc sql;
         create table SCENARIO_CATEGORY_CODE_DISPLAY as
            select distinct LOV_TYPE_CODE as value_cd, LOV_TYPE_DESC as value_desc from DB_KC.FSK_LOV
                where LOV_TYPE_NAME = 'SCENARIO_CATEGORY' and
                      LOV_LANGUAGE_DESC = "&fcf_config_locale_opt" and
                      VALUE_CD IN (&scnCatCDInClauseCond);
    quit;
    %fcf_rcset(&sqlrc);
    %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
        %let _fcfmsg_=ERROR: Unable to create table Scenario Category Code Display, processing will end;
        %fcf_put_error;
        %goto MACRO_END;
    %end;
   /*----------------------------------------------------------------------------*/
   /* Verify at least one SCENARIO_CATEGORY_CODE display code returned.
   /*----------------------------------------------------------------------------*/
    %let dsid = %sysfunc(open(SCENARIO_CATEGORY_CODE_DISPLAY));
    %if %sysfunc(attrn(&dsid, nlobs)) > 0 %then %do;
        %let rc = %sysfunc(close(&dsid));
   /*----------------------------------------------------------------------------*/
   /* Update SCENARIO_CATEGORY_CODE  
   /*----------------------------------------------------------------------------*/
        %fcf_update_display_data(tabName=ALL_UPDATED_SCENARIOS_LABELED,
            LUTAB=SCENARIO_CATEGORY_CODE_DISPLAY,
            existCol=SCENARIO_CATEGORY_CODE,
            LUKey=VALUE_CD,
            LUVal=VALUE_DESC
            );
    %end;
    %else %do;
       %let trans_rc = 909;
       %let _fcfmsg_ = ERROR: No Scenario Category Code Display Codes returned.;  
       %fcf_put_error;
       %goto MACRO_END;
    %end; 

   /*----------------------------------------------------------------------------*/
   /* Build dynamic in clause for display data retrieval. 
   /*----------------------------------------------------------------------------*/
    PROC SQL noprint;
         select "'" || STRIP(PRODUCT_TYPE_CODE) || "'" into :prodTypeCDInClauseCond separated by ", " from
           (select distinct PRODUCT_TYPE_CODE from WORK.ALL_UPDATED_SCENARIOS_LABELED);
    quit;

   /*----------------------------------------------------------------------------*/
   /* Get long display values for PRODUCT_TYPE_CODE
   /*----------------------------------------------------------------------------*/
    proc sql;
         create table PRODUCT_TYPE_CODE_DISPLAY as
            select distinct LOV_TYPE_CODE as value_cd, LOV_TYPE_DESC as value_desc from DB_KC.FSK_LOV
                where LOV_TYPE_NAME = 'PRODUCT_TYPE' and
                      LOV_LANGUAGE_DESC = "&fcf_config_locale_opt" and
                      VALUE_CD IN (&prodTypeCDInClauseCond);
    quit;
    %fcf_rcset(&sqlrc);
    %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
        %let _fcfmsg_=ERROR: Unable to create table Product Type Code Display, processing will end;
        %fcf_put_error;
        %goto MACRO_END;
    %end;
   /*----------------------------------------------------------------------------*/
   /* Verify at least one PRODUCT_TYPE_CODE display code returned.
   /*----------------------------------------------------------------------------*/
    %let dsid = %sysfunc(open(PRODUCT_TYPE_CODE_DISPLAY));
    %if %sysfunc(attrn(&dsid, nlobs)) > 0 %then %do;
        %let rc = %sysfunc(close(&dsid));
   /*----------------------------------------------------------------------------*/
   /* Update PRODUCT_TYPE_CODE  
   /*----------------------------------------------------------------------------*/
        %fcf_update_display_data(tabName=ALL_UPDATED_SCENARIOS_LABELED,
            LUTAB=PRODUCT_TYPE_CODE_DISPLAY,
            existCol=PRODUCT_TYPE_CODE,
            LUKey=VALUE_CD,
            LUVal=VALUE_DESC
            );
    %end;
    %else %do;
       %let trans_rc = 909;
       %let _fcfmsg_ = ERROR: No Product Type Display Codes returned.;  
       %fcf_put_error;
       %goto MACRO_END;
    %end; 

   /*----------------------------------------------------------------------------*/
   /* Build dynamic in clause for display data retrieval. 
   /*----------------------------------------------------------------------------*/
    PROC SQL noprint;
         select "'" || STRIP(SCENARIO_STATUS_CODE) || "'" into :scnStatCDInClauseCond separated by ", " from
           (select distinct SCENARIO_STATUS_CODE from WORK.ALL_UPDATED_SCENARIOS_LABELED);
    quit;

   /*----------------------------------------------------------------------------*/
   /* Get long display values for SCENARIO_STATUS_CODE
   /*----------------------------------------------------------------------------*/
    proc sql;
         create table SCENARIO_STATUS_CODE_DISPLAY as
            select distinct LOV_TYPE_CODE as value_cd, LOV_TYPE_DESC as value_desc from DB_KC.FSK_LOV
                where LOV_TYPE_NAME = 'SCENARIO_STATUS' and
                      LOV_LANGUAGE_DESC = "&fcf_config_locale_opt" and
                      VALUE_CD IN (&scnStatCDInClauseCond);
    quit;
    %fcf_rcset(&sqlrc);
    %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
        %let _fcfmsg_=ERROR: Unable to create table Scenario Status Code Display, processing will end;
        %fcf_put_error;
        %goto MACRO_END;
    %end;
   /*----------------------------------------------------------------------------*/
   /* Verify at least one SCENARIO_STATUS_CODE display code returned.
   /*----------------------------------------------------------------------------*/
    %let dsid = %sysfunc(open(SCENARIO_STATUS_CODE_DISPLAY));
    %if %sysfunc(attrn(&dsid, nlobs)) > 0 %then %do;
        %let rc = %sysfunc(close(&dsid));
   /*----------------------------------------------------------------------------*/
   /* Update SCENARIO_STATUS_CODE  
   /*----------------------------------------------------------------------------*/
        %fcf_update_display_data(tabName=ALL_UPDATED_SCENARIOS_LABELED,
            LUTAB=SCENARIO_STATUS_CODE_DISPLAY,
            existCol=SCENARIO_STATUS_CODE,
            LUKey=VALUE_CD,
            LUVal=VALUE_DESC
            );
    %end;
    %else %do;
       %let trans_rc = 909;
       %let _fcfmsg_ = ERROR: No Scenario Status Code Display Codes returned.;  
       %fcf_put_error;
       %goto MACRO_END;
    %end; 


   /*----------------------------------------------------------------------------*/
   /* Build dynamic in clause for display data retrieval. 
   /*----------------------------------------------------------------------------*/
    PROC SQL noprint;
         select "'" || STRIP(CURRENT_IND) || "'" into :curIndCDInClauseCond separated by ", " from
           (select distinct CURRENT_IND from WORK.ALL_UPDATED_SCENARIOS_LABELED);
    quit;

   /*----------------------------------------------------------------------------*/
   /* Get long display values for CURRENT_IND
   /*----------------------------------------------------------------------------*/
    proc sql;
         create table CURRENT_IND_DISPLAY as
            select distinct LOV_TYPE_CODE as value_cd, LOV_TYPE_DESC as value_desc from DB_KC.FSK_LOV
                where LOV_TYPE_NAME = 'RT_YES_NO' and
                      LOV_LANGUAGE_DESC = "&fcf_config_locale_opt" and
                      VALUE_CD IN (&curIndCDInClauseCond);
    quit;
    %fcf_rcset(&sqlrc);
    %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
        %let _fcfmsg_=ERROR: Unable to create table Current Ind Display, processing will end;
        %fcf_put_error;
        %goto MACRO_END;
    %end;
   /*----------------------------------------------------------------------------*/
   /* Verify at least one CURRENT_IND display code returned.
   /*----------------------------------------------------------------------------*/
    %let dsid = %sysfunc(open(CURRENT_IND_DISPLAY));
    %if %sysfunc(attrn(&dsid, nlobs)) > 0 %then %do;
        %let rc = %sysfunc(close(&dsid));
   /*----------------------------------------------------------------------------*/
   /* Update CURRENT_IND  
   /*----------------------------------------------------------------------------*/
        %fcf_update_display_data(tabName=ALL_UPDATED_SCENARIOS_LABELED,
            LUTAB=CURRENT_IND_DISPLAY,
            existCol=CURRENT_IND,
            LUKey=VALUE_CD,
            LUVal=VALUE_DESC
            );
    %end;
    %else %do;
       %let trans_rc = 909;
       %let _fcfmsg_ = ERROR: No Current Ind Display Codes returned.;  
       %fcf_put_error;
       %goto MACRO_END;
    %end; 


   /*----------------------------------------------------------------------------*/
   /* Build dynamic in clause for display data retrieval. 
   /*----------------------------------------------------------------------------*/
    PROC SQL noprint;
         select "'" || STRIP(RISK_FACTOR_IND) || "'" into :rskFactIndCDInClauseCond separated by ", " from
           (select distinct RISK_FACTOR_IND from WORK.ALL_UPDATED_SCENARIOS_LABELED);
    quit;

   /*----------------------------------------------------------------------------*/
   /* Get long display values for RISK_FACTOR_IND
   /*----------------------------------------------------------------------------*/
    proc sql;
         create table RISK_FACTOR_IND_DISPLAY as
            select distinct LOV_TYPE_CODE as value_cd, LOV_TYPE_DESC as value_desc from DB_KC.FSK_LOV
                where LOV_TYPE_NAME = 'RT_YES_NO' and
                      LOV_LANGUAGE_DESC = "&fcf_config_locale_opt" and
                      VALUE_CD IN (&rskFactIndCDInClauseCond);
    quit;
    %fcf_rcset(&sqlrc);
    %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
        %let _fcfmsg_=ERROR: Unable to create table Risk Factor Ind Display, processing will end;
        %fcf_put_error;
        %goto MACRO_END;
    %end;
   /*----------------------------------------------------------------------------*/
   /* Verify at least one RISK_FACTOR_IND display code returned.
   /*----------------------------------------------------------------------------*/
    %let dsid = %sysfunc(open(RISK_FACTOR_IND_DISPLAY));
    %if %sysfunc(attrn(&dsid, nlobs)) > 0 %then %do;
        %let rc = %sysfunc(close(&dsid));
   /*----------------------------------------------------------------------------*/
   /* Update RISK_FACTOR_IND  
   /*----------------------------------------------------------------------------*/
        %fcf_update_display_data(tabName=ALL_UPDATED_SCENARIOS_LABELED,
            LUTAB=RISK_FACTOR_IND_DISPLAY,
            existCol=RISK_FACTOR_IND,
            LUKey=VALUE_CD,
            LUVal=VALUE_DESC
            );
    %end;
    %else %do;
       %let trans_rc = 909;
       %let _fcfmsg_ = ERROR: No Risk Factor Ind Display Codes returned.;  
       %fcf_put_error;
       %goto MACRO_END;
    %end; 


   /*----------------------------------------------------------------------------*/
   /* Build dynamic in clause for display data retrieval. 
   /*----------------------------------------------------------------------------*/
    PROC SQL noprint;
         select "'" || STRIP(LOGICAL_DELETE_IND) || "'" into :logDelIndCDInClauseCond separated by ", " from
           (select distinct LOGICAL_DELETE_IND from WORK.ALL_UPDATED_SCENARIOS_LABELED);
    quit;

   /*----------------------------------------------------------------------------*/
   /* Get long display values for LOGICAL_DELETE_IND
   /*----------------------------------------------------------------------------*/
    proc sql;
         create table LOGICAL_DELETE_IND_DISPLAY as
            select distinct LOV_TYPE_CODE as value_cd, LOV_TYPE_DESC as value_desc from DB_KC.FSK_LOV
                where LOV_TYPE_NAME = 'RT_YES_NO' and
                      LOV_LANGUAGE_DESC = "&fcf_config_locale_opt" and
                      VALUE_CD IN (&logDelIndCDInClauseCond);
    quit;
    %fcf_rcset(&sqlrc);
    %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
        %let _fcfmsg_=ERROR: Unable to create table Logical Delete Ind Display, processing will end;
        %fcf_put_error;
        %goto MACRO_END;
    %end;
   /*----------------------------------------------------------------------------*/
   /* Verify at least one LOGICAL_DELETE_IND display code returned.
   /*----------------------------------------------------------------------------*/
    %let dsid = %sysfunc(open(LOGICAL_DELETE_IND_DISPLAY));
    %if %sysfunc(attrn(&dsid, nlobs)) > 0 %then %do;
        %let rc = %sysfunc(close(&dsid));
   /*----------------------------------------------------------------------------*/
   /* Update LOGICAL_DELETE_IND  
   /*----------------------------------------------------------------------------*/
        %fcf_update_display_data(tabName=ALL_UPDATED_SCENARIOS_LABELED,
            LUTAB=LOGICAL_DELETE_IND_DISPLAY,
            existCol=LOGICAL_DELETE_IND,
            LUKey=VALUE_CD,
            LUVal=VALUE_DESC
            );
    %end;
    %else %do;
       %let trans_rc = 909;
       %let _fcfmsg_ = ERROR: No Logical Delete Ind Display Codes returned.;  
       %fcf_put_error;
       %goto MACRO_END;
    %end; 

   /*-------------------------------------------------------------------*/
   /* SORT 
   /*-------------------------------------------------------------------*/

    PROC SORT DATA=WORK.ALL_UPDATED_SCENARIOS_LABELED OUT=WORK.SORTED_SPECS ;
        BY SCENARIO_NAME VERSION_NUMBER LSTUPDATE_DATE END_USER_ID;
    RUN;

   /*-------------------------------------------------------------------
   /*   TRANSPOSE SCENARIOS SPECIFICATIONS
   /*------------------------------------------------------------------- */

    PROC TRANSPOSE DATA=WORK.SORTED_SPECS
       OUT=WORK.TRANSPOSED_SPECS
       PREFIX=Column
       NAME=Source
       LABEL=Label
     ;
       BY SCENARIO_NAME VERSION_NUMBER LSTUPDATE_DATE END_USER_ID;
       VAR
             SCENARIO_SHORT_DESCRIPTION
             SCENARIO_DESCRIPTION
             SCENARIO_CATEGORY_CODE
             PRODUCT_TYPE_CODE
             SCENARIO_STATUS_CODE
             SCENARIO_RUN_FREQUENCY_CODE
             ROUTING_USER_LONG_ID
             DFLT_SUPPRESS_DURATION_COUNT
             SCENARIO_DURATION_COUNT
             MONEY_LAUNDERING_BAYES_WEIGHT
             TERROR_FINANCING_BAYES_WEIGHT
             EXECUTION_PROBABILITY_RATE
             RISK_FACTOR_IND
             ROUTING_GROUP_ID
             CURRENT_IND
             LOGICAL_DELETE_IND ;
     RUN;

   /*--------------------------------------------------------------------
   /* LOOP THROUGH ALL CHANGED FSK_SCENARIO_PARAMETER TABLES
   /* LOOKING FOR CHANGED PARAMETERS
   /*---------------------------------------------------------------- */
    %put scenario_count: &scenario_count;
      %do i = 1 %to &scenario_count ;
        %let sn = %scan(%quote(&scenario_list),&i);
        %let scenid = %scan(%quote(&scenario_id_list),&i);
           %do oldv = 1 %to %scan(%quote(&version_number_list),&i) - 1;
             %let newv = %eval(&oldv +1);
                   /*-------------------------------------------------------------
                   /*   SELECT OLDER OF CHANGED FSK_SCENARIO
                   /*--------------------------------------------------------- */
                   PROC SQL;
                   CREATE TABLE WORK.specs_&scenid._V&OLDV AS
                   SELECT a.SCENARIO_NAME                         ,
                      a.VERSION_NUMBER as ORIGINAL_VERSION        ,
                      a.LSTUPDATE_DATE as ORIGINAL_CREATE_DATE       ,
                      strip(a.END_USER_ID) as ORIGINAL_CREATE_USER    ,
                      a.Source AS COLUMN                          ,
                      strip(a.Column1) as ORIGINAL_VALUE
                    FROM WORK.TRANSPOSED_SPECS AS a
                    WHERE ( a.SCENARIO_NAME = "&SN" AND a.VERSION_NUMBER =  &OLDV )
                   ORDER BY a.SCENARIO_NAME, a.SOURCE;
                   QUIT;
                   /*-------------------------------------------------------*/
                   /*   SELECT NEWER OF CHANGED FSK_SCENARIO
                   /*-------------------------------------------------------*/
                   PROC SQL;
                   CREATE TABLE WORK.specs_&scenid._V&NEWV AS
                   SELECT a.SCENARIO_NAME                         ,
                      a.VERSION_NUMBER as UPDATED_VERSION         ,
                      a.LSTUPDATE_DATE as UPDATED_CREATE_DATE        ,
                      strip(a.END_USER_ID) as UPDATED_CREATE_USER     ,
                      a.Source AS COLUMN                          ,
                      strip(a.Column1) as UPDATED_VALUE
                    FROM WORK.TRANSPOSED_SPECS AS a
                    WHERE ( a.SCENARIO_NAME = "&SN" AND a.VERSION_NUMBER =  &NEWV )
                   ORDER BY a.SCENARIO_NAME, a.SOURCE;
                   QUIT;
                   /*--------------------------------------------------------------------*/
                   /*   CREATE MACRO VARIABLES FOR USER_ID AND DATE - NEEDED WHEN A
                   /*   PARAMETER IS DELETED - NEW RECORD DOES NOT HAVE USER_ID AND DATE
                   /*--------------------------------------------------------------------*/
                   PROC SQL NOPRINT;
                   SELECT MAX(a.LSTUPDATE_DATE)          FORMAT=DATETIME20.0,
                           MAX(a.END_USER_ID)
                           INTO :UPDATE_DATE,
                           :UPDATE_USER
                    FROM WORK.ALL_UPDATED_SCENARIOS_SORTED  AS a
                       WHERE SCENARIO_NAME = "&SN" AND VERSION_NUMBER = &NEWV;
                   QUIT;

                   /*--------------------------------------------------------------------*/
                   /*   MERGED OLD AND NEWER CHANGED PARMS
                   /*--------------------------------------------------------------------*/

                   DATA WORK.MERGED_SPECS;
                   MERGE  WORK.specs_&scenid._V&OLDV  WORK.specs_&scenid._V&NEWV;
                   BY SCENARIO_NAME  COLUMN;

                   /*--------------------------------------------------------------------*/
                   /*   FIND CHANGED PARMS
                   /*--------------------------------------------------------------------*/
                   DATA WORK.CHANGED_SPECS;
                   SET  WORK.MERGED_SPECS;
                       DROP COLUMN
                           ORIGINAL_VERSION
                           ORIGINAL_CREATE_DATE
                           ORIGINAL_CREATE_USER
                           updated_create_user
                           updated_create_DATE  ;
                   iF strip(original_value) ne strip(updated_value) then do;
                       PARAMETER = column;
                       ATTRIBUTE = ' ';
                       PARAMETER_TYPE = 'Property';
                       sort_key = 1;
                       if updated_version = .          then updated_version = &newv;
                       if updated_create_user = ' '    then updated_create_user = "&update_user";
                       if updated_create_DATE = .      then   updated_create_DATE = input("&UPDATE_DATE",DATETIME20.0);
                       USER = updated_create_user;
                       CHANGE_DATE = updated_create_DATE;

                   end;
                   run;
                   /*--------------------------------------------------------------------*/
                   /*   APPEND TO SAVE THESE RECORD
                   /*--------------------------------------------------------------------*/
                   PROC APPEND BASE=WORK.CHANGED_RECORDS  DATA=WORK.CHANGED_SPECS FORCE
                        FORCE;
                   RUN;
       %end;
%end;
   /*--------------------------------------------------------------------*/
   /*   SELECT PARAMETERS OF CHANGED SCENARIOS
   /*--------------------------------------------------------------------*/
       PROC SQL;
       CREATE TABLE WORK.SELECT_PARMS AS
       SELECT a.SCENARIO_NAME     ,
          a.VERSION_NUMBER       ,
          a.LSTUPDATE_DATE       ,
          b.PARM_NAME            ,
          b.SCENARIO_ID          ,
          b.PARM_VALUE           ,
          b.PARM_TYPE_DESC       ,
          b.PARM_DESC            ,
          a.END_USER_ID 
       FROM &seg_kc_libname..FSK_SCENARIO_PARAMETER AS b  
           INNER JOIN WORK.ALL_UPDATED_SCENARIOS_SORTED AS a ON (b.SCENARIO_ID = a.SCENARIO_ID)
       ORDER BY a.SCENARIO_NAME, a.VERSION_NUMBER, a.LSTUPDATE_DATE, b.PARM_NAME, b.SCENARIO_ID, b.PARM_VALUE;
       QUIT;

       %fcf_rcset(&sqlrc);
       %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
          %let _fcfmsg_=ERROR: Unable create WORK.SELECT_PARMS.;
          %fcf_put_error;
          %goto MACRO_END;
       %end;

   /*--------------------------------------------------------------------*/
   /*    Sort data set WORK.SELECT_PARMS
   /*--------------------------------------------------------------------*/
      PROC SORT
      DATA=WORK.SELECT_PARMS
       (KEEP=PARM_VALUE
           PARM_TYPE_DESC
           PARM_DESC
           SCENARIO_NAME
           VERSION_NUMBER
           SCENARIO_ID
           LSTUPDATE_DATE
           END_USER_ID
           PARM_NAME)
      OUT=WORK.SELECT_PARMS_SORTED
      ;
         BY SCENARIO_NAME VERSION_NUMBER SCENARIO_ID LSTUPDATE_DATE END_USER_ID PARM_NAME;
      RUN;
   /*----------------------------------------------------------------------*/
   /*   TRANSPOSE SELECTED PARM ENTRIES BY PARM_NAME
   /*----------------------------------------------------------------------*/
      PROC TRANSPOSE DATA=WORK.SELECT_PARMS_SORTED
          OUT=WORK.TRANSPOSED_PARMS(LABEL="Transposed WORK.SELECT_PARMS")
          PREFIX=Column
          NAME=Source
          LABEL=Label
      ;
      BY SCENARIO_NAME VERSION_NUMBER SCENARIO_ID LSTUPDATE_DATE END_USER_ID PARM_NAME;
      VAR PARM_VALUE PARM_TYPE_DESC PARM_DESC;
   /*----------------------------------------------------------------------*/
   /*   LOOP THROUGH ALL CHANGED FSK_SCENARIO_PARAMETER TABLES
   /*   LOOKING FOR CHANGED PARAMETERS
   /*----------------------------------------------------------------------*/
     %do i = 1 %to &scenario_count ;
       %let sn = %scan(%quote(&scenario_list),&i);
       %let scenid = %scan(%quote(&scenario_id_list),&i);
           %do oldv = 1 %to %scan(%quote(&version_number_list),&i) - 1;
           %let newv = %eval(&oldv +1);
                   /*---------------------------------------------------------------*/
                   /*   SELECT OLDER OF CHANGED FSK_SCENARIO_PARAMETER
                   /*---------------------------------------------------------------*/
                   PROC SQL;
                   CREATE TABLE WORK.parms_&scenid._V&OLDV AS
                   SELECT a.SCENARIO_NAME                      ,
                      a.VERSION_NUMBER as ORIGINAL_VERSION     ,
                      a.LSTUPDATE_DATE as ORIGINAL_CREATE_DATE    ,
                      strip(a.END_USER_ID) as ORIGINAL_CREATE_USER ,
                      a.PARM_NAME as SCENARIO_PARAMETER        ,
                      a.Source AS COLUMN                       ,
                      strip(a.Column1) as ORIGINAL_VALUE
                    FROM WORK.TRANSPOSED_PARMS AS a
                    WHERE ( a.SCENARIO_NAME = "&SN" AND a.VERSION_NUMBER =  &OLDV)
                   ORDER BY a.SCENARIO_NAME, a.PARM_NAME, a.SOURCE;
                   QUIT;
                   /*-------------------------------------------------------------------*/
                   /*   SELECT NEWER OF CHANGED FSK_SCENARIO_PARAMETER
                   /*-------------------------------------------------------------------*/
                   PROC SQL;
                   CREATE TABLE WORK.parms_&scenid._V&NEWV AS
                   SELECT a.SCENARIO_NAME                      ,
                      a.VERSION_NUMBER as UPDATED_VERSION      ,
                      a.LSTUPDATE_DATE as UPDATED_CREATE_DATE     ,
                      strip(a.END_USER_ID) as UPDATED_CREATE_USER  ,
                      a.PARM_NAME as SCENARIO_PARAMETER        ,
                      a.Source AS COLUMN                       ,
                      strip(a.Column1) as UPDATED_VALUE
                    FROM WORK.TRANSPOSED_PARMS AS a
                    WHERE ( a.SCENARIO_NAME = "&SN" AND a.VERSION_NUMBER =  &NEWV)
                   ORDER BY a.SCENARIO_NAME, a.PARM_NAME, a.SOURCE;
                   QUIT;
                   /*------------------------------------------------------------------*/
                   /*   CREATE MACRO VARIABLES FOR USER_ID AND DATE - NEEDED WHEN A
                   /*   PARAMETER IS DELETED - NEW RECORD DOES NOT HAVE USER_ID AND DATE
                   /*------------------------------------------------------------------*/
                   PROC SQL NOPRINT;
                   SELECT MAX(a.LSTUPDATE_DATE) ,
                           MAX(a.END_USER_ID)
                           INTO :UPDATE_DATE,
                           :UPDATE_USER
                    FROM WORK.ALL_UPDATED_SCENARIOS_SORTED  AS a
                       WHERE SCENARIO_NAME = "&SN" AND VERSION_NUMBER = &NEWV;
                   QUIT;

                   /*-------------------------------------------------------------------*/
                   /*   MERGED OLD AND NEWER CHANGED PARMS
                   /*-------------------------------------------------------------------*/
                   DATA WORK.MERGED_PARMS;
                   MERGE  WORK.parms_&scenid._V&OLDV  WORK.parms_&scenid._V&NEWV;
                   BY SCENARIO_NAME SCENARIO_PARAMETER COLUMN;


                   /*--------------------------------------------------------------------*/
                   /*   FIND CHANGED PARMS
                   /*--------------------------------------------------------------------*/
                   DATA WORK.CHANGED_PARMS;
                   SET  WORK.MERGED_PARMS;
                       DROP scenario_parameter
                           column
                           original_version
                           original_create_date
                           original_create_user
                           updated_create_user
                           updated_create_date  ;
                        FORMAT parameter_type  $20.
                               attribute $35.;   
                   if strip(original_value) ne strip(updated_value) then do;
                       parameter =  upcase(scenario_parameter);
                       attribute = column;
                       parameter_type = 'Parameter';
                       sort_key = 2;
                       if updated_version = .          then updated_version = &newv;
                       if updated_create_user = ' '    then updated_create_user = "&update_user";
                       if updated_create_DATE = .      then   updated_create_DATE = input("&UPDATE_DATE",DATETIME20.0);
                       user = updated_create_user;
                       change_date = updated_create_date;
                   end;
                   run;
                   /*------------------------------------------------------------*/
                   /*   APPEND TO SAVE THESE RECORD
                   /*------------------------------------------------------------*/
                   PROC APPEND BASE=WORK.CHANGED_RECORDS  DATA=WORK.CHANGED_PARMS FORCE
                        FORCE;
                   RUN;
       %end;
     %end;
   /*---------------------------------------------------------------------*/
   /*   CHECK FOR NUMBER OF RECORDS TO PRINT
   /*---------------------------------------------------------------------*/

     PROC SQL;
        CREATE TABLE WORK.CHANGED_RECORDS_SORTED AS
        SELECT a.SCENARIO_NAME ,
              a.PARAMETER_TYPE ,
              a.PARAMETER ,
              a.ATTRIBUTE ,
              a.ORIGINAL_VALUE ,
              a.UPDATED_VALUE ,
              a.USER ,
              a.CHANGE_DATE ,
              a.UPDATED_VERSION ,
              a.SORT_KEY 
     FROM WORK.CHANGED_RECORDS AS a
     WHERE a.SORT_KEY > 0
     ORDER BY a.SCENARIO_NAME, a.CHANGE_DATE, a.UPDATED_VERSION, a.SORT_KEY, a.PARAMETER;
     QUIT;

    %fcf_rcset(&sqlrc);
    %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
       %let _fcfmsg_=ERROR: Unable create WORK.CHANGED_RECORDS_SORTED.;
       %fcf_put_error;
       %goto MACRO_END;
    %end;

   /*---------------------------------------------------------------------*/
   /*   Setup for printing report.
   /*---------------------------------------------------------------------*/
        DATA WORK.CHANGED_RECORDS_SORTED_MOD;
        SET WORK.CHANGED_RECORDS_SORTED;
        SELECT (ATTRIBUTE);
            WHEN ('PARM_TYPE_DESC')     ATTRIBUTE = "&format";
            WHEN ('PARM_VALUE')         ATTRIBUTE = "&value";
            WHEN ('PARM_DESC')          ATTRIBUTE = "&desc";
            WHEN (' ')
                DO;
                    IF PARAMETER = 'SCENARIO_DESCRIPTION' THEN ATTRIBUTE = "&desc";
                    ELSE  ATTRIBUTE = "&value";
                END;
           OTHERWISE                   ATTRIBUTE = "&value";
        END;
        IF ORIGINAL_VALUE EQ ' ' and UPDATED_VALUE NE ' ' then Action = "&add";
        IF ORIGINAL_VALUE NE ' ' and UPDATED_VALUE EQ ' ' then Action = "&delete";
        IF ORIGINAL_VALUE NE ' ' and UPDATED_VALUE NE ' ' then Action = "&change";
        RUN;

   /*---------------------------------------------------------------------*/
   /*   Select appropriate Scenario Description(s).
   /*---------------------------------------------------------------------*/

        PROC SQL;
        CREATE TABLE WORK.SCENARIO_DESC AS
        SELECT  SCENARIO_NAME,
                SCENARIO_SHORT_DESCRIPTION
        FROM WORK.ALL_UPDATED_SCENARIOS_SORTED
        GROUP BY SCENARIO_NAME
        HAVING SCENARIO_ID = MAX(SCENARIO_ID)
        ORDER BY SCENARIO_NAME;
        QUIT;

        %fcf_rcset(&sqlrc);
        %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
           %let _fcfmsg_=ERROR: Unable create WORK.SCENARIO_DESC.;
           %fcf_put_error;
           %goto MACRO_END;
        %end;

   /*---------------------------------------------------------------------*/
   /*   Join Scenario Description(s).
   /*---------------------------------------------------------------------*/

        PROC SQL;
        CREATE TABLE WORK.PRINT_DATASET AS
            SELECT A.*,
            B.SCENARIO_SHORT_DESCRIPTION
        FROM CHANGED_RECORDS_SORTED_MOD AS A
        LEFT JOIN WORK.SCENARIO_DESC AS B
        ON (a.SCENARIO_NAME = B.SCENARIO_NAME)
        ORDER BY SCENARIO_NAME, SCENARIO_SHORT_DESCRIPTION, UPDATED_VERSION;
        QUIT;

        %fcf_rcset(&sqlrc);
        %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
           %let _fcfmsg_=ERROR: Unable create WORK.PRINT_DATASET.;
           %fcf_put_error;
           %goto MACRO_END;
        %end;
   /*---------------------------------------------------------------------*/
   /*   Create report table, returning proper ECM version number.
   /*---------------------------------------------------------------------*/

        PROC SQL;
           create table FCF_RPT.SCENARIO_CHANGE_HISTORY_DATA as
           select a.SCENARIO_NAME,
                  a.PARAMETER_TYPE,
                  a.PARAMETER,
                  a.ATTRIBUTE,
                  a.ORIGINAL_VALUE,
                  a.UPDATED_VALUE,
                  a.USER,
                  a.CHANGE_DATE,
                  b.ORG_VERSION as UPDATED_VERSION,
                  a.SORT_KEY,
                  a.Action,
                  a.SCENARIO_SHORT_DESCRIPTION
      from WORK.PRINT_DATASET as a,  WORK.org_version_info as b
           where a.SCENARIO_NAME = b.SCENARIO_NAME AND
                 a.UPDATED_VERSION = b.VERSION_NUMBER
           order by SCENARIO_SHORT_DESCRIPTION, UPDATED_VERSION, CHANGE_DATE, PARAMETER;
      quit;

      %fcf_rcset(&sqlrc);
      %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
          %let _fcfmsg_=ERROR: Unable create FCF_RPT.SCENARIO_AUDIT.;
           %fcf_put_error;
           %goto MACRO_END;
      %end;


   /*----------------------------------------------------------------------------*/
   /* END SCENARIOS AUDIT EXTRACT
   /*----------------------------------------------------------------------------*/

%MACRO_END:

%if &trans_rc in (3 5 900 909) %then
     %fcf_execute_macro(fcf_error);
%else %do;
     %fcf_execute_macro(fcf_success);
%end;

%mend fcf_scenario_admin_extract;

