/**
 * Associated parties list
 */
(function() {
    'use strict';
    CustomerListDirectiveController.$inject = ["$scope", "$state", "resources", "kendoGridRendererService", "entityService", "customerService", "amlConstants", "_", "amlLov", "scenarioService", "segmentNameFilter"];
    angular.module('aml.customer.details').controller(
        'CustomerListDirectiveController', CustomerListDirectiveController);

    /* jshint maxparams: 13*/
    function CustomerListDirectiveController($scope, $state, resources, kendoGridRendererService,
                                             entityService, customerService, amlConstants, _, amlLov,
                                             scenarioService, segmentNameFilter) {

        var vm = this;
        var associationAttributeLookupTables = null;
        var yesNoRenderingFilter = null;
        var associationTypeFilter = null;
        var associationAttrCodeFilter = null;
        var partyTypeFilter = null;
        var riskClassificationFilter = null;
        var attributeCharValueFilter = null;

        this.$onInit = function () {
            vm.resources = resources;
            // grid options
            vm.selectedRelatedNumber = null;
            vm.selectedRelType = null;
            vm.selectedParentNumber = null;
            vm.associateAttributesGrid = {};
            associationAttributeLookupTables = [];

            if (amlConstants.config && amlConstants.config.associationAttributeLookupTables) {
                associationAttributeLookupTables = amlConstants.config.associationAttributeLookupTables.split(' ');
            }


            yesNoRenderingFilter = kendoGridRendererService.enum('externalPartyInd', 'yesOrNo', true);
            associationTypeFilter = kendoGridRendererService.enum('type', 'associationType', true);
            associationAttrCodeFilter = kendoGridRendererService.enum('attributeTypeCode', 'associationAttrCode', true);
            partyTypeFilter = kendoGridRendererService.enum('partyTypeDesc', 'partyType', true);
            riskClassificationFilter = kendoGridRendererService.enum('cddRiskClassification', 'scoreClassification', true);
            attributeCharValueFilter = createCharValueEnum('attributeCharValue', associationAttributeLookupTables);

            vm.attrGrid = {};

            vm.attrGridOptions = kendoGridRendererService.initGridOptionsWithDefaults(
                {
                    dataBound: function (e) {
                        setTimeout(function(){
                            e.sender.resize(true);      //workaround for kendo grid responsiveness bug
                        });
                    },
                    selectable: false,
                    filterable: true,
                    sortable: true
                }
            );
            vm.attrGridColumns = [
                {
                    field: 'relatedPartyNumber', type:'string',
                    title: vm.resources.aml.customer.relatedPartyNumber,
                    width: '15%'
                },
                {
                    field: 'attributeTypeCode',
                    title: vm.resources.aml.customer.attributeTypeCode,
                    width: '16%',
                    template: kendoGridRendererService.sanitize(associationAttrCodeFilter),
                    sortable: { compare: kendoGridRendererService.getFilterSortFunction(associationAttrCodeFilter) },
                    filterable: kendoGridRendererService.getCheckboxFilter('associationAttrCode')

                },
                {
                    field: 'attributeNumValue', type:'number',
                    title: vm.resources.aml.customer.attributeNumValue,
                    width: '15%'
                },
                {
                    field: 'attributeCharValue', type:'string',
                    template: kendoGridRendererService.sanitize(attributeCharValueFilter),
                    sortable: { compare: kendoGridRendererService.getFilterSortFunction(associationAttrCodeFilter) },
                    title: vm.resources.aml.customer.attributeCharValue,
                    width: '15%'
                },
                {
                    field: 'attributeDateValue', type:'date', templateType: 'longDateMediumTime',
                    title: vm.resources.aml.customer.attributeDateValue,
                    width: '10%'
                }
            ];

///////
            vm.customersGrid = {};

            vm.customerGridOptions = kendoGridRendererService.initGridOptionsWithDefaults(
                {
                    dataBound: function (e) {
                        setTimeout(function(){
                            e.sender.resize(true);      //workaround for kendo grid responsiveness bug
                        });
                    },
                    selectable: 'row',
                    filterable: true,
                    sortable: true
                }
            );

            vm.customerGridColumns = [
                {
                    field: 'parentPartyNumber', type:'string',
                    template: '<a href="\\#!/customers/{{dataItem.parentPartyNumber}}">{{dataItem.parentPartyNumber}}</a>',
                    title: vm.resources.aml.reviews.entityNumberHeaderTitle,
                    width: '10%'
                },
                {
                    field: 'partyName', type:'string', templateType: 'titleCase',
                    title: vm.resources.aml.reviews.entityNameHeaderTitle,
                    width: '15%'
                },
                {
                    field: 'number', type:'string',
                    template: '<a href="\\#!/customers/{{dataItem.number}}">{{dataItem.number}}</a>',
                    title: vm.resources.aml.customer.relatedPartyNumber,
                    width: '15%'
                },
                {
                    field: 'name', type:'string', templateType: 'titleCase',
                    title: vm.resources.aml.reviews.relatedEntityNameHeaderTitle,
                    width: '15%'
                },
                {
                    field: 'partyTypeDesc', type:'string',
                    title: vm.resources.aml.customersummary.type,
                    width: '15%',
                    template: kendoGridRendererService.sanitize(partyTypeFilter),
                    sortable: { compare: kendoGridRendererService.getFilterSortFunction(partyTypeFilter) },
                    filterable: kendoGridRendererService.getCheckboxFilter('partyType')

                },
                {
                    field: 'type', type:'string',
                    title: vm.resources.aml.customer.relationshipType,
                    width: '15%',
                    template: kendoGridRendererService.sanitize(associationTypeFilter),
                    sortable: { compare: kendoGridRendererService.getFilterSortFunction(associationTypeFilter) },
                    filterable: kendoGridRendererService.getCheckboxFilter('associationType')
                },
                {
                    field: 'externalPartyInd', type:'string',
                    title: vm.resources.aml.customer.externalPartyInd,
                    width: '8%',
                    template: kendoGridRendererService.sanitize(yesNoRenderingFilter),
                    sortable: { compare: kendoGridRendererService.getFilterSortFunction(yesNoRenderingFilter) },
                    filterable: kendoGridRendererService.getCheckboxFilter('yesOrNo')
                },
                {
                    field: 'entitySegmentId', type: 'string',
                    title: vm.resources.aml.segment.segmentLabel,
                    width: '8%',
                    template: kendoGridRendererService.sanitize(segmentNameFilter),
                    sortable: {compare: kendoGridRendererService.getFilterSortFunction(segmentNameFilter)},
                    filterable: kendoGridRendererService.getCheckboxFilterForValues(
                        scenarioService.getSegments('nondeleted'),
                        true,
                        'segmentName',
                        'entitySegmentId',
                        'localizedSegmentName'
                    )
                },
                {
                    field: 'cddRiskClassification', type:'string',
                    title: vm.resources.aml.customer.risk,
                    width: '10%',
                    template: kendoGridRendererService.sanitize(riskClassificationFilter),
                    sortable: { compare: kendoGridRendererService.getFilterSortFunction(riskClassificationFilter) },
                    filterable: kendoGridRendererService.getCheckboxFilter('scoreClassification')
                }
            ];

            vm.loadCustomerGrid = function(gridCallback) {
                if (vm.customerList) {
                    gridCallback.success(vm.customerList);
                }
                else {
                    gridCallback.success([]);
                }
            };

            vm.loadAttrGrid = function(gridCallback) {
                if (vm.selectedParentNumber) {
                    customerService.getAssociatedCustomerAttributes(vm.selectedParentNumber,vm.selectedRelatedNumber, vm.selectedRelType).then(
                        function success (data) {
                            gridCallback.success(data.items);
                        },
                        function error (err) {
                            gridCallback.success([]);
                        }
                    );
                }
                else {
                    gridCallback.success([]);
                }
            };

            vm.handleRowSelect = function(rowData) {
                if (rowData && rowData.number) {
                    vm.selectedRelatedNumber =  rowData.number;
                    vm.selectedRelType = rowData.type;
                    vm.selectedParentNumber = rowData.parentPartyNumber;
                } else {
                    vm.selectedRelatedNumber = null;
                    vm.selectedRelType = null;
                    vm.selectedParentNumber = null;
                }
                kendoGridRendererService.refreshGrid( vm.attrGrid );
            };

            // on double-click, go to alert detail page
            vm.handleDoubleClick = function( selectedEntity) {
                if (selectedEntity && selectedEntity.number) {
                    var entityId = entityService.normalizeEntityId( entityId, 'PTY', selectedEntity.number, selectedEntity.key );
                    var entityState = entityService.getStateForEntity( entityId );
                    $state.go(entityState.stateName, entityState.stateParams);
                    // }
                }
            };

            activate();
        };

        function charValueFilter (input) {
            var value = input;
            if (!input) {return '';}
            _.each(associationAttributeLookupTables, function (tableName) {
                if (tableName !== '') {
                    var messageMap = amlLov.getByLovTableName(tableName);
                    if (messageMap) {
                        var filteredVal = messageMap[input];
                        if (filteredVal && filteredVal.description) {
                            value = filteredVal.description;
                            return value;
                        }
                    }
                }
            });
            return value;
        }

        function createCharValueEnum(field, associationAttributeLookupTables)
        {
            return function (dataItem) {
                if (dataItem && field) {
                    var input = dataItem[field];
                    return charValueFilter(input);
                }
                return '';
            };
        }

        function activate () {
            $scope.$watch('vm.customerList', function(newValue, oldValue){
                // refresh grid
                if (newValue) {
                    kendoGridRendererService.refreshGridSelectFirstRow( vm.customersGrid );
                }
            });
        }

    }
})();
