(function () {
    'use strict';

    QueueListController.$inject = ["$scope", "$rootScope", "amlLov", "amlConstants", "$state", "$q", "queueListService", "resources", "kendoGridRendererService", "messageService"];
    angular
        .module('aml.admin')
        .controller('QueueListController', QueueListController);


    function QueueListController($scope, $rootScope, amlLov, amlConstants, $state, $q,
                                 queueListService, resources, kendoGridRendererService, messageService) {

        var vm = this;
        vm.state = $state.$current;
        vm.queues = []; //null is handled well by kendo-grid too, but we use [] to be consistent
        vm.grid = {};
        vm.amlGridActions = [];
        vm.resources = resources;
        vm.editRowId = -1; //this is the queueKey of the current line that you are updating
        vm.disableDelete = false;
        vm.invalidNameChars = amlConstants.config.invalidCharactersForMetadataName;

        vm.preventAction = false;
        vm.getActiveOnly = false;

        queueListService.getQueues(vm.getActiveOnly).then(
            function (data) {
                vm.queues = data.items;
                activate();
            }
        );


        function activate() {

            var maxPageSizeForGrids = amlConstants.config.maxPageSizeForGrids; //get string 'two, all", etc for maxPageSize found in preferences
            if (!maxPageSizeForGrids) {
                maxPageSizeForGrids = 15000;
            } else {
                if (maxPageSizeForGrids !== 'all') {
                    if (isNaN(parseInt(maxPageSizeForGrids, 10))) { //if there is none them use back-up variables
                        maxPageSizeForGrids = 202;
                    } else {
                        if (maxPageSizeForGrids < 100) {
                            maxPageSizeForGrids = 201;
                        }
                    }
                }
            }

            var logicalDeleteIndRenderingFilter = kendoGridRendererService.enum('logicalDeleteInd', 'yesOrNo');
            var activeIndRenderingFilter = kendoGridRendererService.enum('activeInd', 'yesOrNo');
            //filter object gets status (Y/N) and converts to (Yes/No), it is based on the value of activeInd field

            vm.selectYesOrNo = amlLov.getAsArray(amlLov.yesOrNo);

            vm.gridColumns = [          //grid layout
                {
                    field: 'queueCode', title: resources.aml.queue.header.queueCode,
                    width: '8%',
                   // filterable: queuesFilter,     //checkbox filter, commented out to use text input instead
                    template: '{{dataItem.queueCode | queueName:true}}'
                },
                {
                    field: 'queueDescription', title: resources.aml.queue.header.queueDescription,
                    width: '15%'
                },
                {
                    field: 'accessRoleName', title: resources.aml.queue.header.accessRoleName,
                    width: '15%'
                },
                {
                    field: 'lstUpdateUser', title: resources.aml.queue.header.lstUpdateUser,
                    width: '9%',
                    template: '{{dataItem.lstUpdateUser | userName:true}}'
                },
                {
                    field: 'logicalDeleteInd', title: resources.aml.queue.header.logicalDeleteInd,
                    width: '12%',
                    template: kendoGridRendererService.sanitize(logicalDeleteIndRenderingFilter),
                    editor: function (container, options) {
                        var input = $('<input id="logicalDeleteInd" name="logicalDeleteInd" data-bind="value: ' + options.field + '" />');
                        input.appendTo(container);

                        input.kendoDropDownList({
                            autoBind: true,
                            dataTextField: 'value',
                            dataValueField: 'key',
                            dataSource: vm.selectYesOrNo
                        });
                    },
                    sortable: {compare: kendoGridRendererService.getFilterSortFunction(logicalDeleteIndRenderingFilter)},
                    filterable: kendoGridRendererService.getCheckboxFilter('yesOrNo')
                },
                {
                    field: 'activeInd', title: resources.aml.queue.header.activeInd,
                    width: '8%',
                    template: kendoGridRendererService.sanitize(activeIndRenderingFilter),
                    editor: function (container, options) {
                        var input = $('<input id="activeInd" name="activeInd" data-bind="value: ' + options.field + '" />');
                        input.appendTo(container);

                        input.kendoDropDownList({
                            autoBind: true,
                            dataTextField: 'value',
                            dataValueField: 'key',
                            dataSource: vm.selectYesOrNo
                        });
                    },
                    sortable: {compare: kendoGridRendererService.getFilterSortFunction(activeIndRenderingFilter)},
                    filterable: kendoGridRendererService.getCheckboxFilter('yesOrNo')
                },
                {

                    command: [
                        'edit',
                        {
                            name: 'destroy',
                            text: '{{ dataItem.logicalDeleteInd === "N"  ? "Delete" : "Undelete"}}',
                            iconClass: 'k-icon k-i-close'
                        }
                    ],
                    width: '13%'
                }
            ];


            var isQueueCodeUnique = function (queueCodeInput) {
                if (queueCodeInput === '') {
                    return true;
                }                       //we have to make sure that vm.queues is always updated

                var isUnique = true;

                for (var i = 0; i < vm.queues.length; i++) {
                    if (vm.queues[i].queueKey !== vm.editRowId && vm.queues[i].queueCode.trim().toLowerCase() === queueCodeInput.trim().toLowerCase()) {
                        isUnique = false;
                        break;
                    }
                }

                return isUnique;
            };

            function isRoleNameValid(name) {
                if (vm.invalidNameChars) {
                    for (var i = 0; i < vm.invalidNameChars.length; i++) {
                        if (name.indexOf(vm.invalidNameChars.charAt(i)) >= 0) {
                            return false;
                        }
                    }
                }
                return true;
            }

            function setEnabled(enabled) {
                //mark Edit and Delete buttons so we can find them later, this has to be done each time
                //because Kendo removes them when going into edit mode and replaces with Update and Cancel
                //and then adds them back after edit is complete
                $('.k-grid-delete', '#queuesList').addClass('k-delete-button');
                $('.k-grid-edit', '#queuesList').addClass('k-edit-button');

                //disable all buttons except Update and Cancel when in Edit mode, so that row cannot be closed unfinished
                if (enabled) {
                    //restore Kendo expected classes and attributes based on our marker classes
                    $('.k-add-button', '#queuesList').removeClass('k-state-disabled').addClass('k-grid-add').attr('disabled', false);
                    $('.k-edit-button', '#queuesList').removeClass('k-state-disabled').addClass('k-grid-edit').attr('href', '#');
                    $('.k-delete-button', '#queuesList').removeClass('k-state-disabled').addClass('k-grid-delete').attr('href', '#');
                }
                else {
                    //remove Kendo classes and attributes to disable buttons
                    $('.k-add-button', '#queuesList').addClass('k-state-disabled').removeClass('k-grid-add').attr('disabled', true);
                    $('.k-edit-button', '#queuesList').addClass('k-state-disabled').removeClass('k-grid-edit').removeAttr('href');
                    $('.k-delete-button', '#queuesList').addClass('k-state-disabled').removeClass('k-grid-delete').removeAttr('href');
                }
            }

            vm.dataSourceOptions = new kendo.data.DataSource({      //custom grid option - data handling
                transport: {
                    create: createQueue,        //intercept the CRUD methods to affect kendo
                    read: getQueues,
                    update: editQueue,
                    destroy: deleteQueue
                },
                batch: false,
                schema: {
                    model: {
                        id: 'queueKey',     //need to have id, update should only apply to index 0 element when clicking "create queue"
                        fields: {
                            queueKey: {type: 'number'},     //this will be overwritten with random id, here it is used as an index in grid
                            queueCode: {
                                type: 'string',
                                validation: {
                                    required: {message: resources.aml.queue.inputMessages.queueCodeMissingErrorTxt},
                                    pattern: {
                                        value: '^[^]{0,32}$',
                                        message: resources.aml.queue.inputMessages.queueCodeTooLongErrorTxt
                                    },
                                    unique: function (input) {
                                        // console.log(input.kendoBindingTarget.source);
                                        if (input.is('[name=\'queueCode\']')) {     //see if input type is of type queueCode
                                            if (input.val().trim().length === 0) {  //trim to make sure input is not blank spaces
                                                input.attr('data-unique-msg', resources.aml.queue.inputMessages.queueCodeMissingErrorTxt);
                                                return false;
                                            } else {
                                                if (isQueueCodeUnique(input.val())) {
                                                    return true;
                                                } else {
                                                    //set custom error message
                                                    input.attr('data-unique-msg', resources.aml.queue.inputMessages.queueCodeIsNotUniqueErrorTxt);
                                                    return false;
                                                }
                                            }
                                        }
                                        return true;
                                    }
                                }
                            },
                            queueDescription: {
                                type: 'string',
                                validation: {
                                    required: {message: resources.aml.queue.inputMessages.queueDescriptionMissingErrorTxt},
                                    pattern: {
                                        value: '^[^]{0,100}$',
                                        message: resources.aml.queue.inputMessages.queueDescriptionTooLongErrorTxt
                                    }
                                }
                            },     //these are the column fields
                            accessRoleName: {
                                type: 'string',
                                validation: {
                                    required: {message: resources.aml.queue.inputMessages.queueAccessRoleNameMissingErrorTxt},
                                    pattern: {
                                        value: '^[^]{0,60}$',
                                        message: resources.aml.queue.inputMessages.roleNameTooLongErrorTxt
                                    },
                                    validMetadataName: function (input) {
                                        // console.log(input.kendoBindingTarget.source);
                                        if (input.is('[name=\'accessRoleName\']')) {     //see if input type is of type queueCode
                                            if (input.val().length === 0) {
                                                return true;
                                            } else {
                                                if (isRoleNameValid(input.val())) {
                                                    return true;
                                                } else {
                                                    //set custom error message
                                                    input.attr('data-validMetadataName-msg', vm.resources.aml.getResource('queue.invalidRoleNameErrorTxt', {list: vm.invalidNameChars}));
                                                    return false;
                                                }
                                            }
                                        }
                                        return true;
                                    }
                                }
                            },
                            lstUpdateUser: {type: 'string', editable: false},
                            logicalDeleteInd: {
                                type: 'string',
                                defaultValue: 'N',
                                editable: false
                            },
                            activeInd: {
                                type: 'string',
                                defaultValue: 'Y'
                            }
                        }
                    } //end of model
                },
                requestStart: function (e) {
                    //prevent grid navigation including paging controls, filters and sorting
                    if (vm.preventAction) {
                        e.preventDefault();
                    }
                },
                pageSize: 5,  //set default selection to first option -- 5
                serverPaging: false,
                serverSorting: false,
                serverFiltering: false
            });


            vm.gridOptions = kendoGridRendererService.initGridOptionsWithDefaults(      //custom grid options - UI specs
                {
                    dataSource: vm.dataSourceOptions,
                    columns: vm.gridColumns,
                    pageable: {
                        pageSizes: [5, 10, 20, 50, 100, maxPageSizeForGrids],
                        numeric: false,  //this is a different way to choose page option, we are using array so disable this
                        refresh: true
                    },
                    editable: {
                        mode: 'inline',
                        confirmation: false
                    },
                    resizable: true,
                    selectable: 'multiple',
                    allowCopy: true,
                    filterable: true,
                    batch: false,
                    toolbar: [{text: '', template: kendo.template($('#queuesGrid_toolbar').html())}], //this is to add the top buttons (Create/Cancel Changes)
                    scrollable: false,
                    sortable: {
                        mode: 'multiple',
                        allowUnsort: true       //add row editing under here
                    },
                    edit: function (e) {
                        vm.preventAction = true;
                        //update the id reference to the current row you are updating, if you are creating, value is 0
                        vm.editRowId = e.model.queueKey;

                        if (e.model.isNew() === false) {
                            $('input[name=queueCode]').parent().text(e.model.queueCode);   //take off textbox if you are editing inline
                        }
                        setEnabled(!vm.preventAction);
                    },
                    cancel: function () {
                        vm.preventAction = false;
                        setEnabled(!vm.preventAction);
                    },
                    dataBound: function (e) {
                        setTimeout(function(){
                            e.sender.resize(true);      //workaround for kendo grid responsiveness bug
                        });

                        vm.preventAction = false;
                        setEnabled(!vm.preventAction);
                        //bind our own Add button click handler, so that grid could be unsorted and row will be inserted on top
                        //see https://docs.telerik.com/kendo-ui/knowledge-base/capture-the-add-event-of-the-grid
                        $('.k-grid-add').unbind('click');
                        $('.k-grid-add').bind('click', function(){
                            kendoGridRendererService.clearFilters(vm.grid);
                            kendoGridRendererService.clearSorts(vm.grid);

                        });
                    }
                });


            kendoGridRendererService.initialize(vm, vm.grid, vm.gridOptions, $scope, null, 'queuesList');


            function createQueue(e) {

                var queue = {
                    queueCode: e.data.queueCode,
                    queueDescription: e.data.queueDescription,
                    accessRoleName: e.data.accessRoleName,
                    lstUpdateUser: e.data.lstUpdateUser,    //user cannot input this
                    logicalDeleteInd: e.data.logicalDeleteInd,  //user cannot input this, only delete button can change it
                    activeInd: e.data.activeInd
                };

                if (validateQueue(queue)) {
                    queueListService.createQueue(queue).then(function (result) {
                        e.data.queueKey = result.queueKey;      //we have created the queue, we need to give the object and id for kendo to use
                        e.data.lstUpdateUser = result.lstUpdateUser;
                        vm.queues.push(e.data);
                        e.success(e.data);          //return the data with the new id
                    });
                } else {
                    //this should never happen if buttons are disabled correctly
                    messageService.danger(
                        vm.resources.aml.getResource('queue.queueNotValidErrorTxt'), null, -1);
                    e.error(e.data);
                }
            }


            function getQueues(e) {
                queueListService.getQueues(vm.getActiveOnly).then(function (result) {
                    vm.queues = result.items;
                    //createQueueFilter();   checkbox filter, commented out to use text input instead
                    e.success(vm.queues);
                });
            }

            function validateQueue(q) {
                if (isQueueCodeUnique(q.queueCode) && q.queueDescription && q.accessRoleName) {
                    return true;
                }
                return false;
            }

            function editQueue(e) {

                var newQueue = {
                    queueKey: e.data.queueKey,
                    queueCode: e.data.queueCode,
                    queueDescription: e.data.queueDescription,
                    accessRoleName: e.data.accessRoleName,
                    lstUpdateUser: e.data.lstUpdateUser,
                    logicalDeleteInd: e.data.logicalDeleteInd,
                    activeInd: e.data.activeInd
                };
                if (validateQueue(newQueue)) {
                    queueListService.updateQueue(newQueue).then(function (result) {
                        e.data.queueKey = result.queueKey;      //the object is still updated and returned
                        e.data.lstUpdateUser = result.lstUpdateUser;
                        e.success(e.data);

                        //update queueKey in array without reloading grid
                        for (var i = 0; i < vm.queues.length; i++) {
                            if (vm.queues[i].queueKey === newQueue.queueKey) {
                                vm.queues[i].queueKey = result.queueKey;
                                vm.queues[i].queueCode = result.queueCode;
                                vm.queues[i].queueDescription = result.queueDescription;
                                vm.queues[i].accessRoleName = result.accessRoleName;
                                vm.queues[i].lstUpdateUser = result.lstUpdateUser;
                                vm.queues[i].logicalDeleteInd = result.logicalDeleteInd;
                                vm.queues[i].activeInd = result.activeInd;
                            }
                        }
                    });
                } else {
                    //this should never happen if buttons are disabled correctly
                    messageService.danger(
                        vm.resources.aml.getResource('queue.queueNotValidErrorTxt'), null, -1);
                    e.error(e.data);
                }
            }


            function deleteQueue(e) {

                if (vm.disableDelete) {
                    return;
                } else {
                    vm.disableDelete = true;
                }

                var setAsDelete = e.data.logicalDeleteInd === 'N' ? 'Y' : 'N';

                var queueCopy = {
                    queueKey: e.data.queueKey,
                    queueCode: e.data.queueCode,
                    queueDescription: e.data.queueDescription,
                    accessRoleName: e.data.accessRoleName,
                    lstUpdateUser: e.data.lstUpdateUser,
                    logicalDeleteInd: setAsDelete,      //value switched here and updated in midtier
                    activeInd: e.data.activeInd
                };


                queueListService.updateQueue(queueCopy).then(function (result) {
                    e.data.queueKey = result.queueKey;      //the object is still updated and returned
                    e.success(e.data);
                    reloadGrid(); //updates queues array but reloads grid on screen
                });

            }

            function reloadGrid() {
                vm.grid.dataSource.read();
                vm.disableDelete = false;
            }
        }

    }
})();
