(function () {
    'use strict';

    SegmentListController.$inject = ["$scope", "$rootScope", "amlLov", "amlConstants", "$state", "$q", "segmentListService", "resources", "kendoGridRendererService", "messageService"];
    angular
        .module('aml.admin')
        .controller('SegmentListController', SegmentListController);


    function SegmentListController($scope, $rootScope, amlLov, amlConstants, $state, $q,
                                 segmentListService, resources, kendoGridRendererService, messageService) {

        var vm = this;
        vm.state = $state.$current;
        vm.segments = []; //null is handled well by kendo-grid too, but we use [] to be consistent
        vm.grid = {};
        vm.amlGridActions = [];
        vm.resources = resources;
        vm.editRowId = -1; //this is the segmentKey of the current line that you are updating
        vm.disableDelete = false;

        vm.preventAction = false;


        var maxPageSizeForGrids = amlConstants.config.maxPageSizeForGrids; //get string 'two, all", etc for maxPageSize found in preferences
        if (!maxPageSizeForGrids) {
            maxPageSizeForGrids = 15000;
        } else {
            if (maxPageSizeForGrids !== 'all') {
                if (isNaN(parseInt(maxPageSizeForGrids, 10))) { //if there is none them use back-up variables
                    maxPageSizeForGrids = 202;
                } else {
                    if (maxPageSizeForGrids < 100) {
                        maxPageSizeForGrids = 201;
                    }
                }
            }
        }

        var logicalDeleteIndRenderingFilter = kendoGridRendererService.enum('logicalDeleteInd', 'yesOrNo');
        var activeIndRenderingFilter = kendoGridRendererService.enum('activeInd', 'yesOrNo');
        //filter object gets status (Y/N) and converts to (Yes/No), it is based on the value of activeInd field

        vm.selectYesOrNo = amlLov.getAsArray(amlLov.yesOrNo);

        vm.gridColumns = [          //grid layout
            {
                field: 'entitySegmentId', title: resources.aml.segment.header.entitySegmentId,
                width: '8%'
                //,
                //filterable: kendoGridRendererService.getCheckboxFilter('segmentName'),
                //template: '{{dataItem.entitySegmentId | segmentName:true}}'
            },
            {
                field: 'segmentName', title: resources.aml.segment.header.segmentCode,
                width: '12%'
            },
            {
                field: 'segmentDescription', title: resources.aml.segment.header.segmentDescription,
                width: '15%'
            },
            {
                field: 'lstUpdateUser', title: resources.aml.segment.header.lstUpdateUser,
                width: '9%',
                template: '{{dataItem.lstUpdateUser | userName:true}}'
            },
            {
                field: 'logicalDeleteInd', title: resources.aml.segment.header.logicalDeleteInd,
                width: '12%',
                template: kendoGridRendererService.sanitize(logicalDeleteIndRenderingFilter),
                editor: function (container, options) {
                    var input = $('<input id="logicalDeleteInd" name="logicalDeleteInd" data-bind="value: ' + options.field + '" />');
                    input.appendTo(container);

                    input.kendoDropDownList({
                        autoBind: true,
                        dataTextField: 'value',
                        dataValueField: 'key',
                        dataSource: vm.selectYesOrNo
                    });
                },
                sortable: {compare: kendoGridRendererService.getFilterSortFunction(logicalDeleteIndRenderingFilter)},       //changed to sort logical delete
                filterable: kendoGridRendererService.getCheckboxFilter('yesOrNo')
            },
            {
                field: 'activeInd', title: resources.aml.segment.header.activeInd,
                width: '8%',
                template: kendoGridRendererService.sanitize(activeIndRenderingFilter),
                editor: function (container, options) {
                    var input = $('<input id="activeInd" name="activeInd" data-bind="value: ' + options.field + '" />');
                    input.appendTo(container);

                    input.kendoDropDownList({
                        autoBind: true,
                        dataTextField: 'value',
                        dataValueField: 'key',
                        dataSource: vm.selectYesOrNo
                    });
                },
                sortable: {compare: kendoGridRendererService.getFilterSortFunction(activeIndRenderingFilter)},
                filterable: kendoGridRendererService.getCheckboxFilter('yesOrNo')
            },
            {

            command: [
                 'edit',
                {
                    name: 'destroy',
                    text: '{{ dataItem.logicalDeleteInd === "N"  ? "Delete" : "Undelete"}}',
                    iconClass: 'k-icon k-i-close'
                }
            ],
                width: '13%'
            }
        ];


        var isEntitySegmentIdUnique = function (entitySegmentIdInput) {
            if (entitySegmentIdInput === '') {
                return true;
            }                       //we have to make sure that vm.segment is always updated

            var isUnique = true;

            for(var i=0; i<vm.segments.length; i++) {
                if(vm.segments[i].entitySegmentKey !== vm.editRowId && vm.segments[i].entitySegmentId === parseInt(entitySegmentIdInput)) {
                    isUnique = false;
                    break;
                }
            }

            return isUnique;
        };

        var isEntitySegmentNameUnique = function (entitySegmentNameInput) {
            if (entitySegmentNameInput === '') {
                return true;
            }                       //we have to make sure that vm.segment is always updated

            var isUnique = true;

            for(var i=0; i<vm.segments.length; i++) {
                if(vm.segments[i].entitySegmentKey !== vm.editRowId && vm.segments[i].segmentName.trim().toLowerCase() === entitySegmentNameInput.trim().toLowerCase()) {
                    isUnique = false;
                    break;
                }
            }

            return isUnique;
        };

        function setEnabled(enabled) {
            //mark Edit and Delete buttons so we can find them later, this has to be done each time
            //because Kendo removes them when going into edit mode and replaces with Update and Cancel
            //and then adds them back after edit is complete
            $('.k-grid-delete', '#segmentsList').addClass('k-delete-button');
            $('.k-grid-edit', '#segmentsList').addClass('k-edit-button');

            //disable all buttons except Update and Cancel when in Edit mode, so that row cannot be closed unfinished
            if (enabled) {
                //restore Kendo expected classes and attributes based on our marker classes
                $('.k-add-button', '#segmentsList').removeClass('k-state-disabled').addClass('k-grid-add').attr('disabled', false);
                $('.k-edit-button', '#segmentsList').removeClass('k-state-disabled').addClass('k-grid-edit').attr('href', '#');
                $('.k-delete-button', '#segmentsList').removeClass('k-state-disabled').addClass('k-grid-delete').attr('href', '#');
            }
            else {
                //remove Kendo classes and attributes to disable buttons
                $('.k-add-button', '#segmentsList').addClass('k-state-disabled').removeClass('k-grid-add').attr('disabled', true);
                $('.k-edit-button', '#segmentsList').addClass('k-state-disabled').removeClass('k-grid-edit').removeAttr('href');
                $('.k-delete-button', '#segmentsList').addClass('k-state-disabled').removeClass('k-grid-delete').removeAttr('href');
            }
        }

        vm.dataSourceOptions = new kendo.data.DataSource({      //custom grid option - data handling
            transport: {
                create: createSegment,        //intercept the CRUD methods to affect kendo
                read: getSegments,
                update: editSegment,
                destroy: deleteSegment
            },
            batch: false,
            schema: {
                model: {
                    id: 'entitySegmentKey',     //need to have id, update should only apply to index 0 element when clicking "create segment"
                    fields: {
                        entitySegmentKey: {type: 'number'},     //this will be overwritten with random id, here it is used as an index in grid
                        entitySegmentId: {
                            type: 'number',
                            validation: {
                               required: {message: resources.aml.segment.inputMessages.idRequiredErrorTxt},
                                pattern: {
                                    value: '^-?\\d+$',
                                    message: resources.aml.segment.inputMessages.idNotANumber
                                },
                                uniqueID: function (input) {
                                    if (input.is('[name=\'entitySegmentId\']')) {
                                        if (input.val().length === 0) {
                                            input.attr('data-uniqueID-msg', resources.aml.segment.inputMessages.idRequiredErrorTxt);
                                            return false;
                                        } else if (input.val().length > 12)  {
                                            input.attr('data-uniqueID-msg', resources.aml.segment.inputMessages.idTooLongErrorTxt);
                                            return false;
                                        }
                                        else {
                                            if (isEntitySegmentIdUnique(input.val())) {
                                                return true;
                                            } else {
                                                //set custom error message
                                                input.attr('data-uniqueID-msg', resources.aml.segment.inputMessages.idIsNotUniqueErrorTxt);
                                                return false;
                                            }
                                        }
                                    }
                                    return true;
                                }
                            }
                        },
                        segmentName: {
                            type: 'string',
                            validation: {
                                required: {message: resources.aml.segment.inputMessages.nameRequiredErrorTxt},
                                pattern: {
                                    value: '^[^]{0,50}$',
                                    message: resources.aml.segment.inputMessages.nameTooLongErrorTxt
                                },
                                uniqueName: function (input) {
                                    if (input.is('[name=\'segmentName\']')) {
                                        if (input.val().trim().length === 0) {
                                            input.attr('data-uniqueName-msg', resources.aml.segment.inputMessages.nameRequiredErrorTxt);
                                            return false;
                                        } else {
                                            if (isEntitySegmentNameUnique(input.val())) {
                                                return true;
                                            } else {
                                                //set custom error message
                                                input.attr('data-uniqueName-msg', resources.aml.segment.inputMessages.nameIsNotUniqueErrorTxt);
                                                return false;
                                            }
                                        }
                                    }
                                    return true;
                                }
                            }
                        },
                        segmentDescription: {
                            type: 'string',
                            validation: {
                                required: {message: resources.aml.segment.inputMessages.descriptionRequiredErrorTxt},
                                pattern: {
                                    value: '^[^]{0,100}$',
                                    message: resources.aml.segment.inputMessages.descriptionTooLongErrorTxt
                                }
                            }
                        },     //these are the column fields
                        lstUpdateUser: {type: 'string', editable: false},
                        logicalDeleteInd: {
                            type: 'string',
                            defaultValue: 'N',
                            editable: false
                        },
                        activeInd: {
                            type: 'string',
                            defaultValue: 'Y'
                        }
                    }
                }
            },
            requestStart: function (e) {
                //prevent grid navigation including paging controls, filters and sorting
                if (vm.preventAction) {
                    e.preventDefault();
                }
            },
            pageSize: 20,  //set default selection to first option -- 20
            serverPaging: false,
            serverSorting: false,
            serverFiltering: false
        });


        vm.gridOptions = kendoGridRendererService.initGridOptionsWithDefaults(      //custom grid options - UI specs
            {
                dataSource: vm.dataSourceOptions,
                columns: vm.gridColumns,
                pageable: {
                    pageSizes: [5, 10, 20, 50, 100, maxPageSizeForGrids],
                    numeric: false,  //this is a different way to choose page option, we are using array so disable this
                    refresh: true
                },
                editable: {
                    mode: 'inline',
                    confirmation: false
                },
                resizable: true,
                selectable: 'multiple',
                allowCopy: true,
                filterable: true,
                batch: false,
                toolbar: [{text: '', template: kendo.template($('#segmentsGrid_toolbar').html())}], //this is to add the top buttons (Create/Cancel Changes)
                scrollable: false,
                sortable: {
                    mode: 'multiple',
                    allowUnsort: true       //add row editing under here
                },
                edit: function (e) {
                    vm.preventAction = true;
                    //update the id reference to the current row you are updating, if you are creating, value is 0
                    vm.editRowId = e.model.entitySegmentKey;

                    if (e.model.isNew() === false) {
                        $('td[data-container-for=entitySegmentId]').text(e.model.entitySegmentId);   //take off textbox if you are editing inline
                    }
                    setEnabled(!vm.preventAction);
                },
                cancel: function () {
                    vm.preventAction = false;
                    setEnabled(!vm.preventAction);
                },
                dataBound: function (e) {
                    setTimeout(function(){
                        e.sender.resize(true);      //workaround for kendo grid responsiveness bug
                    });

                    vm.preventAction = false;
                    setEnabled(!vm.preventAction);
                    //bind our own Add button click handler, so that grid could be unsorted and row will be inserted on top
                    //see https://docs.telerik.com/kendo-ui/knowledge-base/capture-the-add-event-of-the-grid
                    $('.k-grid-add').unbind('click');
                    $('.k-grid-add').bind('click', function(){
                        kendoGridRendererService.clearFilters(vm.grid);
                        kendoGridRendererService.clearSorts(vm.grid);
                    });
                }
            });


       kendoGridRendererService.initialize(vm, vm.grid, vm.gridOptions, $scope, null, 'segmentsList');


        function createSegment(e) {

            var segment = {
                entitySegmentId: e.data.entitySegmentId,
                segmentName: e.data.segmentName,
                segmentDescription: e.data.segmentDescription,
                //lstUpdateUser: e.data.lstUpdateUser,    //user cannot input this
               // logicalDeleteInd: e.data.logicalDeleteInd,  //user cannot input this, only delete button can change it
                activeInd: e.data.activeInd
            };


            if (validateSegment(segment)) {
                segmentListService.createSegment(segment).then(function(result) {
                    e.data.entitySegmentKey = result.entitySegmentKey;      //we have created the segment, we need to give the object and id for kendo to use
                    e.data.lstUpdateUser = result.lstUpdateUser;
                    vm.segments.push(e.data);
                    e.success(e.data);          //return the data with the new id
                });
            } else {
                //this should never happen if buttons are disabled correctly
                messageService.danger(
                    vm.resources.aml.getResource('segment.segmentNotValidErrorTxt'), null, -1);
                e.error(e.data);
            }

        }


        function getSegments (e) {
            segmentListService.getSegments().then(function(result) {
                vm.segments = result.items;
                e.success(vm.segments);
            });
        }

        function validateSegment(s) {
            if (isEntitySegmentIdUnique(s.entitySegmentId) && s.segmentName && s.segmentDescription) {
                return true;
            }
            return false;
        }


        function editSegment(e) {

            var newSegment = {
                entitySegmentKey: e.data.entitySegmentKey,
                entitySegmentId: e.data.entitySegmentId,
                segmentName: e.data.segmentName,
                segmentDescription: e.data.segmentDescription,
                lstUpdateUser: e.data.lstUpdateUser,
                logicalDeleteInd: e.data.logicalDeleteInd,
                activeInd: e.data.activeInd
            };



            if (validateSegment(newSegment)) {
                segmentListService.updateSegment(newSegment).then(function(result) {
                    e.data.entitySegmentKey = result.entitySegmentKey;      //the object is still updated and returned
                    e.data.lstUpdateUser = result.lstUpdateUser;
                    e.success(e.data);

                    //update entitySegment in array without reloading grid
                    for(var i=0; i<vm.segments.length; i++) {
                        if(vm.segments[i].entitySegmentKey === newSegment.entitySegmentKey) {
                            vm.segments[i].entitySegmentKey = result.entitySegmentKey;
                            vm.segments[i].entitySegmentId = result.entitySegmentId;
                            vm.segments[i].segmentName = result.segmentName;
                            vm.segments[i].segmentDescription = result.segmentDescription;
                            vm.segments[i].lstUpdateUser = result.lstUpdateUser;
                            vm.segments[i].logicalDeleteInd = result.logicalDeleteInd;
                            vm.segments[i].activeInd = result.activeInd;
                        }
                    }
                });
            } else {
                //this should never happen if buttons are disabled correctly
                messageService.danger(
                    vm.resources.aml.getResource('segment.segmentNotValidErrorTxt'), null, -1);
                e.error(e.data);
            }

        }


        function deleteSegment(e) {

            if(vm.disableDelete) {
                return;
            } else {
                vm.disableDelete = true;
            }

            var setAsDelete = e.data.logicalDeleteInd === 'N' ? 'Y' : 'N';

            var segmentCopy = {
                entitySegmentKey: e.data.entitySegmentKey,
                entitySegmentId: e.data.entitySegmentId,
                segmentName: e.data.segmentName,
                segmentDescription: e.data.segmentDescription,
                lstUpdateUser: e.data.lstUpdateUser,
                logicalDeleteInd: setAsDelete,      //value switched here and updated in midtier
                activeInd: e.data.activeInd
            };


            segmentListService.updateSegment(segmentCopy).then(function(result){
                e.data.entitySegmentKey = result.entitySegmentKey;      //the object is still updated and returned
                e.success(e.data);
                reloadGrid();       //this updates segments array
            });

        }

        function reloadGrid() {
            vm.grid.dataSource.read();
            vm.disableDelete = false;
        }
    }
})();
