-- Update FSC_EXT_PARTY_ACCOUNT_DIM, add SCD2 columns

ALTER TABLE FCFCORE.FSC_EXT_PARTY_ACCOUNT_DIM
ADD
   (
       change_begin_date    DATE DEFAULT  CURRENT_DATE NOT NULL,
       change_end_date      DATE DEFAULT  to_date('59990101','yyyymmdd') NOT NULL,
       change_current_ind   CHAR(1) DEFAULT 'Y' NOT NULL
   );

CREATE OR REPLACE VIEW FCFBU1.FSC_EXT_PARTY_ACCOUNT_DIM AS SELECT * FROM FCFCORE.FSC_EXT_PARTY_ACCOUNT_DIM;

-- Recreate the Alert Triage Datamart to contain entity numbers

---- Drop Datamart Views 
DROP VIEW FCFBU1.FSK_ALERT_TX_AGG CASCADE CONSTRAINTS;
DROP VIEW FCFBU1.FSK_ENTITY_TX_AGG CASCADE CONSTRAINTS;
DROP VIEW FCFBU1.FSK_ALERTED_ENTITY CASCADE CONSTRAINTS;
DROP VIEW FCFBU1.FSK_ENTITY_TRANSACTION CASCADE CONSTRAINTS;
DROP VIEW FCFBU1.FSK_ALERT_TRANSACTION CASCADE CONSTRAINTS;

---- Drop Datamart Tables
DROP TABLE FCFKC.FSK_ENTITY_TX_AGG CASCADE CONSTRAINTS PURGE;
DROP TABLE FCFKC.FSK_ALERT_TX_AGG CASCADE CONSTRAINTS PURGE;
DROP TABLE FCFKC.FSK_ENTITY_TRANSACTION CASCADE CONSTRAINTS PURGE;
---- DROP TABLE FCFKC.FSK_ALERTED_ENTITY CASCADE CONSTRAINTS PURGE;
DROP TABLE FCFKC.FSK_ALERT_TRANSACTION CASCADE CONSTRAINTS PURGE;

---- Drop indexes constraint and then column
DROP INDEX FCFKC.XAK1FSK_ALERTED_ENTITY;
ALTER TABLE FCFKC.FSK_ALERTED_ENTITY DROP CONSTRAINT XPKFSK_ALERTED_ENTITY;
DROP INDEX FCFKC.XPKFSK_ALERTED_ENTITY;
ALTER TABLE FCFKC.FSK_ALERTED_ENTITY DROP COLUMN alerted_entity_key;
ALTER TABLE FCFKC.FSK_ALERTED_ENTITY MODIFY alerted_entity_number VARCHAR2(50) NOT NULL;

CREATE UNIQUE INDEX FCFKC.XPKFSK_ALERTED_ENTITY ON FCFKC.FSK_ALERTED_ENTITY
(alerted_entity_level_code   ASC,alerted_entity_number   ASC)
	TABLESPACE KC_INDEX01;

ALTER TABLE FCFKC.FSK_ALERTED_ENTITY
	ADD CONSTRAINT  XPKFSK_ALERTED_ENTITY PRIMARY KEY (alerted_entity_level_code,alerted_entity_number);

CREATE UNIQUE INDEX FCFKC.XAK1FSK_ALERTED_ENTITY ON FCFKC.FSK_ALERTED_ENTITY
(alerted_entity_number   ASC,alerted_entity_level_code   ASC)
	TABLESPACE KC_INDEX01;

CREATE TABLE FCFKC.FSK_ALERT_TRANSACTION
(
	fsk_alert_transaction_pk NUMBER(22) NOT NULL ,
	alerted_entity_level_code CHAR(3) NULL ,
	alerted_entity_number VARCHAR2(50) NULL ,
	alert_id             NUMBER(12) NULL ,
	transaction_id       VARCHAR2(50) NULL ,
	transaction_amt      NUMERIC(15,3) NULL ,
	transaction_cdi_desc VARCHAR2(30) NULL ,
	primary_medium_desc  VARCHAR2(30) NULL ,
	secondary_medium_desc VARCHAR2(30) NULL ,
	transaction_date     TIMESTAMP NULL ,
	transaction_mechanism VARCHAR2(50) NULL ,
	account_number       VARCHAR2(50) NULL ,
	beneficiary_name     VARCHAR2(200) NULL ,
	associate_name       VARCHAR2(250) NULL ,
	Branch_name          VARCHAR2(100) NULL ,
	transaction_desc     VARCHAR2(255) NULL ,
	transaction_status   VARCHAR2(20) NULL ,
	triggering_indicator_cd VARCHAR2(3) NULL ,
	created_timestamp    TIMESTAMP NULL ,
	date_key             NUMBER(8) NULL ,
	time_key             NUMBER(6) NULL 
)
	 TABLESPACE KC_DATA01;

CREATE UNIQUE INDEX FCFKC.XPKFSK_ALERT_TRANSACTION ON FCFKC.FSK_ALERT_TRANSACTION
(fsk_alert_transaction_pk   ASC)
	TABLESPACE KC_INDEX01;

ALTER TABLE FCFKC.FSK_ALERT_TRANSACTION
	ADD CONSTRAINT  XPKFSK_ALERT_TRANSACTION PRIMARY KEY (fsk_alert_transaction_pk);

CREATE  INDEX FCFKC.XIF2FSK_ALERT_TRANSACTION ON FCFKC.FSK_ALERT_TRANSACTION
(alert_id   ASC)
	TABLESPACE KC_INDEX01;

CREATE  INDEX FCFKC.XIF3FSK_ALERT_TRANSACTION ON FCFKC.FSK_ALERT_TRANSACTION
(alerted_entity_level_code   ASC,alerted_entity_number   ASC)
	TABLESPACE KC_INDEX01;

CREATE TABLE FCFKC.FSK_ALERT_TX_AGG
(
	fsk_alert_tx_agg_pk  NUMBER(12) NOT NULL ,
	alert_id             NUMBER(12) NULL ,
	aggregate_type_code  VARCHAR2(35) NULL ,
	group_code           VARCHAR2(30) NULL ,
	group_desc           VARCHAR2(30) NULL ,
	aggregate_amt        NUMBER(15,3) NULL ,
	created_timestamp    TIMESTAMP NULL 
)
	 TABLESPACE KC_DATA01;

CREATE UNIQUE INDEX FCFKC.XPKFSK_ALERT_TX_AGG ON FCFKC.FSK_ALERT_TX_AGG
(fsk_alert_tx_agg_pk   ASC)
	TABLESPACE KC_INDEX01;

ALTER TABLE FCFKC.FSK_ALERT_TX_AGG
	ADD CONSTRAINT  XPKFSK_ALERT_TX_AGG PRIMARY KEY (fsk_alert_tx_agg_pk);

CREATE  INDEX FCFKC.XIF1FSK_ALERT_TX_AGG ON FCFKC.FSK_ALERT_TX_AGG
(alert_id   ASC)
	TABLESPACE KC_INDEX01;


CREATE TABLE FCFKC.FSK_ENTITY_TRANSACTION
(
	fsk_entity_transaction_pk NUMBER(22) NOT NULL ,
	alerted_entity_level_code CHAR(3) NULL ,
	alerted_entity_number VARCHAR2(50) NULL ,
	transaction_id       VARCHAR2(50) NULL ,
	transaction_amt      NUMERIC(15,3) NULL ,
	transaction_cdi_desc VARCHAR2(30) NULL ,
	primary_medium_desc  VARCHAR2(30) NULL ,
	secondary_medium_desc VARCHAR2(30) NULL ,
	transaction_date     TIMESTAMP NULL ,
	transaction_mechanism VARCHAR2(50) NULL ,
	account_number       VARCHAR2(50) NULL ,
	beneficiary_name     VARCHAR2(200) NULL ,
	associate_name       VARCHAR2(250) NULL ,
	Branch_name          VARCHAR2(100) NULL ,
	transaction_desc     VARCHAR2(255) NULL ,
	transaction_status   VARCHAR2(20) NULL ,
	created_timestamp    TIMESTAMP NULL ,
	date_key             NUMBER(8) NULL ,
	time_key             NUMBER(6) NULL ,
	household_number     VARCHAR2(50) NULL
)
	 TABLESPACE KC_DATA01;

CREATE UNIQUE INDEX FCFKC.XPKFSK_ENTITY_TRANSACTION ON FCFKC.FSK_ENTITY_TRANSACTION
(fsk_entity_transaction_pk   ASC)
	TABLESPACE KC_INDEX01;

ALTER TABLE FCFKC.FSK_ENTITY_TRANSACTION
	ADD CONSTRAINT  XPKFSK_ENTITY_TRANSACTION PRIMARY KEY (fsk_entity_transaction_pk);

CREATE  INDEX FCFKC.XIF1FSK_ENTITY_TRANSACTION ON FCFKC.FSK_ENTITY_TRANSACTION
(alerted_entity_level_code   ASC,alerted_entity_number   ASC)
	TABLESPACE KC_INDEX01;

CREATE TABLE FCFKC.FSK_ENTITY_TX_AGG
(
	fsk_entity_tx_agg_pk NUMBER(12) NOT NULL ,
	alerted_entity_level_code CHAR(3) NULL ,
	alerted_entity_number VARCHAR2(50) NULL ,
	aggregate_type_code  VARCHAR2(4) NULL ,
	group_code           VARCHAR2(50) NULL ,
	group_desc           VARCHAR2(50) NULL ,
	aggregate_amt        NUMBER(15,3) NULL ,
	created_timestamp    TIMESTAMP NULL 
)
	 TABLESPACE KC_DATA01;

CREATE UNIQUE INDEX FCFKC.XPKFSK_ENTITY_TX_AGG ON FCFKC.FSK_ENTITY_TX_AGG
(fsk_entity_tx_agg_pk   ASC)
	TABLESPACE KC_INDEX01;

ALTER TABLE FCFKC.FSK_ENTITY_TX_AGG
	ADD CONSTRAINT  XPKFSK_ENTITY_TX_AGG PRIMARY KEY (fsk_entity_tx_agg_pk);

CREATE  INDEX FCFKC.XIF1FSK_ENTITY_TX_AGG ON FCFKC.FSK_ENTITY_TX_AGG
(alerted_entity_level_code   ASC,alerted_entity_number   ASC)
	TABLESPACE KC_INDEX01;


---- Create Grants for new tables
GRANT SELECT, INSERT, DELETE, UPDATE on FCFKC.FSK_ALERT_TX_AGG  to FCFBU1;
GRANT SELECT, INSERT, DELETE, UPDATE on FCFKC.FSK_ENTITY_TX_AGG  to FCFBU1;
GRANT SELECT, INSERT, DELETE, UPDATE on FCFKC.FSK_ALERTED_ENTITY  to FCFBU1;
GRANT SELECT, INSERT, DELETE, UPDATE on FCFKC.FSK_ALERT_TRANSACTION  to FCFBU1;
GRANT SELECT, INSERT, DELETE, UPDATE on FCFKC.FSK_ENTITY_TRANSACTION  to FCFBU1;

---- Create Views
CREATE OR REPLACE VIEW FCFBU1.FSK_ALERT_TX_AGG AS SELECT * FROM FCFKC.FSK_ALERT_TX_AGG;
CREATE OR REPLACE VIEW FCFBU1.FSK_ENTITY_TX_AGG AS SELECT * FROM FCFKC.FSK_ENTITY_TX_AGG;
CREATE OR REPLACE VIEW FCFBU1.FSK_ALERTED_ENTITY AS SELECT * FROM FCFKC.FSK_ALERTED_ENTITY;
CREATE OR REPLACE VIEW FCFBU1.FSK_ALERT_TRANSACTION AS SELECT * FROM FCFKC.FSK_ALERT_TRANSACTION;
CREATE OR REPLACE VIEW FCFBU1.FSK_ENTITY_TRANSACTION AS SELECT * FROM FCFKC.FSK_ENTITY_TRANSACTION;

-- modify FSC_PARTY_DIM for Beneficial Ownership support
ALTER TABLE FCFCORE.FSC_PARTY_DIM
ADD
   (
       ben_own_exempt_ind   CHAR(1) DEFAULT 'N' NULL
   );
CREATE OR REPLACE VIEW FCFBU1.FSC_PARTY_DIM AS SELECT * FROM FCFCORE.FSC_PARTY_DIM;

-- modify FSC_ACCOUNT_DIM for Beneficial Ownership support
ALTER TABLE FCFCORE.FSC_ACCOUNT_DIM
ADD
   (
       opened_by_party_number       VARCHAR2(50) NULL ,
       opened_by_party_name         VARCHAR2(200) NULL ,
       opened_by_party_title        VARCHAR2(50) NULL
   );
CREATE OR REPLACE VIEW FCFBU1.FSC_ACCOUNT_DIM AS SELECT * FROM FCFCORE.FSC_ACCOUNT_DIM;

ALTER TABLE FCFKC.FSK_CASE
MODIFY
   (
       case_description VARCHAR2(100)
   );

CREATE OR REPLACE VIEW FCFBU1.FSK_CASE AS SELECT * FROM FCFKC.FSK_CASE;
