--------------------------------------------------------------
--------------------------------------------------------------
--Core TABLE, INDEX, AND TABLESPACE CREATION TEMPLATE
--------------------------------------------------------------
--This script is a template for creating the tablespaces, tables,
--indexes, and constraints required for the 'CORE' FCF schema
--if the FCF Core tables are being stored in Postgres.
--
--This script is only a template.  It must be customized
--to the physical environment and volume of data expected.
--
--Indexes may be added or removed as desired for performance reasons,
--however, modifications to the ETL process might be necessary to
--acommodate such changes, since it is often necessary to drop and
--rebuild indexes during ETL for performance reasons.
--
--This script must be run as an account with DBA privileges.
--
--This script assumes that one bank segment is being
--created (FCFBU1).
--------------------------------------------------------------
--------------------------------------------------------------

CREATE TABLE FCFCORE.FSC_ACCOUNT_ANALYSIS_DIM (
     ACCOUNT_NUMBER       VARCHAR(50)     NOT NULL,
     EXPECTED_INCOMING_AMOUNT NUMERIC(18,5),
     EXPECTED_OUTGOING_AMOUNT NUMERIC(18,5),
     EXPECTED_INCOMING_COUNT NUMERIC(10),
     EXPECTED_OUTGOING_COUNT NUMERIC(10),
     INCREASED_BEHAVIOR_CREDIT_AMT NUMERIC(18,5),
     INCREASED_BEHAVIOR_DEBIT_AMT NUMERIC(18,5),
     INCREASED_BEHAVIOR_CREDIT_CNT NUMERIC(15,5),
     INCREASED_BEHAVIOR_DEBIT_CNT NUMERIC(15,5),
     EXPECTED_CREDIT_CEILING_AMOUNT NUMERIC(18,5),
     EXPECTED_DEBIT_CEILING_AMOUNT NUMERIC(18,5),
     LAST_ACTIVITY_DATE   DATE,
     PRIMARY KEY (ACCOUNT_NUMBER)
);

CREATE TABLE FCFCORE.FSC_ACCOUNT_DIM (
     ACCOUNT_KEY          NUMERIC(12)     NOT NULL,
     ACCOUNT_NUMBER       VARCHAR(50)     NOT NULL,
     LINE_OF_BUSINESS_NAME VARCHAR(35),
     ACCOUNT_TYPE_DESC    VARCHAR(20)     NOT NULL,
     ACCOUNT_CURRENCY_CODE CHAR(3)     NOT NULL,
     ACCOUNT_CURRENCY_NAME VARCHAR(100)     NOT NULL,
     ACCOUNT_REGISTRATION_TYPE_DESC VARCHAR(20),
     ACCOUNT_REGISTRATION_NAME VARCHAR(255),
     ACCOUNT_NAME         VARCHAR(35),
     ALTERNATE_NAME       VARCHAR(35),
     ACCOUNT_OPEN_DATE    DATE,
     ACCOUNT_CLOSE_DATE   DATE,
     ACCOUNT_STATUS_DESC  VARCHAR(35),
     DORMANT_IND          CHAR(1),
     PRODUCT_LINE_NAME    VARCHAR(35),
     PRODUCT_CATEGORY_NAME VARCHAR(35),
     PRODUCT_TYPE_NAME    VARCHAR(35),
     PRODUCT_NAME         VARCHAR(35),
     PRODUCT_NUMBER       VARCHAR(25),
     ACCOUNT_TAX_ID       VARCHAR(35),
     ACCOUNT_TAX_ID_TYPE_CODE CHAR(1),
     ACCOUNT_TAX_STATE_CODE CHAR(3),
     ACCOUNT_PRIMARY_BRANCH_NAME VARCHAR(25),
     MAILING_ADDRESS_1    VARCHAR(35),
     MAILING_ADDRESS_2    VARCHAR(35),
     MAILING_CITY_NAME    VARCHAR(35),
     MAILING_STATE_CODE   CHAR(3),
     MAILING_STATE_NAME   VARCHAR(35),
     MAILING_POSTAL_CODE  CHAR(10),
     MAILING_COUNTRY_CODE CHAR(3),
     MAILING_COUNTRY_NAME VARCHAR(100),
     CURRENCY_BASED_ACCOUNT_IND CHAR(1),
     MATURITY_DATE        DATE,
     ORIGINAL_LOAN_AMOUNT NUMERIC(15,5),
     COLLATERAL_TYPE_CODE VARCHAR(10),
     COLLATERAL_TYPE_DESC VARCHAR(35),
     INSURED_AMOUNT       NUMERIC(15,5),
     EMPLOYEE_IND         CHAR(1),
     LETTER_OF_CREDIT_ONFILE_IND CHAR(1),
     CASH_INTENSIVE_BUSINESS_IND CHAR(1),
     TRADE_FINANCE_IND    CHAR(1),
     CHANGE_BEGIN_DATE    DATE,
     CHANGE_END_DATE      DATE     NOT NULL,
     CHANGE_CURRENT_IND   CHAR(1)     NOT NULL,
     OPENED_BY_PARTY_NUMBER VARCHAR(50),
     OPENED_BY_PARTY_NAME VARCHAR(200),
     OPENED_BY_PARTY_TITLE VARCHAR(50),
     ENTITY_SEGMENT_ID    NUMERIC(12),
     PRIMARY KEY (ACCOUNT_KEY)
);
CREATE INDEX XIE1FSC_ACCOUNT_DIM ON 
FCFCORE.FSC_ACCOUNT_DIM( account_number );
CREATE INDEX XIE2FSC_ACCOUNT_DIM ON 
FCFCORE.FSC_ACCOUNT_DIM( account_name );
CREATE INDEX XIE3FSC_ACCOUNT_DIM ON 
FCFCORE.FSC_ACCOUNT_DIM( account_tax_id );

CREATE TABLE FCFCORE.FSC_ACCOUNT_EVENT_FACT (
     TRANSACTION_KEY      NUMERIC(12)     NOT NULL,
     BRANCH_KEY           NUMERIC(12)     NOT NULL,
     TIME_KEY             NUMERIC(6)     NOT NULL,
     DATE_KEY             NUMERIC(8,0)     NOT NULL,
     ACCOUNT_KEY          NUMERIC(12)     NOT NULL,
     COUNTRY_KEY          NUMERIC(5)     NOT NULL,
     TRANSACTION_TYPE_KEY NUMERIC(12)     NOT NULL,
     TRANSACTION_STATUS_KEY NUMERIC(5)     NOT NULL,
     PRIMARY KEY (TRANSACTION_KEY)
);

CREATE TABLE FCFCORE.FSC_ACCOUNT_PROFILE_FACT (
     ACCOUNT_NUMBER       VARCHAR(50)     NOT NULL,
     MONTH_KEY            NUMERIC(6,0)     NOT NULL,
     TRANSACTIONS_COUNT   NUMERIC(10,0),
     DEPOSITS_COUNT       NUMERIC(10,0),
     WITHDRAWALS_COUNT    NUMERIC(10,0),
     WIRES_COUNT          NUMERIC(10,0),
     CASH_TRANSACTIONS_COUNT NUMERIC(10,0),
     ACCOUNT_VALUE_AMOUNT NUMERIC(18,5),
     TOTAL_TRANSACTIONS_AMOUNT NUMERIC(18,5),
     TOTAL_CREDITS_AMOUNT NUMERIC(18,5),
     TOTAL_DEBITS_AMOUNT  NUMERIC(18,5),
     TOTAL_CASH_DEBITS_AMOUNT NUMERIC(18,5),
     TOTAL_CASH_CREDITS_AMOUNT NUMERIC(18,5),
     TOTAL_WIRE_CREDITS_AMOUNT NUMERIC(18,5),
     TOTAL_WIRE_DEBITS_AMOUNT NUMERIC(18,5),
     BEGINNING_BALANCE_AMOUNT NUMERIC(18,5),
     AVERAGE_DAILY_BALANCE_AMOUNT NUMERIC(18,5),
     ENDING_CASH_BALANCE_AMOUNT NUMERIC(18,5),
     MAX_ACCOUNT_VALUE_AMOUNT NUMERIC(18,5),
     MIN_ACCOUNT_VALUE_AMOUNT NUMERIC(18,5),
     AVG_ACCOUNT_VALUE_AMOUNT NUMERIC(18,5),
     CUST_INITIATED_TRANS_COUNT NUMERIC(10,0),
     LARGEST_CREDIT_AMOUNT NUMERIC(18,5),
     LARGEST_DEBIT_AMOUNT NUMERIC(18,5),
     PRIMARY KEY (ACCOUNT_NUMBER, MONTH_KEY)
);

CREATE TABLE FCFCORE.FSC_ACCOUNT_STATE_VECTOR_FACT (
     ACCOUNT_NUMBER       VARCHAR(50)     NOT NULL,
     DATE_KEY             NUMERIC(8)     NOT NULL,
     ACCOUNT_TYPE_DESC    VARCHAR(20)     NOT NULL,
     DEBITS_TOTAL         NUMERIC(18,5),
     CREDITS_TOTAL        NUMERIC(18,5),
     ATM_DEBITS_TOTAL     NUMERIC(18,5),
     ATM_CREDITS_TOTAL    NUMERIC(18,5),
     ATM_D_TRANS_COUNT    NUMERIC(10),
     ATM_C_TRANS_COUNT    NUMERIC(10),
     DEBIT_TRANS_COUNT    NUMERIC(10),
     CREDIT_TRANS_COUNT   NUMERIC(10),
     DEBIT_LOC_COUNT      NUMERIC(10),
     CREDIT_LOC_COUNT     NUMERIC(10),
     ATM_D_LOC_COUNT      NUMERIC(10)     NOT NULL,
     ATM_C_LOC_COUNT      NUMERIC(10),
     WIRE_CREDIT_TOTAL    NUMERIC(18,5),
     WIRE_CREDIT_TRANS_COUNT NUMERIC(10),
     WIRE_DEBITS_TOTAL    NUMERIC(18,5),
     WIRE_DEBIT_TRANS_COUNT NUMERIC(10),
     D_I_WIRE_CREDITS_TOTAL NUMERIC(18,5),
     D_I_WIRE_CREDIT_TRANS_COUNT NUMERIC(10),
     D_I_WIRE_DEBITS_TOTAL NUMERIC(18,5),
     D_I_WIRE_DEBIT_TRANS_COUNT NUMERIC(10),
     BALANCE_INQUIRY_COUNT NUMERIC(10),
     EXCEEDED_DAILY_LIMIT_COUNT NUMERIC(10),
     INSUFFICIENT_FUNDS_COUNT NUMERIC(10),
     PRIMARY KEY (ACCOUNT_NUMBER, DATE_KEY)
);

CREATE TABLE FCFCORE.FSC_ACCOUNT_TRADE_FACT (
     TRANSACTION_KEY      NUMERIC(12)     NOT NULL,
     ACCOUNT_KEY          NUMERIC(12)     NOT NULL,
     BRANCH_KEY           NUMERIC(12)     NOT NULL,
     TRANSACTION_TYPE_KEY NUMERIC(12)     NOT NULL,
     TRANSACTION_STATUS_KEY NUMERIC(5)     NOT NULL,
     TRADE_DATE_KEY       NUMERIC(8,0)     NOT NULL,
     EXECUTION_TIME_KEY   NUMERIC(6)     NOT NULL,
     POSTED_DATE_KEY      NUMERIC(8)     NOT NULL,
     SETTLEMENT_DATE_KEY  NUMERIC(8,0)     NOT NULL,
     QUANTITY_EXECUTED    NUMERIC(15,5),
     EXECUTION_PRICE      NUMERIC(10,5),
     TRANSACTION_CURRENCY_KEY NUMERIC(5)     NOT NULL,
     PRINCIPAL_AMOUNT_IN_TXN_CCY NUMERIC(15,5),
     PRINCIPAL_AMOUNT     NUMERIC(15,5),
     PRINCIPAL_AMOUNT_IN_ACCT_CCY NUMERIC(15,5)     NOT NULL,
     ASSOCIATE_KEY        NUMERIC(12),
     PRIMARY KEY (TRANSACTION_KEY)
);

CREATE TABLE FCFCORE.FSC_ADDRESS_DIM (
     ADDRESS_KEY          NUMERIC(12)     NOT NULL,
     PRIMARY_ENTITY_NUMBER VARCHAR(50),
     PRIMARY_ENTITY_LEVEL_CODE CHAR(3),
     ADDRESS_TYPE_CODE    VARCHAR(20),
     ADDRESS_LINE_1_TEXT  VARCHAR(35),
     ADDRESS_LINE_2_TEXT  VARCHAR(35),
     CITY_NAME            VARCHAR(35),
     STATE_CODE           CHAR(3),
     STATE_NAME           VARCHAR(35),
     POSTAL_CODE          CHAR(10),
     COUNTRY_CODE         CHAR(3),
     COUNTRY_NAME         VARCHAR(100),
     MATCH_CODE_ADDRESS   VARCHAR(140),
     MATCH_CODE_ADDR_LINES VARCHAR(80),
     MATCH_CODE_CITY      VARCHAR(30),
     MATCH_CODE_STATE     VARCHAR(15),
     MATCH_CODE_COUNTRY   VARCHAR(15),
     CHANGE_BEGIN_DATE    DATE,
     CHANGE_END_DATE      DATE     NOT NULL,
     CHANGE_CURRENT_IND   CHAR(1)     NOT NULL,
     PRIMARY KEY (ADDRESS_KEY)
);

CREATE TABLE FCFCORE.FSC_ASSOCIATE_DIM (
     ASSOCIATE_KEY        NUMERIC(12)     NOT NULL,
     ASSOCIATE_NUMBER     VARCHAR(20),
     ASSOCIATE_FIRST_NAME VARCHAR(50),
     ASSOCIATE_LAST_NAME  VARCHAR(50),
     ASSOCIATE_MIDDLE_NAME VARCHAR(100),
     ASSOCIATE_TITLE_DESC VARCHAR(50),
     ASSOCIATE_STATUS_DESC VARCHAR(35),
     STREET_ADDRESS_1     VARCHAR(35),
     STREET_ADDRESS_2     VARCHAR(35),
     STREET_CITY_NAME     VARCHAR(35),
     STREET_STATE_CODE    CHAR(3),
     STREET_STATE_NAME    VARCHAR(35),
     STREET_POSTAL_CODE   CHAR(10),
     STREET_COUNTRY_NAME  VARCHAR(100),
     STREET_COUNTRY_CODE  CHAR(3),
     WORK_PHONE_NUMBER    VARCHAR(25),
     EMAIL_ADDRESS        VARCHAR(35),
     BRANCH_NUMBER        VARCHAR(25),
     BRANCH_NAME          VARCHAR(35),
     CHANGE_BEGIN_DATE    DATE,
     CHANGE_END_DATE      DATE     NOT NULL,
     CHANGE_CURRENT_IND   CHAR(1)     NOT NULL,
     PRIMARY KEY (ASSOCIATE_KEY)
);
CREATE INDEX XIE1FSC_ASSOCIATE_DIM ON 
FCFCORE.FSC_ASSOCIATE_DIM( associate_number );
CREATE INDEX XIE6FSC_ASSOCIATE_DIM ON 
FCFCORE.FSC_ASSOCIATE_DIM( associate_last_name );

CREATE TABLE FCFCORE.FSC_BANK_DIM (
     BANK_KEY             NUMERIC(12)     NOT NULL,
     BANK_NUMBER          VARCHAR(25),
     BANK_CHIPS_NUMBER    VARCHAR(25),
     BANK_SWIFT_NUMBER    VARCHAR(25),
     BANK_NAME            VARCHAR(35),
     BANK_ADDRESS_1       VARCHAR(35),
     BANK_ADDRESS_2       VARCHAR(35),
     BANK_CITY_NAME       VARCHAR(35),
     BANK_STATE_CODE      CHAR(3),
     BANK_STATE_NAME      VARCHAR(35),
     BANK_POSTAL_CODE     CHAR(10),
     BANK_COUNTRY_CODE    CHAR(3),
     BANK_COUNTRY_NAME    CHAR(35),
     BANK_PHONE_NUMBER    VARCHAR(25),
     CHANGE_BEGIN_DATE    DATE,
     CHANGE_END_DATE      DATE     NOT NULL,
     CHANGE_CURRENT_IND   CHAR(1)     NOT NULL,
     PRIMARY KEY (BANK_KEY)
);
CREATE INDEX XIE1FSC_BANK_DIM ON 
FCFCORE.FSC_BANK_DIM( bank_number );

CREATE TABLE FCFCORE.FSC_BRANCH_DIM (
     BRANCH_KEY           NUMERIC(12)     NOT NULL,
     BRANCH_TYPE_DESC     VARCHAR(10),
     BRANCH_NUMBER        VARCHAR(40),
     BRANCH_NAME          VARCHAR(100),
     STREET_ADDRESS_1     VARCHAR(35),
     STREET_ADDRESS_2     VARCHAR(35),
     STREET_CITY_NAME     VARCHAR(35),
     STREET_STATE_CODE    CHAR(3),
     STREET_STATE_NAME    VARCHAR(35),
     STREET_POSTAL_CODE   CHAR(10),
     STREET_COUNTRY_CODE  CHAR(3),
     STREET_COUNTRY_NAME  VARCHAR(100),
     CHANGE_BEGIN_DATE    DATE,
     CHANGE_END_DATE      DATE     NOT NULL,
     CHANGE_CURRENT_IND   CHAR(1)     NOT NULL,
     PRIMARY KEY (BRANCH_KEY)
);
CREATE INDEX XIE3FSC_BRANCH_DIM ON 
FCFCORE.FSC_BRANCH_DIM( branch_number );
CREATE INDEX XIE2FSC_BRANCH_DIM ON 
FCFCORE.FSC_BRANCH_DIM( branch_name );

CREATE TABLE FCFCORE.FSC_CASH_FLOW_BANK_BRIDGE (
     BANK_KEY             NUMERIC(12)     NOT NULL,
     TRANSACTION_KEY      NUMERIC(12)     NOT NULL,
     ROLE_DESC            VARCHAR(20),
     SEQUENCE_NUMBER      NUMERIC(2),
     PRIMARY KEY (BANK_KEY, TRANSACTION_KEY)
);

CREATE TABLE FCFCORE.FSC_CASH_FLOW_FACT (
     TRANSACTION_KEY      NUMERIC(12)     NOT NULL,
     ACCOUNT_KEY          NUMERIC(12)     NOT NULL,
     COUNTRY_KEY          NUMERIC(5)     NOT NULL,
     TRANSACTION_TYPE_KEY NUMERIC(12)     NOT NULL,
     TIME_KEY             NUMERIC(6)     NOT NULL,
     DATE_KEY             NUMERIC(8,0)     NOT NULL,
     TRANSACTION_STATUS_KEY NUMERIC(5)     NOT NULL,
     TRANSACTION_CURRENCY_KEY NUMERIC(5)     NOT NULL,
     BRANCH_KEY           NUMERIC(12)     NOT NULL,
     REMITTER_EXT_PARTY_KEY NUMERIC(12)     NOT NULL,
     BENEFICIARY_EXT_PARTY_KEY NUMERIC(12)     NOT NULL,
     POSTED_DATE_KEY      NUMERIC(8),
     ASSOCIATE_KEY        NUMERIC(12)     NOT NULL,
     EXECUTING_PARTY_KEY  NUMERIC(12)     NOT NULL,
     EXECUTING_EXT_PARTY_KEY NUMERIC(12),
     CURRENCY_AMOUNT      NUMERIC(18,5)     NOT NULL,
     CURRENCY_AMOUNT_IN_TXN_CCY NUMERIC(18,5)     NOT NULL,
     CURRENCY_AMOUNT_IN_ACCOUNT_CCY NUMERIC(18,5)     NOT NULL,
     SECONDARY_ACCOUNT_KEY NUMERIC(12)     NOT NULL,
     RELATED_IND          CHAR(1)     NOT NULL,
     THIRD_PARTY_IND      CHAR(1),
     PRIMARY KEY (TRANSACTION_KEY)
);
CREATE INDEX XIF5ACCOUNT_CREDITS_FACT ON 
FCFCORE.FSC_CASH_FLOW_FACT( date_key );
CREATE INDEX CASH_FLOW_SECONDARY_IDX ON 
FCFCORE.FSC_CASH_FLOW_FACT( secondary_account_key );

CREATE TABLE FCFCORE.FSC_CLASSIFIER_FACT (
     PARTY_NUMBER         VARCHAR(50)     NOT NULL,
     MONTH_KEY            NUMERIC(6,0)     NOT NULL,
     RC_PEP               NUMERIC(1),
     RC_FOREIGN_FINANCIAL_INST NUMERIC(1),
     RC_NON_BANK_FINANCIAL_INST NUMERIC(1),
     RC_FOREIGN_CORPORATION NUMERIC(1),
     RC_DEPOSIT_BROKER    NUMERIC(1),
     RC_CASH_INTENSIVE_BUSINESS NUMERIC(1),
     RC_PROFESSIONAL_SVCS_PROVIDER NUMERIC(1),
     RC_PRIVATE_BANKING   NUMERIC(1),
     RC_TRUST_OR_ASSET_MGMT_ACCT NUMERIC(1),
     RC_FOREIGN_CORRESPONDENT_ACCT NUMERIC(1),
     RC_TRADE_FINANCE     NUMERIC(1),
     RC_SPECIAL_USE_ACCOUNT NUMERIC(1),
     RC_LENDING_ACTIVITY  NUMERIC(1),
     RC_NONDEPOSIT_ACCOUNT NUMERIC(1),
     RC_WIRES_COUNT       NUMERIC(6),
     RC_FUNDS_TRANSFER_COUNT NUMERIC(6),
     RC_NON_PROFIT_ORG    NUMERIC(1),
     RC_FUNDS_PAYMENT_SVCS_COUNT NUMERIC(6),
     RC_INTERNAL_PEP      NUMERIC(1),
     RC_HIGH_RISK_GEOGRAPHY NUMERIC(1),
     RC_MONETARY_INSTRUMENT_COUNT NUMERIC(6),
     PRIMARY KEY (PARTY_NUMBER, MONTH_KEY)
);
CREATE INDEX XIE1FSC_CLASSIFIER_FACT ON 
FCFCORE.FSC_CLASSIFIER_FACT( rc_pep );

CREATE TABLE FCFCORE.FSC_COUNTRY_DIM (
     COUNTRY_KEY          NUMERIC(5)     NOT NULL,
     COUNTRY_CODE_2       CHAR(2),
     COUNTRY_CODE_3       CHAR(3),
     COUNTRY_NAME         VARCHAR(100),
     PRIMARY KEY (COUNTRY_KEY)
);
CREATE INDEX XIE1FSC_COUNTRY_DIM ON 
FCFCORE.FSC_COUNTRY_DIM( country_name );
CREATE INDEX XIE2FSC_COUNTRY_DIM ON 
FCFCORE.FSC_COUNTRY_DIM( country_code_2 );
CREATE INDEX XIE3FSC_COUNTRY_DIM ON 
FCFCORE.FSC_COUNTRY_DIM( country_code_3 );

CREATE TABLE FCFCORE.FSC_CURRENCY_DIM (
     CURRENCY_KEY         NUMERIC(5)     NOT NULL,
     CURRENCY_CODE        CHAR(3),
     CURRENCY_NAME        VARCHAR(100),
     PRIMARY KEY (CURRENCY_KEY)
);
CREATE INDEX XIE1FSC_CURRENCY_DIM ON 
FCFCORE.FSC_CURRENCY_DIM( currency_code );
CREATE INDEX XIE2FSC_CURRENCY_DIM ON 
FCFCORE.FSC_CURRENCY_DIM( currency_name );

CREATE TABLE FCFCORE.FSC_DATE_DIM (
     DATE_KEY             NUMERIC(8,0)     NOT NULL,
     CALENDAR_DATE        DATE,
     CALENDAR_DATE_SAS    NUMERIC(8,0),
     CALENDAR_DATE_DMY    CHAR(9),
     DAY_NAME             VARCHAR(9),
     DAY_NAME_SHORT       CHAR(3),
     DAY_NUMBER_IN_MONTH  NUMERIC(2,0),
     DAY_NUMBER_IN_YEAR   NUMERIC(3,0),
     WEEK_NUMBER_IN_MONTH NUMERIC(1,0),
     WEEK_NUMBER_IN_YEAR  NUMERIC(2,0),
     MONTH_NUMBER_IN_YEAR NUMERIC(2,0),
     MONTH_KEY            NUMERIC(6,0),
     MONTH_AND_YEAR       CHAR(6),
     MONTH_NAME           VARCHAR(9),
     MONTH_NAME_SHORT     CHAR(3),
     QUARTER_NAME         CHAR(4),
     QUARTER_AND_YEAR     CHAR(6),
     MONTH_NAME_3C        CHAR(3),
     QUARTER_NAME_2C      CHAR(2),
     QUARTER_NAME_4C      CHAR(4),
     YEAR_2C              CHAR(2),
     YEAR_4C              CHAR(4),
     HOLIDAY_IND          CHAR(1),
     HOLIDAY_NAME         CHAR(9),
     WEEK_DAY_IND         CHAR(1),
     END_OF_MONTH_IND     CHAR(1),
     ECONOMIC_RELEASE_DESC VARCHAR(20),
     ECONOMIC_EVENT_DESC  VARCHAR(20),
     PRIMARY KEY (DATE_KEY)
);

CREATE TABLE FCFCORE.FSC_ENTITY_PEER_GROUP (
     ENTITY_NUMBER        VARCHAR(50)     NOT NULL,
     ENTITY_LEVEL_CODE    CHAR(3)     NOT NULL,
     PEER_GROUP_ID        VARCHAR(50)     NOT NULL,
     CHANGE_BEGIN_DATE    DATE     NOT NULL,
     CHANGE_END_DATE      DATE     NOT NULL,
     CHANGE_CURRENT_IND   CHAR(1)     NOT NULL,
     PRIMARY KEY (ENTITY_NUMBER, ENTITY_LEVEL_CODE, PEER_GROUP_ID,
      CHANGE_BEGIN_DATE)
);

CREATE TABLE FCFCORE.FSC_ENTITY_PROFILE_AGG (
     ENTITY_NUMBER        VARCHAR(50)     NOT NULL,
     ENTITY_LEVEL_CODE    CHAR(3)     NOT NULL,
     SUMMARY_PERIOD_CODE  CHAR(1)     NOT NULL,
     PROFILE_GROUP_ID     VARCHAR(50)     NOT NULL,
     SUMMARY_BEGIN_DATE_KEY NUMERIC(8)     NOT NULL,
     SUMMARY_END_DATE_KEY NUMERIC(8)     NOT NULL,
     TRANS_COUNT          NUMERIC(10),
     TRANS_AMOUNT         NUMERIC(18,5),
     MAX_TRANS_AMOUNT     NUMERIC(18,5),
     ROUND_TRANS_AMOUNT   NUMERIC(18,5),
     ROUND_TRANS_COUNT    NUMERIC(10),
     NON_MONETARY_TRANS_COUNT NUMERIC(10),
     LOG10_TRANS_AMOUNT   NUMERIC(12,10),
     LOG10_TRANS_COUNT    NUMERIC(12,10),
     LOG10_MAX_TRANS_AMOUNT NUMERIC(12,10),
     LOG10_ROUND_TRANS_COUNT NUMERIC(12,10),
     LOG10_ROUND_TRANS_AMOUNT NUMERIC(12,10),
     PRIMARY KEY (ENTITY_NUMBER, ENTITY_LEVEL_CODE, SUMMARY_PERIOD_CODE,
      PROFILE_GROUP_ID, SUMMARY_BEGIN_DATE_KEY)
);

CREATE TABLE FCFCORE.FSC_ENTITY_PROFILE_HISTORY (
     HISTORY_PERIOD_CODE  CHAR(1)     NOT NULL,
     PROFILE_GROUP_ID     VARCHAR(50)     NOT NULL,
     ENTITY_LEVEL_CODE    CHAR(3)     NOT NULL,
     ENTITY_NUMBER        VARCHAR(50)     NOT NULL,
     HISTORY_BEGIN_DATE_KEY NUMERIC(8)     NOT NULL,
     HISTORY_PERIOD_COUNT NUMERIC(5),
     HISTORY_END_DATE_KEY NUMERIC(8),
     PERIOD_COUNT         NUMERIC(5),
     PERIOD_SUFFICIENCY_COUNT NUMERIC(5),
     AVG_TRANS_COUNT      NUMERIC(10),
     AVG_TRANS_AMOUNT     NUMERIC(18,5),
     AVG_MAX_TRANS_AMOUNT NUMERIC(18,5),
     MAX_TRANS_COUNT      NUMERIC(10),
     MAX_TRANS_AMOUNT     NUMERIC(18,5),
     MAX_MAX_TRANS_AMOUNT NUMERIC(18,5),
     STD_TRANS_COUNT      NUMERIC(10),
     STD_TRANS_AMOUNT     NUMERIC(18,5),
     STD_MAX_TRANS_AMOUNT NUMERIC(18,5),
     AVG_LOG10_TRANS_COUNT NUMERIC(12,10),
     AVG_LOG10_TRANS_AMOUNT NUMERIC(12,10),
     AVG_LOG10_MAX_TRANS_AMOUNT NUMERIC(12,10),
     MAX_LOG10_TRANS_COUNT NUMERIC(12,10),
     MAX_LOG10_TRANS_AMOUNT NUMERIC(12,10),
     MAX_LOG10_MAX_TRANS_AMOUNT NUMERIC(12,10),
     STD_LOG10_TRANS_COUNT NUMERIC(12,10),
     STD_LOG10_TRANS_AMOUNT NUMERIC(12,10),
     STD_LOG10_MAX_TRANS_AMOUNT NUMERIC(12,10),
     PRIMARY KEY (HISTORY_PERIOD_CODE, PROFILE_GROUP_ID, ENTITY_LEVEL_CODE,
      ENTITY_NUMBER, HISTORY_BEGIN_DATE_KEY)
);

CREATE TABLE FCFCORE.FSC_ENTITY_PROFILE_SUMMARY_AGG (
     ENTITY_NUMBER        VARCHAR(50)     NOT NULL,
     ENTITY_LEVEL_CODE    CHAR(3)     NOT NULL,
     SUMMARY_PERIOD_CODE  CHAR(1)     NOT NULL,
     PROFILE_GROUP_ID     VARCHAR(50)     NOT NULL,
     SUMMARY_GROUP_ID     VARCHAR(50)     NOT NULL,
     SUMMARY_BEGIN_DATE_KEY NUMERIC(8)     NOT NULL,
     SUMMARY_END_DATE_KEY NUMERIC(8)     NOT NULL,
     TRANS_COUNT          NUMERIC(10),
     TRANS_AMOUNT         NUMERIC(18,5),
     MAX_TRANS_AMOUNT     NUMERIC(18,5),
     ROUND_TRANS_AMOUNT   NUMERIC(18,5),
     ROUND_TRANS_COUNT    NUMERIC(10),
     NON_MONETARY_TRANS_COUNT NUMERIC(10),
     LOG10_TRANS_AMOUNT   NUMERIC(12,10),
     LOG10_TRANS_COUNT    NUMERIC(12,10),
     LOG10_MAX_TRANS_AMOUNT NUMERIC(12,10),
     LOG10_ROUND_TRANS_COUNT NUMERIC(12,10),
     LOG10_ROUND_TRANS_AMOUNT NUMERIC(12,10),
     PRIMARY KEY (ENTITY_NUMBER, ENTITY_LEVEL_CODE, SUMMARY_PERIOD_CODE,
      PROFILE_GROUP_ID, SUMMARY_GROUP_ID, SUMMARY_BEGIN_DATE_KEY)
);

CREATE TABLE FCFCORE.FSC_ENTITY_WATCH_LIST_DIM (
     ENTITY_WATCH_LIST_KEY NUMERIC(12)     NOT NULL,
     ENTITY_WATCH_LIST_NUMBER VARCHAR(35)     NOT NULL,
     WATCH_LIST_NAME      CHAR(4)     NOT NULL,
     CATEGORY_DESC        VARCHAR(50),
     TYPE_DESC            VARCHAR(20),
     PROGRAMS             VARCHAR(250),
     TAX_ID               VARCHAR(35),
     TAX_ID_TYPE_CODE     CHAR(1),
     IDENTIFICATION_ID    VARCHAR(255),
     IDENTIFICATION_TYPE_DESC VARCHAR(255),
     DATE_OF_BIRTH        DATE,
     YEAR_OF_BIRTH        NUMERIC(4),
     PLACE_OF_BIRTH       VARCHAR(100),
     DECEASED_IND         CHAR(1),
     FIRST_NAME           VARCHAR(350),
     LAST_NAME            VARCHAR(350),
     MIDDLE_NAME          VARCHAR(255),
     ENTITY_NAME          VARCHAR(800),
     MATCH_CODE_INDIVIDUAL VARCHAR(80),
     MATCH_CODE_ORGANIZATION VARCHAR(100),
     MATCH_CODE_ADDR_LINES VARCHAR(80),
     MATCH_CODE_CITY      VARCHAR(30),
     MATCH_CODE_STATE     VARCHAR(15),
     MATCH_CODE_COUNTRY   VARCHAR(15),
     ENTITY_TITLE         VARCHAR(200),
     OCCUPATION_DESC      VARCHAR(500),
     ADDRESS              VARCHAR(750),
     CITY_NAME            VARCHAR(255),
     STATE_NAME           VARCHAR(50),
     POSTAL_CODE          CHAR(30),
     COUNTRY_CODE         CHAR(3),
     COUNTRY_NAME         VARCHAR(255),
     FULL_ADDRESS         VARCHAR(1200),
     MATCH_CODE_FULL_ADDRESS VARCHAR(140),
     CITIZENSHIP_COUNTRY_CODE CHAR(3),
     CITIZENSHIP_COUNTRY_NAME VARCHAR(100),
     MATCH_CODE_CITIZENSHIP VARCHAR(15),
     NATIONALITY_COUNTRY_CODE CHAR(3),
     NATIONALITY_COUNTRY_NAME VARCHAR(100),
     MATCH_CODE_NATIONALITY VARCHAR(15),
     ORG_COUNTRY_OF_BUSINESS_CODE VARCHAR(3),
     ORG_COUNTRY_OF_BUSINESS_NAME VARCHAR(100),
     MATCH_CODE_ORG_COUNTRY VARCHAR(15),
     POLITICALLY_EXPOSED_PERSON_IND CHAR(1),
     CREATE_DATE          DATE,
     UPDATE_DATE          DATE,
     EXCLUDE_IND          CHAR(1)     NOT NULL,
     CHANGE_BEGIN_DATE    DATE     NOT NULL,
     CHANGE_END_DATE      DATE     NOT NULL,
     CHANGE_CURRENT_IND   CHAR(1)     NOT NULL,
     PRIMARY KEY (ENTITY_WATCH_LIST_KEY)
);
CREATE INDEX XIE1FSC_ENTITY_WATCH_LIST_DIM ON 
FCFCORE.FSC_ENTITY_WATCH_LIST_DIM( entity_watch_list_number );
CREATE INDEX XIE4FSC_ENTITY_WATCH_LIST_DIM ON 
FCFCORE.FSC_ENTITY_WATCH_LIST_DIM( last_name );
CREATE INDEX XIE2FSC_ENTITY_WATCH_LIST_DIM ON 
FCFCORE.FSC_ENTITY_WATCH_LIST_DIM( watch_list_name );

CREATE TABLE FCFCORE.FSC_EXT_PARTY_ACCOUNT_DIM (
     EXT_PARTY_ACCOUNT_KEY NUMERIC(12)     NOT NULL,
     EXTERNAL_PARTY_NUMBER VARCHAR(100),
     EXT_PARTY_TYPE_DESC  VARCHAR(20),
     FULL_NAME            VARCHAR(200),
     LAST_NAME            VARCHAR(50),
     FIRST_NAME           VARCHAR(50),
     MIDDLE_NAME          VARCHAR(100),
     BIRTH_DATE           DATE,
     PARTY_TAX_ID         VARCHAR(35),
     PARTY_TAX_ID_TYPE_CODE CHAR(1),
     MATCH_CODE_ORGANIZATION VARCHAR(100),
     MATCH_CODE_INDIVIDUAL VARCHAR(80),
     MATCH_CODE_STREET_ADDRESS VARCHAR(140),
     MATCH_CODE_STREET_ADDR_LINES VARCHAR(80),
     MATCH_CODE_STREET_CITY VARCHAR(30),
     MATCH_CODE_STREET_STATE VARCHAR(15),
     MATCH_CODE_STREET_COUNTRY VARCHAR(15),
     STREET_ADDRESS_1     VARCHAR(35),
     STREET_ADDRESS_2     VARCHAR(35),
     STREET_CITY_NAME     VARCHAR(35),
     STREET_STATE_CODE    CHAR(3),
     STREET_STATE_NAME    VARCHAR(35),
     STREET_POSTAL_CODE   CHAR(10),
     STREET_COUNTRY_CODE  CHAR(3),
     STREET_COUNTRY_NAME  VARCHAR(100),
     ACCOUNT_NUMBER       VARCHAR(50),
     BANK_KEY             NUMERIC(12),
     BRANCH_NUMBER        VARCHAR(25),
     BRANCH_NAME          VARCHAR(35),
     CITIZENSHIP_COUNTRY_CODE CHAR(3),
     CITIZENSHIP_COUNTRY_NAME VARCHAR(100),
     RESIDENCE_COUNTRY_CODE CHAR(3),
     RESIDENCE_COUNTRY_NAME VARCHAR(100),
     PHONE_NUMBER_1       VARCHAR(25),
     PHONE_NUMBER_2       VARCHAR(25),
     IDENTIFICATION_ID    VARCHAR(35),
     IDENTIFICATION_TYPE_DESC CHAR(4),
     IDENTIFICATION_STATE_CODE CHAR(3),
     IDENTIFICATION_COUNTRY_CODE CHAR(3),
     IDENTIFICATION_COUNTRY_NAME VARCHAR(100),
     CREATE_DTTM          TIMESTAMP     NOT NULL,
     PRIMARY KEY (EXT_PARTY_ACCOUNT_KEY)
);
CREATE INDEX XIE1FSC_EXT_PARTY_ACCOUNT_DIM ON 
FCFCORE.FSC_EXT_PARTY_ACCOUNT_DIM( external_party_number );
CREATE INDEX XIE2FSC_EXT_PARTY_ACCOUNT_DIM ON 
FCFCORE.FSC_EXT_PARTY_ACCOUNT_DIM( last_name );
CREATE INDEX XIE4FSC_EXT_PARTY_ACCOUNT_DIM ON 
FCFCORE.FSC_EXT_PARTY_ACCOUNT_DIM( account_number );
CREATE INDEX XIE5FSC_EXT_PARTY_ACCOUNT_DIM ON 
FCFCORE.FSC_EXT_PARTY_ACCOUNT_DIM( full_name );

CREATE TABLE FCFCORE.FSC_HOUSEHOLD_ACCOUNT_BRIDGE (
     HOUSEHOLD_KEY        NUMERIC(12)     NOT NULL,
     ACCOUNT_KEY          NUMERIC(12)     NOT NULL,
     CHANGE_BEGIN_DATE    DATE     NOT NULL,
     CHANGE_END_DATE      DATE     NOT NULL,
     CHANGE_CURRENT_IND   CHAR(1)     NOT NULL,
     PRIMARY KEY (HOUSEHOLD_KEY, ACCOUNT_KEY, CHANGE_BEGIN_DATE)
);

CREATE TABLE FCFCORE.FSC_HOUSEHOLD_DIM (
     HOUSEHOLD_KEY        NUMERIC(12)     NOT NULL,
     HOUSEHOLD_NUMBER     VARCHAR(50),
     HOUSEHOLD_TYPE_DESC  VARCHAR(20),
     STREET_ADDRESS_1     VARCHAR(35),
     STREET_ADDRESS_2     VARCHAR(35),
     STREET_CITY_NAME     VARCHAR(35),
     STREET_STATE_CODE    CHAR(3),
     STREET_STATE_NAME    VARCHAR(35),
     STREET_POSTAL_CODE   VARCHAR(10),
     STREET_COUNTRY_CODE  CHAR(3),
     STREET_COUNTRY_NAME  VARCHAR(100),
     PHONE_NUMBER_1       VARCHAR(25),
     PHONE_NUMBER_2       VARCHAR(25),
     HEAD_OF_HOUSEHOLD_NAME VARCHAR(35),
     EMPLOYEE_IND         CHAR(1),
     CHANGE_BEGIN_DATE    DATE,
     CHANGE_END_DATE      DATE     NOT NULL,
     CHANGE_CURRENT_IND   CHAR(1)     NOT NULL,
     PRIMARY KEY (HOUSEHOLD_KEY)
);
CREATE INDEX XIE1FSC_HOUSEHOLD_DIM ON 
FCFCORE.FSC_HOUSEHOLD_DIM( household_number,change_current_ind );
CREATE INDEX XIE3FSC_HOUSEHOLD_DIM ON 
FCFCORE.FSC_HOUSEHOLD_DIM( head_of_household_name );
CREATE INDEX XIE4FSC_HOUSEHOLD_DIM ON 
FCFCORE.FSC_HOUSEHOLD_DIM( phone_number_1 );
CREATE INDEX XIE5FSC_HOUSEHOLD_DIM ON 
FCFCORE.FSC_HOUSEHOLD_DIM( phone_number_2 );

CREATE TABLE FCFCORE.FSC_HOUSEHOLD_PARTY_BRIDGE (
     PARTY_KEY            NUMERIC(12)     NOT NULL,
     HOUSEHOLD_KEY        NUMERIC(12)     NOT NULL,
     CHANGE_BEGIN_DATE    DATE     NOT NULL,
     CHANGE_END_DATE      DATE     NOT NULL,
     HHD_HEAD_FLG         CHAR(1)     NOT NULL,
     CHANGE_CURRENT_IND   CHAR(1)     NOT NULL,
     PRIMARY KEY (PARTY_KEY, HOUSEHOLD_KEY, CHANGE_BEGIN_DATE)
);

CREATE TABLE FCFCORE.FSC_LOCATION_WATCH_LIST_DIM (
     LOCATION_WATCH_LIST_KEY NUMERIC(12)     NOT NULL,
     LOCATION_WATCH_LIST_NUMBER VARCHAR(35)     NOT NULL,
     WATCH_LIST_NAME      CHAR(4)     NOT NULL,
     PROGRAM              VARCHAR(20),
     COUNTRY_CODE         CHAR(3),
     COUNTRY_NAME         VARCHAR(255),
     MATCH_CODE_COUNTRY_NAME VARCHAR(15),
     CREATE_DATE          DATE,
     UPDATE_DATE          DATE,
     EXCLUDE_IND          CHAR(1)     NOT NULL,
     CHANGE_BEGIN_DATE    DATE     NOT NULL,
     CHANGE_END_DATE      DATE     NOT NULL,
     CHANGE_CURRENT_IND   CHAR(1)     NOT NULL,
     PRIMARY KEY (LOCATION_WATCH_LIST_KEY)
);

CREATE TABLE FCFCORE.FSC_LOOKUP_DIM (
     LOOKUP_KEY           NUMERIC(12)     NOT NULL,
     LOOKUP_LEVEL_1_TYPE_CODE VARCHAR(3)     NOT NULL,
     LOOKUP_LEVEL_2_TYPE_CODE VARCHAR(28)     NOT NULL,
     LOOKUP_CODE          VARCHAR(35)     NOT NULL,
     LOOKUP_CHAR_VALUE    VARCHAR(50),
     LOOKUP_NUM_VALUE     NUMERIC(18,5),
     LOOKUP_DATE_VALUE    DATE,
     CHANGE_BEGIN_DATE    DATE     NOT NULL,
     CHANGE_END_DATE      DATE     NOT NULL,
     CHANGE_CURRENT_IND   CHAR(1)     NOT NULL,
     PRIMARY KEY (LOOKUP_KEY)
);

CREATE TABLE FCFCORE.FSC_MONTH_DIM (
     MONTH_KEY            NUMERIC(6,0)     NOT NULL,
     MONTH_AND_YEAR       CHAR(6),
     MONTH_NAME           VARCHAR(9),
     MONTH_NAME_3C        CHAR(3),
     QUARTER_NAME_2C      CHAR(2),
     QUARTER_NAME_4C      CHAR(4),
     YEAR_2C              CHAR(2),
     YEAR_4C              CHAR(4),
     CURRENT_MONTH_IND    CHAR(1),
     PRIMARY KEY (MONTH_KEY)
);
CREATE INDEX XIE1FSC_MONTH_DIM ON 
FCFCORE.FSC_MONTH_DIM( current_month_ind );

CREATE TABLE FCFCORE.FSC_PARTY_ACCOUNT_BRIDGE (
     ACCOUNT_KEY          NUMERIC(12)     NOT NULL,
     PARTY_KEY            NUMERIC(12)     NOT NULL,
     ROLE_KEY             NUMERIC(2)     NOT NULL,
     CHANGE_BEGIN_DATE    DATE     NOT NULL,
     ROLE_DESC            VARCHAR(20),
     CHANGE_END_DATE      DATE     NOT NULL,
     CHANGE_CURRENT_IND   CHAR(1)     NOT NULL,
     PRIMARY KEY (ACCOUNT_KEY, PARTY_KEY, ROLE_KEY, CHANGE_BEGIN_DATE)
);

CREATE TABLE FCFCORE.FSC_PARTY_ASSOC (
     PARTY_NUMBER         VARCHAR(50)     NOT NULL,
     RELATED_PARTY_NUMBER VARCHAR(50)     NOT NULL,
     RELATIONSHIP_TYPE_CODE VARCHAR(20)     NOT NULL,
     CHANGE_BEGIN_DATE    DATE     NOT NULL,
     CHANGE_END_DATE      DATE     NOT NULL,
     CHANGE_CURRENT_IND   CHAR(1)     NOT NULL,
     PRIMARY KEY (PARTY_NUMBER, RELATED_PARTY_NUMBER, RELATIONSHIP_TYPE_CODE,
      CHANGE_BEGIN_DATE)
);

CREATE TABLE FCFCORE.FSC_PARTY_ASSOC_ATTRIBUTE (
     PARTY_NUMBER         VARCHAR(50)     NOT NULL,
     RELATED_PARTY_NUMBER VARCHAR(50)     NOT NULL,
     RELATIONSHIP_TYPE_CODE VARCHAR(20)     NOT NULL,
     ATTRIBUTE_TYPE_CODE  VARCHAR(35)     NOT NULL,
     CHANGE_BEGIN_DATE    DATE     NOT NULL,
     ATTRIBUTE_CHAR_VALUE VARCHAR(32),
     ATTRIBUTE_NUM_VALUE  NUMERIC(18,5),
     ATTRIBUTE_DATE_VALUE DATE,
     CHANGE_END_DATE      DATE     NOT NULL,
     CHANGE_CURRENT_IND   CHAR(1)     NOT NULL,
     PRIMARY KEY (PARTY_NUMBER, RELATED_PARTY_NUMBER, RELATIONSHIP_TYPE_CODE,
      ATTRIBUTE_TYPE_CODE, CHANGE_BEGIN_DATE)
);

CREATE TABLE FCFCORE.FSC_PARTY_DIM (
     PARTY_KEY            NUMERIC(12)     NOT NULL,
     PARTY_NUMBER         VARCHAR(50)     NOT NULL,
     PARTY_TYPE_DESC      VARCHAR(20)     NOT NULL,
     PARTY_TAX_ID         VARCHAR(35),
     PARTY_TAX_ID_TYPE_CODE CHAR(1),
     PARTY_IDENTIFICATION_ID VARCHAR(35),
     PARTY_IDENTIFICATION_TYPE_DESC CHAR(4),
     PARTY_ID_STATE_CODE  CHAR(3),
     PARTY_ID_COUNTRY_CODE CHAR(3),
     PARTY_DATE_OF_BIRTH  DATE,
     PARTY_FIRST_NAME     VARCHAR(50),
     PARTY_LAST_NAME      VARCHAR(50),
     PARTY_MIDDLE_NAME    VARCHAR(100),
     PARTY_NAME           VARCHAR(200),
     DOING_BUSINESS_AS_NAME VARCHAR(35),
     PARTY_STATUS_DESC    VARCHAR(20),
     ULTIMATE_PARENT_NAME VARCHAR(35),
     MATCH_CODE_ORGANIZATION VARCHAR(100),
     MATCH_CODE_INDIVIDUAL VARCHAR(80),
     MATCH_CODE_STREET_ADDRESS VARCHAR(140),
     MATCH_CODE_MAILING_ADDRESS VARCHAR(140),
     MATCH_CODE_STREET_ADDR_LINES VARCHAR(80),
     MATCH_CODE_STREET_CITY VARCHAR(30),
     MATCH_CODE_STREET_STATE VARCHAR(15),
     MATCH_CODE_STREET_COUNTRY VARCHAR(15),
     MATCH_CODE_MAILING_ADDR_LINES VARCHAR(80),
     MATCH_CODE_MAILING_CITY VARCHAR(30),
     MATCH_CODE_MAILING_STATE VARCHAR(15),
     MATCH_CODE_MAILING_COUNTRY VARCHAR(15),
     STREET_ADDRESS_1     VARCHAR(35),
     STREET_ADDRESS_2     VARCHAR(35),
     STREET_CITY_NAME     VARCHAR(35),
     STREET_STATE_CODE    CHAR(3),
     STREET_STATE_NAME    VARCHAR(35),
     STREET_POSTAL_CODE   CHAR(10),
     STREET_COUNTRY_CODE  CHAR(3),
     STREET_COUNTRY_NAME  VARCHAR(100),
     MAILING_ADDRESS_1    VARCHAR(35),
     MAILING_ADDRESS_2    VARCHAR(35),
     MAILING_CITY_NAME    VARCHAR(35),
     MAILING_STATE_CODE   CHAR(3),
     MAILING_STATE_NAME   VARCHAR(35),
     MAILING_POSTAL_CODE  CHAR(10),
     MAILING_COUNTRY_CODE CHAR(3),
     MAILING_COUNTRY_NAME VARCHAR(100),
     RESIDENCE_COUNTRY_CODE CHAR(3),
     RESIDENCE_COUNTRY_NAME VARCHAR(100),
     CITIZENSHIP_COUNTRY_CODE CHAR(3),
     CITIZENSHIP_COUNTRY_NAME VARCHAR(100),
     ORG_COUNTRY_OF_BUSINESS_CODE CHAR(3),
     ORG_COUNTRY_OF_BUSINESS_NAME VARCHAR(100),
     EMPLOYEE_IND         CHAR(1),
     EMPLOYEE_NUMBER      VARCHAR(20),
     EMPLOYER_NAME        VARCHAR(35),
     EMPLOYER_PHONE_NUMBER VARCHAR(25),
     EMAIL_ADDRESS        VARCHAR(35),
     OCCUPATION_DESC      VARCHAR(35),
     INDUSTRY_CODE        CHAR(10),
     INDUSTRY_CODE_RR     VARCHAR(10),
     INDUSTRY_DESC        VARCHAR(255),
     PHONE_NUMBER_1       VARCHAR(25),
     PHONE_NUMBER_2       VARCHAR(25),
     PHONE_NUMBER_3       VARCHAR(25),
     ANNUAL_INCOME_AMOUNT NUMERIC(10,0),
     NET_WORTH_AMOUNT     NUMERIC(10,0),
     MARITAL_STATUS_DESC  VARCHAR(20),
     LAST_CONTACT_DATE    DATE,
     POLITICALLY_EXPOSED_PERSON_IND CHAR(1)     NOT NULL,
     NON_PROFIT_ORG_IND   CHAR(1),
     CUSTOMER_SINCE_DATE  DATE,
     LAST_SUSP_ACTV_RPT_DATE DATE,
     LAST_CASH_TRANS_RPT_DATE DATE,
     LAST_RISK_ASSESSMENT_DATE DATE,
     RISK_CLASSIFICATION  NUMERIC(1),
     CHANGE_BEGIN_DATE    DATE,
     CHANGE_END_DATE      DATE     NOT NULL,
     CHANGE_CURRENT_IND   CHAR(1)     NOT NULL,
     EXTERNAL_PARTY_IND   CHAR(1),
     LEGAL_ENTITY_TYPE    VARCHAR(30),
     MONEY_ORDERS_IND     CHAR(1),
     TRAVELERS_CHEQUES_IND CHAR(1),
     PREPAID_CARDS_IND    CHAR(1),
     MSB_IND              CHAR(1),
     MONEY_TRANSMITTER_IND CHAR(1),
     CURRENCY_EXCHANGE_IND CHAR(1),
     CHECK_CASHER_IND     CHAR(1),
     INTERNET_GAMBLING_IND CHAR(1),
     TRUST_ACCOUNT_IND    CHAR(1),
     FOREIGN_CONSULATE_EMBASSY_IND CHAR(1),
     ISSUES_BEARER_SHARES_IND CHAR(1),
     NEGATIVE_NEWS_IND    CHAR(1),
     SUSP_ACTV_RPT_COUNT  NUMERIC(4),
     LST_UPDATE_DATE      DATE,
     BEN_OWN_EXEMPT_IND   CHAR(1),
     ENTITY_SEGMENT_ID    NUMERIC(12),
     PRIMARY KEY (PARTY_KEY)
);
CREATE INDEX XIE12FSC_PARTY_DIM ON 
FCFCORE.FSC_PARTY_DIM( party_name );
CREATE INDEX XIE13FSC_PARTY_DIM ON 
FCFCORE.FSC_PARTY_DIM( party_number );
CREATE INDEX XIE14FSC_PARTY_DIM ON 
FCFCORE.FSC_PARTY_DIM( party_tax_id );
CREATE INDEX XIE15FSC_PARTY_DIM ON 
FCFCORE.FSC_PARTY_DIM( match_code_mailing_address );
CREATE INDEX XIE16FSC_PARTY_DIM ON 
FCFCORE.FSC_PARTY_DIM( match_code_street_address );
CREATE INDEX XIE17FSC_PARTY_DIM ON 
FCFCORE.FSC_PARTY_DIM( phone_number_1 );
CREATE INDEX XIE18FSC_PARTY_DIM ON 
FCFCORE.FSC_PARTY_DIM( phone_number_2 );
CREATE INDEX XIE19FSC_PARTY_DIM ON 
FCFCORE.FSC_PARTY_DIM( phone_number_3 );
CREATE INDEX XIE20FSC_PARTY_DIM ON 
FCFCORE.FSC_PARTY_DIM( employer_name );
CREATE INDEX XIE21FSC_PARTY_DIM ON 
FCFCORE.FSC_PARTY_DIM( match_code_individual );
CREATE INDEX XIE22FSC_PARTY_DIM ON 
FCFCORE.FSC_PARTY_DIM( match_code_organization );
CREATE INDEX XIE23FSC_PARTY_DIM ON 
FCFCORE.FSC_PARTY_DIM( employer_phone_number );
CREATE INDEX XIE7FSC_PARTY_DIM ON 
FCFCORE.FSC_PARTY_DIM( party_last_name );

CREATE TABLE FCFCORE.FSC_PARTY_PROFILE_FACT (
     PARTY_NUMBER         VARCHAR(50)     NOT NULL,
     MONTH_KEY            NUMERIC(6,0)     NOT NULL,
     AGGREGATE_ASSETS_AMOUNT NUMERIC(18,5),
     TRANSACTIONS_COUNT   NUMERIC(10,0),
     DEPOSITS_COUNT       NUMERIC(10,0),
     WITHDRAWALS_COUNT    NUMERIC(10,0),
     WIRES_COUNT          NUMERIC(10,0),
     CASH_TRANSACTIONS_COUNT NUMERIC(10,0),
     ACCOUNT_VALUE_AMOUNT NUMERIC(18,5),
     TOTAL_TRANSACTIONS_AMOUNT NUMERIC(18,5),
     TOTAL_CREDITS_AMOUNT NUMERIC(18,5),
     TOTAL_DEBITS_AMOUNT  NUMERIC(18,5),
     TOTAL_CASH_DEBITS_AMOUNT NUMERIC(18,5),
     TOTAL_CASH_CREDITS_AMOUNT NUMERIC(18,5),
     TOTAL_WIRE_CREDITS_AMOUNT NUMERIC(18,5),
     TOTAL_WIRE_DEBITS_AMOUNT NUMERIC(18,5),
     LARGEST_CREDIT_AMOUNT NUMERIC(18,5),
     LARGEST_DEBIT_AMOUNT NUMERIC(18,5),
     FUNDS_PAYMENT_SVCS_COUNT NUMERIC(10,0),
     FUNDS_TRANSFER_COUNT NUMERIC(10),
     MONETARY_INSTRUMENT_COUNT NUMERIC(10),
     PRIMARY KEY (PARTY_NUMBER, MONTH_KEY)
);

CREATE TABLE FCFCORE.FSC_PARTY_SEQUENCE (
     NEXT_SEQUENCE_ID     NUMERIC(12)     NOT NULL
);

CREATE TABLE FCFCORE.FSC_PEER_GROUP (
     PEER_GROUP_KEY       NUMERIC(12)     NOT NULL,
     PEER_GROUP_ID        VARCHAR(50),
     PEER_GROUP_NAME      VARCHAR(50),
     PEER_GROUP_DESC      VARCHAR(200),
     CHANGE_BEGIN_DATE    DATE,
     CHANGE_END_DATE      DATE     NOT NULL,
     CHANGE_CURRENT_IND   CHAR(1)     NOT NULL,
     PRIMARY KEY (PEER_GROUP_KEY)
);

CREATE TABLE FCFCORE.FSC_PEER_GROUP_PROFILE_HISTORY (
     HISTORY_PERIOD_CODE  CHAR(1)     NOT NULL,
     PEER_GROUP_ID        VARCHAR(50)     NOT NULL,
     PROFILE_GROUP_ID     VARCHAR(50)     NOT NULL,
     HISTORY_BEGIN_DATE_KEY NUMERIC(8)     NOT NULL,
     HISTORY_END_DATE_KEY NUMERIC(8)     NOT NULL,
     HISTORY_PERIOD_COUNT NUMERIC(5),
     ENTITY_COUNT         NUMERIC(5),
     ENTITY_SUFFICIENCY_COUNT NUMERIC(5),
     AVG_TRANS_COUNT      NUMERIC(10),
     AVG_TRANS_AMOUNT     NUMERIC(18,5),
     AVG_MAX_TRANS_AMOUNT NUMERIC(18,5),
     MAX_TRANS_COUNT      NUMERIC(10),
     MAX_TRANS_AMOUNT     NUMERIC(18,5),
     MAX_MAX_TRANS_AMOUNT NUMERIC(18,5),
     STD_TRANS_COUNT      NUMERIC(10),
     STD_TRANS_AMOUNT     NUMERIC(18,5),
     STD_MAX_TRANS_AMOUNT NUMERIC(18,5),
     AVG_LOG10_TRANS_COUNT NUMERIC(12,10),
     AVG_LOG10_TRANS_AMOUNT NUMERIC(12,10),
     AVG_LOG10_MAX_TRANS_AMOUNT NUMERIC(12,10),
     MAX_LOG10_TRANS_COUNT NUMERIC(12,10),
     MAX_LOG10_TRANS_AMOUNT NUMERIC(12,10),
     MAX_LOG10_MAX_TRANS_AMOUNT NUMERIC(12,10),
     STD_LOG10_TRANS_COUNT NUMERIC(12,10),
     STD_LOG10_TRANS_AMOUNT NUMERIC(12,10),
     STD_LOG10_MAX_TRANS_AMOUNT NUMERIC(12,10),
     PRIMARY KEY (HISTORY_PERIOD_CODE, PEER_GROUP_ID, PROFILE_GROUP_ID,
      HISTORY_BEGIN_DATE_KEY)
);

CREATE TABLE FCFCORE.FSC_PROFILE_GROUP (
     PROFILE_GROUP_KEY    NUMERIC(12)     NOT NULL,
     PROFILE_GROUP_ID     VARCHAR(50),
     PROFILE_GROUP_NAME   VARCHAR(50),
     PROFILE_GROUP_DESC   VARCHAR(200),
     CHANGE_BEGIN_DATE    DATE,
     CHANGE_END_DATE      DATE     NOT NULL,
     CHANGE_CURRENT_IND   CHAR(1)     NOT NULL,
     PRIMARY KEY (PROFILE_GROUP_KEY)
);

CREATE TABLE FCFCORE.FSC_PROFILE_SUMMARY_BRIDGE (
     PROFILE_GROUP_KEY    NUMERIC(12)     NOT NULL,
     SUMMARY_GROUP_KEY    NUMERIC(12)     NOT NULL,
     CHANGE_BEGIN_DATE    DATE,
     CHANGE_END_DATE      DATE     NOT NULL,
     CHANGE_CURRENT_IND   CHAR(1)     NOT NULL,
     PRIMARY KEY (PROFILE_GROUP_KEY, SUMMARY_GROUP_KEY)
);

CREATE TABLE FCFCORE.FSC_SUMMARY_GROUP (
     SUMMARY_GROUP_KEY    NUMERIC(12)     NOT NULL,
     SUMMARY_GROUP_ID     VARCHAR(50),
     SUMMARY_GROUP_NAME   VARCHAR(50),
     SUMMARY_GROUP_DESC   VARCHAR(200),
     CHANGE_BEGIN_DATE    DATE,
     CHANGE_END_DATE      DATE     NOT NULL,
     CHANGE_CURRENT_IND   CHAR(1)     NOT NULL,
     PRIMARY KEY (SUMMARY_GROUP_KEY)
);

CREATE TABLE FCFCORE.FSC_SUMMARY_TRANS_TYPE_BRIDGE (
     TRANSACTION_TYPE_KEY NUMERIC(12)     NOT NULL,
     SUMMARY_GROUP_KEY    NUMERIC(12)     NOT NULL,
     CHANGE_BEGIN_DATE    DATE,
     CHANGE_END_DATE      DATE     NOT NULL,
     CHANGE_CURRENT_IND   CHAR(1)     NOT NULL,
     PRIMARY KEY (TRANSACTION_TYPE_KEY, SUMMARY_GROUP_KEY)
);

CREATE TABLE FCFCORE.FSC_TIME_DIM (
     TIME_KEY             NUMERIC(6)     NOT NULL,
     TIME_HHMMSS          CHAR(6),
     TIME_HH              CHAR(2),
     TIME_MM              CHAR(2),
     TIME_SS              CHAR(2),
     TIME_AM_PM           CHAR(2),
     PRIMARY KEY (TIME_KEY)
);
CREATE INDEX XIE1FSC_TIME_DIM ON 
FCFCORE.FSC_TIME_DIM( time_hhmmss );

CREATE TABLE FCFCORE.FSC_TRANSACTION_DIM (
     TRANSACTION_KEY      NUMERIC(12)     NOT NULL,
     DATE_KEY             NUMERIC(8,0)     NOT NULL,
     TRANSACTION_REFERENCE_NUMBER VARCHAR(50)     NOT NULL,
     TRANSACTION_DESCRIPTION VARCHAR(255),
     SECURITY_NAME        VARCHAR(35),
     DEAL_NUMBER          VARCHAR(35),
     CHECK_NUMBER         VARCHAR(10),
     MECHANISM_ID         VARCHAR(40),
     PRIMARY KEY (TRANSACTION_KEY)
);
CREATE INDEX XIE1FSC_TRANSACTION_DIM ON 
FCFCORE.FSC_TRANSACTION_DIM( date_key );

CREATE TABLE FCFCORE.FSC_TRANSACTION_STATUS_DIM (
     TRANSACTION_STATUS_KEY NUMERIC(5)     NOT NULL,
     STATUS_DESC          VARCHAR(20),
     STATUS_REASON_DESC   VARCHAR(35),
     PRIMARY KEY (TRANSACTION_STATUS_KEY)
);
CREATE INDEX XIE1FSC_TRANSACTION_STATUS_DIM ON 
FCFCORE.FSC_TRANSACTION_STATUS_DIM( status_desc );
CREATE INDEX XIE2FSC_TRANSACTION_STATUS_DIM ON 
FCFCORE.FSC_TRANSACTION_STATUS_DIM( status_reason_desc );

CREATE TABLE FCFCORE.FSC_TRANSACTION_TYPE_DIM (
     TRANSACTION_TYPE_KEY NUMERIC(12)     NOT NULL,
     FUNDS_SECURITIES_CODE CHAR(1),
     FUNDS_SECURITIES_DESC VARCHAR(20),
     TRANSACTION_CDI_CODE CHAR(1),
     TRANSACTION_CDI_DESC VARCHAR(20),
     PRIMARY_MEDIUM_DESC  VARCHAR(30),
     SECONDARY_MEDIUM_DESC VARCHAR(30),
     TERTIARY_MEDIUM_DESC VARCHAR(30),
     MECHANISM_DESC       VARCHAR(20),
     PRIMARY KEY (TRANSACTION_TYPE_KEY)
);
CREATE INDEX XIE1FSC_TRANSACTION_TYPE_DIM ON 
FCFCORE.FSC_TRANSACTION_TYPE_DIM( funds_securities_code,funds_securities_desc );
CREATE INDEX XIE2FSC_TRANSACTION_TYPE_DIM ON 
FCFCORE.FSC_TRANSACTION_TYPE_DIM( transaction_cdi_code,transaction_cdi_desc );
CREATE INDEX XIE3FSC_TRANSACTION_TYPE_DIM ON 
FCFCORE.FSC_TRANSACTION_TYPE_DIM( primary_medium_desc,secondary_medium_desc );

CREATE TABLE FCFCORE.FSC_TRANSPORT_WATCH_LIST_DIM (
     TRANSPORT_WATCH_LIST_KEY NUMERIC(12)     NOT NULL,
     TRANSPORT_WATCH_LIST_NUMBER VARCHAR(35)     NOT NULL,
     WATCH_LIST_NAME      CHAR(4)     NOT NULL,
     TYPE_DESC            VARCHAR(20),
     PROGRAMS             VARCHAR(250),
     IDENTIFICATION_ID    VARCHAR(255),
     IDENTIFICATION_TYPE_DESC VARCHAR(255),
     ENTITY_NAME          VARCHAR(800),
     ENTITY_MODEL_TYPE    VARCHAR(200),
     ENTITY_OWNER_OPERATOR VARCHAR(200),
     ENTITY_FLAG          VARCHAR(200),
     ADDRESS              VARCHAR(750),
     CITY_NAME            VARCHAR(155),
     STATE_NAME           VARCHAR(50),
     COUNTRY_CODE         CHAR(3),
     COUNTRY_NAME         VARCHAR(255),
     CREATE_DATE          DATE,
     UPDATE_DATE          DATE,
     EXCLUDE_IND          CHAR(1)     NOT NULL,
     CHANGE_BEGIN_DATE    DATE     NOT NULL,
     CHANGE_END_DATE      DATE     NOT NULL,
     CHANGE_CURRENT_IND   CHAR(1)     NOT NULL,
     PRIMARY KEY (TRANSPORT_WATCH_LIST_KEY)
);
CREATE INDEX XIE1FSC_TRANSPORT_WATCH_LIST_D ON 
FCFCORE.FSC_TRANSPORT_WATCH_LIST_DIM( transport_watch_list_number );
CREATE INDEX XIE2FSC_TRANSPORT_WATCH_LIST_D ON 
FCFCORE.FSC_TRANSPORT_WATCH_LIST_DIM( watch_list_name );
