--------------------------------------------------------------
--------------------------------------------------------------
-- This script creates the FCFCORE, FCFKC, 
-- FCFBU1 schema owners.
--
-- ALL tablespaces for the Core and Knowledge Center
-- are created.
--
-- This script must be run by a user with DBA privileges.  
--
-- It is assumed that an appropriately sized temporary 
-- tablespace 'TEMP' already exists.
--
--Instructions:
-- 1. Run the postgres_users_and_tablespaces.sql file.
-- 2. Run postgres_core_ddl.sql which contains table creation statements for the
--    Core.
-- 3. Run postgres_knowledge_center_ddl.sql which contains table creation statements
--    for the Knowledge Center.
-- 4. Run postgres_create_grants.sql which will create the postgres_grants.sql file.
-- 5. Run postgres_grants.sql (or whatever you name the file that you spooled the
--    results of #4 to). If you didn't use SQL Plus and instead used a GUI tool, just
--    run the results set of #4 to add the required grants.
-- 6. Run postgres_bu1_ddl.sql
--------------------------------------------------------------
--------------------------------------------------------------

--FCFKC is the schema owner for the 'Knowledge Center' tables.  
--Both the Front-End and data management process use this account for 
--part of the ETL process.  
CREATE USER FCFKC
	PASSWORD 'FCFKC1';

CREATE USER FCFBU1
	PASSWORD 'FCFBU11';

CREATE USER FCFCORE
	PASSWORD 'FCFCORE1';

--Core Tablespace
CREATE TABLESPACE CORE_DATA01
	OWNER FCFCORE
	LOCATION '/<mount point>/<directory>';

CREATE TABLESPACE CORE_INDEX01
	OWNER FCFCORE
	LOCATION '/<mount point>/<directory>';

--Knowledge Center Tablespaces 
CREATE TABLESPACE KC_DATA01
	OWNER FCFKC
	LOCATION '/<mount point>/<directory>';

CREATE TABLESPACE KC_INDEX01
	OWNER FCFKC
	LOCATION '/<mount point>/<directory>';

CREATE SCHEMA FCFCORE AUTHORIZATION FCFCORE;
CREATE SCHEMA FCFKC AUTHORIZATION FCFKC;
CREATE SCHEMA FCFBU1 AUTHORIZATION FCFBU1;

GRANT ALL PRIVILEGES ON ALL TABLES IN SCHEMA FCFCORE TO FCFCORE;
GRANT ALL PRIVILEGES ON ALL TABLES IN SCHEMA FCFKC TO FCFKC;
GRANT SELECT ON ALL TABLES IN SCHEMA FCFBU1 TO FCFBU1;