-- Update FSC_EXT_PARTY_ACCOUNT_DIM, add SCD2 columns
USE [LOCALDB]
GO

ALTER TABLE SCHCORE.FSC_EXT_PARTY_ACCOUNT_DIM
ADD
       change_begin_date    DATETIME DEFAULT GETDATE() NOT NULL,
       change_end_date      DATETIME DEFAULT '5999-01-01T00:00:00' NOT NULL,
       change_current_ind   CHAR(1) DEFAULT 'Y' NOT NULL;
GO

ALTER VIEW SCHBU1.FSC_EXT_PARTY_ACCOUNT_DIM AS SELECT * FROM SCHCORE.FSC_EXT_PARTY_ACCOUNT_DIM
GO


-- Recreate the Alert Triage Datamart to contain entity numbers

---- Drop Datamart Views 
DROP VIEW SCHBU1.FSK_ALERT_TX_AGG
GO

DROP VIEW SCHBU1.FSK_ENTITY_TX_AGG
GO

DROP VIEW SCHBU1.FSK_ALERTED_ENTITY
GO

DROP VIEW SCHBU1.FSK_ENTITY_TRANSACTION
GO

DROP VIEW SCHBU1.FSK_ALERT_TRANSACTION
GO


---- Drop Datamart Tables
ALTER TABLE SCHKC.FSK_ALERT_TRANSACTION
DROP CONSTRAINT R_358
GO

ALTER TABLE SCHKC.FSK_ALERT_TRANSACTION
DROP CONSTRAINT R_370
GO

ALTER TABLE SCHKC.FSK_ALERT_TX_AGG
DROP CONSTRAINT R_365
GO

ALTER TABLE SCHKC.FSK_ENTITY_TRANSACTION
DROP CONSTRAINT R_404
GO

ALTER TABLE SCHKC.FSK_ENTITY_TX_AGG
DROP CONSTRAINT R_369
GO

DROP TABLE SCHKC.FSK_ENTITY_TX_AGG
GO

DROP TABLE SCHKC.FSK_ALERT_TX_AGG
GO

DROP TABLE SCHKC.FSK_ENTITY_TRANSACTION
GO

---- DROP TABLE SCHKC.FSK_ALERTED_ENTITY
---- GO

DROP TABLE SCHKC.FSK_ALERT_TRANSACTION
GO

---- Drop indexes constraint and column
DROP INDEX XAK1FSK_ALERTED_ENTITY ON SCHKC.FSK_ALERTED_ENTITY;
ALTER TABLE SCHKC.FSK_ALERTED_ENTITY DROP CONSTRAINT XPKFSK_ALERTED_ENTITY;
ALTER TABLE SCHKC.FSK_ALERTED_ENTITY DROP COLUMN alerted_entity_key;
ALTER TABLE SCHKC.FSK_ALERTED_ENTITY ALTER COLUMN alerted_entity_number VARCHAR(50) NOT NULL;

CREATE UNIQUE  INDEX XAK1FSK_ALERTED_ENTITY ON SCHKC.FSK_ALERTED_ENTITY
(
	alerted_entity_number  ASC, 	alerted_entity_level_code ASC
)
GO

CREATE TABLE SCHKC.FSK_ALERT_TRANSACTION
(
	fsk_alert_transaction_pk DECIMAL(22) NOT NULL ,
	alerted_entity_level_code CHAR(3)  ,
	alerted_entity_number VARCHAR(50)  ,
	alert_id             DECIMAL(12)  ,
	transaction_id       VARCHAR(50)  ,
	transaction_amt      NUMERIC(15,3)  ,
	transaction_cdi_desc VARCHAR(30)  ,
	primary_medium_desc  VARCHAR(30)  ,
	secondary_medium_desc VARCHAR(30)  ,
	transaction_date     DATETIME  ,
	transaction_mechanism VARCHAR(50)  ,
	account_number       VARCHAR(50)  ,
	beneficiary_name     VARCHAR(200)  ,
	associate_name       VARCHAR(250)  ,
	Branch_name          VARCHAR(100)  ,
	transaction_desc     VARCHAR(255)  ,
	transaction_status   VARCHAR(20)  ,
	triggering_indicator_cd VARCHAR(3)  ,
	created_timestamp    DATETIME  ,
	date_key             DECIMAL(8)  ,
	time_key             DECIMAL(6)  ,
	CONSTRAINT XPKFSK_ALERT_TRANSACTION PRIMARY KEY CLUSTERED (fsk_alert_transaction_pk))
GO

CREATE INDEX XIF2FSK_ALERT_TRANSACTION ON SCHKC.FSK_ALERT_TRANSACTION
(
	alert_id ASC
)
GO

CREATE INDEX XIF3FSK_ALERT_TRANSACTION ON SCHKC.FSK_ALERT_TRANSACTION
(
	alerted_entity_level_code ASC, 	alerted_entity_number  ASC
)
GO

CREATE TABLE SCHKC.FSK_ALERT_TX_AGG
(
	fsk_alert_tx_agg_pk  DECIMAL(12) NOT NULL ,
	alert_id             DECIMAL(12)  ,
	aggregate_type_code  VARCHAR(35)  ,
	group_code           VARCHAR(30)  ,
	group_desc           VARCHAR(30)  ,
	aggregate_amt        DECIMAL(15,3)  ,
	created_timestamp    DATETIME  ,
	CONSTRAINT XPKFSK_ALERT_TX_AGG PRIMARY KEY CLUSTERED (fsk_alert_tx_agg_pk))
GO

CREATE INDEX XIF1FSK_ALERT_TX_AGG ON SCHKC.FSK_ALERT_TX_AGG
(
	alert_id ASC
)
GO

CREATE TABLE SCHKC.FSK_ENTITY_TRANSACTION
(
	fsk_entity_transaction_pk DECIMAL(22) NOT NULL ,
	alerted_entity_level_code CHAR(3)  ,
        alerted_entity_number VARCHAR(50)  ,
	transaction_id       VARCHAR(50)  ,
	transaction_amt      NUMERIC(15,3)  ,
	transaction_cdi_desc VARCHAR(30)  ,
	primary_medium_desc  VARCHAR(30)  ,
	secondary_medium_desc VARCHAR(30)  ,
	transaction_date     DATETIME  ,
	transaction_mechanism VARCHAR(50)  ,
	account_number       VARCHAR(50)  ,
	beneficiary_name     VARCHAR(200)  ,
	associate_name       VARCHAR(250)  ,
	Branch_name          VARCHAR(100)  ,
	transaction_desc     VARCHAR(255)  ,
	transaction_status   VARCHAR(20)  ,
	created_timestamp    DATETIME  ,
	date_key             DECIMAL(8)  ,
	time_key             DECIMAL(6)  ,
	household_number     VARCHAR(50)  ,
	CONSTRAINT XPKFSK_ENTITY_TRANSACTION PRIMARY KEY CLUSTERED (fsk_entity_transaction_pk))
GO

CREATE INDEX XIF1FSK_ENTITY_TRANSACTION ON SCHKC.FSK_ENTITY_TRANSACTION
(
	alerted_entity_level_code ASC, 	alerted_entity_number ASC
)
GO

CREATE TABLE SCHKC.FSK_ENTITY_TX_AGG
(
	fsk_entity_tx_agg_pk DECIMAL(12) NOT NULL ,
	alerted_entity_level_code CHAR(3)  ,
        alerted_entity_number VARCHAR(50)  ,
	aggregate_type_code  VARCHAR(4)  ,
	group_code           VARCHAR(50)  ,
	group_desc           VARCHAR(50)  ,
	aggregate_amt        DECIMAL(15,3)  ,
	created_timestamp    DATETIME  ,
	CONSTRAINT XPKFSK_ENTITY_TX_AGG PRIMARY KEY CLUSTERED (fsk_entity_tx_agg_pk))
GO

CREATE INDEX XIF1FSK_ENTITY_TX_AGG ON SCHKC.FSK_ENTITY_TX_AGG
(
	alerted_entity_level_code ASC, 	alerted_entity_number ASC
)
GO

---- Create Datamart Views 
CREATE  VIEW SCHBU1.FSK_ALERT_TX_AGG AS SELECT * FROM SCHKC.FSK_ALERT_TX_AGG
GO

CREATE  VIEW SCHBU1.FSK_ENTITY_TX_AGG AS SELECT * FROM SCHKC.FSK_ENTITY_TX_AGG
GO

CREATE  VIEW SCHBU1.FSK_ALERTED_ENTITY AS SELECT * FROM SCHKC.FSK_ALERTED_ENTITY
GO

CREATE  VIEW SCHBU1.FSK_ALERT_TRANSACTION AS SELECT * FROM SCHKC.FSK_ALERT_TRANSACTION
GO

CREATE  VIEW SCHBU1.FSK_ENTITY_TRANSACTION AS SELECT * FROM SCHKC.FSK_ENTITY_TRANSACTION
GO

-- modify FSC_PARTY_DIM for Beneficial Ownership support
USE [LOCALDB]
GO
ALTER TABLE SCHCORE.FSC_PARTY_DIM
ADD
       ben_own_exempt_ind   CHAR(1) DEFAULT 'N' NULL;
GO
ALTER VIEW SCHBU1.FSC_PARTY_DIM AS SELECT * FROM SCHCORE.FSC_PARTY_DIM
GO

-- modify FSC_ACCOUNT_DIM for Beneficial Ownership support
USE [LOCALDB]
GO
ALTER TABLE SCHCORE.FSC_ACCOUNT_DIM
ADD
       opened_by_party_number       VARCHAR(50) NULL ,
       opened_by_party_name         VARCHAR(200) NULL ,
       opened_by_party_title        VARCHAR(50) NULL;
GO
ALTER VIEW SCHBU1.FSC_ACCOUNT_DIM AS SELECT * FROM SCHCORE.FSC_ACCOUNT_DIM
GO

ALTER TABLE SCHKC.FSK_CASE ALTER COLUMN case_description VARCHAR(100)
GO
ALTER VIEW SCHBU1.FSK_CASE AS SELECT * FROM SCHKC.FSK_CASE
GO
