USE [LOCALDB]
GO

CREATE TABLE SCHKC.FSK_SEGMENT (
  entity_segment_key  DECIMAL(12) NOT NULL,
  entity_segment_id   DECIMAL(12) NOT NULL,
  segment_name        NVARCHAR(50),
  segment_description NVARCHAR(100),
  lstupdate_user      VARCHAR(60),
  logical_delete_ind  CHAR(1),
  active_ind          CHAR(1),
  change_begin_date   DATETIME DEFAULT GETDATE() NOT NULL,
  change_end_date     DATETIME DEFAULT '5999-01-01T00:00:00' NOT NULL,
  change_current_ind  CHAR(1) DEFAULT 'Y' NOT NULL,
  CONSTRAINT XPKFSK_SEGMENT PRIMARY KEY CLUSTERED (entity_segment_key)
)
GO

ALTER TABLE SCHCORE.FSC_ACCOUNT_DIM   ADD entity_segment_id DECIMAL(12) NULL
GO
ALTER TABLE SCHCORE.FSC_PARTY_DIM     ADD entity_segment_id DECIMAL(12) NULL
GO
ALTER TABLE SCHKC.FSK_ALERT           ADD entity_segment_id DECIMAL(12) NULL
GO
ALTER TABLE SCHKC.FSK_ALERTED_ENTITY  ADD alerted_entity_segment_id DECIMAL(12) NULL
GO
ALTER TABLE SCHKC.FSK_ALERTED_ENTITY  ALTER COLUMN alerted_entity_name NVARCHAR(200)
GO
ALTER TABLE SCHKC.FSK_ALERTED_ENTITY  DROP COLUMN owner_userid
GO


CREATE VIEW SCHBU1.FSK_SEGMENT AS SELECT * FROM SCHKC.FSK_SEGMENT
GO
ALTER VIEW SCHBU1.FSC_PARTY_DIM AS SELECT * FROM SCHCORE.FSC_PARTY_DIM
GO
ALTER VIEW SCHBU1.FSK_ALERTED_ENTITY AS SELECT * FROM SCHKC.FSK_ALERTED_ENTITY
GO


ALTER TABLE SCHKC.FSK_SCENARIO_PARAMETER DROP CONSTRAINT  PK_SCENARIO_PARAMETER;
GO
ALTER TABLE SCHKC.FSK_SCENARIO_PARAMETER
ADD
       btl_parm_value      NVARCHAR(1024) NULL ,
       entity_segment_id   DECIMAL(12) DEFAULT -1 NOT NULL
GO
ALTER TABLE SCHKC.FSK_SCENARIO_PARAMETER ADD CONSTRAINT PK_SCENARIO_PARAMETER PRIMARY KEY CLUSTERED (scenario_id, parm_name, entity_segment_id)
GO	
ALTER VIEW SCHBU1.FSK_SCENARIO_PARAMETER AS SELECT * FROM SCHKC.FSK_SCENARIO_PARAMETER
GO

ALTER TABLE SCHKC.FSK_SCENARIO
ADD
       segments_enabled_ind CHAR(1) DEFAULT 'N' NULL,
       btl_enabled_ind      CHAR(1) DEFAULT 'N' NULL
GO
ALTER VIEW SCHBU1.FSK_SCENARIO AS SELECT * FROM SCHKC.FSK_SCENARIO
GO


-- Add queues

CREATE TABLE SCHKC.FSK_QUEUE (
  queue_key           DECIMAL(12) NOT NULL,
  queue_code          VARCHAR(32) NOT NULL,
  queue_description   NVARCHAR(100),
  access_role_name    VARCHAR(60) NOT NULL,
  lstupdate_user      VARCHAR(60),
  logical_delete_ind  CHAR(1),
  active_ind          CHAR(1),
  change_begin_date   DATETIME DEFAULT GETDATE() NOT NULL,
  change_end_date     DATETIME DEFAULT '5999-01-01T00:00:00' NOT NULL,
  change_current_ind  CHAR(1) DEFAULT 'Y' NOT NULL,
  CONSTRAINT XPKFSK_QUEUE PRIMARY KEY CLUSTERED (queue_key)
)
GO
CREATE INDEX XIE1FSK_QUEUE ON SCHKC.FSK_QUEUE
(
	queue_code ASC
)
GO

ALTER TABLE SCHKC.FSK_ALERT           ADD queue_code         VARCHAR(32) NULL
GO
ALTER TABLE SCHKC.FSK_CASE            ADD queue_code         VARCHAR(32) NULL
GO
ALTER TABLE SCHKC.FSK_CDD_REVIEW      ADD queue_code         VARCHAR(32) NULL
GO
ALTER TABLE SCHKC.FSK_RC_REPORT       ADD queue_code         VARCHAR(32) NULL
GO
ALTER TABLE SCHKC.FSK_RC_REPORT       ADD employee_ind  CHAR(1) DEFAULT 'N' NULL
GO
CREATE INDEX XEIQFSK_ALERT ON SCHKC.FSK_ALERT (queue_code ASC)
GO
CREATE INDEX XEIQFSK_CASE ON SCHKC.FSK_CASE (queue_code  ASC)
GO
CREATE INDEX XEIQFSK_CDD_REVIEW ON SCHKC.FSK_CDD_REVIEW (queue_code  ASC)
GO
CREATE INDEX XEIQFSK_RC_REPORT ON SCHKC.FSK_RC_REPORT (queue_code  ASC)
GO

CREATE VIEW SCHBU1.FSK_QUEUE AS SELECT * FROM SCHKC.FSK_QUEUE
GO
ALTER VIEW SCHBU1.FSK_CDD_REVIEW AS SELECT * FROM SCHKC.FSK_CDD_REVIEW
GO
ALTER VIEW SCHBU1.FSK_RC_REPORT AS SELECT * FROM SCHKC.FSK_RC_REPORT
GO

CREATE TABLE SCHKC.FSK_ENTITY_QUEUE (
  queue_code                VARCHAR(32) NULL,
	alerted_entity_level_code CHAR(3) NOT NULL ,
	alerted_entity_number     VARCHAR(50) NOT NULL,
	owner_userid              VARCHAR(60) NULL
)
GO
CREATE INDEX XEI1FSK_ENTITY_QUEUE ON SCHKC.FSK_ENTITY_QUEUE (alerted_entity_level_code, alerted_entity_number, queue_code, owner_userid)
GO
CREATE VIEW SCHBU1.FSK_ENTITY_QUEUE AS SELECT * FROM SCHKC.FSK_ENTITY_QUEUE
GO

ALTER TABLE SCHKC.FSK_CASE ADD case_close_date DATETIME NULL
GO
ALTER VIEW SCHBU1.FSK_CASE AS SELECT * FROM SCHKC.FSK_CASE
GO

CREATE TABLE SCHKC.FSK_RC_REPORT_ENTITY_BRIDGE (
	report_key           DECIMAL(12) NOT NULL ,
	parent_level_code    VARCHAR(32) NOT NULL ,
	parent_key           DECIMAL(12) NOT NULL ,
	entity_level_code    VARCHAR(32) NOT NULL ,
	entity_key           DECIMAL(12) NOT NULL ,
	ui_json              NVARCHAR(MAX) NULL ,
  CONSTRAINT XPKFSK_RPT_ENT_BR PRIMARY KEY CLUSTERED (report_key, parent_key, entity_key)
)
GO
ALTER TABLE SCHKC.FSK_RC_REPORT_ENTITY_BRIDGE
	ADD CONSTRAINT FSK_RC_ENT_BRIDGE_RPT FOREIGN KEY (report_key) REFERENCES SCHKC.FSK_RC_REPORT (report_key)
GO
CREATE VIEW SCHBU1.FSK_RC_REPORT_ENTITY_BRIDGE AS SELECT * FROM SCHKC.FSK_RC_REPORT_ENTITY_BRIDGE
GO

ALTER TABLE SCHKC.FSK_ALERT ALTER COLUMN alerted_entity_name VARCHAR(200)
GO
ALTER TABLE SCHKC.FSK_ALERT alter column primary_entity_name VARCHAR(200)
GO
ALTER TABLE SCHKC.FSK_CASE_ENTITY alter column entity_name VARCHAR(200)
GO
ALTER TABLE SCHKC.FSK_RC_REPORT_ENTITY alter column entity_name VARCHAR(200)
GO
ALTER TABLE SCHKC.FSK_RC_REPORT_ENTITY_INFO alter column entity_name VARCHAR(200)
GO
ALTER TABLE SCHCORE.FSC_BANK_DIM alter column bank_name VARCHAR(200)
GO
ALTER TABLE SCHCORE.FSC_ASSOCIATE_DIM alter column associate_last_name VARCHAR(200)
GO
ALTER TABLE SCHCORE.FSC_HOUSEHOLD_DIM alter column head_of_household_name VARCHAR(200)
GO
ALTER TABLE SCHCORE.FSC_ACCOUNT_DIM alter column account_name VARCHAR(200)
GO

ALTER VIEW SCHBU1.FSK_ALERT AS SELECT * FROM SCHKC.FSK_ALERT
GO
ALTER VIEW SCHBU1.FSK_CASE_ENTITY AS SELECT * FROM SCHKC.FSK_CASE_ENTITY
GO
ALTER VIEW SCHBU1.FSK_RC_REPORT_ENTITY AS SELECT * from SCHKC.FSK_RC_REPORT_ENTITY
GO
ALTER VIEW SCHBU1.FSK_RC_REPORT_ENTITY_INFO AS SELECT * from SCHKC.FSK_RC_REPORT_ENTITY_INFO
GO
ALTER VIEW SCHBU1.FSC_BANK_DIM AS SELECT * FROM SCHCORE.FSC_BANK_DIM
GO
ALTER VIEW SCHBU1.FSC_ASSOCIATE_DIM AS SELECT * FROM SCHCORE.FSC_ASSOCIATE_DIM
GO
ALTER VIEW SCHBU1.FSC_HOUSEHOLD_DIM AS SELECT * FROM SCHCORE.FSC_HOUSEHOLD_DIM
GO
ALTER VIEW SCHBU1.FSC_ACCOUNT_DIM AS SELECT * FROM SCHCORE.FSC_ACCOUNT_DIM
GO

ALTER VIEW SCHBU1.FSC_TRANSACTION_VIEW (account_key, account_number, branch_key, date_key, time_key, transaction_type_key, transaction_key,
currency_amount, transaction_reference_number, transaction_description, security_name, deal_number, bank_name_1, role_desc_1, bank_name_2,
role_desc_2, bank_name_3, role_desc_3, bank_name_4, role_desc_4, bank_name_5, role_desc_5, bank_name_6, role_desc_6) AS SELECT CFF.account_key,
ACC.account_number, CFF.branch_key, CFF.date_key, CFF.time_key, CFF.transaction_type_key, CFF.transaction_key, CFF.currency_amount, TD.transaction_reference_number,
TD.transaction_description, TD.security_name, TD.deal_number, BD.BANK_NAME AS bank_name_1, CFBB.Role_Desc AS role_desc_1, BD2.BANK_NAME AS bank_name_2,
 CFBB2.Role_Desc AS role_desc_2, BD3.BANK_NAME AS bank_name_3, CFBB3.Role_Desc AS role_desc_3, BD4.BANK_NAME AS bank_name_4, CFBB4.Role_Desc AS role_desc_4,
BD5.BANK_NAME AS bank_name_5, CFBB5.Role_Desc AS role_desc_5, BD6.BANK_NAME AS bank_name_6, CFBB6.Role_Desc AS role_desc_6
FROM SCHCORE.FSC_CASH_FLOW_FACT CFF JOIN SCHCORE.FSC_TRANSACTION_DIM TD ON CFF.transaction_key = TD.transaction_key
JOIN SCHCORE.FSC_ACCOUNT_DIM ACC ON CFF.account_key = ACC.account_key  LEFT JOIN SCHCORE.FSC_CASH_FLOW_BANK_BRIDGE CFBB
ON CFF.TRANSACTION_KEY = CFBB.TRANSACTION_KEY AND CFBB.SEQUENCE_NUMBER = 1 LEFT JOIN SCHCORE.FSC_BANK_DIM BD
ON CFBB.BANK_KEY = BD.BANK_KEY LEFT JOIN SCHCORE.FSC_CASH_FLOW_BANK_BRIDGE CFBB2 ON CFF.TRANSACTION_KEY = CFBB2.TRANSACTION_KEY
AND CFBB2.SEQUENCE_NUMBER = 2  LEFT JOIN SCHCORE.FSC_BANK_DIM BD2 ON CFBB2.BANK_KEY = BD2.BANK_KEY
LEFT JOIN SCHCORE.FSC_CASH_FLOW_BANK_BRIDGE CFBB3 ON CFF.TRANSACTION_KEY = CFBB3.TRANSACTION_KEY AND CFBB3.SEQUENCE_NUMBER = 3
LEFT JOIN SCHCORE.FSC_BANK_DIM BD3 ON CFBB3.BANK_KEY = BD3.BANK_KEY  LEFT JOIN SCHCORE.FSC_CASH_FLOW_BANK_BRIDGE CFBB4
ON CFF.TRANSACTION_KEY = CFBB4.TRANSACTION_KEY AND CFBB4.SEQUENCE_NUMBER = 4 LEFT JOIN SCHCORE.FSC_BANK_DIM BD4
ON CFBB4.BANK_KEY = BD4.BANK_KEY  LEFT JOIN SCHCORE.FSC_CASH_FLOW_BANK_BRIDGE CFBB5 ON CFF.TRANSACTION_KEY = CFBB5.TRANSACTION_KEY
AND CFBB5.SEQUENCE_NUMBER = 5  LEFT JOIN SCHCORE.FSC_BANK_DIM BD5 ON CFBB5.BANK_KEY = BD5.BANK_KEY
LEFT JOIN SCHCORE.FSC_CASH_FLOW_BANK_BRIDGE CFBB6 ON CFF.TRANSACTION_KEY = CFBB6.TRANSACTION_KEY AND CFBB6.SEQUENCE_NUMBER = 6
LEFT JOIN SCHCORE.FSC_BANK_DIM BD6 ON CFBB6.BANK_KEY = BD6.BANK_KEY
UNION ALL(SELECT AEF.account_key,
ACC.account_number, AEF.branch_key, AEF.date_key, AEF.time_key, AEF.transaction_type_key, AEF.transaction_key, 0, TD.transaction_reference_number, TD.transaction_description,
TD.security_name, TD.deal_number, '', '', '', '', '', '', '', '', '', '', '', '' FROM SCHCORE.FSC_ACCOUNT_EVENT_FACT AEF JOIN SCHCORE.FSC_ACCOUNT_DIM ACC
ON AEF.account_key = ACC.account_key  JOIN SCHCORE.FSC_TRANSACTION_DIM TD ON AEF.transaction_key = TD.transaction_key
UNION ALL
(SELECT ATF.account_key, ACC.account_number, ATF.branch_key, ATF.trade_date_key AS date_key,
ATF.execution_time_key AS time_key, ATF.transaction_type_key, ATF.transaction_key, ATF.principal_amount AS currency_amount, TD.transaction_reference_number,
TD.transaction_description, TD.security_name, TD.deal_number, '', '', '', '', '', '', '', '', '', '', '', '' FROM SCHCORE.FSC_ACCOUNT_TRADE_FACT ATF
JOIN SCHCORE.FSC_ACCOUNT_DIM ACC ON ATF.account_key = ACC.account_key  JOIN SCHCORE.FSC_TRANSACTION_DIM TD
ON ATF.transaction_key = TD.transaction_key))
GO