--------------------------------------------------------------
--------------------------------------------------------------
--KNOWLEDGE CENTER TABLE, INDEX, AND TABLESPACE CREATION TEMPLATE
--------------------------------------------------------------
--This script is a template for creating the tablespaces, tables,
--indexes, views, and constraints required for the 'KNOWLEDGE CENTER' AML
--schema.
--
--This script is only a template.  It must be customized
--to the physical environment and volume of data expected.
--
--This script must be run as SCHKC.
--
--This script assumes that two multibank segments are being
--created (SCHBU1). If more segments
--are required then this script must be modified to create each of
--the individual segment schema owner's objects in the additional
--segment schema. We suggest that you copy the DDL for
--SCHBU1, substitute your schema name, and run
--the additional statments for each segment added.
--------------------------------------------------------------
--------------------------------------------------------------


----------------------------------------------------------------------------
--Create sequences in each multibank segment schema. Additional sequences 
--will be needed if this script is customized to add additional multibank segments.
----------------------------------------------------------------------------
USE [LOCALDB]
GO

CREATE TABLE SCHKC.FSK_SEQ
(
	next_sequence_id     DECIMAL(12) NOT NULL )
GO

insert into SCHKC.FSK_SEQ ( next_sequence_id ) values ( 11000 )
GO

----------------------------------------------------------------------------
--Create table statements
----------------------------------------------------------------------------

CREATE TABLE SCHKC.FSK_ACCOUNT_EVENT_ALERT
(
	alert_id             DECIMAL(12) NOT NULL ,
	transaction_key      DECIMAL(12) NOT NULL ,
	account_key          DECIMAL(12) NOT NULL ,
	date_key             DECIMAL(8,0) NOT NULL ,
	transaction_type_key DECIMAL(12) NOT NULL ,
	time_key             DECIMAL(6) NOT NULL ,
	country_key          DECIMAL(5) NOT NULL ,
	branch_key           DECIMAL(12) NOT NULL ,
	transaction_status_key DECIMAL(5) NOT NULL ,
	trigger_ind          CHAR(1)  ,
	CONSTRAINT XPKFSK_ACCOUNT_EVENT_ALERT PRIMARY KEY CLUSTERED (alert_id,transaction_key))
GO

CREATE INDEX XIE1FSK_ACCOUNT_EVENT_ALERT ON SCHKC.FSK_ACCOUNT_EVENT_ALERT
(
	account_key ASC
)
GO

CREATE INDEX XIE2FSK_ACCOUNT_EVENT_ALERT ON SCHKC.FSK_ACCOUNT_EVENT_ALERT
(
	transaction_key ASC
)
GO

CREATE INDEX XIE3FSK_ACCOUNT_EVENT_ALERT ON SCHKC.FSK_ACCOUNT_EVENT_ALERT
(
	transaction_type_key ASC
)
GO

CREATE INDEX XIE4FSK_ACCOUNT_EVENT_ALERT ON SCHKC.FSK_ACCOUNT_EVENT_ALERT
(
	branch_key ASC
)
GO

CREATE INDEX XIE5FSK_ACCOUNT_EVENT_ALERT ON SCHKC.FSK_ACCOUNT_EVENT_ALERT
(
	date_key ASC
)
GO

CREATE TABLE SCHKC.FSK_ACCOUNT_KEYS_ACC
(
	alert_id             DECIMAL(12) NOT NULL ,
	account_key          DECIMAL(12) NOT NULL ,
	run_date             DATETIME  ,
	CONSTRAINT XPKFSK_ACCOUNT_KEYS_ACC PRIMARY KEY CLUSTERED (alert_id,account_key))
GO

CREATE TABLE SCHKC.FSK_ACCOUNT_KEYS_ASC
(
	alert_id             DECIMAL(12) NOT NULL ,
	account_key          DECIMAL(12) NOT NULL ,
	run_date             DATETIME  ,
	CONSTRAINT XPKFSK_ACCOUNT_KEYS_ASC PRIMARY KEY CLUSTERED (alert_id,account_key))
GO

CREATE INDEX XIE1FSK_ACCOUNT_KEYS_ASC ON SCHKC.FSK_ACCOUNT_KEYS_ASC
(
	account_key ASC
)
GO

CREATE TABLE SCHKC.FSK_ACCOUNT_KEYS_HHD
(
	alert_id             DECIMAL(12) NOT NULL ,
	account_key          DECIMAL(12) NOT NULL ,
	run_date             DATETIME  ,
	CONSTRAINT XPKFSK_ACCOUNT_KEYS_HHD PRIMARY KEY CLUSTERED (alert_id,account_key))
GO

CREATE INDEX XIEFSK_ACCOUNT_KEYS_HHD ON SCHKC.FSK_ACCOUNT_KEYS_HHD
(
	account_key ASC
)
GO

CREATE TABLE SCHKC.FSK_ACCOUNT_KEYS_PTY
(
	alert_id             DECIMAL(12) NOT NULL ,
	account_key          DECIMAL(12) NOT NULL ,
	run_date             DATETIME  ,
	CONSTRAINT XPKFSK_ACCOUNT_KEYS_PTY PRIMARY KEY CLUSTERED (alert_id,account_key))
GO

CREATE INDEX XIE1FSK_ACCOUNT_KEYS_PTY ON SCHKC.FSK_ACCOUNT_KEYS_PTY
(
	account_key ASC
)
GO

CREATE TABLE SCHKC.FSK_ACCOUNT_PROFILE_ALERT
(
	alert_id             DECIMAL(12) NOT NULL ,
	month_key            DECIMAL(6,0) NOT NULL ,
	account_number       VARCHAR(50) NOT NULL ,
	transactions_count   DECIMAL(10,0)  ,
	deposits_count       DECIMAL(10,0)  ,
	withdrawals_count    DECIMAL(10,0)  ,
	wires_count          DECIMAL(10,0)  ,
	cash_transactions_count DECIMAL(10,0)  ,
	account_value_amount DECIMAL(18,5)  ,
	total_transactions_amount DECIMAL(18,5)  ,
	total_credits_amount DECIMAL(18,5)  ,
	total_debits_amount  DECIMAL(18,5)  ,
	total_cash_debits_amount DECIMAL(18,5)  ,
	total_cash_credits_amount DECIMAL(18,5)  ,
	total_wire_credits_amount DECIMAL(18,5)  ,
	total_wire_debits_amount DECIMAL(18,5)  ,
	beginning_balance_amount DECIMAL(18,5)  ,
	average_daily_balance_amount DECIMAL(18,5)  ,
	ending_cash_balance_amount DECIMAL(18,5)  ,
	max_account_value_amount DECIMAL(18,5)  ,
	min_account_value_amount DECIMAL(18,5)  ,
	avg_account_value_amount DECIMAL(18,5)  ,
	cust_initiated_trans_count DECIMAL(10)  ,
	largest_credit_amount DECIMAL(18,5)  ,
	largest_debit_amount DECIMAL(18,5)  ,
	CONSTRAINT XPKFSK_ACCOUNT_PROFILE_ALERT PRIMARY KEY CLUSTERED (alert_id,month_key,account_number))
GO

CREATE TABLE SCHKC.FSK_ACCOUNT_TRADE_ALERT
(
	alert_id             DECIMAL(12) NOT NULL ,
	transaction_key      DECIMAL(12) NOT NULL ,
	account_key          DECIMAL(12) NOT NULL ,
	branch_key           DECIMAL(12)  ,
	transaction_type_key DECIMAL(12)  ,
	transaction_status_key DECIMAL(5)  ,
	trade_date_key       DECIMAL(8,0)  ,
	associate_key        DECIMAL(12)  ,
	execution_time_key   DECIMAL(6)  ,
	posted_date_key      DECIMAL(8) NOT NULL ,
	settlement_date_key  DECIMAL(8,0) NOT NULL ,
	quantity_executed    DECIMAL(15,5)  ,
	execution_price      DECIMAL(10,5)  ,
	transaction_currency_key DECIMAL(5)  ,
	principal_amount_in_txn_ccy DECIMAL(15,5)  ,
	principal_amount     DECIMAL(15,5)  ,
	principal_amount_in_acct_ccy DECIMAL(15,5) NOT NULL ,
	trigger_ind          CHAR(1)  ,
	CONSTRAINT XPKFSK_ACCOUNT_TRADE_ALERT PRIMARY KEY CLUSTERED (alert_id,transaction_key))
GO

CREATE INDEX XIE1FSK_ACCOUNT_TRADE_ALERT ON SCHKC.FSK_ACCOUNT_TRADE_ALERT
(
	account_key ASC
)
GO

CREATE INDEX XIE2FSK_ACCOUNT_TRADE_ALERT ON SCHKC.FSK_ACCOUNT_TRADE_ALERT
(
	transaction_key ASC, 	transaction_type_key ASC
)
GO

CREATE INDEX XIE3FSK_ACCOUNT_TRADE_ALERT ON SCHKC.FSK_ACCOUNT_TRADE_ALERT
(
	associate_key ASC
)
GO

CREATE TABLE SCHKC.FSK_ALERT_CASE
(
	case_id              DECIMAL(12) NOT NULL ,
	alert_id             DECIMAL(12) NOT NULL ,
	lstupdate_user_id    VARCHAR(60) NOT NULL ,
	lstupdate_date       DATETIME NOT NULL ,
	version_number       DECIMAL(10) NOT NULL ,
	CONSTRAINT XPKFSK_ALERT_CASE PRIMARY KEY CLUSTERED (case_id,alert_id))
GO

CREATE INDEX XIE1FSK_ALERT_CASE ON SCHKC.FSK_ALERT_CASE
(
	alert_id ASC
)
GO

CREATE TABLE SCHKC.FSK_ALERT
(
	alert_id             DECIMAL(12) NOT NULL ,
	product_type         CHAR(3) NOT NULL ,
	alert_status_code    CHAR(3) NOT NULL ,
	money_laundering_risk_score DECIMAL(3) NOT NULL ,
	terror_financing_risk_score DECIMAL(3)  ,
	alert_description    VARCHAR(100) NOT NULL ,
	primary_entity_level_code CHAR(3) NOT NULL ,
	alerted_entity_number VARCHAR(50) NOT NULL ,
	alerted_entity_name  VARCHAR(35)  ,
	primary_entity_number VARCHAR(50) NOT NULL ,
	primary_entity_key   DECIMAL(12)  ,
	primary_entity_name  VARCHAR(35)  ,
	scenario_id          DECIMAL(12)  ,
	scenario_name        VARCHAR(35)  ,
	suppression_end_date DATETIME  ,
	actual_values_text   VARCHAR(255)  ,
	run_date             DATETIME NOT NULL ,
	create_date          DATETIME NOT NULL ,
	create_user_id       VARCHAR(60) NOT NULL ,
	employee_ind         CHAR(1)  ,
	version_number       DECIMAL(10) NOT NULL ,
	logical_delete_ind   CHAR(1) NOT NULL ,
	alert_type_cd        VARCHAR(32)  ,
	alert_category_cd    VARCHAR(32)  ,
	alert_subcategory_cd VARCHAR(32)  ,
	alerted_entity_key   DECIMAL(12)  ,
	alerted_entity_level_code CHAR(3)  ,
	CONSTRAINT PK_ALERT PRIMARY KEY CLUSTERED (alert_id))
GO

CREATE INDEX XIE5FSK_ALERT ON SCHKC.FSK_ALERT
(
	primary_entity_key ASC
)
GO

CREATE INDEX XIE6FSK_ALERT ON SCHKC.FSK_ALERT
(
	primary_entity_name ASC
)
GO

CREATE INDEX XIE9FSK_ALERT ON SCHKC.FSK_ALERT
(
	primary_entity_number ASC
)
GO

CREATE INDEX IDX_ALERT_SCENARIO ON SCHKC.FSK_ALERT
(
	scenario_id ASC
)
GO

CREATE TABLE SCHKC.FSK_ALERT_RISK_FACTOR
(
	entity_number        VARCHAR(50) NOT NULL ,
	alert_id             DECIMAL(12) NOT NULL ,
	scenario_id          DECIMAL(12) NOT NULL ,
	entity_level_code    CHAR(3) NOT NULL ,
	actual_values_text   VARCHAR(255)  ,
	CONSTRAINT XPKFSK_ALERT_RISK_FACTOR PRIMARY KEY CLUSTERED (entity_number,alert_id,scenario_id))
GO

CREATE INDEX XIE2FSK_ALERT_RISK_FACTOR ON SCHKC.FSK_ALERT_RISK_FACTOR
(
	entity_number ASC
)
GO

CREATE INDEX XIF1FSK_ALERT_RISK_FACTOR ON SCHKC.FSK_ALERT_RISK_FACTOR
(
	alert_id ASC
)
GO

CREATE INDEX XIF2FSK_ALERT_RISK_FACTOR ON SCHKC.FSK_ALERT_RISK_FACTOR
(
	scenario_id ASC
)
GO

CREATE TABLE SCHKC.FSK_LIST
(
	list_id              DECIMAL(12) NOT NULL ,
	list_category_id     DECIMAL(12)  ,
	list_name            VARCHAR(35)  ,
	list_desc            VARCHAR(255)  ,
	validation_type_code VARCHAR(4) NOT NULL ,
	create_date          DATETIME  ,
	create_user_id       VARCHAR(60)  ,
	delete_date          DATETIME  ,
	delete_user_id       VARCHAR(60)  ,
	logical_delete_ind   CHAR(1)  ,
	CONSTRAINT XPKFSK_LIST PRIMARY KEY CLUSTERED (list_id))
GO

CREATE INDEX XIF1FSK_LIST ON SCHKC.FSK_LIST
(
	list_category_id ASC
)
GO

CREATE TABLE SCHKC.FSK_ASSESSMENT_ROUTING_RULE
(
	routing_rule_id      DECIMAL(12) NOT NULL ,
	list_id              DECIMAL(12)  ,
	risk_assessment_column_name VARCHAR(30) NOT NULL ,
	route_priority_number DECIMAL(3)  ,
	assessment_type_cd   VARCHAR(32)  ,
	assessment_category_cd VARCHAR(32)  ,
	assessment_subcategory_cd VARCHAR(32)  ,
	routing_user_long_id VARCHAR(60)  ,
	CONSTRAINT XPKFSK_ASSESSMENT_ROUTING_RULE PRIMARY KEY CLUSTERED (routing_rule_id))
GO

CREATE INDEX XIF1FSK_ASSESSMENT_ROUTING_RUL ON SCHKC.FSK_ASSESSMENT_ROUTING_RULE
(
	list_id ASC
)
GO

CREATE TABLE SCHKC.FSK_ATTACHMENT
(
	attachment_id        DECIMAL(12) NOT NULL ,
	attachment_name      VARCHAR(255) NOT NULL ,
	attachment_desc      VARCHAR(255)  ,
	attachment_path      VARCHAR(2000) NOT NULL ,
	attachment_mime_type_desc VARCHAR(255) NOT NULL ,
	create_date          DATETIME NOT NULL ,
	create_user_id       VARCHAR(60) NOT NULL ,
	object_type_cd       CHAR(3) NOT NULL ,
	object_id            VARCHAR(50) NOT NULL ,
	logical_delete_ind   CHAR(1) NOT NULL ,
	comment_id           DECIMAL(12)  ,
	attachment_size      DECIMAL(12) NOT NULL ,
	CONSTRAINT XPKFSK_ATTACHMENT PRIMARY KEY CLUSTERED (attachment_id))
GO

CREATE TABLE SCHKC.FSK_CASE_ENTITY_EVENT
(
	event_id             DECIMAL(12) NOT NULL ,
	case_id              DECIMAL(12) NOT NULL ,
	event_type_code      CHAR(3) NOT NULL ,
	entity_key           DECIMAL(12)  ,
	entity_level_code    CHAR(3)  ,
	create_user_id       VARCHAR(60) NOT NULL ,
	create_date          DATETIME NOT NULL ,
	event_description    VARCHAR(225)  ,
	CONSTRAINT XPKFSK_CASE_ENTITY_EVENT PRIMARY KEY CLUSTERED (event_id))
GO

CREATE INDEX XIE1FSK_CASE_ENTITY_EVENT ON SCHKC.FSK_CASE_ENTITY_EVENT
(
	case_id ASC
)
GO

CREATE TABLE SCHKC.FSK_CASE_EVENT
(
	event_id             DECIMAL(12) NOT NULL ,
	case_id              DECIMAL(12)  ,
	event_type_code      CHAR(3) NOT NULL ,
	event_description    VARCHAR(255)  ,
	create_user_id       VARCHAR(60) NOT NULL ,
	create_date          DATETIME NOT NULL ,
	CONSTRAINT XPKFSK_CASE_EVENT PRIMARY KEY CLUSTERED (event_id))
GO

CREATE INDEX XIE1FSK_CASE_EVENT ON SCHKC.FSK_CASE_EVENT
(
	case_id ASC
)
GO

CREATE TABLE SCHKC.FSK_CASH_FLOW_BANK_ALERT
(
	alert_id             DECIMAL(12) NOT NULL ,
	bank_key             DECIMAL(12) NOT NULL ,
	transaction_key      DECIMAL(12) NOT NULL ,
	role_desc            VARCHAR(20)  ,
	sequence_number      DECIMAL(2)  ,
	CONSTRAINT XPKFSK_CASH_FLOW_BANK_AL PRIMARY KEY CLUSTERED (alert_id,bank_key,transaction_key))
GO

CREATE TABLE SCHKC.FSK_CDD_RULE
(
	cdd_rule_id          VARCHAR(32) NOT NULL ,
	version_no           DECIMAL(10) NOT NULL ,
	current_ind          CHAR(1)  ,
	cdd_update_date      DATETIME NOT NULL ,
	cdd_deploy_date      DATETIME NOT NULL ,
	cdd_rule_name_id     VARCHAR(32) NOT NULL ,
	cdd_rule_name        VARCHAR(100) NOT NULL ,
	cdd_rule_description_id VARCHAR(32) NOT NULL ,
	cdd_rule_description VARCHAR(100) NOT NULL ,
	cdd_rule_status_code VARCHAR(32) NOT NULL ,
	cdd_rule_type_code   VARCHAR(32) NOT NULL ,
	cdd_rule_save_id_flg CHAR(1)  ,
	cdd_rule_order_in_group DECIMAL(12) NOT NULL ,
	cdd_rule_group_id    VARCHAR(32)  ,
	CONSTRAINT XPKFSK_CDD_RULE PRIMARY KEY CLUSTERED (cdd_rule_id,version_no))
GO

CREATE INDEX XIF1FSK_CDD_RULE ON SCHKC.FSK_CDD_RULE
(
	cdd_rule_group_id ASC
)
GO

CREATE TABLE SCHKC.FSK_CDD_SCORING_EVENT
(
	cdd_scoring_event_key DECIMAL(12) NOT NULL ,
	primary_entity_key   DECIMAL(12) NOT NULL ,
	primary_entity_number VARCHAR(50) NOT NULL ,
	primary_entity_level_code CHAR(3) NOT NULL ,
	cdd_rule_id          VARCHAR(32) NOT NULL ,
	version_no           DECIMAL(10)  ,
	rule_score           DECIMAL(10)  ,
	score_classification_code VARCHAR(32)  ,
	event_date           DATETIME NOT NULL ,
	auto_high_ind        CHAR(1)  ,
	investigation_ind    CHAR(1)  ,
	investigation_action_code VARCHAR(32)  ,
	category_code        VARCHAR(32)  ,
	score_type_code      VARCHAR(32)  ,
	investigation_type_cd VARCHAR(32)  ,
	investigation_category_cd VARCHAR(32)  ,
	investigation_subcategory_cd VARCHAR(32)  ,
	investigation_rk     DECIMAL(12)  ,
	investigation_status_cd VARCHAR(10)  ,
	investigation_object_code CHAR(1)  ,
	CONSTRAINT XPKFSK_CDD_SCORING_EVENT PRIMARY KEY CLUSTERED (cdd_scoring_event_key))
GO

CREATE UNIQUE  INDEX XAK1FSK_CDD_SCORING_EVENT ON SCHKC.FSK_CDD_SCORING_EVENT
(
	cdd_scoring_event_key ASC
)
GO

CREATE UNIQUE  INDEX XAK2FSK_CDD_SCORING_EVENT ON SCHKC.FSK_CDD_SCORING_EVENT
(
	cdd_rule_id ASC, 	primary_entity_key ASC, 	event_date ASC
)
GO

CREATE INDEX XIE1FSK_CDD_SCORING_EVENT ON SCHKC.FSK_CDD_SCORING_EVENT
(
	investigation_rk ASC
)
GO

CREATE INDEX XIE2FSK_CDD_SCORING_EVENT ON SCHKC.FSK_CDD_SCORING_EVENT
(
	primary_entity_number ASC
)
GO

CREATE INDEX XIF1FSK_CDD_SCORING_EVENT ON SCHKC.FSK_CDD_SCORING_EVENT
(
	cdd_rule_id ASC, 	version_no ASC
)
GO

CREATE TABLE SCHKC.FSK_COMMENT
(
	comment_id           DECIMAL(12) NOT NULL ,
	object_type_cd       CHAR(3) NOT NULL ,
	object_id            VARCHAR(50) NOT NULL ,
	comment_text         VARCHAR(4000) NOT NULL ,
	comment_category_cd  CHAR(3) NOT NULL ,
	create_date          DATETIME NOT NULL ,
	create_user_id       VARCHAR(60) NOT NULL ,
	lstupdate_user_id    VARCHAR(60)  ,
	lstupdate_date       DATETIME  ,
	logical_delete_ind   CHAR(1) NOT NULL ,
	CONSTRAINT XPKFSK_COMMENT PRIMARY KEY CLUSTERED (comment_id))
GO

CREATE INDEX XIE1FSK_COMMENT ON SCHKC.FSK_COMMENT
(
	object_type_cd ASC, 	object_id ASC
)
GO

CREATE TABLE SCHKC.FSK_ENHANCED_ALERT_RISK_FACTOR
(
	column_name          CHAR(32) NOT NULL ,
	entity_number        VARCHAR(50) NOT NULL ,
	alert_id             DECIMAL(12) NOT NULL ,
	scenario_id          DECIMAL(12) NOT NULL ,
	column_type_code     CHAR(1) NOT NULL ,
	column_value_number  DOUBLE PRECISION  ,
	column_value_char_text VARCHAR(4000)  ,
	CONSTRAINT XPKFSK_ENHANCED_ALERT_RISK_FAC PRIMARY KEY CLUSTERED (column_name,entity_number,alert_id,scenario_id))
GO

CREATE INDEX XIF1FSK_ENHANCED_ALERT_RISK_FA ON SCHKC.FSK_ENHANCED_ALERT_RISK_FACTOR
(
	entity_number ASC, 	alert_id ASC, 	scenario_id ASC
)
GO

CREATE TABLE SCHKC.FSK_CASE_ENTITY
(
	case_id              DECIMAL(12) NOT NULL ,
	entity_level_code    CHAR(3) NOT NULL ,
	entity_key           DECIMAL(12) NOT NULL ,
	entity_number        VARCHAR(50)  ,
	entity_name          VARCHAR(35)  ,
	primary_suspect_ind  CHAR(1) NOT NULL ,
	relation_description VARCHAR(32)  ,
	lstupdate_date       DATETIME NOT NULL ,
	lstupdate_user_id    VARCHAR(60) NOT NULL ,
	version_number       DECIMAL(10,0) NOT NULL ,
	rr_ind               CHAR(1)  ,
	CONSTRAINT XPKFSK_CASE_ENTITY PRIMARY KEY CLUSTERED (case_id,entity_level_code,entity_key))
GO

CREATE INDEX XIE1FSK_CASE_ENTITY ON SCHKC.FSK_CASE_ENTITY
(
	case_id ASC, 	entity_level_code ASC, 	entity_number ASC
)
GO

CREATE INDEX XIF1FSK_CASE_ENTITY ON SCHKC.FSK_CASE_ENTITY
(
	case_id ASC
)
GO

CREATE TABLE SCHKC.FSK_CDD_ENTITY_FACT
(
	primary_entity_number VARCHAR(50) NOT NULL ,
	primary_entity_level_code CHAR(3) NOT NULL ,
	last_change_date     DATETIME NOT NULL ,
	next_review_date     DATETIME  ,
	override_score_class_code VARCHAR(32)  ,
	final_disposition_code VARCHAR(32)  ,
	last_review_date     DATETIME  ,
	last_scoring_event_key DECIMAL(12)  ,
	last_review_scoring_event_key DECIMAL(12)  ,
	curr_review_scoring_event_key DECIMAL(12)  ,
	CONSTRAINT XPKFSK_CDD_ENTITY_FACT PRIMARY KEY CLUSTERED (primary_entity_number,primary_entity_level_code))
GO

CREATE TABLE SCHKC.FSK_ENHANCED_ALERT
(
	alert_id             DECIMAL(12) NOT NULL ,
	column_name          CHAR(32) NOT NULL ,
	column_type_code     CHAR(1) NOT NULL ,
	column_value_number  DOUBLE PRECISION  ,
	column_value_char_text VARCHAR(4000)  ,
	CONSTRAINT XPKFSK_ENHANCED_ALERT PRIMARY KEY CLUSTERED (alert_id,column_name))
GO

CREATE INDEX XIF1FSK_ENHANCED_ALERT ON SCHKC.FSK_ENHANCED_ALERT
(
	alert_id ASC
)
GO

CREATE TABLE SCHKC.FSK_ALERT_EMAIL
(
	email_id             DECIMAL(12) NOT NULL ,
	alert_id             DECIMAL(12) NOT NULL ,
	email_to_text        VARCHAR(2000) NOT NULL ,
	email_cc_text        VARCHAR(2000)  ,
	email_subject_desc   VARCHAR(255)  ,
	email_message_text   VARCHAR(4000)  ,
	create_date          DATETIME NOT NULL ,
	create_user_id       VARCHAR(60) NOT NULL ,
	CONSTRAINT PK_ALERT_EMAIL PRIMARY KEY CLUSTERED (email_id))
GO

CREATE INDEX IDX_ALERT_EMAIL_ALERT ON SCHKC.FSK_ALERT_EMAIL
(
	alert_id ASC
)
GO

CREATE TABLE SCHKC.FSK_ALERT_EVENT
(
	event_id             DECIMAL(12) NOT NULL ,
	alert_id             DECIMAL(12) NOT NULL ,
	event_type_code      CHAR(3) NOT NULL ,
	event_description    VARCHAR(255)  ,
	create_date          DATETIME NOT NULL ,
	create_user_id       VARCHAR(60) NOT NULL ,
	CONSTRAINT PK_ALERT_EVENT PRIMARY KEY CLUSTERED (event_id))
GO

CREATE INDEX XIE1FSK_ALERT_EVENT ON SCHKC.FSK_ALERT_EVENT
(
	create_date ASC, 	event_type_code ASC, 	alert_id ASC
)
GO

CREATE INDEX IDX_ALERT_EVENT_ALERT ON SCHKC.FSK_ALERT_EVENT
(
	alert_id ASC
)
GO

CREATE TABLE SCHKC.FSK_ALERT_NEIGHBOR
(
	alert_id             DECIMAL(12) NOT NULL ,
	target_account_number VARCHAR(50) NOT NULL ,
	neighbor_account_number VARCHAR(50) NOT NULL ,
	distance             DECIMAL(4,3)  ,
	CONSTRAINT XPKFSK_ALERT_NEIGHBOR PRIMARY KEY CLUSTERED (alert_id,target_account_number,neighbor_account_number))
GO

CREATE INDEX XIE1FSK_ALERT_NEIGHBOR ON SCHKC.FSK_ALERT_NEIGHBOR
(
	target_account_number ASC
)
GO

CREATE INDEX XIE2FSK_ALERT_NEIGHBOR ON SCHKC.FSK_ALERT_NEIGHBOR
(
	neighbor_account_number ASC
)
GO

CREATE INDEX XIF1FSK_ALERT_NEIGHBOR ON SCHKC.FSK_ALERT_NEIGHBOR
(
	alert_id ASC
)
GO

CREATE TABLE SCHKC.FSK_ALERT_REMINDER
(
	alert_id             DECIMAL(12) NOT NULL ,
	reminder_date        DATETIME NOT NULL ,
	user_long_id         VARCHAR(60) NOT NULL ,
	reminder_sent_ind    CHAR(1)  ,
	CONSTRAINT XPKFSK_ALERT_REMINDER PRIMARY KEY CLUSTERED (alert_id,reminder_date,user_long_id))
GO

CREATE INDEX XIF1FSK_ALERT_REMINDER ON SCHKC.FSK_ALERT_REMINDER
(
	alert_id ASC
)
GO

CREATE TABLE SCHKC.FSK_ALERTED_ENTITY
(
	alerted_entity_level_code CHAR(3) NOT NULL ,
	alerted_entity_key   DECIMAL(12) NOT NULL ,
	alerted_entity_number VARCHAR(50)  ,
	alerted_entity_name  VARCHAR(35)  ,
	alerts_cnt           DECIMAL(4)  ,
	transactions_cnt     DECIMAL(8)  ,
	aggregate_amt        DECIMAL(15,3)  ,
	age_oldest_alert     DECIMAL(4)  ,
	risk_Score_code      VARCHAR(32)  ,
	money_laundering_score DECIMAL(4)  ,
	employee_ind         CHAR(1)  ,
	owner_userid         VARCHAR(240)  ,
	politically_exposed_person_ind CHAR(1)  ,
	created_timestamp    DATETIME  ,
	CONSTRAINT XPKFSK_ALERTED_ENTITY PRIMARY KEY CLUSTERED (alerted_entity_level_code,alerted_entity_key))
GO

CREATE UNIQUE  INDEX XAK1FSK_ALERTED_ENTITY ON SCHKC.FSK_ALERTED_ENTITY
(
	alerted_entity_key ASC, 	alerted_entity_level_code ASC
)
GO

CREATE TABLE SCHKC.FSK_ALERT_TRANSACTION
(
	fsk_alert_transaction_pk DECIMAL(22) NOT NULL ,
	alerted_entity_level_code CHAR(3)  ,
	alerted_entity_key   DECIMAL(12)  ,
	alert_id             DECIMAL(12)  ,
	transaction_id       VARCHAR(50)  ,
	transaction_amt      NUMERIC(15,3)  ,
	transaction_cdi_desc VARCHAR(30)  ,
	primary_medium_desc  VARCHAR(30)  ,
	secondary_medium_desc VARCHAR(30)  ,
	transaction_date     DATETIME  ,
	transaction_mechanism VARCHAR(50)  ,
	account_number       VARCHAR(50)  ,
	beneficiary_name     VARCHAR(200)  ,
	associate_name       VARCHAR(250)  ,
	Branch_name          VARCHAR(100)  ,
	transaction_desc     VARCHAR(255)  ,
	transaction_status   VARCHAR(20)  ,
	triggering_indicator_cd VARCHAR(3)  ,
	created_timestamp    DATETIME  ,
	date_key             DECIMAL(8)  ,
	time_key             DECIMAL(6)  ,
	CONSTRAINT XPKFSK_ALERT_TRANSACTION PRIMARY KEY CLUSTERED (fsk_alert_transaction_pk))
GO

CREATE INDEX XIF2FSK_ALERT_TRANSACTION ON SCHKC.FSK_ALERT_TRANSACTION
(
	alert_id ASC
)
GO

CREATE INDEX XIF3FSK_ALERT_TRANSACTION ON SCHKC.FSK_ALERT_TRANSACTION
(
	alerted_entity_level_code ASC, 	alerted_entity_key ASC
)
GO

CREATE TABLE SCHKC.FSK_ALERT_TX_AGG
(
	fsk_alert_tx_agg_pk  DECIMAL(12) NOT NULL ,
	alert_id             DECIMAL(12)  ,
	aggregate_type_code  VARCHAR(35)  ,
	group_code           VARCHAR(30)  ,
	group_desc           VARCHAR(30)  ,
	aggregate_amt        DECIMAL(15,3)  ,
	created_timestamp    DATETIME  ,
	CONSTRAINT XPKFSK_ALERT_TX_AGG PRIMARY KEY CLUSTERED (fsk_alert_tx_agg_pk))
GO

CREATE INDEX XIF1FSK_ALERT_TX_AGG ON SCHKC.FSK_ALERT_TX_AGG
(
	alert_id ASC
)
GO

CREATE TABLE SCHKC.FSK_CASE
(
	case_id              DECIMAL(12) NOT NULL ,
	case_category_code   VARCHAR(32) NOT NULL ,
	case_sub_category_code VARCHAR(32) NOT NULL ,
	case_priority_code   VARCHAR(32) NOT NULL ,
	case_type_code       VARCHAR(32) NOT NULL ,
	case_close_reason_code VARCHAR(3)  ,
	case_description     VARCHAR(35)  ,
	case_summary         VARCHAR(4000)  ,
	aggregate_amt        DECIMAL(15,3)  ,
	le_contacted_ind     CHAR(1) NOT NULL ,
	le_contact_agency    VARCHAR(150)  ,
	le_contact_name      VARCHAR(150)  ,
	le_contact_phone     VARCHAR(16)  ,
	le_contact_phone_ext VARCHAR(16)  ,
	le_contact_date      DATETIME  ,
	create_date          DATETIME NOT NULL ,
	create_user_id       VARCHAR(60) NOT NULL ,
	opened_ind           CHAR(1) NOT NULL ,
	modified_ind         CHAR(1) NOT NULL ,
	employee_ind         CHAR(1) NOT NULL ,
	case_status_code     VARCHAR(3) NOT NULL ,
	first_transaction_date DATETIME  ,
	last_transaction_date DATETIME  ,
	version_number       DECIMAL(10) NOT NULL ,
	logical_delete_ind   CHAR(1) NOT NULL ,
	lstupdate_user_id    VARCHAR(60)  ,
	lstupdate_date       DATETIME NOT NULL ,
	owner_user_long_id   VARCHAR(60)  ,
	CONSTRAINT XPKFSK_CASE PRIMARY KEY CLUSTERED (case_id))
GO

CREATE TABLE SCHKC.FSK_CASE_TRANSACTION
(
	CASE_ID              DECIMAL(12) NOT NULL ,
	ALERT_ID             DECIMAL(12) NOT NULL ,
	TRANSACTION_ID       VARCHAR(50) NOT NULL ,
	ALERTED_ENTITY_KEY   DECIMAL(12)  ,
	ALERTED_ENTITY_LEVEL_CODE CHAR(3)  ,
	TRANSACTION_AMT      NUMERIC(15,3)  ,
	TRANSACTION_CDI_DESC VARCHAR(30)  ,
	PRIMARY_MEDIUM_DESC  VARCHAR(30)  ,
	SECONDARY_MEDIUM_DESC VARCHAR(30)  ,
	TRANSACTION_DATE     DATETIME  ,
	TRANSACTION_MECHANISM VARCHAR(50)  ,
	ACCOUNT_NUMBER       VARCHAR(50)  ,
	BENEFICIARY_NAME     VARCHAR(200)  ,
	ASSOCIATE_NAME       VARCHAR(250)  ,
	BRANCH_NAME          VARCHAR(100)  ,
	TRANSACTION_DESC     VARCHAR(255)  ,
	TRANSACTION_STATUS   VARCHAR(20)  ,
	TRIGGERING_INDICATOR_CD VARCHAR(3)  ,
	CREATED_TIMESTAMP    DATETIME  ,
	DATE_KEY             DECIMAL(8)  ,
	TIME_KEY             DECIMAL(6)  ,
	CONSTRAINT XPKFSK_CASE_TRANSACTION PRIMARY KEY CLUSTERED (CASE_ID,ALERT_ID,TRANSACTION_ID))
GO
	
CREATE TABLE SCHKC.FSK_CASE_ENTITY_TRANSACTION
(
	CASE_ID              DECIMAL(12) NOT NULL ,
	ALERTED_ENTITY_NUMBER VARCHAR(50) NOT NULL ,
	ALERTED_ENTITY_LEVEL_CODE CHAR(3) NOT NULL ,
	TRANSACTION_ID       VARCHAR(50) NOT NULL ,
	ALERTED_ENTITY_KEY   DECIMAL(12)  ,
	TRANSACTION_AMT      NUMERIC(15,3)  ,
	TRANSACTION_CDI_DESC VARCHAR(30)  ,
	PRIMARY_MEDIUM_DESC  VARCHAR(30)  ,
	SECONDARY_MEDIUM_DESC VARCHAR(30)  ,
	TRANSACTION_DATE     DATETIME  ,
	TRANSACTION_MECHANISM VARCHAR(50)  ,
	ACCOUNT_NUMBER       VARCHAR(50)  ,
	BENEFICIARY_NAME     VARCHAR(200)  ,
	ASSOCIATE_NAME       VARCHAR(250)  ,
	BRANCH_NAME          VARCHAR(100)  ,
	TRANSACTION_DESC     VARCHAR(255)  ,
	TRANSACTION_STATUS   VARCHAR(20)  ,
	CREATED_TIMESTAMP    DATETIME ,
	DATE_KEY             DECIMAL(8)  ,
	TIME_KEY             DECIMAL(6)  ,
	HOUSEHOLD_NUMBER     VARCHAR(50)  ,
	CONSTRAINT XPKFSK_CASE_ENTITY_TRANSACTION PRIMARY KEY CLUSTERED (CASE_ID,ALERTED_ENTITY_NUMBER,ALERTED_ENTITY_LEVEL_CODE,TRANSACTION_ID))
GO

CREATE TABLE SCHKC.FSK_CASH_FLOW_ALERT
(
	alert_id             DECIMAL(12) NOT NULL ,
	transaction_key      DECIMAL(12) NOT NULL ,
	account_key          DECIMAL(12) NOT NULL ,
	date_key             DECIMAL(8,0) NOT NULL ,
	time_key             DECIMAL(6) NOT NULL ,
	transaction_type_key DECIMAL(12) NOT NULL ,
	country_key          DECIMAL(5) NOT NULL ,
	transaction_status_key DECIMAL(5) NOT NULL ,
	remitter_ext_party_key DECIMAL(12)  ,
	beneficiary_ext_party_key DECIMAL(12) NOT NULL ,
	transaction_currency_key DECIMAL(5) NOT NULL ,
	branch_key           DECIMAL(12) NOT NULL ,
	posted_date_key      DECIMAL(8)  ,
	associate_key        DECIMAL(12)  ,
	executing_party_key  DECIMAL(12)  ,
	executing_ext_party_key DECIMAL(12)  ,
	currency_amount      DECIMAL(18,5)  ,
	currency_amount_in_txn_ccy DECIMAL(18,5)  ,
	currency_amount_in_account_ccy DECIMAL(18,5)  ,
	secondary_account_key DECIMAL(12) NOT NULL ,
	related_ind          CHAR(1) DEFAULT 'N' NOT NULL ,
	trigger_ind          CHAR(1)  ,
	third_party_ind      CHAR(1)  ,
	CONSTRAINT XPKFSK_CASH_FLOW_ALERT PRIMARY KEY CLUSTERED (alert_id,transaction_key))
GO

CREATE INDEX XIE1FSK_CASH_FLOW_ALERT ON SCHKC.FSK_CASH_FLOW_ALERT
(
	account_key ASC
)
GO

CREATE INDEX XIE2FSK_CASH_FLOW_ALERT ON SCHKC.FSK_CASH_FLOW_ALERT
(
	transaction_key ASC, 	transaction_type_key ASC
)
GO

CREATE INDEX XIE3FSK_CASH_FLOW_ALERT ON SCHKC.FSK_CASH_FLOW_ALERT
(
	associate_key ASC
)
GO

CREATE INDEX XIE4FSK_CASH_FLOW_ALERT ON SCHKC.FSK_CASH_FLOW_ALERT
(
	executing_party_key ASC
)
GO

CREATE INDEX XIE5FSK_CASH_FLOW_ALERT ON SCHKC.FSK_CASH_FLOW_ALERT
(
	date_key ASC
)
GO

CREATE TABLE SCHKC.FSK_CDD_RULE_GROUP
(
	cdd_rule_group_id    VARCHAR(32) NOT NULL ,
	version_no           DECIMAL(10) NOT NULL ,
	current_ind          CHAR(1)  ,
	cdd_update_date      DATETIME NOT NULL ,
	cdd_deploy_date      DATETIME NOT NULL ,
	cdd_rule_group_file_name VARCHAR(128) NOT NULL ,
	cdd_rule_group_category_code VARCHAR(32) NOT NULL ,
	cdd_rule_group_desc_id VARCHAR(32) NOT NULL ,
	cdd_rule_group_description VARCHAR(100) NOT NULL ,
	cdd_rule_group_name_id VARCHAR(32) NOT NULL ,
	cdd_rule_group_name  VARCHAR(100) NOT NULL ,
	cdd_rule_group_input_ds_name VARCHAR(32)  ,
	cdd_rule_group_by_var_1_name VARCHAR(32)  ,
	cdd_rule_group_by_var_2_name VARCHAR(32)  ,
	cdd_rule_group_level DECIMAL(10)  ,
	cdd_rule_group_order_in_level DECIMAL(10)  ,
	cdd_rule_group_save_to_kc_flg CHAR(1)  ,
	cdd_rule_group_save_trig_v_flg CHAR(1)  ,
	CONSTRAINT XPKFSK_CDD_RULE_GROUP PRIMARY KEY CLUSTERED (cdd_rule_group_id,version_no))
GO

CREATE TABLE SCHKC.FSK_CDD_RULE_PARAMETER
(
	cdd_rule_version_no  DECIMAL(10) NOT NULL ,
	cdd_rule_parm_name   VARCHAR(100) NOT NULL ,
	cdd_rule_id          VARCHAR(32) NOT NULL ,
	cdd_rule_parm_desc_id VARCHAR(32) NOT NULL ,
	cdd_rule_parm_description VARCHAR(100) NOT NULL ,
	cdd_rule_parm_type_code VARCHAR(32) NOT NULL ,
	cdd_rule_parm_val    VARCHAR(1024) NOT NULL ,
	CONSTRAINT XPKFSK_CDD_RULE_PARAMETER PRIMARY KEY CLUSTERED (cdd_rule_version_no,cdd_rule_parm_name,cdd_rule_id))
GO

CREATE INDEX XIF1FSK_CDD_RULE_PARAMETER ON SCHKC.FSK_CDD_RULE_PARAMETER
(
	cdd_rule_id ASC
)
GO

CREATE TABLE SCHKC.FSK_CDD_TRIGGERING_VALUES
(
	cdd_triggering_value_key DECIMAL(12) NOT NULL ,
	cdd_scoring_event_key DECIMAL(12) NOT NULL ,
	triggering_value_id  DECIMAL(12)  ,
	triggering_char_value VARCHAR(35)  ,
	triggering_num_value DECIMAL(18,5)  ,
	triggering_date_value DATETIME  ,
	triggering_value_type_code VARCHAR(32)  ,
	ref_table_nm         VARCHAR(30)  ,
	CONSTRAINT XPKFSK_CDD_TRIGGERING_VALUES PRIMARY KEY CLUSTERED (cdd_triggering_value_key))
GO

CREATE INDEX XIF1FSK_CDD_TRIGGERING_VALUES ON SCHKC.FSK_CDD_TRIGGERING_VALUES
(
	cdd_scoring_event_key ASC
)
GO

CREATE TABLE SCHKC.FSK_ENTITY_EVENT
(
	event_id             DECIMAL(12) NOT NULL ,
	case_id              DECIMAL(12)  ,
	event_type_code      CHAR(3) NOT NULL ,
	event_description    VARCHAR(255)  ,
	entity_number        VARCHAR(50) NOT NULL ,
	entity_level_code    CHAR(3) NOT NULL ,
	create_user_id       VARCHAR(60) NOT NULL ,
	create_date          DATETIME NOT NULL ,
	CONSTRAINT XPKFSK_ENTITY_EVENT PRIMARY KEY CLUSTERED (event_id))
GO

CREATE INDEX XIE1FSK_ENTITY_EVENT ON SCHKC.FSK_ENTITY_EVENT
(
	case_id ASC
)
GO

CREATE TABLE SCHKC.FSK_ENTITY_TRANSACTION
(
	fsk_entity_transaction_pk DECIMAL(22) NOT NULL ,
	alerted_entity_level_code CHAR(3)  ,
	alerted_entity_key   DECIMAL(12)  ,
	transaction_id       VARCHAR(50)  ,
	transaction_amt      NUMERIC(15,3)  ,
	transaction_cdi_desc VARCHAR(30)  ,
	primary_medium_desc  VARCHAR(30)  ,
	secondary_medium_desc VARCHAR(30)  ,
	transaction_date     DATETIME  ,
	transaction_mechanism VARCHAR(50)  ,
	account_number       VARCHAR(50)  ,
	beneficiary_name     VARCHAR(200)  ,
	associate_name       VARCHAR(250)  ,
	Branch_name          VARCHAR(100)  ,
	transaction_desc     VARCHAR(255)  ,
	transaction_status   VARCHAR(20)  ,
	created_timestamp    DATETIME  ,
	date_key             DECIMAL(8)  ,
	time_key             DECIMAL(6)  ,
	household_number     VARCHAR(50)  ,
	CONSTRAINT XPKFSK_ENTITY_TRANSACTION PRIMARY KEY CLUSTERED (fsk_entity_transaction_pk))
GO

CREATE INDEX XIF1FSK_ENTITY_TRANSACTION ON SCHKC.FSK_ENTITY_TRANSACTION
(
	alerted_entity_level_code ASC, 	alerted_entity_key ASC
)
GO

CREATE TABLE SCHKC.FSK_ENTITY_TX_AGG
(
	fsk_entity_tx_agg_pk DECIMAL(12) NOT NULL ,
	alerted_entity_level_code CHAR(3)  ,
	alerted_entity_key   DECIMAL(12)  ,
	aggregate_type_code  VARCHAR(4)  ,
	group_code           VARCHAR(50)  ,
	group_desc           VARCHAR(50)  ,
	aggregate_amt        DECIMAL(15,3)  ,
	created_timestamp    DATETIME  ,
	CONSTRAINT XPKFSK_ENTITY_TX_AGG PRIMARY KEY CLUSTERED (fsk_entity_tx_agg_pk))
GO

CREATE INDEX XIF1FSK_ENTITY_TX_AGG ON SCHKC.FSK_ENTITY_TX_AGG
(
	alerted_entity_level_code ASC, 	alerted_entity_key ASC
)
GO

CREATE TABLE SCHKC.FSK_LIST_CATEGORY
(
	list_category_id     DECIMAL(12) NOT NULL ,
	list_category_name   VARCHAR(35) NOT NULL ,
	list_category_desc   VARCHAR(255)  ,
	create_date          DATETIME  ,
	create_user_id       VARCHAR(60)  ,
	delete_date          DATETIME  ,
	delete_user_id       VARCHAR(60)  ,
	logical_delete_ind   CHAR(1)  ,
	CONSTRAINT XPKFSK_LIST_CATEGORY PRIMARY KEY CLUSTERED (list_category_id))
GO

CREATE TABLE SCHKC.FSK_LIST_ELEMENT
(
	list_element_id      DECIMAL(12) NOT NULL ,
	list_id              DECIMAL(12)  ,
	list_element_desc    VARCHAR(35)  ,
	list_element_value   VARCHAR(75) NOT NULL ,
	create_date          DATETIME  ,
	create_user_id       VARCHAR(60)  ,
	delete_date          DATETIME  ,
	delete_user_id       VARCHAR(60)  ,
	logical_delete_ind   CHAR(1)  ,
	CONSTRAINT XPKFSK_LIST_ELEMENT PRIMARY KEY CLUSTERED (list_element_id))
GO

CREATE INDEX XIE1FSK_LIST_ELEMENT ON SCHKC.FSK_LIST_ELEMENT
(
	list_element_value ASC
)
GO

CREATE INDEX XIF1FSK_LIST_ELEMENT ON SCHKC.FSK_LIST_ELEMENT
(
	list_id ASC
)
GO

CREATE TABLE SCHKC.FSK_NN_ENTITY
(
	primary_entity_number VARCHAR(76) NOT NULL ,
	primary_entity_level_code CHAR(3) NOT NULL ,
	alert_id             DECIMAL(12) NOT NULL ,
	CONSTRAINT XPKFSK_NN_ENTITY PRIMARY KEY CLUSTERED (primary_entity_number,primary_entity_level_code,alert_id))
GO

CREATE INDEX XIE1FSK_NN_ENTITY ON SCHKC.FSK_NN_ENTITY
(
	alert_id ASC
)
GO

CREATE TABLE SCHKC.FSK_NN_PARTY
(
	alert_id             DECIMAL(12) NOT NULL ,
	party_number         VARCHAR(76) NOT NULL ,
	CONSTRAINT XPKFSK_NN_PARTY PRIMARY KEY CLUSTERED (alert_id,party_number))
GO

CREATE INDEX XIE1FSK_NN_PARTY ON SCHKC.FSK_NN_PARTY
(
	party_number ASC
)
GO

CREATE TABLE SCHKC.FSK_PARTY_PROFILE_ALERT
(
	alert_id             DECIMAL(12) NOT NULL ,
	month_key            DECIMAL(6,0) NOT NULL ,
	party_number         VARCHAR(50) NOT NULL ,
	aggregate_assets_amount DECIMAL(18,5)  ,
	transactions_count   DECIMAL(10,0)  ,
	deposits_count       DECIMAL(10,0)  ,
	withdrawals_count    DECIMAL(10,0)  ,
	wires_count          DECIMAL(10,0)  ,
	cash_transactions_count DECIMAL(10,0)  ,
	account_value_amount DECIMAL(18,5)  ,
	total_transactions_amount DECIMAL(18,5)  ,
	total_credits_amount DECIMAL(18,5)  ,
	total_debits_amount  DECIMAL(18,5)  ,
	total_cash_debits_amount DECIMAL(18,5)  ,
	total_cash_credits_amount DECIMAL(18,5)  ,
	total_wire_credits_amount DECIMAL(18,5)  ,
	total_wire_debits_amount DECIMAL(18,5)  ,
	largest_credit_amount DECIMAL(18,5)  ,
	largest_debit_amount DECIMAL(18,5)  ,
	funds_payment_svcs_count DECIMAL(10)  ,
	funds_transfer_count DECIMAL(10)  ,
	monetary_instrument_count DECIMAL(10)  ,
	CONSTRAINT XPKFSK_PARTY_PROFILE_ALERT PRIMARY KEY CLUSTERED (alert_id,month_key,party_number))
GO

CREATE INDEX XIE1FSK_PARTY_PROFILE_ALERT ON SCHKC.FSK_PARTY_PROFILE_ALERT
(
	party_number ASC
)
GO

CREATE TABLE SCHKC.FSK_PREFERENCE
(
	pref_name            VARCHAR(255) NOT NULL ,
	pref_value           VARCHAR(255) NOT NULL ,
	pref_type            VARCHAR(8) NOT NULL ,
	pref_value_default   VARCHAR(255)  ,
	CONSTRAINT XPKFSK_PREFERENCE PRIMARY KEY CLUSTERED (pref_name))
GO

CREATE TABLE SCHKC.FSK_RC_EFILE
(
	efile_key            DECIMAL(12) NOT NULL ,
	efile_id             VARCHAR(32)  ,
	efile_status_code    VARCHAR(32)  ,
	efile_desc           VARCHAR(100)  ,
	form_config_key      DECIMAL(6)  ,
	coverage_begin_date  DATETIME  ,
	coverage_end_date    DATETIME  ,
	efile_agency_ref_id  VARCHAR(32)  ,
	efile_agency_status_code VARCHAR(32)  ,
	output_create_date   DATETIME  ,
	output_file_size     DECIMAL(10)  ,
	output_line_count    DECIMAL(10)  ,
	output_name          VARCHAR(100)  ,
	output_path_name     VARCHAR(100)  ,
	output_report_count  DECIMAL(10)  ,
	transmission_date    DATETIME  ,
	transmission_id      VARCHAR(100)  ,
	output_zip_name      VARCHAR(32)  ,
	response_process_date DATETIME  ,
	response_file_name   VARCHAR(100)  ,
	direct_transfer_efile_name VARCHAR(100)  ,
	create_user_id       VARCHAR(60)  ,
	create_date          DATETIME NOT NULL ,
	lstupdate_date       DATETIME NOT NULL ,
	lstupdate_user_id    VARCHAR(60) NOT NULL ,
	version_number       DECIMAL(10) NOT NULL ,
	logical_delete_ind   CHAR(1) NOT NULL ,
	CONSTRAINT XPKFSK_RC_EFILE PRIMARY KEY CLUSTERED (efile_key))
GO

CREATE INDEX XIF1FSK_RC_EFILE ON SCHKC.FSK_RC_EFILE
(
	form_config_key ASC
)
GO

CREATE TABLE SCHKC.FSK_RC_REPORT
(
	report_key           DECIMAL(12) NOT NULL ,
	report_status_code   VARCHAR(32)  ,
	report_ready_code    VARCHAR(32) NOT NULL ,
	report_desc          VARCHAR(100)  ,
	form_config_key      DECIMAL(6) NOT NULL ,
	parent_object_name   VARCHAR(100)  ,
	parent_object_key    DECIMAL(12)  ,
	parent_create_date   DATETIME  ,
	correction_ind       CHAR(1)  ,
	root_report_key      DECIMAL(12) NOT NULL ,
	prev_report_key      DECIMAL(12)  ,
	prior_agency_ref_id  VARCHAR(100)  ,
	ui_json              NVARCHAR(MAX)  ,
	narrative_long_desc  NVARCHAR(MAX)  ,
	create_user_id       VARCHAR(60)  ,
	create_date          DATETIME NOT NULL ,
	lstupdate_date       DATETIME NOT NULL ,
	version_number       DECIMAL(10) NOT NULL ,
	lstupdate_user_id    VARCHAR(60)  ,
	owner_user_long_id   VARCHAR(60)  ,
	logical_delete_ind   CHAR(1) NOT NULL ,
	CONSTRAINT XPKFSK_RC_REPORT PRIMARY KEY CLUSTERED (report_key))
GO

CREATE INDEX XIF1FSK_RC_REPORT ON SCHKC.FSK_RC_REPORT
(
	form_config_key ASC
)
GO

CREATE TABLE SCHKC.FSK_RC_EFILE_REPORT
(
	efile_key            DECIMAL(12) NOT NULL ,
	report_key           DECIMAL(12) NOT NULL ,
	report_seq_number    DECIMAL(6)  ,
	file_status_code     VARCHAR(32)  ,
	report_agency_ref_id VARCHAR(100)  ,
	CONSTRAINT XPKFSK_RC_EFILE_REPORT PRIMARY KEY CLUSTERED (efile_key,report_key))
GO

CREATE INDEX XIF1FSK_RC_EFILE_REPORT ON SCHKC.FSK_RC_EFILE_REPORT
(
	report_key ASC
)
GO

CREATE INDEX XIF2FSK_RC_EFILE_REPORT ON SCHKC.FSK_RC_EFILE_REPORT
(
	efile_key ASC
)
GO

CREATE TABLE SCHKC.FSK_RC_FORM_CODE_MAPPING
(
	form_config_key      DECIMAL(6) NOT NULL ,
	format_name          VARCHAR(60) NOT NULL ,
	input_code           VARCHAR(60)  ,
	output_code          VARCHAR(60)  )
GO

CREATE UNIQUE  INDEX XAK1FSK_RC_FORM_CODE_MAPPING ON SCHKC.FSK_RC_FORM_CODE_MAPPING
(
	form_config_key ASC, 	format_name ASC, 	input_code ASC
)
GO

CREATE TABLE SCHKC.FSK_RC_FORM_CONFIG
(
	form_config_key      DECIMAL(6) NOT NULL ,
	form_agency_code     VARCHAR(32) NOT NULL ,
	form_type_code       VARCHAR(32) NOT NULL ,
	form_country_code    VARCHAR(2)  ,
	effective_from_date  DATETIME NOT NULL ,
	effective_to_date    DATETIME  ,
	form_desc            VARCHAR(100)  ,
	efile_file_prefix    VARCHAR(60)  ,
	efile_driver_pgm_name VARCHAR(60)  ,
	efile_max_report_count DECIMAL(6)  ,
	sensitive_ind        CHAR(1)  ,
	create_user_id       VARCHAR(60)  ,
	create_date          DATETIME NOT NULL ,
	lstupdate_date       DATETIME  ,
	lstupdate_user_id    VARCHAR(60)  ,
	logical_delete_ind   CHAR(1) NOT NULL ,
	CONSTRAINT XPKFSK_RC_FORM_CONFIG PRIMARY KEY CLUSTERED (form_config_key))
GO

CREATE TABLE SCHKC.FSK_RC_REPORT_ENTITY
(
	report_key           DECIMAL(12) NOT NULL ,
	entity_level_code    VARCHAR(32) NOT NULL ,
	entity_key           DECIMAL(12) NOT NULL ,
	entity_number        VARCHAR(32)  ,
	entity_name          VARCHAR(32)  ,
	lstupdate_date       DATETIME NOT NULL ,
	lstupdate_user_id    VARCHAR(60) NOT NULL ,
	ui_json              NVARCHAR(MAX)  ,
	version_number       DECIMAL(20) NOT NULL ,
	logical_delete_ind   CHAR(1) NOT NULL ,
	CONSTRAINT XPKFSK_RC_REPORT_ENTITY PRIMARY KEY CLUSTERED (report_key,entity_level_code,entity_key))
GO

CREATE INDEX XIF1FSK_RC_REPORT_ENTITY ON SCHKC.FSK_RC_REPORT_ENTITY
(
	report_key ASC
)
GO

CREATE TABLE SCHKC.FSK_RC_REPORT_ENTITY_EVENT
(
	event_id             DECIMAL(12) NOT NULL ,
	event_type_code      CHAR(3) NOT NULL ,
	event_description    VARCHAR(255)  ,
	report_key           DECIMAL(12) NOT NULL ,
	entity_level_code    VARCHAR(32) NOT NULL ,
	entity_key           DECIMAL(12) NOT NULL ,
	create_user_id       VARCHAR(60) NOT NULL ,
	create_date          DATETIME NOT NULL ,
	CONSTRAINT XPKFSK_RC_REPORT_ENTITY_EVENT PRIMARY KEY CLUSTERED (event_id))
GO

CREATE INDEX XIF1FSK_RC_REPORT_ENTITY_EVENT ON SCHKC.FSK_RC_REPORT_ENTITY_EVENT
(
	report_key ASC, 	entity_level_code ASC, 	entity_key ASC
)
GO

CREATE TABLE SCHKC.FSK_RC_REPORT_ENTITY_INFO
(
	entity_type_name     VARCHAR(50) NOT NULL ,
	entity_key           DECIMAL(12) NOT NULL ,
	entity_level_code    VARCHAR(32)  ,
	entity_name          VARCHAR(100)  ,
	entity_number        VARCHAR(32)  ,
	entity_description   VARCHAR(100)  ,
	effective_from_date  DATETIME NOT NULL ,
	effective_to_date    DATETIME NOT NULL ,
	ui_json              NVARCHAR(MAX) ,
	CONSTRAINT XPKFSK_RC_REPORT_ENTITY_INFO PRIMARY KEY CLUSTERED (entity_type_name,entity_key))
GO

CREATE TABLE SCHKC.FSK_RC_REPORT_EVENT
(
	event_id             DECIMAL(12) NOT NULL ,
	report_key           DECIMAL(12)  ,
	event_type_code      CHAR(3) NOT NULL ,
	event_description    VARCHAR(255)  ,
	create_user_id       VARCHAR(60) NOT NULL ,
	create_date          DATETIME NOT NULL ,
	CONSTRAINT XPKFSK_RC_REPORT_EVENT PRIMARY KEY CLUSTERED (event_id))
GO

CREATE INDEX XIF1FSK_RC_REPORT_EVENT ON SCHKC.FSK_RC_REPORT_EVENT
(
	report_key ASC
)
GO

CREATE TABLE SCHKC.FSK_REPLICATION_DATES
(
	alert_id             DECIMAL(12) NOT NULL ,
	start_date           DATETIME  ,
	start_date_key       DECIMAL(8)  ,
	CONSTRAINT XPKFSK_REPLICATION_DATES PRIMARY KEY CLUSTERED (alert_id))
GO

CREATE TABLE SCHKC.FSK_RISK_ASSESSMENT
(
	risk_assessment_id   DECIMAL(12) NOT NULL ,
	risk_assessment_status_code CHAR(3) NOT NULL ,
	risk_classification  DECIMAL(1)  ,
	proposed_risk_classification DECIMAL(1)  ,
	party_number         VARCHAR(50) NOT NULL ,
	party_key            DECIMAL(12)  ,
	party_name           VARCHAR(200)  ,
	starting_month_key   DECIMAL(6,0)  ,
	risk_assessment_duration DECIMAL(3) NOT NULL ,
	create_date          DATETIME NOT NULL ,
	create_user_id       VARCHAR(60) NOT NULL ,
	employee_ind         CHAR(1)  ,
	version_number       DECIMAL(10) NOT NULL ,
	logical_delete_ind   CHAR(1) NOT NULL ,
	assessment_type_cd   VARCHAR(32)  ,
	assessment_category_cd VARCHAR(32)  ,
	assessment_subcategory_cd VARCHAR(32)  ,
	owner_user_long_id   VARCHAR(60)  ,
	CONSTRAINT PK_RISK_ASMNT PRIMARY KEY CLUSTERED (risk_assessment_id))
GO

CREATE INDEX XIE5FSK_RISK_ASMNT ON SCHKC.FSK_RISK_ASSESSMENT
(
	party_key ASC
)
GO

CREATE INDEX XIE9FSK_RISK_ASMNT ON SCHKC.FSK_RISK_ASSESSMENT
(
	party_number ASC
)
GO

CREATE TABLE SCHKC.FSK_RISK_CLASSIFIER
(
	risk_classifier_id   DECIMAL(12) NOT NULL ,
	risk_classifier_name VARCHAR(35) NOT NULL ,
	risk_classifier_short_desc VARCHAR(35)  ,
	risk_classifier_desc VARCHAR(255)  ,
	risk_classifier_type_code CHAR(3)  ,
	active_ind           CHAR(1)  ,
	weight               DECIMAL(10) NOT NULL ,
	source_table         VARCHAR(35)  ,
	source_column        VARCHAR(30)  ,
	source_value         CHAR(1)  ,
	classifier_fact_column VARCHAR(30)  ,
	operator_desc        VARCHAR(3)  ,
	locked_ind           CHAR(1)  ,
	classifier_threshold DECIMAL(10)  ,
	risk_classifier_category_id DECIMAL(12,0)  ,
	list_id              DECIMAL(12)  ,
	create_date          DATETIME  ,
	create_user_id       VARCHAR(60)  ,
	end_date             DATETIME  ,
	end_user_id          VARCHAR(60)  ,
	version_number       DECIMAL(5,0)  ,
	current_ind          CHAR(1) NOT NULL ,
	logical_delete_ind   CHAR(1)  ,
	CONSTRAINT XPKFSK_RISK_CLASSIFIER PRIMARY KEY CLUSTERED (risk_classifier_id))
GO

CREATE INDEX XIF1FSK_RISK_CLASSIFIER ON SCHKC.FSK_RISK_CLASSIFIER
(
	risk_classifier_category_id ASC
)
GO

CREATE INDEX XIF2FSK_RISK_CLASSIFIER ON SCHKC.FSK_RISK_CLASSIFIER
(
	list_id ASC
)
GO

CREATE TABLE SCHKC.FSK_RISK_ASSESSMENT_CLASSIFIER
(
	risk_assessment_id   DECIMAL(12) NOT NULL ,
	risk_classifier_id   DECIMAL(12) NOT NULL ,
	CONSTRAINT XPKFSK_RISK_ASSESSMENT_CLASSIF PRIMARY KEY CLUSTERED (risk_assessment_id,risk_classifier_id))
GO

CREATE INDEX XIF1FSK_RISK_ASSESSMENT_CLASSI ON SCHKC.FSK_RISK_ASSESSMENT_CLASSIFIER
(
	risk_assessment_id ASC
)
GO

CREATE INDEX XIF2FSK_RISK_ASSESSMENT_CLASSI ON SCHKC.FSK_RISK_ASSESSMENT_CLASSIFIER
(
	risk_classifier_id ASC
)
GO

CREATE TABLE SCHKC.FSK_RISK_ASSESSMENT_EVENT
(
	event_id             DECIMAL(12) NOT NULL ,
	risk_assessment_id   DECIMAL(12) NOT NULL ,
	event_type_code      CHAR(3) NOT NULL ,
	event_desc           VARCHAR(255)  ,
	create_date          DATETIME NOT NULL ,
	create_user_id       VARCHAR(60) NOT NULL ,
	CONSTRAINT PK_RISK_ASMNT_EVENT PRIMARY KEY CLUSTERED (event_id))
GO

CREATE INDEX IDX_RISK_ASMNT_EVENT ON SCHKC.FSK_RISK_ASSESSMENT_EVENT
(
	risk_assessment_id ASC
)
GO

CREATE TABLE SCHKC.FSK_RISK_CLASSIFIER_CATEGORY
(
	risk_classifier_category_id DECIMAL(12,0) NOT NULL ,
	risk_classifier_category_name VARCHAR(35)  ,
	risk_classifier_category_desc VARCHAR(255)  ,
	create_date          DATETIME  ,
	create_user_id       VARCHAR(60)  ,
	delete_date          DATETIME  ,
	delete_user_id       VARCHAR(60)  ,
	logical_delete_ind   CHAR(1) DEFAULT 'N' NOT NULL ,
	CONSTRAINT XPKFSK_RISK_CLASSIFIER_CATEGOR PRIMARY KEY CLUSTERED (risk_classifier_category_id))
GO

CREATE TABLE SCHKC.FSK_ROUTING_RULE
(
	routing_group_id     DECIMAL(12) NOT NULL ,
	routing_rule_id      DECIMAL(12) NOT NULL ,
	route_order_number   DECIMAL(3) NOT NULL ,
	alert_type_cd        VARCHAR(32)  ,
	alert_category_cd    VARCHAR(32)  ,
	alert_subcategory_cd VARCHAR(32)  ,
	routing_user_long_id VARCHAR(60)  ,
	CONSTRAINT XPKFSK_ROUTING_RULE PRIMARY KEY CLUSTERED (routing_group_id,routing_rule_id,route_order_number))
GO

CREATE UNIQUE  INDEX XAK1FSK_ROUTING_RULE ON SCHKC.FSK_ROUTING_RULE
(
	routing_group_id ASC, 	routing_rule_id ASC
)
GO

CREATE INDEX XIF1FSK_ROUTING_RULE ON SCHKC.FSK_ROUTING_RULE
(
	routing_group_id ASC
)
GO

CREATE TABLE SCHKC.FSK_ROUTING_CONSTRAINT
(
	routing_group_id     DECIMAL(12) NOT NULL ,
	routing_rule_id      DECIMAL(12) NOT NULL ,
	constraint_order_number DECIMAL(2) NOT NULL ,
	column_name          VARCHAR(35)  ,
	operator_desc        CHAR(6)  ,
	value_desc           VARCHAR(1024)  ,
	compound_operator_name CHAR(4)  ,
	CONSTRAINT XPKFSK_ROUTING_CONSTRAINT PRIMARY KEY CLUSTERED (routing_group_id,routing_rule_id,constraint_order_number))
GO

CREATE INDEX XIF2FSK_ROUTING_CONSTRAINT ON SCHKC.FSK_ROUTING_CONSTRAINT
(
	routing_group_id ASC, 	routing_rule_id ASC
)
GO

CREATE TABLE SCHKC.FSK_ROUTING_GROUP
(
	routing_group_id     DECIMAL(12) NOT NULL ,
	routing_group_name   VARCHAR(50) NOT NULL ,
	version_number       DECIMAL(5)  ,
	logical_delete_ind   CHAR(1) NOT NULL ,
	lstupdate_user_id    VARCHAR(60)  ,
	lstupdate_date       DATETIME  ,
	CONSTRAINT XPKFSK_ROUTING_GROUP PRIMARY KEY CLUSTERED (routing_group_id))
GO

CREATE TABLE SCHKC.FSK_HEADER
(
	header_id            DECIMAL(12) NOT NULL ,
	header_name          VARCHAR(32) NOT NULL ,
	header_description   VARCHAR(255) NOT NULL ,
	entity_level_code    CHAR(3) NOT NULL ,
	denorm_table_name    VARCHAR(32)  ,
	alert_table_name     VARCHAR(24) NOT NULL ,
	header_autogen_ind   CHAR(1) NOT NULL ,
	header_location_desc VARCHAR(255)  ,
	source_type_desc     VARCHAR(32) NOT NULL ,
	create_user_id       VARCHAR(60) NOT NULL ,
	create_date          DATETIME NOT NULL ,
	lstupdate_user_id    VARCHAR(60)  ,
	lstupdate_date       DATETIME  ,
	header_host_desc     VARCHAR(50) NOT NULL ,
	version_number       DECIMAL(5)  ,
	logical_delete_ind   CHAR(1) NOT NULL ,
	CONSTRAINT PK_HEADER PRIMARY KEY CLUSTERED (header_id))
GO

CREATE TABLE SCHKC.FSK_HEADER_ELEMENT
(
	header_id            DECIMAL(12) NOT NULL ,
	element_name         VARCHAR(35) NOT NULL ,
	element_type_code    CHAR(6) NOT NULL ,
	element_length_count DECIMAL(8)  ,
	element_format_code  CHAR(12) NOT NULL ,
	element_label_desc   VARCHAR(35) NOT NULL ,
	element_usage_desc   VARCHAR(35)  ,
	CONSTRAINT PK_HEADER_ELEMENT PRIMARY KEY CLUSTERED (header_id,element_name))
GO

CREATE INDEX IDX_HEADER_ELEMENT_HEADER ON SCHKC.FSK_HEADER_ELEMENT
(
	header_id ASC
)
GO

CREATE TABLE SCHKC.FSK_INT_XFER
(
	remitter_account_number VARCHAR(304) NOT NULL ,
	remitter_name        VARCHAR(304) NOT NULL ,
	remitter_party_key   DECIMAL(12) NOT NULL ,
	beneficiary_account_number VARCHAR(304) NOT NULL ,
	beneficiary_name     VARCHAR(304) NOT NULL ,
	beneficiary_party_key DECIMAL(12) NOT NULL ,
	date_key             DECIMAL(8,0) NOT NULL ,
	currency_amount      DECIMAL(18,5) NOT NULL ,
	edge_type_code       CHAR(4) NOT NULL )
GO

CREATE TABLE SCHKC.FSK_JOB_CALENDAR
(
	job_calendar_id      DECIMAL(5) NOT NULL ,
	calendar_date        DATETIME  ,
	rundate_ind          CHAR(1)  ,
	daily_rundate_ind    CHAR(1) NOT NULL ,
	weekly_rundate_ind   CHAR(1) NOT NULL ,
	monthly_rundate_ind  CHAR(1) NOT NULL ,
	status_ind           CHAR(1) NOT NULL ,
	business_day_count   DECIMAL(15)  ,
	CONSTRAINT PK_JOB_CALENDAR PRIMARY KEY CLUSTERED (job_calendar_id))
GO

CREATE TABLE SCHKC.FSK_LOV
(
	lov_type_name        VARCHAR(64) NOT NULL ,
	lov_type_code        VARCHAR(64) NOT NULL ,
	lov_language_desc    VARCHAR(20) NOT NULL ,
	lov_type_desc        VARCHAR(100) NOT NULL ,
	lov_sort_position_number INTEGER  ,
	active_flg           CHAR(1) DEFAULT 'Y' NOT NULL ,
	CONSTRAINT PK_LOV PRIMARY KEY CLUSTERED (lov_type_name,lov_type_code,lov_language_desc))
GO

CREATE TABLE SCHKC.FSK_RC_FORM_DEFAULT
(
	form_config_key      DECIMAL(6) NOT NULL ,
	entity_level_code    VARCHAR(32) NOT NULL ,
	default_ui_json      NVARCHAR(MAX)  ,
	CONSTRAINT XPKFSK_RC_FORM_DEFAULT PRIMARY KEY CLUSTERED (form_config_key,entity_level_code))
GO

CREATE TABLE SCHKC.FSK_RISK_ASSESSMENT_EMAIL
(
	email_id             DECIMAL(12) NOT NULL ,
	risk_assessment_id   DECIMAL(12) NOT NULL ,
	email_to_text        VARCHAR(2000) NOT NULL ,
	email_cc_text        VARCHAR(2000)  ,
	email_subject_desc   VARCHAR(255)  ,
	email_message_text   VARCHAR(4000)  ,
	create_date          DATETIME NOT NULL ,
	create_user_id       VARCHAR(60) NOT NULL ,
	CONSTRAINT PK_RISK_ASMNT_EMAIL PRIMARY KEY CLUSTERED (email_id))
GO

CREATE INDEX IDX_RISK_ASMNT_EMAIL_ALERT ON SCHKC.FSK_RISK_ASSESSMENT_EMAIL
(
	risk_assessment_id ASC
)
GO

CREATE TABLE SCHKC.FSK_SCD2_COLUMNS
(
	scd2_key             DECIMAL(12) NOT NULL ,
	table_name           VARCHAR(35) NOT NULL ,
	column_name          VARCHAR(35) NOT NULL ,
	xref_valid_ind       CHAR(1) NOT NULL ,
	create_date          DATETIME NOT NULL ,
	end_date             DATETIME NOT NULL ,
	create_user_id       VARCHAR(60) NOT NULL ,
	version_number       DECIMAL(10) NOT NULL ,
	current_ind          CHAR(1) NOT NULL ,
	CONSTRAINT XPKFSK_SCD2_COLUMNS PRIMARY KEY CLUSTERED (scd2_key))
GO

CREATE TABLE SCHKC.FSK_SCENARIO
(
	scenario_id          DECIMAL(12) NOT NULL ,
	header_id            DECIMAL(12) NOT NULL ,
	root_key             DECIMAL(12)  ,
	scenario_name        VARCHAR(32) NOT NULL ,
	scenario_short_description VARCHAR(100) NOT NULL ,
	scenario_description VARCHAR(255) NOT NULL ,
	scenario_category_code CHAR(3) NOT NULL ,
	scenario_code_location_desc VARCHAR(255) NOT NULL ,
	product_type_code    CHAR(3) NOT NULL ,
	scenario_status_code CHAR(3) NOT NULL ,
	current_ind          CHAR(1) NOT NULL ,
	dflt_suppress_duration_count DECIMAL(8) NOT NULL ,
	scenario_duration_count DECIMAL(8) NOT NULL ,
	money_laundering_bayes_weight DECIMAL(15,5) NOT NULL ,
	terror_financing_bayes_weight DECIMAL(15,5)  ,
	execution_probability_rate DECIMAL(7,7) NOT NULL ,
	risk_factor_ind      CHAR(1)  ,
	create_date          DATETIME NOT NULL ,
	create_user_id       VARCHAR(60) NOT NULL ,
	end_date             DATETIME DEFAULT '5999-01-01T00:00:00' NOT NULL ,
	end_user_id          VARCHAR(60)  ,
	version_number       DECIMAL(5) NOT NULL ,
	logical_delete_ind   CHAR(1) NOT NULL ,
	routing_group_id     DECIMAL(12)  ,
	order_in_header      DECIMAL(5)  ,
	alert_type_cd        VARCHAR(32)  ,
	alert_category_cd    VARCHAR(32)  ,
	alert_subcategory_cd VARCHAR(32)  ,
	routing_user_long_id VARCHAR(60)  ,
	lstupdate_date       DATETIME  ,
	scenario_type_code   CHAR(3)  ,
	scenario_run_frequency_code CHAR(3)  ,
	save_trig_trans_ind  CHAR(1)  ,
	skip_if_no_trans_curr_day_ind CHAR(1)  ,
	entity_level_code    CHAR(3)  ,
	primary_entity_number_var_name VARCHAR(32)  ,
	vsd_window_name      VARCHAR(25)  ,
	vsd_deployment_name  VARCHAR(255)  ,
	lstupdate_user_id    VARCHAR(60)  ,
	CONSTRAINT PK_SCENARIO PRIMARY KEY CLUSTERED (scenario_id))
GO

CREATE INDEX IDX_SCENARIO_HEADER ON SCHKC.FSK_SCENARIO
(
	header_id ASC
)
GO

CREATE INDEX XIF2FSK_SCENARIO ON SCHKC.FSK_SCENARIO
(
	routing_group_id ASC
)
GO

CREATE TABLE SCHKC.FSK_SCENARIO_ALERT_COLUMN
(
	scenario_id          DECIMAL(12) NOT NULL ,
	column_name          CHAR(32) NOT NULL ,
	column_usage_code    CHAR(1) NOT NULL ,
	CONSTRAINT XPKFSK_SCENARIO_ALERT_COLUMN PRIMARY KEY CLUSTERED (scenario_id,column_name))
GO

CREATE INDEX XIF1FSK_SCENARIO_ALERT_COLUMN ON SCHKC.FSK_SCENARIO_ALERT_COLUMN
(
	scenario_id ASC
)
GO

CREATE TABLE SCHKC.FSK_SCENARIO_ALERT_CONSTRAINT
(
	constraint_order_number DECIMAL(5) NOT NULL ,
	scenario_id          DECIMAL(12) NOT NULL ,
	left_operand         VARCHAR(32) NOT NULL ,
	left_operand_type    CHAR(1) NOT NULL ,
	constraint_operator  VARCHAR(6) NOT NULL ,
	right_operand        VARCHAR(256) NOT NULL ,
	right_operand_type   CHAR(1) NOT NULL ,
	compound_operator    CHAR(3) NOT NULL ,
	CONSTRAINT XPKFSK_SCENARIO_ALERT_CONSTRAI PRIMARY KEY CLUSTERED (constraint_order_number,scenario_id))
GO

CREATE INDEX XIF1FSK_SCENARIO_ALERT_CONSTRA ON SCHKC.FSK_SCENARIO_ALERT_CONSTRAINT
(
	scenario_id ASC
)
GO

CREATE TABLE SCHKC.FSK_SCENARIO_FILTER
(
	filter_id            DECIMAL(12) NOT NULL ,
	filter_order_number  DECIMAL(5) NOT NULL ,
	scenario_id          DECIMAL(12) NOT NULL ,
	filter_name          VARCHAR(35) NOT NULL ,
	save_trig_trans_ind  CHAR(1) NOT NULL ,
	days_number          DECIMAL(5)  ,
	CONSTRAINT XPKFSK_SCENARIO_FILTER PRIMARY KEY CLUSTERED (filter_id,filter_order_number,scenario_id))
GO

CREATE UNIQUE  INDEX XAK1FSK_SCENARIO_FILTER ON SCHKC.FSK_SCENARIO_FILTER
(
	filter_id ASC
)
GO

CREATE TABLE SCHKC.FSK_SCENARIO_FILTER_CONSTRAINT
(
	constraint_order_number DECIMAL(5) NOT NULL ,
	filter_id            DECIMAL(12) NOT NULL ,
	left_operand         VARCHAR(32) NOT NULL ,
	left_operand_type    CHAR(1) NOT NULL ,
	constraint_operator  VARCHAR(6) NOT NULL ,
	right_operand        VARCHAR(256) NOT NULL ,
	right_operand_type   CHAR(1) NOT NULL ,
	compound_operator    CHAR(3) NOT NULL ,
	CONSTRAINT XPKFSK_SCENARIO_FILTER_CONSTRA PRIMARY KEY CLUSTERED (constraint_order_number,filter_id))
GO

CREATE INDEX XIF1FSK_SCENARIO_FILTER_CONSTR ON SCHKC.FSK_SCENARIO_FILTER_CONSTRAINT
(
	filter_id ASC
)
GO

CREATE TABLE SCHKC.FSK_SCENARIO_FILTER_VARIABLE
(
	variable_name        VARCHAR(32) NOT NULL ,
	filter_id            DECIMAL(12) NOT NULL ,
	function_name        VARCHAR(32) NOT NULL ,
	variable_type        CHAR(1)  ,
	CONSTRAINT XPKFSK_SCENARIO_FILTER_VARIABL PRIMARY KEY CLUSTERED (variable_name,filter_id))
GO

CREATE INDEX XIF1FSK_SCENARIO_FILTER_VARIAB ON SCHKC.FSK_SCENARIO_FILTER_VARIABLE
(
	filter_id ASC
)
GO

CREATE TABLE SCHKC.FSK_SCENARIO_LOCALIZED_MSG
(
	scenario_id          DECIMAL(12) NOT NULL ,
	locale               VARCHAR(5) NOT NULL ,
	scenario_message_text VARCHAR(255) NOT NULL ,
	CONSTRAINT XPKFSK_SCENARIO_LOCALIZED_MSG PRIMARY KEY CLUSTERED (scenario_id))
GO

CREATE TABLE SCHKC.FSK_SCENARIO_MESSAGE
(
	scenario_message_name CHAR(35) NOT NULL ,
	scenario_message_text VARCHAR(255) NOT NULL ,
	CONSTRAINT XPKFSK_SCENARIO_MESSAGE PRIMARY KEY CLUSTERED (scenario_message_name))
GO

CREATE TABLE SCHKC.FSK_SCENARIO_MESSAGE_PARAMETER
(
	parameter_number     DECIMAL(5) NOT NULL ,
	scenario_id          DECIMAL(12) NOT NULL ,
	message_parameter    VARCHAR(32) NOT NULL ,
	message_parameter_type CHAR(1) NOT NULL ,
	variable_format      VARCHAR(32)  ,
	CONSTRAINT XPKFSK_SCENARIO_MESSAGE_PARAME PRIMARY KEY CLUSTERED (parameter_number,scenario_id))
GO

CREATE INDEX XIF1FSK_SCENARIO_MESSAGE_PARAM ON SCHKC.FSK_SCENARIO_MESSAGE_PARAMETER
(
	scenario_id ASC
)
GO

CREATE TABLE SCHKC.FSK_SCENARIO_PARAMETER
(
	scenario_id          DECIMAL(12) NOT NULL ,
	parm_name            VARCHAR(32) NOT NULL ,
	parm_value           VARCHAR(1024) NOT NULL ,
	parm_type_desc       VARCHAR(32) NOT NULL ,
	parm_desc            VARCHAR(255) NOT NULL ,
	CONSTRAINT PK_SCENARIO_PARAMETER PRIMARY KEY CLUSTERED (scenario_id,parm_name))
GO

CREATE INDEX IDX_SCENARIO_PARAM_SCENARIO ON SCHKC.FSK_SCENARIO_PARAMETER
(
	scenario_id ASC
)
GO

CREATE TABLE SCHKC.FSK_TEMP_ASSESS
(
	party_key            DECIMAL(12) NOT NULL ,
	create_date          DATETIME NOT NULL ,
	CONSTRAINT XPKFSK_TEMP_ASSESS PRIMARY KEY CLUSTERED (party_key))
GO

CREATE TABLE SCHKC.FSK_TEMP_EXT_PARTY_KEYS
(
	alert_id             DECIMAL(12) NOT NULL ,
	ext_party_account_key DECIMAL(12) NOT NULL ,
	run_date             DATETIME  ,
	CONSTRAINT XPKFSK_TEMP_EXT_PARTY_KEYS PRIMARY KEY CLUSTERED (alert_id,ext_party_account_key))
GO

CREATE INDEX XIE1FSK_TEMP_EXT_PARTY_KEYS ON SCHKC.FSK_TEMP_EXT_PARTY_KEYS
(
	ext_party_account_key ASC
)
GO

CREATE TABLE SCHKC.FSK_TEMP_NUMBER
(
	primary_entity_number VARCHAR(75) NOT NULL ,
	CONSTRAINT XPKFSK_TEMP_NUMBER PRIMARY KEY CLUSTERED (primary_entity_number))
GO

CREATE TABLE SCHKC.FSK_TEMP_TABLE
(
	temp_char_1_value    VARCHAR(100)  ,
	temp_char_2_value    VARCHAR(100)  ,
	temp_char_3_value    VARCHAR(100)  ,
	temp_char_4_value    VARCHAR(100)  ,
	temp_date_1_value    DATETIME  ,
	temp_date_2_value    DATETIME  ,
	temp_date_3_value    DATETIME  ,
	temp_date_4_value    DATETIME  ,
	temp_num_1_value     DECIMAL(18,5)  ,
	temp_num_2_value     DECIMAL(18,5)  ,
	temp_num_3_value     DECIMAL(18,5)  ,
	temp_num_4_value     DECIMAL(18,5)  )
GO

CREATE TABLE SCHKC.FSK_TRANSACTION_ALERT
(
	alert_id             DECIMAL(12) NOT NULL ,
	transaction_key      DECIMAL(12) NOT NULL ,
	date_key             DECIMAL(8,0) NOT NULL ,
	transaction_reference_number VARCHAR(50) NOT NULL ,
	transaction_description VARCHAR(255)  ,
	security_name        VARCHAR(35)  ,
	deal_number          VARCHAR(35)  ,
	check_number         VARCHAR(10)  ,
	mechanism_id         VARCHAR(40)  ,
	CONSTRAINT XPKFSK_TRANSACTION_AL PRIMARY KEY CLUSTERED (alert_id,transaction_key))
GO

CREATE INDEX XIE1FSK_TRANSACTION_AL ON SCHKC.FSK_TRANSACTION_ALERT
(
	transaction_reference_number ASC
)
GO

CREATE INDEX XIE2FSK_TRANSACTION_AL ON SCHKC.FSK_TRANSACTION_ALERT
(
	date_key ASC
)
GO

CREATE INDEX XIE3FSK_TRANSACTION_AL ON SCHKC.FSK_TRANSACTION_ALERT
(
	transaction_key ASC
)
GO

CREATE TABLE SCHKC.FSK_UI_AVAILABILITY
(
	ui_availability_ind  CHAR(1) NOT NULL )
GO

CREATE TABLE SCHKC.FSK_UI_COLUMN
(
	table_ui_name        VARCHAR(35) NOT NULL ,
	column_ui_name       VARCHAR(35) NOT NULL ,
	group_ui_name        VARCHAR(35) NOT NULL ,
	column_expression_text VARCHAR(255)  ,
	column_label_desc    VARCHAR(64)  ,
	column_position_number DECIMAL(5)  ,
	format_code          CHAR(3)  ,
	format_modifier_text VARCHAR(1024)  ,
	column_display_level_code CHAR(3)  ,
	column_search_level_code CHAR(3)  ,
	sorted_by_position_number DECIMAL(5)  ,
	column_active_ind    CHAR(1)  ,
	local_key_db_name    VARCHAR(35)  ,
	remote_key_db_name   VARCHAR(35)  ,
	remote_table_ui_name VARCHAR(35)  ,
	CONSTRAINT XPKFSK_UI_COLUMN PRIMARY KEY CLUSTERED (table_ui_name,column_ui_name))
GO

CREATE INDEX XIF1FSK_UI_COLUMN ON SCHKC.FSK_UI_COLUMN
(
	table_ui_name ASC
)
GO

CREATE INDEX XIF2FSK_UI_COLUMN ON SCHKC.FSK_UI_COLUMN
(
	group_ui_name ASC
)
GO

CREATE TABLE SCHKC.FSK_UI_GROUP
(
	group_ui_name        VARCHAR(35) NOT NULL ,
	group_label_desc     VARCHAR(64)  ,
	group_position_number DECIMAL(5)  ,
	CONSTRAINT XPKFSK_UI_GROUP PRIMARY KEY CLUSTERED (group_ui_name))
GO

CREATE TABLE SCHKC.FSK_UI_TABLE
(
	table_ui_name        VARCHAR(35) NOT NULL ,
	table_expression_text VARCHAR(2000)  ,
	table_label_desc     VARCHAR(64)  ,
	table_data_source_code CHAR(3)  ,
	table_search_level_code CHAR(3)  ,
	table_active_ind     CHAR(1)  ,
	CONSTRAINT XPKFSK_UI_TABLE PRIMARY KEY CLUSTERED (table_ui_name))
GO

CREATE   VIEW SCHKC.FSK_ACCOUNT_LIST_VIEW
     AS  SELECT element.list_id,element.list_element_value
        FROM SCHKC.FSK_LIST list,SCHKC.FSK_LIST_ELEMENT element
        WHERE list.list_id = element.list_id
and list.validation_type_code = 'ACC'
and list.logical_delete_ind = 'N'
and element.logical_delete_ind = 'N'
GO

CREATE   VIEW SCHKC.FSK_PARTY_LIST_VIEW
     AS  SELECT element.list_id,element.list_element_value
        FROM SCHKC.FSK_LIST list,SCHKC.FSK_LIST_ELEMENT element
        WHERE list.list_id = element.list_id
and list.validation_type_code = 'PTY'
and list.logical_delete_ind = 'N'
and element.logical_delete_ind = 'N'
GO

ALTER TABLE SCHKC.FSK_ALERT
	ADD  CONSTRAINT FK_ALRT_SCENARIO FOREIGN KEY (scenario_id) REFERENCES SCHKC.FSK_SCENARIO (scenario_id)
GO

ALTER TABLE SCHKC.FSK_ALERT_RISK_FACTOR
	ADD  CONSTRAINT R_51 FOREIGN KEY (alert_id) REFERENCES SCHKC.FSK_ALERT (alert_id)
GO

ALTER TABLE SCHKC.FSK_ALERT_RISK_FACTOR
	ADD  CONSTRAINT R_52 FOREIGN KEY (scenario_id) REFERENCES SCHKC.FSK_SCENARIO (scenario_id)
GO

ALTER TABLE SCHKC.FSK_LIST
	ADD  CONSTRAINT R_72 FOREIGN KEY (list_category_id) REFERENCES SCHKC.FSK_LIST_CATEGORY (list_category_id)
GO

ALTER TABLE SCHKC.FSK_ASSESSMENT_ROUTING_RULE
	ADD  CONSTRAINT R_100 FOREIGN KEY (list_id) REFERENCES SCHKC.FSK_LIST (list_id)
GO

ALTER TABLE SCHKC.FSK_ENHANCED_ALERT_RISK_FACTOR
	ADD  CONSTRAINT R_269 FOREIGN KEY (entity_number, alert_id, scenario_id) REFERENCES SCHKC.FSK_ALERT_RISK_FACTOR (entity_number, alert_id, scenario_id)
GO

ALTER TABLE SCHKC.FSK_CASE_ENTITY
	ADD  CONSTRAINT R_393 FOREIGN KEY (case_id) REFERENCES SCHKC.FSK_CASE (case_id)
GO

ALTER TABLE SCHKC.FSK_ENHANCED_ALERT
	ADD  CONSTRAINT R_266 FOREIGN KEY (alert_id) REFERENCES SCHKC.FSK_ALERT (alert_id)
GO

ALTER TABLE SCHKC.FSK_ALERT_EMAIL
	ADD  CONSTRAINT FK_ALERT_EMAIL_ALERT FOREIGN KEY (alert_id) REFERENCES SCHKC.FSK_ALERT (alert_id)
GO

ALTER TABLE SCHKC.FSK_ALERT_EVENT
	ADD  CONSTRAINT FK_ALERT_EVENT_ALERT FOREIGN KEY (alert_id) REFERENCES SCHKC.FSK_ALERT (alert_id)
GO

ALTER TABLE SCHKC.FSK_ALERT_NEIGHBOR
	ADD  CONSTRAINT R_56 FOREIGN KEY (alert_id) REFERENCES SCHKC.FSK_ALERT (alert_id)
GO

ALTER TABLE SCHKC.FSK_ALERT_REMINDER
	ADD  CONSTRAINT R_67 FOREIGN KEY (alert_id) REFERENCES SCHKC.FSK_ALERT (alert_id)
GO

ALTER TABLE SCHKC.FSK_ALERT_TRANSACTION
	ADD  CONSTRAINT R_358 FOREIGN KEY (alert_id) REFERENCES SCHKC.FSK_ALERT (alert_id)
GO

ALTER TABLE SCHKC.FSK_ALERT_TRANSACTION
	ADD  CONSTRAINT R_370 FOREIGN KEY (alerted_entity_level_code, alerted_entity_key) REFERENCES SCHKC.FSK_ALERTED_ENTITY (alerted_entity_level_code, alerted_entity_key)
GO

ALTER TABLE SCHKC.FSK_ALERT_TX_AGG
	ADD  CONSTRAINT R_365 FOREIGN KEY (alert_id) REFERENCES SCHKC.FSK_ALERT (alert_id)
GO

ALTER TABLE SCHKC.FSK_ENTITY_TRANSACTION
	ADD  CONSTRAINT R_404 FOREIGN KEY (alerted_entity_level_code, alerted_entity_key) REFERENCES SCHKC.FSK_ALERTED_ENTITY (alerted_entity_level_code, alerted_entity_key)
GO

ALTER TABLE SCHKC.FSK_ENTITY_TX_AGG
	ADD  CONSTRAINT R_369 FOREIGN KEY (alerted_entity_level_code, alerted_entity_key) REFERENCES SCHKC.FSK_ALERTED_ENTITY (alerted_entity_level_code, alerted_entity_key)
GO

ALTER TABLE SCHKC.FSK_LIST_ELEMENT
	ADD  CONSTRAINT R_73 FOREIGN KEY (list_id) REFERENCES SCHKC.FSK_LIST (list_id)
GO

ALTER TABLE SCHKC.FSK_RC_EFILE
	ADD  CONSTRAINT R_392 FOREIGN KEY (form_config_key) REFERENCES SCHKC.FSK_RC_FORM_CONFIG (form_config_key)
GO

ALTER TABLE SCHKC.FSK_RC_REPORT
	ADD  CONSTRAINT R_391 FOREIGN KEY (form_config_key) REFERENCES SCHKC.FSK_RC_FORM_CONFIG (form_config_key)
GO

ALTER TABLE SCHKC.FSK_RC_EFILE_REPORT
	ADD  CONSTRAINT R_383 FOREIGN KEY (report_key) REFERENCES SCHKC.FSK_RC_REPORT (report_key)
GO

ALTER TABLE SCHKC.FSK_RC_EFILE_REPORT
	ADD  CONSTRAINT R_384 FOREIGN KEY (efile_key) REFERENCES SCHKC.FSK_RC_EFILE (efile_key)
GO

ALTER TABLE SCHKC.FSK_RC_REPORT_ENTITY
	ADD  CONSTRAINT R_385 FOREIGN KEY (report_key) REFERENCES SCHKC.FSK_RC_REPORT (report_key)
GO

ALTER TABLE SCHKC.FSK_RC_REPORT_ENTITY_EVENT
	ADD  CONSTRAINT R_407 FOREIGN KEY (report_key, entity_level_code, entity_key) REFERENCES SCHKC.FSK_RC_REPORT_ENTITY (report_key, entity_level_code, entity_key)
GO

ALTER TABLE SCHKC.FSK_RC_REPORT_EVENT
	ADD  CONSTRAINT R_409 FOREIGN KEY (report_key) REFERENCES SCHKC.FSK_RC_REPORT (report_key)
GO

ALTER TABLE SCHKC.FSK_RISK_CLASSIFIER
	ADD  CONSTRAINT R_79 FOREIGN KEY (risk_classifier_category_id) REFERENCES SCHKC.FSK_RISK_CLASSIFIER_CATEGORY (risk_classifier_category_id)
GO

ALTER TABLE SCHKC.FSK_RISK_CLASSIFIER
	ADD  CONSTRAINT R_80 FOREIGN KEY (list_id) REFERENCES SCHKC.FSK_LIST (list_id)
GO

ALTER TABLE SCHKC.FSK_RISK_ASSESSMENT_CLASSIFIER
	ADD  CONSTRAINT R_95 FOREIGN KEY (risk_assessment_id) REFERENCES SCHKC.FSK_RISK_ASSESSMENT (risk_assessment_id)
GO

ALTER TABLE SCHKC.FSK_RISK_ASSESSMENT_CLASSIFIER
	ADD  CONSTRAINT R_97 FOREIGN KEY (risk_classifier_id) REFERENCES SCHKC.FSK_RISK_CLASSIFIER (risk_classifier_id)
GO

ALTER TABLE SCHKC.FSK_RISK_ASSESSMENT_EVENT
	ADD  CONSTRAINT FK_RISK_ASS_EVENT_ALERT FOREIGN KEY (risk_assessment_id) REFERENCES SCHKC.FSK_RISK_ASSESSMENT (risk_assessment_id)
GO

ALTER TABLE SCHKC.FSK_ROUTING_RULE
	ADD  CONSTRAINT R_64 FOREIGN KEY (routing_group_id) REFERENCES SCHKC.FSK_ROUTING_GROUP (routing_group_id)
GO

ALTER TABLE SCHKC.FSK_HEADER_ELEMENT
	ADD  CONSTRAINT FK_HEADER_ELEMENT_HEADER FOREIGN KEY (header_id) REFERENCES SCHKC.FSK_HEADER (header_id)
GO

ALTER TABLE SCHKC.FSK_RISK_ASSESSMENT_EMAIL
	ADD  CONSTRAINT FK_RISK_ASS_EMAIL_ALERT FOREIGN KEY (risk_assessment_id) REFERENCES SCHKC.FSK_RISK_ASSESSMENT (risk_assessment_id)
GO

ALTER TABLE SCHKC.FSK_SCENARIO
	ADD  CONSTRAINT FK_SCENARIO_HEADER FOREIGN KEY (header_id) REFERENCES SCHKC.FSK_HEADER (header_id)
GO

ALTER TABLE SCHKC.FSK_SCENARIO
	ADD  CONSTRAINT R_66 FOREIGN KEY (routing_group_id) REFERENCES SCHKC.FSK_ROUTING_GROUP (routing_group_id)
GO

ALTER TABLE SCHKC.FSK_SCENARIO_ALERT_COLUMN
	ADD  CONSTRAINT R_265 FOREIGN KEY (scenario_id) REFERENCES SCHKC.FSK_SCENARIO (scenario_id)
GO

ALTER TABLE SCHKC.FSK_SCENARIO_ALERT_CONSTRAINT
	ADD  CONSTRAINT R_273 FOREIGN KEY (scenario_id) REFERENCES SCHKC.FSK_SCENARIO (scenario_id)
GO

ALTER TABLE SCHKC.FSK_SCENARIO_FILTER
	ADD  CONSTRAINT R_270 FOREIGN KEY (scenario_id) REFERENCES SCHKC.FSK_SCENARIO (scenario_id)
GO

ALTER TABLE SCHKC.FSK_SCENARIO_LOCALIZED_MSG
	ADD  CONSTRAINT R_285 FOREIGN KEY (scenario_id) REFERENCES SCHKC.FSK_SCENARIO (scenario_id)
GO

ALTER TABLE SCHKC.FSK_SCENARIO_MESSAGE_PARAMETER
	ADD  CONSTRAINT R_274 FOREIGN KEY (scenario_id) REFERENCES SCHKC.FSK_SCENARIO (scenario_id)
GO

ALTER TABLE SCHKC.FSK_SCENARIO_PARAMETER
	ADD  CONSTRAINT FK_SCENARIO_PARAMETER_SCENARIO FOREIGN KEY (scenario_id) REFERENCES SCHKC.FSK_SCENARIO (scenario_id)
GO

ALTER TABLE SCHKC.FSK_UI_COLUMN
	ADD  CONSTRAINT R_49 FOREIGN KEY (table_ui_name) REFERENCES SCHKC.FSK_UI_TABLE (table_ui_name)
GO

ALTER TABLE SCHKC.FSK_UI_COLUMN
	ADD  CONSTRAINT R_50 FOREIGN KEY (group_ui_name) REFERENCES SCHKC.FSK_UI_GROUP (group_ui_name)
GO