/*******************************************************************************/
/* Load custom sample configuration data                                       */
/* To test the code without loading the data,set rc_debug to Y                 */
/*******************************************************************************/


%macro rc_custom_load_form_sample; 



data rc_form_config_sample;
    if 0 then set seg_kc.fsk_rc_form_config;
    form_config_key=&form_config_key;
    form_agency_code='CUSTOM';
    form_type_code="&form_type_code";
    form_country_code='US';
    effective_from_date='01JUL2012:00:00:00'dt;    
    form_desc='Sample Custom Form (SAMPLE)';
    efile_file_prefix=' ';
    efile_driver_pgm_name=' ';
    efile_max_report_count=60;
    create_user_id="&sysuserid";
    create_date=datetime();
    sensitive_ind='Y';
    logical_delete_ind='N';
    implementation_type_code='CUSTOM';
    output;
run;
%if &rc_debug = N %then
%do;
    proc sql;
         delete from seg_kc.fsk_rc_form_default
         where form_config_key=&form_config_key;

         delete from seg_kc.fsk_rc_form_code_mapping
         where form_config_key=&form_config_key;

         delete from seg_kc.fsk_rc_form_config
         where form_config_key=&form_config_key;
    quit;

    proc append base=seg_kc.fsk_rc_form_config (dbforce=yes) data=rc_form_config_sample force;
    run;
%end;

%mend;

%macro rc_custom_load_efile_sample;
/**********************************************************/
/* Load record level efile configuration data             */
/**********************************************************/

/* Record level configuration data */

data efile_record_config_sample;
if 0 then set rc_cfg.form_efile_record_config(%fcf_get_ds_opts(lib_name=rc_cfg, ds_name=form_efile_record_config));

     infile  rc_tmplt(rc_custom_sample_efile_record_config.csv)  
             dsd lrecl=32764 truncover firstobs=2 delimiter=',' ;
             retain form_config_key &form_config_key;
             retain form_efile_record_seq_number;
     input form_efile_record_id $
           form_efile_record_desc $
           record_sort_order
           record_length 
           source_table_name $
           source_entity_level_code  $
           source_group_name $
           
    ;
    drop record_sort_order  ;
    form_config_key=&form_config_key;
    if form_efile_record_id > '' then 
    do;     
        form_efile_record_seq_number+1;
        output;
    end;

run;
 
/* Field level configuration data */


data efile_field_config_sample;
if 0 then set rc_cfg.form_efile_field_config(%fcf_get_ds_opts(lib_name=rc_cfg, ds_name=form_efile_field_config));

     
           
     infile  rc_tmplt(rc_custom_sample_efile_field_config.csv)  
             dsd lrecl=32764 truncover firstobs=2 delimiter=',' ;
     
     input 
           form_efile_record_id $
           target_field_start_position 
           target_field_end_position 
           target_field_short_desc $
           target_field_length
           target_field_desc $
           target_field_name   $           
           source_field_name   $
           source_field_type   $
           source_field_type_parm_list $
           source_field_default_value $
           source_field_mapped_flg $
           target_field_num_flg $           
           target_sas_format_name $
           
          
    ;
   
    form_config_key=&form_config_key;
    form_efile_field_seq_number=_n_; 


    
    drop form_efile_record_seq_number ; /* to be assigned in the next step */
     
run;
proc sql noprint;
     create table form_efile_field_config_sample as
     select a.*, b.form_efile_record_seq_number
     from efile_field_config_sample as a,
          efile_record_config_sample as b
     where a.form_efile_record_id=b.form_efile_record_id
     order by form_efile_record_seq_number,  form_efile_field_seq_number;
quit;

%if &sysrc <= 4 and &rc_debug=N %then
%do;
   proc sql;
     delete 
     from rc_cfg.form_efile_field_config(%fcf_get_ds_opts(lib_name=rc_cfg, ds_name=form_efile_field_config))
     where form_config_key=&form_config_key;

     delete 
     from rc_cfg.form_efile_record_config(%fcf_get_ds_opts(lib_name=rc_cfg, ds_name=form_efile_record_config))
     where form_config_key=&form_config_key;
   quit;

    proc append base=rc_cfg.form_efile_record_config(%fcf_get_ds_opts(lib_name=rc_cfg, ds_name=form_efile_record_config, output_ds=Y))
                data=efile_record_config_sample force; 
    run;

    proc append base=rc_cfg.form_efile_field_config(%fcf_get_ds_opts(lib_name=rc_cfg, ds_name=form_efile_field_config, output_ds=Y))
                data=form_efile_field_config_sample
                force; 
    run;
%end;

%mend;

%macro rc_custom_load_ref_sample;

/******************************************************************************/
/*  Load reference table values                                               */
/******************************************************************************/

data lov_sample;
          
     infile  rc_tmplt(rc_custom_sample_efile_ref.csv)
             dsd lrecl=32764 truncover firstobs=2 delimiter=',' ;
   
   length tmp_word source_ref_list$ 32767;
   if 0 then set rc_cfg.form_efile_field_config(%fcf_get_ds_opts(lib_name=rc_cfg, ds_name=form_efile_field_config));
   if 0 then set seg_kc.fsk_lov;
   input 
           form_efile_record_id $
           target_field_name $
           target_field_length
           target_field_desc $
           source_field_name $
           source_ref_list $                
    ;
    
    retain lov_language_desc 'en';
    retain active_flg 'Y';
     
    keep lov_type_name lov_type_code lov_type_desc  
         lov_sort_position_number active_flg lov_language_desc;
   
    
    tmp_word='';
    tmp_i=1;
    do until (scan(source_ref_list,tmp_i,'|')='');
       tmp_word=left(scan(source_ref_list,tmp_i,'|'));
       lov_type_name="&form_type_code"||'.'||strip(form_efile_record_id)||'.'
                    ||strip(source_field_name);
       lov_type_code=substr(tmp_word,1,1);
       lov_type_desc=left(substr(tmp_word,2));
       lov_sort_position_number=tmp_i;
       output;
       tmp_i+1;
    end;
 
run;

%if &syserr <= 4 and &rc_debug=N %then
%do;
     
     proc sql noprint;
         delete from seg_kc.fsk_lov as ref
         where exists 
          (select lov_type_name
          from lov_sample as sample
          where sample.lov_type_name=ref.lov_type_name 
           );

     
    proc append base=seg_kc.fsk_lov data=lov_sample force;
    run;
%end;
%mend;


%macro rc_custom_load_mapping_sample;

/******************************************************************************/
/*  Load code mapping table                                               */
/******************************************************************************/

data code_mapping_sample;
          
     infile  rc_tmplt(rc_custom_sample_code_mapping.csv)
             dsd lrecl=32764 truncover firstobs=2 delimiter=',' ;  
   
  
   if 0 then set seg_kc.fsk_rc_form_code_mapping;
   form_config_key=&form_config_key;
   input 
            format_name $
            input_code  $
            output_code $ 
    ;
    if format_name ne '' /* and input_code ne '' */ then output;
 
run;

%if &syserr <= 4 and &rc_debug=N %then
%do;
     
     proc sql noprint;
         delete from seg_kc.fsk_rc_form_code_mapping 
     where form_config_key=&form_config_key;

     
     proc append base=seg_kc.fsk_rc_form_code_mapping (dbforce=yes) 
                data=code_mapping_sample force;
    run;

%end;
%mend;

 


%macro rc_add_lov_sample;


 data add_lov_sample;
      if 0 then set seg_kc.fsk_lov;
      retain lov_language_desc 'en';
      retain active_flg 'Y';       
      lov_type_name="RC_FORM_NAME_SHORT";              
      lov_type_code="&form_config_key";
      lov_type_desc="&form_type_code";
      lov_sort_position_number=&form_config_key;
      output;
      lov_type_name="RC_FORM_NAME_LONG";              
      lov_type_code="&form_config_key";
      lov_type_desc='custom form';
      lov_sort_position_number=&form_config_key;
      output;
          
 run;

 %if &syserr <= 4 and &rc_debug=N %then
 %do;
     
     proc sql noprint;
         delete from seg_kc.fsk_lov as ref
         where exists 
          (select lov_type_name
          from add_lov_sample as sample
          where sample.lov_type_name=ref.lov_type_name and sample.lov_type_code=ref.lov_type_code
           );

     
    proc append base=seg_kc.fsk_lov data=add_lov_sample force;
    run;
%end;    

%mend;


%macro rc_add_form_default;


 data rc_form_default;
      if 0 then set seg_kc.fsk_rc_form_default;
      form_config_key=&form_config_key;
      entity_level_code='REPORT';
      default_ui_json='{}';
      output;
      form_config_key=&form_config_key;
      entity_level_code='PTY';
      default_ui_json='{}';
      output;
          
 run;

 %if &syserr <= 4 and &rc_debug=N %then
 %do;
     
     proc sql noprint;
         delete from seg_kc.fsk_rc_form_default 
         where form_config_key=&form_config_key
         ;
    quit;
     
    proc append base=seg_kc.fsk_rc_form_default data=rc_form_default force;
    run;
%end;    

%mend;


 
 

/* Change rc_debug to Y for testing */
%let rc_debug=N;

%let form_config_key=901;
%let form_type_code=SAMPLE;
 
%rc_custom_load_form_sample;   /* load form configuration data         */

%rc_custom_load_efile_sample;  /* load efile definition                */ 

%rc_custom_load_ref_sample;    /* load look up values                  */

%rc_custom_load_mapping_sample; /* load mapping data                   */
 
/* Generate sas code to define report data tables in SAS  */
%rc_efile_gen_sasddl(form_config_key=&form_config_key,
                     form_type_code=&form_type_code, 
                     ddlfref=rc_tmplt,
                     outlib=rc_db);

/* create sas tables to store report data */
%inc rc_tmplt(&form_type_code._ddl.sas);

 
/* Initialize FSK_RC_FORM_DEFAULT with default values as null if FSK_RC_REPORT.UI_JSON is not used for saving data */
%rc_add_form_default;

%rc_add_lov_sample; /* Add form names to LOV */

%inc rc_tmplt(rc_custom_&form_type_code._gen_input_form); /* Generate html form */

%inc rc_tmplt(rc_custom_&form_type_code._gen_macro); /* Generate sas macros for retrieving and saving data */


 




