
/* MAINDOC
+------------------------------------------------------------------------------+
| NAME:    rc_custom_sample_gen_macro
| PRODUCT: SAS Regulatory Console
| SYSTEM:  Windows, Unix
| DESC:    Sample program to demonstrate how to use the form configuration data defined in  
|          RC_CFG.FORM_EFLE_FIELD_CONFIG table to sas macro for retrieving and saving data.  
+------------------------------------------------------------------------------+
| PARAMETERS:  form_config_key      = form key  (form key of the shipped sample is 901) 
|              form_type_code       = form type (form type of the shipped sample is SAMPLE)
|              report_status_includedYN = Y or N to indicate whether the form supports editing of REPORT_STATUS_CODE. 
|                                          Y for the shipped sample.
|
| NOTE:   This program is called by rc_custom_config_sample.sas when 
|          the sample form is configured. 
|          This program supports multiple record types although the shipped sample only has one record type (3A). 
+------------------------------------------------------------------------------+
MAINDOCEND */

/*-------------------------------------------------------------------
 * Copyright (c) 2016 by SAS Institute Inc., Cary, NC 27513 USA
 *  ---All Rights Reserved.
 *-------------------------------------------------------------------*/
 
 
%macro  rc_custom_sample_gen_macro( form_config_key=901
                                  , form_type_code=SAMPLE
                                  , report_status_includedYN=Y 
                   ) /  des='Macro to create sas code for generating javascript with data values';                                                                                                                                                                                                                                              
                 
   
    /* Get all the record types */       
    proc sql noprint;        
        select distinct form_efile_record_id into :record_id_1 -  
        from rc_cfg.form_efile_field_config(%fcf_get_ds_opts(lib_name=rc_cfg, ds_name=form_efile_field_config))
        where form_config_key=&form_config_key 
               and source_field_name ne ''
        order by form_efile_record_id
        ;
        %let record_cnt=&sqlobs;
        
   quit;
  
    

   /* Loop thru each record type */
   %do record_i=1 %to &record_cnt;
     
        %let form_efile_record_id=&&&record_id_&record_i;
        proc sql;
            create table form_efile_field_config as
            select *
            from rc_cfg.form_efile_field_config(%fcf_get_ds_opts(lib_name=rc_cfg, ds_name=form_efile_field_config))
            where form_config_key=&form_config_key
                  and form_efile_record_id="&form_efile_record_id"
                  and source_field_name ne ''
                  order form_efile_record_id, form_efile_field_seq_number
            ;                                                                                                                                                                                                                
       quit;

       /* Generate macro for assigning field values to javascript variables */
       data _null_;                                                                                                                                                                                                                                              
        
       Set form_efile_field_config end = eof ;
       length stmt $ 4000; 
       %if &record_i=1 %then
       %do;
       file rc_tmplt(&form_type_code._macro_value_js.sas);
       %end;
       %else 
       %do;
        file rc_tmplt(&form_type_code._macro_value_js.sas) mod;
       %end;

       If _n_ = 1 then 
       do ; 
           
          stmt= '%macro read_value_js_'
                ||strip("&form_type_code")
                ||'_'||strip("&form_efile_record_id")
                ||';'; 
          put stmt;                                                                                                                           
       end ; 

       select (upcase(source_field_type));
            
           when ('DATE')
           do;
                stmt='target_value=strip(compress(put('||strip(target_field_name)||',YYMMDD10.),"."));';
                put stmt;
                 stmt='tmpstmt=''var '||strip(source_field_name)||'Value = "''||strip(target_value)||''";'';';
               put stmt;
               put 'put tmpstmt;';
           end;
           when ('BOOLEAN')
           do;
                stmt='target_value=strip(put('||strip(target_field_name)||',booleanfmt.));';
                put stmt;
                 stmt='tmpstmt=''var '||strip(source_field_name)||'Value = ''||strip(target_value)||'';'';';
               put stmt;
               put 'put tmpstmt;';
           end;
           otherwise
           do;  
               /*
               var nameValue = 'John Doe';
               */ 
               if target_field_num_flg='' then
                  stmt='target_value=strip('||strip(target_field_name)||');';
               else 
                  stmt='target_value=strip(put('||strip(target_field_name)||',best.));';
               put stmt;
               stmt='tmpstmt=''var '||strip(source_field_name)||'Value = "''||strip(target_value)||''";'';';
               put stmt;
               put 'put tmpstmt;';
               
           end;
            
       end;
       
        
       If eof then 
       do;
          %if %upcase(&report_status_includedYN)=Y %then
          %do;
             source_field_name='reportStatusCode';
             target_field_name='REPORT_STATUS_CODE';
             stmt='target_value=symgetc("'||strip(target_field_name)||'");'; 
             put stmt;
             stmt='tmpstmt=''var '||strip(source_field_name)||'Value = "''||strip(target_value)||''";'';';
             put stmt;
             put 'put tmpstmt;';
          %end; 

          stmt='%mend;'; put stmt; put; 
       end;
    run; 

   /* Generate macro to save SAS macro variable values to SAS table. */

   data _null_;                                                                                                                                                                                                                                              
        
       Set form_efile_field_config end = eof ;
       length stmt $ 4000; 
 
       file rc_tmplt(&form_type_code._macro_value_js.sas) mod;
     

       If _n_ = 1 then 
       do ;                                                                                                                                                                                                                                        
          stmt= '%macro save_value_'
                ||strip("&form_type_code")
                ||'_'||strip("&form_efile_record_id")
                ||';'; 
          put stmt;                                                                                                                           
       end ; 

       select (upcase(source_field_type));
            
           when ('DATE')
           do;
               stmt=strip(target_field_name)||'=inputn(symgetc("'||strip(target_field_name)||'"),"YYMMDD10.");';
               put stmt;
                 
           end;
           when ('BOOLEAN')
           do;
               stmt=strip(target_field_name)||'=ifc(symgetc("'||strip(target_field_name)||'")="on","X","");';
               put stmt;
           end;
           otherwise
           do;  
               /*
                  NAME= symgetc("NAME");
               */ 
               if target_field_num_flg='' then
                  stmt=strip(target_field_name)||'=symgetc("'||strip(target_field_name)||'");';
               else 
                   stmt=strip(target_field_name)||'=symgetn("'||strip(target_field_name)||'");';
               put stmt;
              
               
           end;
            
       end;
       
        
       If eof then 
       do;
         %if %upcase(&report_status_includedYN)=Y %then
          %do;
             target_field_name='REPORT_STATUS_CODE';
             stmt=strip(target_field_name)||'=symgetc("'||strip(target_field_name)||'");';
             put stmt;
             
          %end; 
          stmt='%mend; '; put stmt; put; 
       end;
    run; 

       /* Generate macro for populating javascript variable values to html form input fields. */
       data _null_;                                                                                                                                                                                                                                                  
        
       Set form_efile_field_config end = eof ;
       length stmt $ 4000; 
       
       file rc_tmplt(&form_type_code._macro_value_js.sas) mod;
        

       If _n_ = 1 then 
       do ;                                                                                                                                                                                                                                        
          stmt= '%macro populate_js_'
                ||strip("&form_type_code")
                ||'_'||strip("&form_efile_record_id")
                ||';'; 
          put stmt;
          stmt='put "function populate() {";';
          put stmt;
          
           
       end ; 
      
       if upcase(source_field_type) ne 'BOOLEAN' then
       do;
          stmt='put "document.'||"&form_type_code"||'.'
               ||strip(source_field_name)
               ||'.value='||strip(source_field_name)||'Value;";';
          put stmt;
      end;
      else 
      do;
          stmt='put "document.'||"&form_type_code"||'.'
               ||strip(source_field_name)
               ||'.checked='||strip(source_field_name)||'Value;";';
          put stmt;
      end;
           
        
       If eof then 
       do;
          %if %upcase(&report_status_includedYN)=Y %then
          %do;
              source_field_name='reportStatusCode';
              stmt='put "document.'||"&form_type_code"||'.'
               ||strip(source_field_name)
               ||'.value='||strip(source_field_name)||'Value;";';
          put stmt;
             
          %end; 
          stmt='put "}";'; put stmt;
          stmt='%mend; '; put stmt; put; 
       end;
    run; 
  
%end;
  

 
%MEND; 

%let form_config_key=901;
%let form_type_code=SAMPLE;
 
%rc_custom_sample_gen_macro(form_config_key=&form_config_key
                            , form_type_code=&form_type_code
                            , report_status_includedYN=Y

                           );

