/* MAINDOC
+------------------------------------------------------------------------------+
| NAME:    rc_custom_sample_get.sas
| PRODUCT: SAS Regulatory Console
| SYSTEM:  Windows, Unix
| DESC:    Sample program to demonstrate how to generate a HTML form for
|          data entry of a custom report.
|          This macro is called by rc_custom_sample_stp_driver. 
+------------------------------------------------------------------------------+
| USAGE: 
|          form_config_key      = form key  (form key of the shipped sample is 901) 
|          form_type_code       = form type (form type of the shipped sample is SAMPLE) 
|          form_efile_record_id = record id of the form (record ID of the shipped sammple is 3A)
|          indsn                = sas table that contains data of the custom report 
|                                 Any data such as REPORT_STATUS_CODE that is not in the table
|                                 has to be defined as global macro variables.
| NOTE: Macros called by this macro was generated by rc_custom_sample_gen_macro.sas.
|       The HTML code included in _webout was generated by rc_custom_sample_gen_input_form.sas
|       stp_url is the url for SAS Stored Process web application.
|       aml_url is the url for SAS AML web application.
|       Fix the urls if they are not correct.   
| 
+------------------------------------------------------------------------------+
MAINDOCEND */

/*-------------------------------------------------------------------
 * Copyright (c) 2016 by SAS Institute Inc., Cary, NC 27513 USA
 *  ---All Rights Reserved.
 *-------------------------------------------------------------------*/

%macro rc_custom_sample_get(  form_config_key=
                            , form_type_code=
                            , form_efile_record_id=
                            , indsn=                            
                           );                          

/* Temporary SAS format for converting data value into boolean values (true or false) */
/* This example is using X for true.                                                  */
/* It is used in read_value_js_<form_efile_record_id> macrro.                         */
proc format ;
value $ booleanFmt 
'X'='true'
other='false'
;
run;


%inc rc_tmplt(&form_type_code._macro_value_js.sas);

%let stp_url=http://&SYSTCPIPHOSTNAME:7980/SASStoredProcess/do;
%let aml_url=http://&SYSTCPIPHOSTNAME:7980/SASComplianceSolutionsMid;

    data _null_;
        set &indsn(%fcf_get_ds_opts(ds_name=&indsn));
        length target_value tmpstmt $ 32767;
        file _webout ;
        link HTML_INIT;
        link JS_INIT;
        %read_value_js_&form_type_code._&form_efile_record_id;
        %populate_js_&form_type_code._&form_efile_record_id;
        link JS_TERM;
        link FORM_INIT;
        link GET_FORM;
        link FORM_TERM;
        link HTML_TERM;
        return;
     
    HTML_INIT:

        put '<html>';

         /* Add head tag to define css and font styles */
        put '<head>';
        put @5 '<meta http-equiv="Content-Type" content="text/html; charset=UTF-8">';   
        tmpstmt='<link rel="stylesheet" type="text/css" href="'||"%trim(&aml_url)"
                ||'/stylesheets/app.min.css" href2="app.min.css">';

        put @5 tmpstmt; tmpstmt='';
        put @5 '<style>';
        put @8 '@font-face {';
        put @10 "font-family: 'AvenirNext';";
        tmpstmt="src: url('"||
                "&aml_url"||"/fonts/avenir_next/AvenirNextLT-Regular.woff') format('woff');";
        put @10  tmpstmt $; tmpstmt='';
        put @10 'font-weight: 400;';
        put @10 'font-style: normal;';
        put @8 '}';
        put @8 '@font-face {';
        put "        font-family: 'AvenirNext';";
        tmpstmt="src: url('"||
                "&aml_url"||"/fonts/avenir_next/AvenirNextLT-Light.woff') format('woff');";
        put @10 tmpstmt; tmpstmt='';
        put @10 'font-weight: 300;';
        put @10 'font-style: normal;';
        put @8 '}';
        put @8 '@font-face {';
        put @10 "font-family: 'AvenirNext';";
        tmpstmt="src: url('"||
                 "&aml_url"||"/fonts/avenir_next/AvenirNextLT-Demi.woff') format('woff');";
        put @10 tmpstmt; tmpstmt='';            
        put @10 'font-weight: 600;';
        put @10 'font-style: normal;';
        put @8 '}';
        put @5 '</style>';
        put '</head>';
       
        /* Add body tag to run populate() to initialize the form.  */
        put '<body onload="populate();" style="padding-top: 5px">';        
        tmpstmt='';
     
     
    return;

    JS_INIT:

    /* Add javascript begin tag  */

    put '<script type="text/javascript">';    
    tmpstmt='';     
     
    return;

    JS_TERM:
     /* Add javascript end tag  */
    put '</script>';    
    tmpstmt='';    
     
    return;

    

    GET_FORM:
        /* Add the predefined html data entry form.  */
        rc=filename('form',"&rc_template_path&slash.&form_type_code._&form_efile_record_id._input_form.htm");
        fileid=fopen('form');
        if (fileid>0) then
           do while(fread(fileid)=0);
              rc=fget(fileid,tmpstmt,200);
              put @10 tmpstmt;
           end;
        rc=fclose(fileid);
        rc=filename('form','');
    return;


    FORM_INIT:

        /* Add form begin tag with action url */

        tmpstmt='<form id="'||"&form_type_code"||'"'||' name="'||"&form_type_code"||'"';
        put @3 tmpstmt; tmpstmt='';

        tmpstmt=' action="'||strip("&stp_url")||'"   method="POST">';
        put @10 tmpstmt; tmpstmt='';

        /* Add hidden input tag to call next stored process */
        put @5 '<INPUT TYPE="HIDDEN" NAME="_program" VALUE="/System/Applications/SAS Compliance Solutions/Compliance Solutions Svr/Application SAS Code/rc_custom_form_next">';
        put @5 '<INPUT TYPE="HIDDEN" NAME="_ACTION" VALUE="form,execute">';

        /* Add hidden input tag to pass more macro variables to the next stored process */
        tmpstmt='<INPUT TYPE="HIDDEN" NAME="segment_id" VALUE="'||"&segment_id"||'">';
        put @5 tmpstmt;
        tmpstmt='<INPUT TYPE="HIDDEN" NAME="report_key" VALUE="'||strip(put(report_key,best.))||'">';
        put @5 tmpstmt;
        tmpstmt='<INPUT TYPE="HIDDEN" NAME="form_config_key" VALUE="901">';
        put @5 tmpstmt;
        tmpstmt='<INPUT TYPE="HIDDEN" NAME="form_type_code" VALUE="SAMPLE">';
        put @5 tmpstmt;
        /* define the name of macro to run in rc_custom_2 stored process */ 
        tmpstmt='<INPUT TYPE="HIDDEN" NAME="next_program" VALUE="rc_custom_sample_put">'; 
        put @5 tmpstmt;  
        tmpstmt='<INPUT TYPE="HIDDEN" NAME="report_key" VALUE="'||strip(put(report_key,best.))||'">';
        put @5 tmpstmt;
        tmpstmt='<INPUT TYPE="HIDDEN" NAME="entity_key" VALUE="'||strip(put(entity_key,best.))||'">';
        put @5 tmpstmt;
        tmpstmt='<INPUT TYPE="HIDDEN" NAME="entity_level_code" VALUE="'||strip(entity_level_code)||'">';
        put @5 tmpstmt;
        tmpstmt='<INPUT TYPE="HIDDEN" NAME="form_efile_record_id" VALUE="'||"&form_efile_record_id"||'">';
        put @5 tmpstmt;
        tmpstmt='<INPUT TYPE="HIDDEN" NAME="row_seq_number" VALUE="'||strip(put(row_seq_number,best.))||'">';
        put @5 tmpstmt;
        put;
         
        /* Add tags to display form title */
        tmpstmt=' <div class="aml-heading text-primary offsetLeftMargin">Report '||"&report_key &form_type_code &form_efile_record_id"||'</div>';
        put @5 tmpstmt; tmpstmt='';
        /* Add tag to define container */
        /* Max-width can be adjusted for bigger or smaller container */
        tmpstmt='<div class="panel panel-primary" style="max-width: 1000px">';
        put @5 tmpstmt; tmpstmt='';
        tmpstmt='<div class="panel-body">';
        put @5 tmpstmt; tmpstmt=''; 

    return;

    FORM_TERM:

        /* add Save button tag */
        put @5 '</div>';
        put @8 '<div class="button">';
        put @10 '<button type="Save">Save</button>';
        put @8 '</div>';
        put;   
        /* Add close tags to close the form */ 
        put @5 '</div>';
        put;
        put  '</div>';
        put;
        put  '</form>';
         
    return;
  

    HTML_TERM:    
        put @3 '</body>';
        put '</html>';
    return;

run;

%mend;
 
