%global segment_id report_key form_type_code form_config_key;

/* MAINDOC
+------------------------------------------------------------------------------+
| NAME:    rc_custom_sample_stp_driver
| PRODUCT: SAS Regulatory Console
| SYSTEM:  Windows, Unix
| DESC:    Sample program to demonstrate how to retrieve data of a custom report 
|          and generate html form for data entry.  
+------------------------------------------------------------------------------+
| USAGE:   This macro is called by rc_custom_form stored process.
|          These global macro variables are passed from the calling program.
|          segment_id           = business unit ID
|          report_key           = report key
|          form_config_key      = form key  (form key of the shipped sample is 901) 
|          form_type_code       = form type (form type of the shipped sample is SAMPLE)
| 
| NOTE:    This sample has only one record type. 
|          A more complicated program is needed to handle multiple record types.          
+------------------------------------------------------------------------------+
MAINDOCEND */

/*-------------------------------------------------------------------
 * Copyright (c) 2016 by SAS Institute Inc., Cary, NC 27513 USA
 *  ---All Rights Reserved.
 *-------------------------------------------------------------------*/

%macro rc_custom_sample_stp_driver;

    %let first_dsn=;
    %let first_form_efile_record_id=;
                          
    /* Retrieve report data */

    %rc_custom_sample_init_data(   form_config_key=&form_config_key
                                 , form_type_code=&form_type_code
                                 , report_key=&report_key
                                 , outdsn_var=first_dsn
                                 , form_efile_record_id_var=first_form_efile_record_id
                          );

    /* Generate the html form with data for the type of record (form_efile_record_id) returned by rc_custom_sample_init_data. */          
        
    %rc_custom_sample_get(  form_config_key=&form_config_key
                          , form_type_code=&form_type_code
                          , indsn=&first_dsn
                          , form_efile_record_id=&first_form_efile_record_id
                           
                          );

%mend;
 

/* include macro source code */ 
%inc rc_tmplt(rc_custom_sample_init_data);
%inc rc_tmplt(rc_custom_sample_get);

/* Define the macro call because the calling program is expecting a sas program, not macro.  */
%rc_custom_sample_stp_driver;
