/*******************************************************************************/
/* Load FINCEN ctrx configuration data                                         */
/* To test the code without loading the data, set rc_debug to Y                */
/*******************************************************************************/


%macro rc_fincen_load_form_config_ctrx;

/*****************************************************************************************/
/* Add CTRX form to SEG_KC.FORM_CONFIG                                                   */
/*****************************************************************************************/
 

data rc_form_config_ctrx;
    if 0 then set seg_kc.fsk_rc_form_config;
    form_config_key=&form_config_key;
    form_agency_code='FINCEN';
    form_type_code="&form_type_code";
    form_country_code='US';
    effective_from_date='01SEP2017:00:00:00'dt;    
    form_desc='FinCEN Currency Transaction Report (CTRX)';
    efile_file_prefix='fincen-ctrx-v1';
    efile_driver_pgm_name='';
    efile_max_report_count=200;
    create_user_id="&sysuserid";
    create_date=datetime();
    sensitive_ind='Y';
    logical_delete_ind='N';
    output;
run;


%if &rc_debug = N %then
%do;
    %let ctrxReportExistYN=N;
    proc sql noprint;      
         select 'Y' into :ctrxReportExistYN
         from seg_kc.fsk_rc_report
         where form_config_key=&form_config_key
         ;
    quit;

    %if &ctrxReportExistYN=N %then
    %do; 
         /* Skip this step if there is any existing CTRX reports   */
         /* to prevent foreign key constraint violation            */
         /* In that case, the original definition is not replaced. */
 
         proc sql;
         delete from seg_kc.fsk_rc_form_config
         where form_config_key=&form_config_key;
         quit;
         proc append base=seg_kc.fsk_rc_form_config (dbforce=yes) data=rc_form_config_ctrx force;
         run;

    %end;
        
     proc sql noprint;
         
         delete from seg_kc.fsk_rc_form_default
         where form_config_key=&form_config_key;

         delete from seg_kc.fsk_rc_form_code_mapping
         where form_config_key=&form_config_key;    
          
    quit;

%end;

%mend;


%macro rc_fincen_load_ref_ctrx;

/******************************************************************************/
/*  Load LOV values (report data codes and labels)                            */
/******************************************************************************/

data lov_ctrx;
          
     infile  rc_tmplt(rc_fincen_ctrx_ref.csv)
             dsd lrecl=32764 truncover firstobs=2 delimiter=',' ;
   
   length tmp_word source_ref_list$ 32767;  
   if 0 then set seg_kc.fsk_lov;
   input 
            
           lov_type_name $            
           source_ref_list $                
    ;
    
    retain lov_language_desc 'en';
    retain active_flg 'Y';
     
    keep lov_type_name lov_type_code lov_type_desc  
         lov_sort_position_number active_flg lov_language_desc;
   
    
    tmp_word='';
    tmp_i=1;
    do until (scan(source_ref_list,tmp_i,'|')='');
       tmp_word=left(scan(source_ref_list,tmp_i,'|'));       
       lov_type_code=substr(tmp_word,1,1);
       lov_type_desc=left(substr(tmp_word,2));
       lov_sort_position_number=tmp_i;
       output;
       tmp_i+1;
    end;
 
run;

%if &syserr <= 4 and &rc_debug=N %then
%do;
     
     proc sql noprint;
         delete from seg_kc.fsk_lov as ref
         where exists 
          (select lov_type_name
          from lov_ctrx as ctrx
          where ctrx.lov_type_name=ref.lov_type_name 
           );

     
    proc append base=seg_kc.fsk_lov data=lov_ctrx force;
    run;
%end;
%mend;


%macro rc_fincen_load_mapping_ctrx;

/****************************************************************************************/
/*  Load code mapping table                                                             */
/****************************************************************************************/

data code_mapping_ctrx;
          
     infile  rc_tmplt(rc_fincen_ctrx_code_mapping.csv)
             dsd lrecl=32764 truncover firstobs=2 delimiter=',' ;  
   
  
   if 0 then set seg_kc.fsk_rc_form_code_mapping;
   form_config_key=&form_config_key;
   input 
            format_name $
            input_code  $
            output_code $ 
    ;
    if format_name ne '' then output;
 
run;

%if &syserr <= 4 and &rc_debug=N %then
%do;
     
     proc sql noprint;
         delete from seg_kc.fsk_rc_form_code_mapping 
     where form_config_key=&form_config_key;

     
     proc append base=seg_kc.fsk_rc_form_code_mapping (dbforce=yes) 
                data=code_mapping_ctrx force;
    run;

%end;
%mend;

%macro rc_fincen_load_error_code_ctrx;

/****************************************************************/
/* Load FINCEN ctrx error codes                                 */
/****************************************************************/

data rc_cfg.ctrx_fincen_error_code(%fcf_get_ds_opts(lib_name=rc_cfg, ds_name=ctrx_fincen_error_code, output_ds=Y));

      attrib ERROR_RECORD_TYPE length=$32 label='Error record type'
             ERROR_CODE  length=$10 label='Error Type Code'
             ERROR_DESC length=$4000 label='Error Text'              
             ERROR_TYPE_CODE length=$1 label='Error Severity Code' 
             ERROR_TYPE_TEXT length=$32 label='Error Severity Description'
             ASSOC_ELEMENT length=$256 label='Associated Element(s)'
             FIELD_REFERENCE length=$4000 label='Field Reference'
     ;
   
     infile rc_tmplt(rc_fincen_ctrx_error_code.csv)  
             dsd lrecl=32764 truncover firstobs=2  delimiter=',' ;            
     input error_record_type $
           error_code $          
           error_desc $             
           error_type_text $
           assoc_element $
           field_reference $
    ;
    error_desc=compress(error_desc,,'kw');
    assoc_element=compress(assoc_element,,'kw');
    field_reference=compress(field_reference,,'kw');
    select (error_type_text);
        when ('Fatal') error_type_code='F';    
        when ('Warning (Primary)') error_type_code='P';
        when ('Warning') error_type_code='S';
    otherwise;
  end;

run;
  

%mend;



%macro rc_add_lov_ctrx;

/******************************************************************************/
/*  Define long and short labels for CTRX form                                */
/******************************************************************************/

 data add_lov_ctrx;
      if 0 then set seg_kc.fsk_lov;
      retain lov_language_desc 'en';
      retain active_flg 'Y';       
      lov_type_name="RC_FORM_NAME_SHORT";              
      lov_type_code="&form_config_key";
      lov_type_desc="&form_type_code";
      lov_sort_position_number=&form_config_key;
      output;
      lov_type_name="RC_FORM_NAME_LONG";              
      lov_type_code="&form_config_key";
      lov_type_desc='FinCEN Currency Transaction Report (CTRX)';
      lov_sort_position_number=&form_config_key;
      output;
          
 run;

 %if &syserr <= 4 and &rc_debug=N %then
 %do;
     
     proc sql noprint;
         delete from seg_kc.fsk_lov as ref
         where exists 
          (select lov_type_name
          from add_lov_ctrx as ctrx
          where ctrx.lov_type_name=ref.lov_type_name and ctrx.lov_type_code=ref.lov_type_code
           );

     
    proc append base=seg_kc.fsk_lov data=add_lov_ctrx force;
    run;
%end;    

%mend;


%macro rc_add_lov_us_terr;

/*********************************************************************************/
/*  Create US territories state by countries and US territories country list     */
/*  The state code is always the same as country code for US territories         */
/*********************************************************************************/


data lov_us_terr;

     if 0 then set seg_kc.fsk_lov; 
     infile  rc_tmplt(state_code_list_us_territories.csv)  
             dsd lrecl=1024 truncover delimiter=',' ;   
      
     retain lov_language_desc 'en';
     retain us_country_order_pos 0;
     retain active_flg 'Y';
     drop us_terr_code us_country_order_pos;
     if _n_=1 then link ADD_US; 
   
     input us_terr_code $
           lov_type_code $ 
           lov_type_desc $
     ;
     
     lov_type_name='STATE_'||strip(us_terr_code);
     lov_sort_position_number=1;
     output;
     lov_type_name = 'COUNTRY_ISO_US';
     us_country_order_pos+1;
     lov_sort_position_number=us_country_order_pos;
     output;
     return;

ADD_US:
      
      lov_type_name = 'COUNTRY_ISO_US';
      lov_type_code = 'US' ;
      lov_type_desc = 'United States';
      us_country_order_pos+1;
      lov_sort_position_number=us_country_order_pos;
      output;
return;    
         
run; 


%if &sysrc <= 4 %then
%do;
        proc sql noprint;
          delete from lov_us_terr  as new
          where exists 
         (select lov_type_name, lov_type_code 
          from seg_kc.fsk_lov as old 
          where new.lov_type_name=old.lov_type_name
                and new.lov_type_code=old.lov_type_code                
           )
          ;  
    quit;
    
    
    proc append base= seg_kc.fsk_lov data=lov_us_terr force;
    run;
     
%end;

%mend;


%macro rc_upgrade_resp_table;
    %let upgraded=N;

    proc contents data=rc_db.resp_fincen_error_list(%fcf_get_ds_opts(lib_name=rc_db, ds_name=resp_fincen_error_list))
                   out=rc_db_tab_cols(keep=name)
                  noprint;
     run;

    data _null_;
     set rc_db_tab_cols;
      if upcase(name) eq 'ERROR_CONTEXT' then
      do;
         call symputx('upgraded','Y');
         stop;
      end;
     run;

    %if &upgraded=N %then
    %do;
       /* Upgrade table structure of RC_DB.RESP_FINCEN_ERROR_LIST */
       proc sql noprint;
       alter table rc_db.resp_fincen_error_list(%fcf_get_ds_opts(lib_name=rc_db, ds_name=resp_fincen_error_list))
       add ERROR_CONTEXT char(256) label='Error Content'      
       ; 
       alter table rc_db.resp_fincen_error_list(%fcf_get_ds_opts(lib_name=rc_db, ds_name=resp_fincen_error_list))
       modify RECORD_TYPE char(32) label='Record Type' 
       ;
       quit;
    %end;

    %let upgraded=N;

    proc contents data=rc_db.resp_fincen_summary(%fcf_get_ds_opts(lib_name=rc_db, ds_name=resp_fincen_summary))
                   out=rc_db_tab_cols(keep=name)
                  noprint;
     run;

    data _null_;
     set rc_db_tab_cols;
      if upcase(name) eq 'SUBMISSION_STATUS_CODE' then
      do;
         call symputx('upgraded','Y');
         stop;
      end;
     run;
    
    %if &upgraded=N %then
    %do;
       /* Upgrade table structure of ECM_RPT.ECMRR_RESP_FINCEN_ERROR_LIST */
       proc sql noprint;
       alter table rc_db.resp_fincen_summary(%fcf_get_ds_opts(lib_name=rc_db, ds_name=resp_fincen_summary))
       add SUBMISSION_STATUS_CODE char(256) label='submission status code'     
       ; 
       quit;
    %end;

    proc datasets lib=work nowarn nolist;
         delete rc_db_tab_cols;
    quit;
%mend;

%macro rc_fincen_load_efile_ctrx;

/*********************************************************************/
/* Load record level efile configuration data                        */
/*********************************************************************/

/* Load record level configuration data                              */
/* Although CTRX efiles are in xml, we still want to define the      */
/* data fields as in a table for cross field validation and          */
/* transformation.                                                   */


data efile_record_config_ctrx;
if 0 then set rc_cfg.form_efile_record_config(%fcf_get_ds_opts(lib_name=rc_cfg, ds_name=form_efile_record_config));

     infile  rc_tmplt(rc_fincen_ctrx_efile_record_config.csv)  
             dsd lrecl=32764 truncover firstobs=2 delimiter=',' ;
             retain form_config_key &form_config_key;
             retain form_efile_record_seq_number;
     input form_efile_record_id $
           form_efile_record_desc $
           record_sort_order
           record_length 
           source_table_name $
           source_entity_level_code  $
           source_group_name $
           
    ;
    drop record_sort_order  ;
    form_config_key=&form_config_key;
    if form_efile_record_id > '' then 
    do;     
        form_efile_record_seq_number+1;
        output;
    end;

run;
 
/* Load field level configuration data  */
/* Note: Data fields without source_field_name will be sourced from tables in RC_CFG. */

data efile_field_config_ctrx;
if 0 then set rc_cfg.form_efile_field_config(%fcf_get_ds_opts(lib_name=rc_cfg, ds_name=form_efile_field_config));

     
           
     infile  rc_tmplt(rc_fincen_ctrx_efile_field_config.csv)  
             dsd lrecl=32764 truncover firstobs=2 delimiter=',' ;
     
     input 
           form_efile_record_id $            
           target_field_short_desc $
           target_field_length
           target_field_desc $
           target_field_name   $           
           source_field_name   $
           source_field_type   $
           source_field_type_parm_list $
           source_field_default_value $
           source_field_mapped_flg $
           target_field_num_flg $           
           target_sas_format_name $
           
          
    ;
   
    form_config_key=&form_config_key;
    form_efile_field_seq_number=_n_;
    if source_field_name ne '' then target_field_name=source_field_name; 


    
    drop form_efile_record_seq_number ; /* to be assigned in the next step */
     
run;
proc sql noprint;
     create table form_efile_field_config_ctrx as
     select a.*, b.form_efile_record_seq_number
     from efile_field_config_ctrx as a,
          efile_record_config_ctrx as b
     where a.form_efile_record_id=b.form_efile_record_id
     order by form_efile_record_seq_number,  form_efile_field_seq_number;
quit;

%if &sysrc <= 4 and &rc_debug=N %then
%do;
   proc sql;
     delete 
     from rc_cfg.form_efile_field_config(%fcf_get_ds_opts(lib_name=rc_cfg, ds_name=form_efile_field_config))
     where form_config_key=&form_config_key;

     delete 
     from rc_cfg.form_efile_record_config(%fcf_get_ds_opts(lib_name=rc_cfg, ds_name=form_efile_record_config))
     where form_config_key=&form_config_key;
   quit;

    proc append base=rc_cfg.form_efile_record_config(%fcf_get_ds_opts(lib_name=rc_cfg, ds_name=form_efile_record_config, output_ds=Y))
                data=efile_record_config_ctrx force; 
    run;

    proc append base=rc_cfg.form_efile_field_config(%fcf_get_ds_opts(lib_name=rc_cfg, ds_name=form_efile_field_config, output_ds=Y))
                data=form_efile_field_config_ctrx
                force; 
    run;
%end;

%mend;



%macro rc_fincen_load_code_ctr2ctrx;

/****************************************************************/
/* Load CTR to CTRX code conversion mapping                     */
/****************************************************************/
 
data rc_cfg.ctrx_code_conversion(%fcf_get_ds_opts(lib_name=rc_cfg, ds_name=ctrx_code_conversion, output_ds=Y));

     attrib NODE_PATH    length=$32 label='Node Path' 
            NODE_NAME    length=$32 label='Node Name'   
            FORMAT_NAME   length=$32 label='Format Name'
            FORMAT_TYPE length=$1  label='Format Type'
            INPUT_CODE  length=$1 label='Input Code'
            OUTPUT_CODE length=$10 label='Output Code'   
            CODE_DESC   length=$100 label='Code Description'       
     ;
        
     retain format_type 'C';
     infile  rc_tmplt(rc_fincen_ctrx_mapping_ctr2ctrx.csv)  
             dsd lrecl=32764 truncover firstobs=2 delimiter=',' ;           
     input node_path $
           node_name $          
           input_code $
           output_code $
           code_desc $
                          
    ;
    
    format_name=node_name;

run;
%mend;

/* Change rc_debug to Y for testing */
%let rc_debug=N;

%let form_config_key=312;
%let form_type_code=CTRX;
 
%rc_fincen_load_form_config_ctrx;   /* load form configuration data         */

%rc_fincen_load_efile_ctrx;

%rc_efile_gen_macro_xpose_node( form_config_key=&form_config_key,
                                form_type_code=&form_type_code);

%rc_efile_gen_json_schema(form_config_key=&form_config_key,
                          form_type_code=&form_type_code
                           );

%rc_efile_gen_json_default(form_config_key=&form_config_key,
                           form_type_code=&form_type_code);

%rc_efile_gen_macro_wrt_xml(form_config_key=&form_config_key,
                            form_type_code=&form_type_code);

/* Generate CTRX tables based on the definition rc_cfg.form_efile_*_config */
/* Since CTRX e-files are in XML, these tables will not be populated after */
/* after e-file is generated.                                              */
/* These empty SAS tables are created mainly for validation purpose.       */
 
%rc_efile_gen_sasddl(form_config_key=&form_config_key,
                     form_type_code=&form_type_code, 
                     ddlfref=rc_tmplt,
                     outlib=rc_db);

%inc rc_tmplt(&form_type_code._ddl.sas);   

%rc_fincen_load_ref_ctrx;

%rc_fincen_load_error_code_ctrx; 

%rc_fincen_load_mapping_ctrx;

%rc_fincen_load_code_ctr2ctrx;

%rc_add_lov_ctrx;

%rc_add_lov_us_terr;

%rc_upgrade_resp_table;






