/*******************************************************************************/
/* Load FINCEN sarx configuration data                                         */
/* To test the code without loading the data, set rc_debug to Y                */
/*******************************************************************************/


%macro rc_fincen_load_form_config_sarx;

/*****************************************************************************************/
/* Add SARX form to SEG_KC.FORM_CONFIG                                                   */
/*****************************************************************************************/
 

data rc_form_config_sarx;
    if 0 then set seg_kc.fsk_rc_form_config;
    form_config_key=&form_config_key;
    form_agency_code='FINCEN';
    form_type_code="&form_type_code";
    form_country_code='US';
    effective_from_date='01AUG2018:00:00:00'dt;    
    form_desc='FinCEN Suspicious Activity Report (SARX)';
    efile_file_prefix='fincen-sarx-v1';
    efile_driver_pgm_name='';
    efile_max_report_count=200;
    create_user_id="&sysuserid";
    create_date=datetime();
    sensitive_ind='Y';
    implementation_type_code='311';
    logical_delete_ind='N';
    output;
run;


%if &rc_debug = N %then
%do;
    %let sarxReportExistYN=N;
    proc sql noprint;      
         select 'Y' into :sarxReportExistYN
         from seg_kc.fsk_rc_report
         where form_config_key=&form_config_key
         ;
    quit;

    %if &sarxReportExistYN=N %then
    %do; 
         /* Skip this step if there are any existing SARX reports   */
         /* to prevent foreign key constraint violation             */
         /* In that case, the original definition is not replaced.  */
 
         proc sql;
         delete from seg_kc.fsk_rc_form_config
         where form_config_key=&form_config_key;
         quit;
         proc append base=seg_kc.fsk_rc_form_config (dbforce=yes) data=rc_form_config_sarx force;
         run;

    %end;
        
     proc sql noprint;
         
         delete from seg_kc.fsk_rc_form_default
         where form_config_key=&form_config_key;

         delete from seg_kc.fsk_rc_form_code_mapping
         where form_config_key=&form_config_key;    
          
    quit;

%end;

%mend;

%macro rc_fincen_load_default_sarx;

     data fsk_rc_form_default_sarx;
          if 0 then set seg_kc.fsk_rc_form_default;
          form_config_key=&form_config_key;
          
          entity_level_code='INSTITUTION';
          default_ui_json= '{"lossAmount":"", "institutionRoleCode":"", "internalFileNumber":""}';
          output;   
          
          entity_level_code='BRANCH';
          default_ui_json= '{}';
          output;   
          entity_level_code='PTY';
          default_ui_json= '{  "entityFlag":"format(''<<customer.partyTypeDesc>>'',entityFlag)", "subjectDetailsUnknownFlag":"", "lastName":"<<customer.lastName>>", "lastNameUnknownFlag":"<<customer.lastName.null>>", "firstName":"<<customer.firstName>>", "firstNameUnknownFlag":"<<customer.firstName.null>>", "middleName":"<<customer.middleName>>",'
           || ' "suffix":"", "gender":"C", "occupation":"<<customer.occupation>>", "NAICS":"<<customer.industryCodeReport>>", "TaxID":"<<customer.taxID>>", "TaxIDUnknownFlag":"<<customer.taxID.null>>",   "TaxIDType":"format(''<<customer.partyTaxIdTypeCode>>'',TaxIDType)",' 
           || ' "noSubjectIDFlag":"<<customer.idNumber.null>>", "birthDate":"<<customer.dateOfBirth>>", "birthDateUnknownFlag":"<<customer.dateOfBirth.null>>",'
           || ' "corroborativeStatementFiler":"", "noAccountFlag":"", "subjectRoleCode":"",'
           || ' "subjectAccount":[{"id":1,  "accountInstitutionNonUSFlag":"", "accountInstitutionTaxID":"", "accountID":"", "accountClosedFlag":""}],'
           || ' "subjectAddress":[{"id":1,  "address":"<<customer.address1>>", "addressUnknownFlag":"<<customer.address1.null>>", "city":"<<customer.city>>", "cityUnknownFlag":"<<customer.city.null>>", "stateCode":"<<customer.stateCode>>", "stateUnknownFlag":"<<customer.stateCode.null>>", "postalCode":"<<customer.postal>>", "postalCodeUnknownFlag":"<<customer.postal.null>>", "countryCode":"<<customer.countryCode>>", "countryUnknownFlag":"<<customer.countryCode.null>>"}],'
           || ' "subjectAlternateName":[{"id":1,  "alternateName":"<<customer.doingBusinessAsName>>"}], "subjectEmail":[{"id":1,  "emailAddress":"<<customer.emailAddress>>"}], "subjectID":[{"id":1,  "IDType":"format(''<<customer.idType>>'',IDType)", "IDNumber":"<<customer.idNumber>>", "IDAuthorityStateCode":"<<customer.IDState>>", "IDAuthorityCountryCode":"<<customer.IDCountry>>", "IDTypeOther":"format(''<<customer.idType>>'',IDTypeOther)"}],'
           || ' "subjectPhone":[{"id":1,  "phoneTypeCode":"A", "phoneNumber":"<<customer.phone>>", "phoneExtension":""}, {"id":2,  "phoneTypeCode":"B", "phoneNumber":"<<customer.phone2>>", "phoneExtension":""}, {"id":3,  "phoneTypeCode":"C", "phoneNumber":"<<customer.phoneNumber3>>", "phoneExtension":""}], "subjectUrl":[{"id":1,  "URLAddress":""}]}'
          ;
          output;   
          entity_level_code='REPORT';
          default_ui_json=   '{  "noteToFincen":"",  "attachmentId":"", "filingTypeCode":"A", "continuingActivityReportFlag":"", "jointReportFlag":"", "involvedAmount":"<<case.aggregatedTransactionsAmount>>", "involvedAmountUnknownCode":"", "SARBeginDate":"<<case.firstTransactionDate>>", "SAREndDate":"<<case.lastTransactionDate>>", "cumulativeAmount":"","LEContactAgency":"<<case.lawEnforcementContactAgency>>",'
            || ' "LEContactName":"<<case.lawEnforcementContactName>>", "LEContactTelephone":"<<case.lawEnforcementContactPhone>>", "LEContactTelephoneExt":"<<case.lawEnforcementContactPhoneExt>>", "LEContactDate":"<<case.lawEnforcementContactDate>>", "contactOffice":"<<formEntity.contactOffice>>", "contactPhoneNumber":"<<formEntity.contactPhoneNumber>>", "contactPhoneExtension":"<<formEntity.contactPhoneExtension>>", "SARInternalControlNumber":"<<case.caseId>>",'
            || ' "SARStructuredTypeA":"", "SARStructuredTypeB":"", "SARStructuredTypeC":"", "SARStructuredTypeD":"", "SARStructuredTypeE":"", "SARStructuredTypeF":"", "SARStructuredTypeZ":"", "SARStructuredOther":"",'
            || ' "SARTerroristTypeA":"", "SARTerroristTypeZ":"", "SARTerroristTypeOther":"",'
            || ' "SARFraudTypeA":"", "SARFraudTypeB":"", "SARFraudTypeC":"", "SARFraudTypeD":"", "SARFraudTypeE":"", "SARFraudTypeF":"", "SARFraudTypeG":"", "SARFraudTypeH":"", "SARFraudTypeI":"", "SARFraudTypeJ":"", "SARFraudTypeK":"","SARFraudTypeL":"", "SARFraudTypeM":"","SARFraudTypeZ":"", "SARFraudTypeOther":"",'
            || ' "SARCasinosTypeA":"", "SARCasinosTypeB":"", "SARCasinosTypeC":"", "SARCasinosTypeD":"", "SARCasinosTypeZ":"", "SARCasinosTypeOther":"",'
            || ' "SARMoneyLaundryTypeA":"", "SARMoneyLaundryTypeB":"", "SARMoneyLaundryTypeC":"", "SARMoneyLaundryTypeD":"", "SARMoneyLaundryTypeE":"", "SARMoneyLaundryTypeF":"", "SARMoneyLaundryTypeG":"", "SARMoneyLaundryTypeH":"", "SARMoneyLaundryTypeI":"", "SARMoneyLaundryTypeJ":"", "SARMoneyLaundryTypeK":"", "SARMoneyLaundryTypeL":"", "SARMoneyLaundryTypeM":"", "SARMoneyLaundryTypeZ":"", "SARMoneyLaundryTypeOther":"",'
            || ' "SARIDTypeA":"", "SARIDTypeB":"", "SARIDTypeC":"", "SARIDTypeD":"", "SARIDTypeE":"", "SARIDTypeF":"", "SARIDTypeZ":"", "SARIDTypeOther":"",'
            || ' "SAROtherTypeA":"", "SAROtherTypeB":"", "SAROtherTypeC":"", "SAROtherTypeD":"", "SAROtherTypeE":"", "SAROtherTypeF":"", "SAROtherTypeG":"", "SAROtherTypeH":"", "SAROtherTypeI":"", "SAROtherTypeJ":"", "SAROtherTypeK":"", "SAROtherTypeL":"", "SAROtherTypeM":"", "SAROtherTypeN":"", "SAROtherTypeO":"", "SAROtherTypeP":"", "SAROtherTypeQ":"", "SAROtherTypeR":"", "SAROtherTypeS":"", "SAROtherTypeZ":"", "SAROtherTypeOther":"",'
            || ' "SARInsuranceTypeA":"", "SARInsuranceTypeB":"", "SARInsuranceTypeC":"", "SARInsuranceTypeD":"", "SARInsuranceTypeE":"", "SARInsuranceTypeF":"", "SARInsuranceTypeZ":"", "SARInsuranceTypeOther":"", '
            || ' "SARSFTypeA":"", "SARSFTypeB":"", "SARSFTypeC":"", "SARSFTypeD":"", "SARSFTypeE":"","SARSFTypeZ":"", "SARSFTypeOther":"",'
            || ' "SARMortgageFraudTypeA":"", "SARMortgageFraudTypeB":"", "SARMortgageFraudTypeC":"", "SARMortgageFraudTypeD":"", "SARMortgageFraudTypeE":"","SARMortgageFraudTypeZ":"", "SARMortgageFraudTypeOther":"",'
            || ' "SARProductTypeA":"", "SARProductTypeB":"", "SARProductTypeC":"", "SARProductTypeD":"", "SARProductTypeE":"", "SARProductTypeF":"", "SARProductTypeG":"", "SARProductTypeH":"", "SARProductTypeI":"", "SARProductTypeJ":"", "SARProductTypeK":"", "SARProductTypeL":"", "SARProductTypeM":"", "SARProductTypeN":"", "SARProductTypeO":"", "SARProductTypeP":"", "SARProductTypeQ":"", "SARProductTypeR":"", "SARProductTypeS":"", "SARProductTypeT":"", "SARProductTypeZ":"", "SARProductTypeOther":"",'
            || ' "SARInstrumentTypeA":"", "SARInstrumentTypeB":"", "SARInstrumentTypeC":"", "SARInstrumentTypeD":"", "SARInstrumentTypeE":"", "SARInstrumentTypeF":"", "SARInstrumentTypeG":"", "SARInstrumentTypeH":"", "SARInstrumentTypeI":"", "SARInstrumentTypeZ":"", "SARInstrumentTypeOther":"",'
            || ' "SARCyberTypeA":"", "SARCyberTypeB":"",  "SARCyberTypeZ":"", "SARCyberTypeOther":"",'
            || ' "IPAddress":[{"id":1,  "IPAddress":"", "IPAddressUTCDate":"", "IPAddressUTCTime":""}],' 
            || ' "cyberEvent":[{"id":1,  "cyberEventTypeCode":"", "cyberEventTypeOther":"", "cyberEventValue":"", "cyberEventUTCDate":"", "cyberEventUTCTime":""}],'
            || ' "CUSIP":[{"id":1,  "CUSIP":""}],'
            || ' "MIC":[{"id":1,  "MIC":""}],'
            || ' "commodity":[{"id":1,  "commodity":""}],'
            || ' "product":[{"id":1,  "product":""}]}'
          ;
          output;   

           
          entity_level_code='PTY2INSTITUTION';
          default_ui_json='{"subjectRelationTypeB":"", "subjectRelationTypeC":"", "subjectRelationTypeD":"", "subjectRelationTypeE":"", "subjectRelationTypeF":"", "subjectRelationTypeG":"", "subjectRelationTypeH":"", "subjectRelationTypeI":"", "subjectRelationTypeJ":true, "subjectRelationTypeK":"", "subjectRelationTypeL":"", "subjectRelationTypeZ":"",'
            ||' "subjectRelationTypeOther":"", "statusCode":"", "statusDate":""}'
          ;
          output;

          entity_level_code='INSTITUTION2BRANCH';
          default_ui_json='{"branchRoleCode":""}';
          ;
          output;    
          
     run;
     
%if &syserr <= 4 and &rc_debug=N %then
%do;
    
     proc sql;
     delete 
     from seg_kc.fsk_rc_form_default
     where form_config_key=&form_config_key;

     proc append base=seg_kc.fsk_rc_form_default data=fsk_rc_form_default_sarx force;
     run;

%end;
     
     

%mend;
 



%macro rc_fincen_load_ref_sarx;

/******************************************************************************/
/*  Load LOV values (report data codes and labels)                            */
/******************************************************************************/

data lov_sarx;
          
    infile  rc_tmplt(rc_fincen_sarx_ref.csv)
            dsd lrecl=32764 truncover firstobs=2 delimiter=',' ;
   
    length tmp_word source_ref_list$ 32767;
    if 0 then set seg_kc.fsk_lov;
    input
           lov_type_name $            
           source_ref_list $                
     ;
    
    retain lov_language_desc 'en';
    retain active_flg 'Y';
     
    keep lov_type_name lov_type_code lov_type_desc
         lov_sort_position_number active_flg lov_language_desc;
   
    
    tmp_word='';
    tmp_i=1;
    do until (scan(source_ref_list,tmp_i,'|')='');
       tmp_word=left(scan(source_ref_list,tmp_i,'|')); 
       /* use the first space to separate the code from the description */     
       lov_type_code=substrn(tmp_word,1,indexc(tmp_word,' ')-1);
       lov_type_desc=substrn(tmp_word,indexc(tmp_word,' '));
       lov_sort_position_number=tmp_i;
       output;
       tmp_i+1;
    end;
 
run;

%if &syserr <= 4 and &rc_debug=N %then
%do;
     
     proc sql noprint;
         delete from seg_kc.fsk_lov as ref
         where exists 
          (select lov_type_name
          from lov_sarx as sarx
          where sarx.lov_type_name=ref.lov_type_name 
           );

     proc append base=seg_kc.fsk_lov data=lov_sarx force;
     run;
%end;
%mend;


%macro rc_fincen_load_mapping_sarx;

/****************************************************************************************/
/*  Load code mapping table                                                             */
/****************************************************************************************/

data code_mapping_sarx;
          
     infile  rc_tmplt(rc_fincen_sarx_code_mapping.csv)
             dsd lrecl=32764 truncover firstobs=2 delimiter=',' ;  
   
  
     if 0 then set seg_kc.fsk_rc_form_code_mapping;
     form_config_key=&form_config_key;
     input
            format_name $
            input_code  $
            output_code $ 
     ;
     if format_name ne '' then output;
 
run;

%if &syserr <= 4 and &rc_debug=N %then
%do;
     
     proc sql noprint;
         delete from seg_kc.fsk_rc_form_code_mapping 
     where form_config_key=&form_config_key;

     proc append base=seg_kc.fsk_rc_form_code_mapping (dbforce=yes) 
                data=code_mapping_sarx force;
     run;

%end;
%mend;

%macro rc_fincen_load_error_code_sarx;

/****************************************************************/
/* Load FINCEN sarx error codes                                 */
/****************************************************************/

data rc_cfg.sarx_fincen_error_code(%fcf_get_ds_opts(lib_name=rc_cfg, ds_name=sarx_fincen_error_code, output_ds=Y));

      attrib ERROR_RECORD_TYPE length=$32 label='Error record type'
             ERROR_CODE  length=$10 label='Error Type Code'
             ERROR_DESC length=$4000 label='Error Text'              
             ERROR_TYPE_CODE length=$1 label='Error Severity Code' 
             ERROR_TYPE_TEXT length=$32 label='Error Severity Description'
             ASSOC_ELEMENT length=$256 label='Associated Element(s)'
             FIELD_REFERENCE length=$4000 label='Field Reference'
      ;
   
     infile rc_tmplt(rc_fincen_sarx_error_code.csv)  
             dsd lrecl=32764 truncover firstobs=2  delimiter=',' ;            
     input error_record_type $
           error_code $          
           error_desc $             
           error_type_text $
           assoc_element $
           field_reference $
    ;
    error_desc=compress(error_desc,,'kw');
    assoc_element=compress(assoc_element,,'kw');
    field_reference=compress(field_reference,,'kw');
    select (error_type_text);
        when ('Fatal') error_type_code='F';    
        when ('Warning (Primary)') error_type_code='P';
        when ('Warning') error_type_code='S';
    otherwise;
  end;

run;
  

%mend;



%macro rc_add_lov_sarx;

/******************************************************************************/
/*  Define long and short labels for SARX form                                */
/******************************************************************************/

 data add_lov_sarx;
      if 0 then set seg_kc.fsk_lov;
      retain lov_language_desc 'en';
      retain active_flg 'Y';       
      lov_type_name="RC_FORM_NAME_SHORT";              
      lov_type_code="&form_config_key";
      lov_type_desc="&form_type_code";
      lov_sort_position_number=&form_config_key;
      output;
      lov_type_name="RC_FORM_NAME_LONG";              
      lov_type_code="&form_config_key";
      lov_type_desc='FinCEN Suspicious Activity Report (SARX)';
      lov_sort_position_number=&form_config_key;
      output;
          
 run;

 %if &syserr <= 4 and &rc_debug=N %then
 %do;
     
     proc sql noprint;
         delete from seg_kc.fsk_lov as ref
         where exists 
          (select lov_type_name
          from add_lov_sarx as sarx
          where sarx.lov_type_name=ref.lov_type_name and sarx.lov_type_code=ref.lov_type_code
           );

     
    proc append base=seg_kc.fsk_lov data=add_lov_sarx force;
    run;
%end;    

%mend;
 
 

/* Change rc_debug to Y for testing */
%let rc_debug=N;

%let form_config_key=311;
%let form_type_code=SARX;
 
%rc_fincen_load_form_config_sarx;   /* load form configuration data to SEG_KC.FSK_RC_FORM_CONFIG        */
 
%rc_fincen_load_default_sarx; /* load form default json to SEG_KC.FSK_RC_FORM_DEFAULT  */ 

%rc_fincen_load_ref_sarx;  /* load drop down codes and descriptions to SEG_KC.FSK_LOV */

%rc_fincen_load_error_code_sarx; /* create RC_CFG.SARX_FINCEN_ERROR_CODE */

%rc_fincen_load_mapping_sarx; /* load mapping for customer and/or case data to report data */

%rc_add_lov_sarx; /* add labels for SARX to SEG_KC.FSK_LOV */






