/******************************************************************************/
/* This code may serve as a model for how you can validate data fields and    */ 
/* formatting in auto-generated CTRX files, prior to submission.              */    
/* This macro will also be used by the Stored Process that is invoked by      */
/* the 'Validate Report' capability when editing report details.              */              
/* The code provided is merely a sample; for your particular implementation,  */
/* code modifications may be needed and testing will be required.             */
/*                                                                            */
/* File modifications from 6.3 to 7.1 for field name changes:                 */
/*      source_field_nm ==> target_field_name                                 */
/*      error_cd        ==> error_code                                        */
/*      X_*             ==> new naming convention variables                   */
/******************************************************************************/
/*-----------------------------------------------------------------------------
 * Copyright (c) 2018 by SAS Institute Inc., Cary, NC 27513 USA
 *  ---All Rights Reserved.
 *----------------------------------------------------------------------------*/


%MACRO VLDT_CTRX_branch;

/* E3: The element is not recorded.  */
error_code="E3";
target_field_name="branch_prim_fed_reg_code";
if branch_prim_fed_reg_code=""  then output;

/* E5: The element contains a value that is not a valid code. */
error_code="E5";
target_field_name="branch_prim_fed_reg_code";
if branch_prim_fed_reg_code ne "" and index("ABCDEFGZ",strip(branch_prim_fed_reg_code))=0  then output;

/* E6: The element is not recorded or does not contain a value. */
error_code="E6";
target_field_name="branch_name";
if branch_name=""  then output;

/* E8: The element is not recorded or does not contain a value and unknown is not indicated.  */
error_code="E8";
target_field_name="branch_tax_id";
if branch_tax_id="" and branch_tax_id_unknown_flag ne "X" then output;

/* E7: The element contains an invalid number string for a US TIN.  */
error_code="E7";
target_field_name="branch_tax_id";
if ((length(branch_tax_id) ne 9 or branch_tax_id in ('999999999' '000000000' '123456789') or notdigit(strip(branch_tax_id))))  
   and (branch_tax_id_unknown_flag ne "X") then output;

/* E12: The element is not recorded or does not contain a value. */
error_code="E12";
target_field_name="branch_address";
if branch_address=""  then output;

/* E13: The element is not recorded or does not contain a value. */
error_code="E13";
target_field_name="branch_city_name";
if branch_city_name=""  then output;

/* E15: The element contains a value that is not a valid code. */
error_code="E15";
target_field_name="branch_state_code";
if (put((trim(branch_country_code)||'_'||trim(branch_state_code)),$RT_STATE_PROVINCE.) ne 'VALID')   
    and branch_country_code in ('CA' 'MX' 'US' 'AS' 'GU' 'MH' 'FM' 'MP' 'PW' 'PR') then output;

/* E14: The element is not recorded or does not contain a value. */
error_code="E14";
target_field_name="branch_state_code";
if branch_state_code=""  and branch_country_code in ('CA' 'MX' 'US' 'AS' 'GU' 'MH' 'FM' 'MP' 'PW' 'PR') then output;

/* E20: The element contains a value that is not a valid code. */
error_code="E20";
target_field_name="branch_country_code";
if (put((branch_country_code),$RT_COUNTRY.) ne 'VALID') then output;

/* E17: The element is not recorded or does not contain a value. */
error_code="E17";
target_field_name="branch_zip_code";
if branch_zip_code=""  then output;

/* E18: The value recorded contains non- numeric characters or is in an invalid format and the country is US or a U.S. Territory. */
error_code="E18";
target_field_name="branch_zip_code";
if (length(branch_zip_code) =9 and substr(branch_zip_code,6,4) in ('0000' '9999'))  
    and branch_country_code in ('US' 'AS' 'GU' 'MH' 'FM' 'MP' 'PW' 'PR') then output;

/* E18: The value recorded contains non- numeric characters or is in an invalid format and the country is US or a U.S. Territory. */
error_code="E18";
target_field_name="branch_zip_code";
if (((length(branch_zip_code) ne 5 and length(branch_zip_code) ne 9)  or notdigit(strip(branch_zip_code)) > 0)) and (branch_zip_code ne ' ') 
   and branch_country_code in ('US' 'AS' 'GU' 'MH' 'FM' 'MP' 'PW' 'PR') then output;


/* E23: The element is recorded but without a value (i.e. the value is null). */
error_code="E23";
target_field_name="branch_type_ctr_code";
if branch_type_ctr_code=""  then output;

/* E24: The element contains a value that is not a valid code. */
error_code="E24";
target_field_name="branch_type_ctr_code";
if branch_type_ctr_code ne "" and index("ABCDZ",strip(branch_type_ctr_code))=0  then output;

/* E25: The element does not contain a value and Other is indicated. */
error_code="E25";
target_field_name="branch_type_ctr_other";
if branch_type_ctr_other="" and (branch_type_ctr_code  ='Z') then output;

/* E28: The element is recorded but without a value (i.e. the value is null). */
error_code="E28";
target_field_name="branch_gaming_type_code";
if branch_gaming_type_code="" and (branch_type_ctr_code = 'A') then output;

/* E29: The element contains a value that is not a valid code. */
error_code="E29";
target_field_name="branch_gaming_type_code";
if branch_gaming_type_code ne "" and index("ABCZ",strip(branch_gaming_type_code))=0 and (branch_type_ctr_code = 'A') then output;

/* E31: The element does not contain a value and Other is indicated. */
error_code="E31";
target_field_name="branch_gaming_type_other";
if branch_gaming_type_other="" and (branch_gaming_type_code = 'Z') then output;

/* E34: The element contains a value that is not a valid code. */
error_code="E34";
target_field_name="branch_id_type_code";
if branch_id_type_code ne "" and index("ABCDE",strip(branch_id_type_code))=0  then output;

/* E35: The element is not recorded or does not contain a value. */
error_code="E35";
target_field_name="branch_id";
if branch_id="" and (branch_id_type_code ne '') then output;

/* E36: The cash-in and cash-out amounts for the transaction location are blank. */
error_code="E36";  
if ( ((cashInAmount=0) or (cashInAmount=.)) AND ((cashOutAmount=0) or (cashOutAmount=.)) ) then do ;
    target_field_name="cashInAmount";
    output;
	target_field_name="cashOutAmount";
    output;
	end;

%mend; /* VLDT_CTRX_branch */


%MACRO VLDT_CTRX_report; 
                            
/*C301: Filing type is blank.*/
/* B1: The type of filing is not specified. */
error_code="B1";
target_field_name="filingTypeCode";
if filingTypeCode=""  then output;

/*C302: Filing type contains an invalid code.*/
/* B4:The element contains a value not equal to 'Y' or the element is null. */
error_code="B4";
target_field_name="filingTypeCode";
if filingTypeCode ne "" and index("ABC",strip(filingTypeCode))=0  then output;

/*C303: Prior report Document Control Number or BSA Identifier is blank.*/
/* B5: The element is not recorded and <CorrectsAmendsPriorReportIndicator> contains a 'Y' value. */
error_code="B5";
target_field_name="priorAgencyRefID";
if priorAgencyRefID="" and (priorAgencyRefID not in ( 'A',' ')) then output;

/*C304: Prior report Document Control Number or BSA Identifier contains non-numeric values.*/
/* B7: The value recorded for the element contains non-numeric characters. */
error_code="B7";
target_field_name="priorAgencyRefID";
if (priorAgencyRefID ne "" and (notdigit(strip(priorAgencyRefID)) > 0)) then output;

/*C307: Date of transaction is blank.*/
/* D1: The element is recorded but without a value (i.e. the value is null) */
error_code="D1";
target_field_name="transactionDate";
if transactionDate=.  then output;

/*C308: Date of transaction is greater than the date filed.*/
/* D3: The value recorded is greater than the date filed.*/
error_code="D3";
target_field_name="transactionDate";
if (transactionDate > today())  then output;

/*C309: Date of transaction is prior to January 1, 1950.*/
/* D4: The value recorded is prior to January 1, 1950. */
error_code="D4";
target_field_name="transactionDate";
if (transactionDate < mdy(1,1,1950)) and (transactionDate ne .) then output;

/*C311: Method of transaction(s) contains an invalid code.*/
/* D5: The element contains a value not equal to “Y” or the element is null. */
error_code="D5";
target_field_name="transactionType";
if (compress(transactionType,'ABCDEF') ne ' ') and (transactionType ne ' ') then output;

/*C310: Date of transaction is not a numeric 8-position field in MMDDCCYY format where MM=month, DD=day,  CC=century, YY=year.*/
/* D2: The value recorded contains non-numeric characters or is in an invalid format.  */
error_code="D2";
target_field_name="transactionDate";
if put(transactionDate,MMDDYYN8.) = " "  then output;

/*C312: Total cash-in and total cash-out are blank.*/
/* D26: The total cash in and total cash out amounts for the FinCEN CTR are blank. (TotalCashOutAmountText) */
/* D12: The total cash in and total cash out amounts for the FinCEN CTR are blank. (totalCashInReceiveAmountText) */
error_code="D12";
if ( ((usCashInAmount  <= 0) OR (usCashInAmount =.))  and
     ((usCashOutAmount <= 0) OR (usCashOutAmount =.)) ) then do;
	 target_field_name="usCashInAmount";
	 output;
	 error_code="D26";
	 target_field_name="usCashOutAmount";
	 output;
	 end;

/*C313: Total cash-in contains non-numeric values or is in an invalid format.*/
/* D14: The value recorded for the element contains non-numeric characters */
error_code="D14";
target_field_name="usCashInAmount";
if (index(put(usCashInAmount,Z15.) ,'E') > 0) and (usCashInAmount ne .) then output;

/*C314: Total cash-in Deposit(s) amount contains non-numeric values or is in an invalid format.*/
/* D16: The value recorded for the element contains non-numeric characters. */
error_code="D16";
target_field_name="usCashInAmountA";
if (usCashInAmountA <= 0 or index(put(usCashInAmountA,Z15.) ,'E') > 0) and (usCashInAmountA ne .) then output;

/*C315: Total cash-in Payment(s) amount contains non-numeric values or is in an invalid format.*/
/* D16: The value recorded for the element contains non-numeric characters. */
error_code="D16";
target_field_name="usCashInAmountB";
if (usCashInAmountB <= 0 or index(put(usCashInAmountB,Z15.) ,'E') > 0) and (usCashInAmountB ne .) then output;

/*C316: Total cash-in Currency received for fund transfer(s) out amount contains non-numeric values or is in an invalid format.*/
/* D16: The value recorded for the element contains non-numeric characters. */
error_code="D16";
target_field_name="usCashInAmountC";
if (usCashInAmountC <= 0 or index(put(usCashInAmountC,Z15.) ,'E') > 0) and (usCashInAmountC ne .) then output;

/*C317: Total cash-in Purchase of negotiable instrument(s) amount contains non-numeric values or is in an invalid format.*/
/* D16: The value recorded for the element contains non-numeric characters. */
error_code="D16";
target_field_name="usCashInAmountD";
if (usCashInAmountD <= 0 or index(put(usCashInAmountD,Z15.) ,'E') > 0) and (usCashInAmountD ne .) then output;

/*C318: Total cash-in Currency exchange(s) amount contains non-numeric values or is in an invalid format.*/
/* D16: The value recorded for the element contains non-numeric characters. */
error_code="D16";
target_field_name="usCashInAmountE";
if (usCashInAmountE <= 0 or index(put(usCashInAmountE,Z15.) ,'E') > 0) and (usCashInAmountE ne .) then output;

/*C319: Total cash-in "Currency to prepaid access" amount contains non-numeric values or is in an invalid format.*/
/* D16: The value recorded for the element contains non-numeric characters. */
error_code="D16";
target_field_name="usCashInAmountF";
if (usCashInAmountF <= 0 or index(put(usCashInAmountF,Z15.) ,'E') > 0) and (usCashInAmountF ne .) then output;

/*C320: Total cash-in Purchase(s) of casino chips, tokens, and other gaming instruments amount contains non-numeric values or is in an invalid format.*/
/* D16: The value recorded for the element contains non-numeric characters. */
error_code="D16";
target_field_name="usCashInAmountG";
if (usCashInAmountG <= 0 or index(put(usCashInAmountG,Z15.) ,'E') > 0) and (usCashInAmountG ne .) then output;

/*C321: Total cash-in "Currency wager(s) including money plays" amount contains non-numeric values or is in an invalid format.*/
/* D16: The value recorded for the element contains non-numeric characters. */
error_code="D16";
target_field_name="usCashInAmountH";
if (usCashInAmountH <= 0 or index(put(usCashInAmountH,Z15.) ,'E') > 0) and (usCashInAmountH ne .) then output;

/*C322: Total cash-in Bills inserted into gaming devices amount contains non-numeric values or is in an invalid format.*/
/* D16: The value recorded for the element contains non-numeric characters. */
error_code="D16";
target_field_name="usCashInAmountI";
if (usCashInAmountI <= 0 or index(put(usCashInAmountI,Z15.) ,'E') > 0) and (usCashInAmountI ne .) then output;

/*C323: Total cash-in Other amount contains non-numeric values or is in an invalid format.*/
/* D16: The value recorded for the element contains non-numeric characters. */
error_code="D16";
target_field_name="usCashInAmountOther";
if (usCashInAmountOther <= 0 or index(put(usCashInAmountOther,Z15.) ,'E') > 0) and (usCashInAmountOther ne .) then output;

/*C324: Total cash-in Other description is blank.*/
/* D21: The element does not contain a value and Other is indicated. */
error_code="D21";
target_field_name="usCashInAmountOther";
if usCashInTypeOther ne "" and (usCashInAmountOther < 0) then output;

/*C327: Total cash-out contains non-numeric values or is in an invalid format.*/
/* D28: The value recorded for the element contains non-numeric characters. */
error_code="D28";
target_field_name="usCashOutAmount";
if (index(put(usCashOutAmount,Z15.) ,'E') > 0) and (usCashOutAmount ne .) then output;

/*C328: Total cash-out "Withdrawal(s)" amount contains non-numeric values or is in an invalid format.*/
/* D30: The value recorded for the element contains non-numeric characters. */
error_code="D30";
target_field_name="usCashOutAmountA";
if (usCashOutAmountA <= 0 or index(put(usCashOutAmountA,Z15.) ,'E') > 0) and (usCashOutAmountA ne .) then output;

/*C329: Total cash-out Advance(s) on credit (including markers) amount contains non-numeric values or is in an invalid format.*/
/* D30: The value recorded for the element contains non-numeric characters. */
error_code="D30";
target_field_name="usCashOutAmountB";
if (usCashOutAmountB <= 0 or index(put(usCashOutAmountB,Z15.) ,'E') > 0) and (usCashOutAmountB ne .) then output;

/*C330: Total cash-out "Currency paid from funds transfer(s) in" amount contains non-numeric values or is in  an invalid format.*/
/* D30: The value recorded for the element contains non-numeric characters. */
error_code="D30";
target_field_name="usCashOutAmountC";
if (usCashOutAmountC <= 0 or index(put(usCashOutAmountC,Z15.) ,'E') > 0) and (usCashOutAmountC ne .) then output;

/*C331: Total cash-out Negotiable instrument(s) cashed amount contains non-numeric values or is in an invalid format.*/
/* D30: The value recorded for the element contains non-numeric characters. */
error_code="D30";
target_field_name="usCashOutAmountD";
if (usCashOutAmountD <= 0 or index(put(usCashOutAmountD,Z15.) ,'E') > 0) and (usCashOutAmountD ne .) then output;

/*C332: Total cash-out "Currency exchange(s)" amount contains non-numeric values or is in an invalid format.*/
/* D30: The value recorded for the element contains non-numeric characters. */
error_code="D30";
target_field_name="usCashOutAmountE";
if (usCashOutAmountE <= 0 or index(put(usCashOutAmountE,Z15.) ,'E') > 0) and (usCashOutAmountE ne .) then output;

/*C333: Total cash-out Currency to prepaid access amount contains non-numeric values or is in an invalid format.*/
/* D30: The value recorded for the element contains non-numeric characters. */
error_code="D30";
target_field_name="usCashOutAmountF";
if (usCashOutAmountF <= 0 or index(put(usCashOutAmountF,Z15.) ,'E') > 0) and (usCashOutAmountF ne .) then output;

/*C334: Total cash-out Redemption(s) of casino chips, tokens, TITO tickets, and other gaming instruments amount contains non-numeric values or is in an invalid format.*/
/* D30: The value recorded for the element contains non-numeric characters. */
error_code="D30";
target_field_name="usCashOutAmountG";
if (usCashOutAmountG <= 0 or index(put(usCashOutAmountG,Z15.) ,'E') > 0) and (usCashOutAmountG ne .) then output;

/*C335: Total cash-out Payment(s) on wager(s) (including race book and OTB or sports pool) amount contains non-numeric values or is in an invalid format.*/
/* D30: The value recorded for the element contains non-numeric characters. */
error_code="D30";
target_field_name="usCashOutAmountH";
if (usCashOutAmountH <= 0 or index(put(usCashOutAmountH,Z15.) ,'E') > 0) and (usCashOutAmountH ne .) then output;

/*C336: Total cash-out Travel and complimentary expenses and gaming incentives amount contains non-numeric values or is in an invalid format.*/
/* D30: The value recorded for the element contains non-numeric characters. */
error_code="D30";
target_field_name="usCashOutAmountI";
if (usCashOutAmountI <= 0 or index(put(usCashOutAmountI,Z15.) ,'E') > 0) and (usCashOutAmountI ne .) then output;

/*C337: Total cash-out Payment for tournament, contest or other promotions amount contains non-numeric values  or is in an invalid format.*/
/* D30: The value recorded for the element contains non-numeric characters. */
error_code="D30";
target_field_name="usCashOutAmountJ";
if (usCashOutAmountJ <= 0 or index(put(usCashOutAmountJ,Z15.) ,'E') > 0) and (usCashOutAmountJ ne .) then output;

/*C338: Total cash-out Other amount contains non-numeric values or is in an invalid format.*/
/* D28: The value recorded for the element contains non-numeric characters. */
error_code="D28";
target_field_name="usCashOutAmountOther";
if (usCashOutAmountOther <= 0 or index(put(usCashOutAmountOther,Z15.) ,'E') > 0) and (usCashOutAmountOther ne .) then output;

/*C339: Total cash-out Other description is blank.*/
/* D35: The element does not contain a value and Other is indicated. */
error_code="D35";
target_field_name="usCashOutTypeOther";
if usCashOutTypeOther ne "" and (usCashOutAmountOther < 0) then output;

/*C342: Total cash-in is not equal to the total amounts recorded in items 25a-i and 25z.*/
/* D15: The sum of all subtotal cash in amounts does not equal the total cash in amount recorded.*/
error_code="D15";
target_field_name="usCashInAmount";
if (usCashInAmount ne sum(usCashInAmountA,usCashInAmountB,usCashInAmountC,usCashInAmountD,usCashInAmountE,
                            usCashInAmountF,usCashInAmountG,usCashInAmountH,usCashInAmountI,usCashInAmountOther)) 
                            and (usCashInAmount > 0) then output;

/*C343: Total cash-out is not equal to the total amounts recorded in items 27a-j and 27z.*/
/* D29: The sum of all subtotal cash out amounts does not equal the total cash out amount recorded. */
error_code="D29";
target_field_name="usCashOutAmount";
if (usCashOutAmount ne sum(usCashOutAmountA,usCashOutAmountB,usCashOutAmountC,usCashOutAmountD,usCashOutAmountE,
                             usCashOutAmountF,usCashOutAmountG,usCashOutAmountH,usCashOutAmountI,usCashOutAmountJ,
                             usCashOutAmountOther)) and (usCashOutAmount > 0) then output;

/*C344: Contact office is blank.*/
/* G3: The element is not recorded or does not contain a value.*/
error_code="G3";
target_field_name="contactOffice";
if contactOffice=""  then output;

/*C345: Contact telephone number is blank.*/
/* G5: The element is not recorded or does not contain a value (e.g. the value is null). */
error_code="G5";
target_field_name="contactPhoneNumber";
if contactPhoneNumber=""  then output;

/*C346: Contact telephone number is contains non-numeric values or is in an invalid format.*/
/* G4: The value recorded for the element contains non-numeric characters. */
error_code="G4";
target_field_name="contactPhoneNumber";
if (contactPhoneNumber ne "" and (notdigit(strip(contactPhoneNumber)) > 0))   then output;
 

/*C347: Date filed is blank.*/
/* F37: The element is recorded but without a value (i.e. the value is null).  */

/*C348: Date filed is not a numeric 8-position field in MMDDCCYY format where MM=month, DD=day, CC=century, YY=year.*/
/* F38: The value recorded for the element is not in the correct format (YYYYMMDD) */
error_code="F38";
target_field_name="FILED_DATE";
if put(FILED_DATE,YYMMDDN8.) = " "  then output;
 

/*C349: Date filed is greater than the current date or is less than 01/01/2000.*/

/*C350: Total cash-in and/or total cash-out contains an amount less than or equal to $10,000.*/
/* D13: The Total cash in and/or total cash out amounts for the FinCEN CTR contain an amount less than or equal to $10,000. (TotalCashInReceiveAmountText)*/
/* D27: The Total cash in and/or total cash out amounts for the FinCEN CTR contain an amount less than or equal to $10,000. (TotalCashOutAmountText)*/
error_code="D13";
target_field_name="usCashInAmount";
if (0 < usCashInAmount <= 10000) then output;
error_code="D27";
target_field_name="usCashOutAmount";
if (0 < usCashOutAmount <= 10000) then output;


%mend; /* VLDT_CTRX_report */


%MACRO VLDT_CTRX_party;

/*C401: Person last/legal name is blank.*/
/* C8: The element is not recorded or does not contain a value, <PartyNameTypeCode> is "L" (Legal), and unknown is not indicated. */
error_code="C8";
target_field_name="lastName";
if lastName="" and (lastNameUnknownFlag NE "X") then output;

/*C402: Person first name is blank.*/
/* C11: The element is not recorded or does not contain a value for an individual and unknown is not indicated.  */
error_code="C11";
target_field_name="firstName";
if firstName="" and (firstNameUnknownFlag NE "X" and entityFlag ne "X") then output;

/*C403: Person gender contains an invalid code.*/
/* C13: The person is an individual and gender is not specified in FemaleGenderIndicator, MaleGenderIndicator, or UnknownGenderIndicator. */
error_code="C13";
target_field_name="gender";
if index("ABC",strip(gender))=0 and (entityFlag ne "X") then output;

/*C404: Person street address is blank.*/
/* C16: The element is not recorded or does not contain a value and unknown is not indicated. */
error_code="C16";
target_field_name="address";
if address="" and (addressUnknownFlag NE "X") then output;

/*C405: Person city is blank.*/
/* C18: The element is not recorded or does not contain a value and unknown is not indicated. */
error_code="C18";
target_field_name="city";
if city="" and (cityUnknownFlag NE "X") then output;

/*C406: Person state is not a valid state code and person country is equal to CA, MX, or US.*/
/* C21: The element contains a value that is not a valid code. */
error_code="C21";
target_field_name="stateCode";
if (put((trim(countryCode)||'_'||trim(stateCode)),$RT_STATE_PROVINCE.) ne 'VALID') and
    ((stateCode ne ' ' and countryCode in ('CA' 'MX' 'US' 'AS' 'GU' 'MH' 'FM' 'MP' 'PW' 'PR'))) then output;

/*C407: Person state is blank and person country is equal to CA, MX, or US.*/
/* C20: The element is not recorded or does not contain a value and unknown is not indicated. */
error_code="C20";
target_field_name="stateCode";
if stateCode="" and (stateUnknownFlag NE "X" and countryCode in ('CA' 'MX' 'US' 'AS' 'GU' 'MH' 'FM' 'MP' 'PW' 'PR')) then output;

/*C408: Person ZIP Code or foreign postal code is blank.*/
/* C25: The element is not recorded or does not contain a value and unknown is not indicated. */
error_code="C25";
target_field_name="postalCode";
if postalCode="" and (postalCodeUnknownFlag NE "X") then output;

/*C409: Person ZIP Code is a nine digit code ending in four zeros/nines and person country is equal to US.*/
/* C26: The value recorded contains non- numeric characters or is in an invalid format and the country is US or a U.S. Territory. */
error_code="C26";
target_field_name="postalCode";
if ((LENGTH(postalCode)=9 AND SUBSTRN(postalCode,6,4) IN  ('0000' '9999' ))) and ((postalCodeUnknownFlag ne "X" and countryCode = 'US')) then output;

/*C410: Person ZIP Code is not equal to five or nine digits or contains non-numeric values and person country is  equal to US.*/
/* C26: The value recorded contains non- numeric characters or is in an invalid format and the country is US or a U.S. Territory. */
error_code="C26";
target_field_name="postalCode";
if (((length(postalCode) ne 5 and length(postalCode) ne 9)  or notdigit(strip(postalCode)))) and ((postalCodeUnknownFlag NE "X" and countryCode='US')) then output;

/*C411: Person country is blank.*/
/* C28: The element is not recorded or does not contain a value and unknown is not indicated. */
error_code="C28";
target_field_name="countryCode";
if countryCode="" and (countryUnknownFlag NE "X") then output;

/*C412: Person country is not a valid country code.*/
/* C29: The element contains a value that is not a valid code. */
error_code="C29";
target_field_name="countryCode";
if (put(countryCode,$RT_COUNTRY.) ne 'VALID') and (countryUnknownFlag NE "X") then output;

/*C413: Person TIN is blank.*/
/* C32: The element is not recorded or does not contain a value and unknown is not indicated. */
error_code="C32";
target_field_name="TaxID";
if TaxID="" and (TaxIDUnknownFlag ne "X") then output;

/*C414: Person TIN is an invalid number string such as all zeros, all nines, 123456789, or a U.S. TIN and not nine digits.*/
/* C33: The element contains an invalid number string for a US TIN.  */
error_code="C33";
target_field_name="TaxID";
if ((length(TaxID) ne 9 or TaxID in ('999999999' '000000000' '123456789') or notdigit(strip(TaxID)))) and (TaxID ne ' ') 
   and (TaxIDUnknownFlag ne "X") then output;

/*C415: Person TIN type is blank.*/
/* C32: The element is not recorded or does not contain a value and unknown is not indicated. */
error_code="C32";
target_field_name="TaxID";
if TaxID="" and (TaxIDUnknownFlag ne "X") then output;


/*C417: Person date of birth is blank.*/
/* C37: The element is not recorded for an individual and unknown is not indicated. */
error_code="C37";
target_field_name="birthDate";
if birthDate=. and (birthDateUnknownFlag NE "X" and entityFlag ne "X") then output;

/*C418: Person date of birth is less than January 1, 1900.*/
/* C39: The date of birth is less than January 1, 1900 or is greater than the date of transaction.*/
error_code="C39";
target_field_name="birthDate";
if (birthDate  < mdy(1,1,1900)) and (birthDate > .) then output;

/*C419: Person date of birth contains non-numeric values or is in an invalid format.*/
/* C40: The value recorded for the element is not in the correct format (YYYYMMDD) or is not a valid date. */
error_code="C40";
target_field_name="birthDate";
if birthDate=. and (birthDateUnknownFlag NE "X" and entityFlag ne "X") then output;

/*C420: Person telephone number contains non-numeric values or is in an invalid format.*/
error_code="C420";
error_code="C42";
target_field_name="phoneNumber";
if ((phoneNumber ne compress(phoneNumber,'0123456789','k'))) and (phoneNumber ne ' ') then output;

/*C421: Person e-mail address is in an invalid format.*/
error_code="C421";
error_code="C43";
target_field_name="emailAddress";
if (prxmatch("/[^@]+@[^@]+\.[^@]+/", emailAddress) = 0) and (emailAddress ne ' ') then output;

/*C422: Person identification is blank.*/
/* C45: The element is recorded but without a value (i.e. the value is null). */
error_code="C45";
target_field_name="IDType";
if IDType=""  then output;

/*C423: Person identification type contains an invalid code.*/
/* C46: The element contains a value that is not a valid code. */
error_code="C46";
target_field_name="IDType";
if IDType ne "" and index("ABCDZ",strip(IDType))=0  then output;

/* C47: The element is missing or does not contain a value (i.e. the value is null), unknown is not indicated,  */
/*      and the ID type is not Other. */
error_code="C47";
target_field_name="IDNumber";
if (IDNumber = ' ') and (index(IDType,"AZ") > 0) then output;

/*C424: Person identification other description is blank.*/
/* C48: The element is not recorded or does not contain a value and Other is indicated. */
error_code="C48";
target_field_name="IDTypeOther";
if (IDTypeOther = ' ') and (index(IDType,"Z") > 0) then output;

/* C50: The element is not recorded or does not contain a value and unknown is not indicated, and the  */
/*      corresponding country is US, CA, MX or a US Territory.                                         */
error_code="C50";
target_field_name="IDAuthorityStateCode";
if IDAuthorityStateCode="" and (IDType NE 'A') 
   and (IDAuthorityCountryCode IN ('CA' 'MX' 'US' 'AS' 'GU' 'MH' 'FM' 'MP' 'PW' 'PR')) then output;
   
/* C51: The element contains a value that is not a valid code.  */
error_code="C51";
target_field_name="IDAuthorityStateCode";
if IDAuthorityStateCode ^= "" and (IDType = 'A') then output;

/* C54: The element contains a value that is not a valid code.  */
error_code="C54";
target_field_name="IDAuthorityCountryCode";
if IDAuthorityCountryCode ^= "" and (IDType = 'A') then output;

/*C425: Person identification issuing state is not a valid state code and person country is equal to CA,  MX, or US.*/
/* C55: State code and country code mismatch when US Territory is recorded. */
error_code="C55";
target_field_name="IDAuthorityStateCode";
if (put((trim(IDAuthorityCountryCode)||'_'||trim(IDAuthorityStateCode)),$RT_STATE_PROVINCE.) ne 'VALID') 
   and (IDAuthorityCountryCode IN ('CA' 'MX' 'US' 'AS' 'GU' 'MH' 'FM' 'MP' 'PW' 'PR')) 
   and (index("BCDZ",strip(IDType)) > 0) then output;

/* C53: The element is not recorded or does not contain a value and unknown is not indicated. */
error_code="C53";
target_field_name="IDAuthorityCountryCode";
if IDAuthorityCountryCode="" and (index("AZ",strip(IDType)) = 0) then output;
   
/*C426: Person identification issuing country is not a valid country code.*/
/* C54: The element contains a value that is not a valid code. */
error_code="C54";
target_field_name="IDAuthorityCountryCode";
if (put(IDAuthorityCountryCode,$RT_COUNTRY.) ne 'VALID') and (IDAuthorityCountryCode  > '') then output;

/*C429: Person identification number is blank.*/
/* C56 The element is not recorded or does not contain a value and unknown is not indicated. */
error_code="C56";
target_field_name="IDNumber";
if IDNumber="" and (IDType NE 'A') then output;

/*C427: Cash-in amount for the person involved in the transaction contains non-numeric values or is in an invalid format.*/
/* C59: The value recorded for the element contains non-numeric characters. */
error_code="C59";
target_field_name="cashInAmount";
if ((cashInAmount=0 or notdigit(put(cashInAmount,z15.)))) and (cashInAmount ne .) then output;

/*C428: Cash-out amount for the person involved in the transaction contains non-numeric values or is in an invalid format.*/
/* C61: The value recorded for the element contains non-numeric characters. */
error_code="C61";
target_field_name="cashOutAmount";
if ((cashOutAmount=0 or notdigit(put(cashOutAmount,z15.)))) and (cashOutAmount ne .) then output;

/* C58: The cash-in and cash-out amounts transacted by or for the person involved are blanked. */
error_code="C58";  
if ( ((cashInAmount=0) or (cashInAmount=.)) AND ((cashOutAmount=0) or (cashOutAmount=.)) ) then do ;
    target_field_name="cashInAmount";
    output;
	target_field_name="cashOutAmount";
    output;
	end;

/* C1: A required party associated with either the person on whose behalf the transaction was conducted  */
/*     or the person conducting transaction on own behalf is missing.                                    */
error_code="C1";
target_field_name="personInvolvedTypeCode";
if index("ABCD",strip(personInvolvedTypeCode))=0  then output;



%mend; /* VLDT_CTRX_party */


%MACRO VLDT_CTRX_foreign_cash_in;

/*C325: Foreign cash-in amount contains non-numeric values or is in an invalid format.*/
/* D16: The value recorded for the element contains non-numeric characters. */
error_code="D16";
target_field_name="foreignCashInAmount";
if (foreignCashInAmount <= 0 or index(put(foreignCashInAmount,Z15.) ,'E') > 0) and (foreignCashInAmount ne .) then output;

/*C326: Foreign cash-in country is not a valid country code.*/
/* D25: The element contains a value that is not a valid code. */
error_code="D25";
target_field_name="foreignCashInCountryCode";
if (put(foreignCashInCountryCode,$RT_COUNTRY.) ne 'VALID')  and (foreignCashInCountryCode ne "") then output;

/* D23: The element is not recorded. */
error_code="D23";
target_field_name="foreignCashInCountryCode";
if foreignCashInCountryCode = ""  and foreignCashInAmount ne . then output;

/* D17: The element is not recorded. */
error_code="D17";
target_field_name="foreignCashInAmount";
if (foreignCashInAmount = . or foreignCashInAmount = 0) and foreignCashInCountryCode ne "" then output;

%mend; /* VLDT_CTRX_foreign_cash_in */


%MACRO VLDT_CTRX_foreign_cash_out;

/*C340: Foreign cash-out amount contains non-numeric values or is in an invalid format.*/
/* D30: The value recorded for the element contains non-numeric characters. */
error_code="D30";
target_field_name="foreignCashOutAmount";
if ((foreignCashOutAmount=0 or notdigit(put(foreignCashOutAmount,z15.)))) and (foreignCashOutAmount ne .) then output;

/*C341: Foreign cash-out country is not a valid country code.*/
/* D39: The element contains a value that is not a valid code. */
error_code="D39";
target_field_name="foreignCashOutCountryCode";
if (put(foreignCashOutCountryCode,$RT_COUNTRY.) ne 'VALID')  and (foreignCashOutCountryCode ne "") then output;

/* D37: The element is not recorded. */
error_code="D37";
target_field_name="foreignCashOutCountryCode";
if foreignCashOutCountryCode = ""  and foreignCashOutAmount ne . then output;

/* D31: The element is not recorded. */
error_code="D31";
target_field_name="foreignCashOutAmount";
if (foreignCashOutAmount = . or foreignCashOutAmount = 0) and foreignCashOutCountryCode ne "" then output;


%mend; /* VLDT_CTRX_foreign_cash_out */


/* */
%MACRO VLDT_CTRX_party_acct_in;
%mend;  /* VLDT_CTRX_party_acct_no_cash_in */

%MACRO VLDT_CTRX_party_acct_out;
%mend; /* VLDT_CTRX_party_acct_no_cash_out */

/* Section to allow cross validation and to look for empty datasets to catch missing data. */
%MACRO VLDT_CTRX;
   %let transmitter_exist=N;
   %let filer_exist=N;
   proc sql noprint;
        select 'Y' into :transmitter_exist
            from rc_cfg.fincen_transmitter(%fcf_get_ds_opts(lib_name=rc_cfg, ds_name=fincen_transmitter))
        where  form_config_key=&form_config_key
               and datetime() between effective_from_date and effective_to_date
        ;
		select 'Y' into :filer_exist
            from rc_cfg.fincen_institution(%fcf_get_ds_opts(lib_name=rc_cfg, ds_name=fincen_institution))
        where  form_config_key=&form_config_key
               and datetime() between effective_from_date and effective_to_date
        ;
   quit;
   /* H1: A required party associated with the transmitter is missing. */
   %if &transmitter_exist=N %then %do;
        proc sql noprint;
          insert into CTRX_error 
		     ( error_record_type, error_code, target_field_name, report_key, entity_key, entity_level_code)
          values ('transmitter' 
             ,'H1'
             ,'Party/ActivityPartyTypeCode'
             ,&report_key. 
             ,. 
             ,'TRANSMITTER'
			 ); 
         quit; 
       %end;
   /* G1: A required party associated with the Contact for assistance is missing. */
   %if &filer_exist=N %then %do;
        proc sql noprint;
          insert into CTRX_error 
		     ( error_record_type, error_code, target_field_name, report_key, entity_key, entity_level_code)
          values ('report'  
             ,'G1'
             ,'Party/ActivityPartyTypeCode'
             ,&report_key.
             ,. 
             ,'REPORT'
			 ); 
         quit; 
       %end;
	
	/* Test for missing CTRX_BRANCH dataset, which means a branch has not been selected. */
	/* E1: A required party associated with the transaction location is missing.         */
	%let num_of_branches=0;
    proc sql noprint;
        select nlobs into :num_of_branches from sashelp.vtable
        where libname='WORK' and memname='CTRX_BRANCH';
    quit; 
	%if &num_of_branches=0 %then %do;
	   proc sql noprint;
          insert into CTRX_error 
		     ( error_record_type, error_code, target_field_name, report_key, entity_key, entity_level_code)
          values ('branch'
             ,'E1' 
             /*,'BRANCH_NAME',*/
			 ,'Party/ActivityPartyTypeCode'
             ,&report_key. 
             ,. 
             ,'BRANCH'
			 ); 
         quit; 
	   %end;

	/* Must have at least some currency amount to generate a Cash Amount or will fail with A7.        */
    /* A7: One or more attributes are missing, incorrectly formatted, or contain invalid data.        */
    %let reportTotalAmount=0;
	proc sql noprint;
        select strip(put(sum(input(node_value,best.)),best.)) into :reportTotalAmount
        from work.rc_report_node
        where entity_key=&report_key.
              and entity_level_code='REPORT' 
              and node_name in ('usCashInAmount' 'usCashOutAmount' 'foreignCashInAmount' 'foreignCashOutAmount')
         ;
	quit;
	%if (&reportTotalAmount=0) or (&reportTotalAmount=.) %then %do;
	    proc sql noprint;
          insert into CTRX_error 
		     ( error_record_type, error_code, error_field, target_field_name, report_key, entity_key, entity_level_code)
          values ('batch'
             ,'A7' 
			 , 'TotalAmount'
             ,'TotalAmount'
             ,&report_key. 
             ,. 
             ,'REPORT'
			 ); 
	    insert into CTRX_error 
		     ( error_record_type, error_code, error_field, target_field_name, report_key, entity_key, entity_level_code)
          values ('batch'
             ,'A14' 
			 , 'CurrencyTransactionActivityDetail'
             ,'TotalAmount'
             ,&report_key. 
             ,. 
             ,'REPORT'
			 ); 		 
        quit; 
	    %end;
	
	   
	/* Test for empty CTRX_PARTY dataset, which means a person has not been selected.                 */
	/* C1: A required party associated with either the person on whose behalf the transaction was     */
	/*     conducted or the person conducting transaction on own behalf is missing.                   */
	%let num_of_parties=0;
    proc sql noprint;
        select nlobs into :num_of_parties from sashelp.vtable
        where libname='WORK' and memname='CTRX_PARTY';
    quit; 
	%if &num_of_parties=0 %then %do;
	   proc sql noprint;
          insert into CTRX_error 
		     ( error_record_type, error_code, target_field_name, report_key, entity_key, entity_level_code)
          values ('party'
             ,'C1' 
             ,'Party/ActivityPartyTypeCode'
             ,&report_key. 
             ,. 
             ,'PARTY'
			 ); 
       quit; 
	   %end;  
    /* Some parties are chosen, so will have some extra validations to perform to find Fatal errors. */	   
	%else %do;
	   /* A2: The element is recorded for an inappropriate party type.  */
	   proc sql noprint;
          insert into CTRX_error 
		     ( error_record_type, error_code, target_field_name, report_key, entity_key, entity_level_code)
	      select 'batch'
            ,'A2'
            ,'Party/ActivityPartyTypeCode'
            ,report_key
            ,entity_key 
            ,'batch'  
			
          from ctrx_party		 
             where index("AB",strip(personInvolvedTypeCode)) > 0 and (entityFlag eq "X");
	      quit;
	   %end;
 
%MEND; 



