/* MAINDOC
+------------------------------------------------------------------------------+
| NAME:    cdd_ra_test_rules.sas
| PRODUCT: SAS Compliance Solutions
| SYSTEM:  Windows, Unix
| DESC:    macro test Scenario Administrator scenarios
| PARAMETERS:
|            samplesize - number of records to use from prep data set, 0 or blank use all
|            keys - list of groups IDs
|            display_all_scores - if Y then all generated scores will be displayed in the output,
|                                 note that score table could be very large
+------------------------------------------------------------------------------+
MAINDOCEND */

/*-------------------------------------------------------------------
 * Copyright (c) 2016 by SAS Institute Inc., Cary, NC 27513 USA
 *  ---All Rights Reserved.
 *-------------------------------------------------------------------*/
%macro cdd_ra_test_rules(samplesize=,
                         keys=,
                         display_all_scores=);

    %let samplesize_p=&samplesize;

    %if %sysevalf(&samplesize eq 0.0 or &samplesize eq . or &samplesize eq 0) %then %do;
      %let samplesize_p=;
    %end;

    /* using work folder path for all generated files to avoid collisions between users */
    %let cdd_test_folder=%sysfunc(pathname(work));

    data _null_;
        tday = translate(put(datetime(),e8601dt25.3), "--", ":.");
        call symput('cdd_deploy_date', tday);
    run;

    %macro cdd_sm_run_rules();
      /* get all rule and rule group keys */
      proc sql;
          create table rg_keys as
              select CDD_RULE_GROUP_ID  from seg_kc.fsk_cdd_rule_group
              where (CDD_RULE_GROUP_ID in (&keys) or CDD_RULE_GROUP_TYPE='AGGR')
                    and CURRENT_IND='Y' and LOGICAL_DELETE_IND = 'N';
        ;
      quit;

      proc sql;
          create table rule_keys as
            select CDD_RULE_ID from seg_kc.fsk_cdd_rule
              where (CDD_RULE_GROUP_ID in select CDD_RULE_GROUP_ID from rg_keys)
                    and CURRENT_IND='Y' and LOGICAL_DELETE_IND = 'N' and CDD_RULE_STATUS_CODE='ACT';
        ;
      quit;

      %let cdd_gen_success_flg = 0;
      %cdd_generate_rules(     codegen_path=&cdd_test_folder,
                               outlib=work,
                               rule_ids_tab_name=rule_keys,
                               rule_group_ids_tab_name=rg_keys,
                               gen_type=T,
                               cdd_gen_success_flg_mvar=cdd_gen_success_flg);
                               
      %if &cdd_gen_success_flg=0 %then %do;
        %goto MACRO_END;
      %end;

      %cdd_crr_driver(      testYN=Y
                          , test_obs=&samplesize_p
                          , out_test_ds=cdd_crr_test_out
                          , cdd_codegen_path=&cdd_test_folder
                           );

      %MACRO_END:
    %mend cdd_sm_run_rules;

    %cdd_sm_run_rules

    /****************************************************************************
     ****************************************************************************
     **          Return the result: error messages or success message
     ****************************************************************************
     ****************************************************************************/
    %macro cdd_sm_update_rc ();
        %let cdd_sm_sp_msg=%sysfunc(sasmsg(sashelp.cddmsg, cdd_sm_sp_run_success_msg, N));
        %let cdd_sm_sp_run_success_title=%sysfunc(sasmsg(sashelp.cddmsg, cdd_sm_sp_run_success_title, N));
        data messages;
            length msg $400;
            msg = "&cdd_sm_sp_msg";
            output;
        run;
        proc print data=messages NOOBS LABEL;
            Var   msg;
            Label msg='00'x;
            Title "&cdd_sm_sp_run_success_title";
        run;
        title;
        /* user configurable ouptut */
        %cdd_crr_test_display_results(score_ds_nm=cdd_crr_test_out, display_all_scores=&display_all_scores, cddlib=work);
    %mend cdd_sm_update_rc;
    %cdd_sm_update_rc()
%mend cdd_ra_test_rules;