/* MAINDOC
+------------------------------------------------------------------------------+
| NAME:    cdd_rule_cat_agg.sas
| PRODUCT: SAS Customer Due Diligence
| SYSTEM:  Windows Unix
| DESC:    Aggregate rule scores using sum of scores, sum of max scores, and
|          record counts.
+------------------------------------------------------------------------------+
| USAGE:   This macro is used in a rule or the header of a rule group.
|
| PARAMETERS:
|    WEIGHT          = Not required unless used in other parameters. 
|                      Weight to apply to RULE_SCORE. It can be used by
|                      RULE_SCORE_EXP. 
|    SCORE_TYPE_CODE = type of score. Required if the score is saved in KC.
|    BY_LIST         = list of by variables. Not required. If it is blank, all 
|                      records in the table will be aggregated into a single
|                      score. Assuming that the input data is sorted properly.
|    RULE_SCORE_EXP =  expression for RULE_SCORE assignment. If blank, average
|                      score is used. 
|    AUTO_HIGH_SCORE = Score to use when auto_high is Y. Not required.
|    AUTO_HIGH_EXP   = Expression for auto_high_ind assignment. Required. 
|                      Default is MAX_AUTO_HIGH_IND.
+------------------------------------------------------------------------------+
MAINDOCEND */

/*-------------------------------------------------------------------
 * Copyright (c) 2013-2016 by SAS Institute Inc., Cary, NC 27513 USA
 *  ---All Rights Reserved.
 *-------------------------------------------------------------------*/

%macro cdd_rule_cat_agg(  weight=
                        , score_type_code=
                        , by_list=PRIMARY_ENTITY_NUMBER
                        , rule_score_exp=
						, auto_high_score=
						, auto_high_exp=MAX_AUTO_HIGH_IND
                        );


%let last_by_var=;
%if %str(&by_list) ne %str() %then %do; 
%let last_by_var=%scan(&by_list,%sysfunc(countw(&by_list),) );
%end;
data &cdd_output_ds;
      
	set &cdd_input_ds end=eof;
%if %str(&by_list) ne %str() %then %do; 
	     by &by_list;
%end;

	length SUM_MAX_SCORE
	       SUM_RULE_SCORE
		   SUM_COUNT
           8.;
    
	retain SUM_MAX_SCORE
	       SUM_RULE_SCORE
	       SUM_COUNT
	       ;
	length MAX_AUTO_HIGH_IND $ 1;
    retain MAX_AUTO_HIGH_IND;

	drop SUM_RULE_SCORE SUM_MAX_SCORE SUM_COUNT MAX_AUTO_HIGH_IND;

	/* initialize SUM  columns to missing, not 0 because the data can be missing */
%if %str(&last_by_var) ne %str() %then %do; 

	if first.&last_by_var then do;
%end;
%else %do;
    if _n_=1 then do;
%end;
	      SUM_COUNT=0;
	      SUM_MAX_SCORE = .; 
	      SUM_RULE_SCORE =.;
		  MAX_AUTO_HIGH_IND='';
	end;
	 
	SUM_COUNT+1;
	SUM_MAX_SCORE + MAX_SCORE; 
	SUM_RULE_SCORE + RULE_SCORE;
	/* AUTO_HIGH_IND should be '', 'N', 'Y', 'Y' is highest possible value */ 
	if AUTO_HIGH_IND > MAX_AUTO_HIGH_IND then MAX_AUTO_HIGH_IND=AUTO_HIGH_IND;

%if %str(&last_by_var) ne %str() %then %do;    
	if last.&last_by_var then do;
%end;
%else %do;
    if eof then do;
%end;
	 %if %str(&score_type_code) ne %str() %then %do;
	      SCORE_TYPE_CODE=&score_type_code;
	 %end;
	      CDD_RULE_ID="&cdd_rule_id";
		  VERSION_NO=&version_no;
	      ATTRIBUTE_CODE='';
		  ATTRIBUTE_CHAR_VALUE='';
		  ATTRIBUTE_TYPE_CODE='';
		  TRIGGERING_CHAR_VALUE='';
	      WEIGHT=&weight;
	 %if %str(&rule_score_exp) ne %str() %then %do;
	      RULE_SCORE=%unquote(&rule_score_exp); 
	 %end;
	 %else %do;
	      /* if no expression is provided, use the average */
	      RULE_SCORE=SUM_RULE_SCORE/SUM_COUNT;
	 %end;
		  RULE_SCORE=ROUND(RULE_SCORE,1);
	 
	 	  AUTO_HIGH_IND=%unquote(&auto_high_exp);
		
		  %if %str(&auto_high_score) ne %str()  %then %do;
		      if AUTO_HIGH_IND='Y' then RULE_SCORE=&auto_high_score;
		  %end;
	      output;
	end;


%mend;
