/* MAINDOC
+------------------------------------------------------------------------------+
| NAME:    fcf_get_header_elements.sas
| PRODUCT: SAS Compliance Solutions
| SYSTEM:  Windows, Unix
| DESC:    reads the list of prep data sets in a library and creates a datasets
|          describing all columns for a specified dataset
+------------------------------------------------------------------------------+
| USAGE:   %fcf_get_header_elements(preplib, outlib, datasetName)
|          Note: this macro is used by mid-tier services
+------------------------------------------------------------------------------+
| PARAMETERS:
|     preplib
|         libname for prep data sets
|     outlib
|         libname for the output datasets
|     datasetName
|         name of the dataset to query the elements,
|         if name is empty then will create a list of elements for all datasets
|
|     Output data sets created in outlib library:
|         DATASET_LIST - list of datasets
|         ELEMENTS - list of columns attributes for all prep data sets
|                    attributes match FSK_HEADER_ELEMENT table
|
+------------------------------------------------------------------------------+
MAINDOCEND */

/*-------------------------------------------------------------------
 * Copyright (c) 2018 by SAS Institute Inc., Cary, NC 27513 USA
 *  ---All Rights Reserved.
 *-------------------------------------------------------------------*/

%macro fcf_get_header_elements(preplib=MST_PREP, outlib=WORK, datasetName=);

 proc sql noprint;
          create table &outlib..DATASET_LIST %fcf_get_ds_opts(lib_name=&outlib, ds_name=dataset_list, output_ds=Y, add_parens=Y) as
          select UPCASE(memname) as DATASET_NAME
          from dictionary.tables
          where UPCASE(libname) = UPCASE("&preplib") and ( UPCASE(memname) = UPCASE("&datasetName") or trim("&datasetName") = "" )
          order by DATASET_NAME
          ;
 quit;

 data &outlib..elements(%fcf_get_ds_opts(lib_name=&outlib, ds_name=elements, output_ds=Y));
    set &outlib..dataset_list(%fcf_get_ds_opts(lib_name=&outlib, ds_name=dataset_list));
    length  ELEMENT_TYPE_CODE   $6
         ELEMENT_LENGTH_COUNT    8
         ELEMENT_FORMAT_CODE    $8
         ELEMENT_LABEL_DESC    $35
         ELEMENT_NAME          $35 ;
    keep  DATASET_NAME ELEMENT_TYPE_CODE ELEMENT_LENGTH_COUNT ELEMENT_FORMAT_CODE ELEMENT_LABEL_DESC ELEMENT_NAME;
    dsid = open("&preplib.."|| DATASET_NAME ||'(%fcf_get_ds_opts(lib_name='||"&preplib, ds_name=" || DATASET_NAME || "))", "i");
    num=attrn(dsid,"nvars");
    do i=1 to num;
       ELEMENT_NAME=upcase(varname(dsid,i));
       ELEMENT_TYPE_CODE=vartype(dsid,i);
       ELEMENT_FORMAT_CODE=varfmt(dsid,i);
       ELEMENT_LABEL_DESC=varlabel(dsid,i);
       ELEMENT_LENGTH_COUNT=varlen(dsid,i);
       if  ELEMENT_LABEL_DESC = ' ' then ELEMENT_LABEL_DESC = ELEMENT_NAME;
       output;
    end;
    rc=close(dsid);
 run;
%mend fcf_get_header_elements;
