/* MAINDOC
+------------------------------------------------------------------------------+
| NAME:    fcf_pref_to_ds.sas
| PRODUCT: SAS Compliance Solutions
| SYSTEM:  Windows, Unix
| DESC:    Creates a SAS data set from the given ref file with AML preferences
+------------------------------------------------------------------------------+
| USAGE:   This macro should only be executed from within a SAS UTF-8 session.
+------------------------------------------------------------------------------+
| PARAMETERS:
|     file
|         name of the ref file, all files matching pattern: <file>_<locale>.ref or <file>.ref
|         will be processed
|
|     file_path
|         folder where the ref files are located
|
|     DS - name of the data set that will be generated
|
+------------------------------------------------------------------------------+
| COMMENTS:
|
|     The key in the properties file must have the form:
|         <REF_TABLE_NM>.<VALUE_CD>[.<DISPLAY_ORDER_NUMBER>.<PARENT_REF_TABLE_NM>.<PARENT_VALUE_CD>]
|         <dot_separated_preference_name>:<preference_data_type>=<preference_value>
|     <preference_data_type> is optional, default value string
|
|     Description of a SAS data set created by this macro (like FCFKC.FSK_PREFERENCES table)
|     # Variable Name           Type        Length
|        PREF_NAME		        VARCHAR2	as defined by database
|        PREF_VALUE		        VARCHAR2	as defined by database
|        PREF_TYPE		        VARCHAR2	as defined by database
|        PREF_VALUE_DEFAULT		VARCHAR2	as defined by database
|
+------------------------------------------------------------------------------+
MAINDOCEND */

/*-------------------------------------------------------------------
 * Copyright (c) 2016 by SAS Institute Inc., Cary, NC 27513 USA
 *  ---All Rights Reserved.
 *-------------------------------------------------------------------*/

%macro fcf_pref_to_ds(file=, file_path=, DS=);
 	data file_list;
 	 length locale $5;
 	 length fref $8 filename $256;
 	 keep filename locale;

 	 length u_idx  d_idx 8;
 	 rc = filename(fref, "&file_path");
 	 if rc = 0 then do;
 		 did = dopen(fref);
 		 rc = filename(fref);
 	 end;
 	 else do;
 	 	length msg $200.;
 	 	msg = sysmsg();
 	 	put msg=;
 	 	did = .;
 	 end;

 	 if did <= 0  then putlog 'ERR' 'OR: Unable to open directory.';
     else do;
         dnum = dnum(did);
         do i = 1 to dnum;
            filename = dread(did, i);
            /* If this entry is a file, then process */
            fid = mopen(did, filename);
            if fid > 0 then do;
                if index(UPCASE(filename), UPCASE("&file")) ne 0 then do;
                  u_idx=index(filename, '_');
                  d_idx=index(filename, '.');
                  if u_idx = 0 then locale="en";
                            else locale=substr(filename,u_idx+1, d_idx-u_idx-1);
                  filename="&file_path/" || filename;
                  output;
                end;
            end;
         end;
         rc = dclose(did);
     end;
 	run;

       data &ds (%fcf_get_ds_opts(ds_name=&ds) ENCODING=ASCII);
        if 0 then set seg_kc.FSK_PREFERENCE;
 		set file_list;
 	          length key $90;
 	          length key_orig $90;
 		keep PREF_NAME PREF_VALUE PREF_TYPE PREF_VALUE_DEFAULT;
 		infile inf filevar=filename
 			   filename=myfile
 			   end=done;
 		do while (not done);
 		    input;
 	        if (_infile_ ne ' ') then do;
 	            if (ksubstr(_infile_,1,1) ne '#') then do;
 	                    key_orig=kscan(_infile_,1,'=');
 	                    PREF_NAME=kscan(key_orig,1,':');
 	                    PREF_TYPE = 'string';
 	                    type_separator_indx=kindex(key_orig, ':');
 	                    if type_separator_indx ne 0 then PREF_TYPE=kscan(key_orig,-1,':');
 	                    if PREF_TYPE eq "" then PREF_TYPE = 'string';
 	                    key_separator_indx=kindex(_infile_, '=');
 	                    PREF_VALUE=ksubstr(_infile_,key_separator_indx+1);
 	                    PREF_VALUE_DEFAULT = PREF_VALUE;
 	                    output;
 	             end;
 	        end;
 		end;
 	run;
%mend fcf_pref_to_ds;

