/* MAINDOC
+------------------------------------------------------------------------------+
| NAME:    fcf_prep_create_empty_data_sets.sas
| PRODUCT: SAS Compliance Solutions
| SYSTEM:  Windows, Unix
| DESC:    Create empty prep data sets for use in populating Scenario 
|          Administrator after installation/configuration.
+------------------------------------------------------------------------------+
MAINDOCEND */

/*-------------------------------------------------------------------
 * Copyright (c) 2012-2016 by SAS Institute Inc., Cary, NC 27513 USA
 *  ---All Rights Reserved.
 *-------------------------------------------------------------------*/

%macro fcf_prep_create_empty_data_sets;

    %if 0 EQ %sysfunc(exist(mst_prep.account_transactions,view)) %then %do;
        data mst_prep.account_transactions(%fcf_get_ds_opts(lib_name=mst_prep, ds_name=account_transactions, output_ds=Y));
            if 0 then
                set 
                  seg_kc.fsc_account_analysis_dim
                  (keep=
                    expected_credit_ceiling_amount
                    expected_debit_ceiling_amount
                    expected_incoming_amount
                    expected_incoming_count
                    expected_outgoing_amount
                    expected_outgoing_count
                    increased_behavior_credit_amt
                    increased_behavior_credit_cnt
                    increased_behavior_debit_amt
                    increased_behavior_debit_cnt
                  )
                                                   
                  seg_kc.fsc_account_dim
                  (keep=
                    account_number
                    account_type_desc
                    account_tax_state_code
                  )
               
                  seg_kc.fsc_branch_dim
                  (keep=
                    branch_number
                    branch_type_desc
                    street_state_code
                  )
                
                  seg_kc.fsc_cash_flow_fact
                  (keep=
                    currency_amount
                    transaction_key
                  )
                
                  seg_kc.fsc_currency_dim
                  (keep=currency_code)
                
                  seg_kc.fsc_transaction_status_dim
                  (keep=
                    status_desc
                    status_reason_desc
                  )
                
                  seg_kc.fsc_transaction_type_dim
                  (keep=
                    mechanism_desc
                    primary_medium_desc
                    secondary_medium_desc
                    transaction_cdi_code
                  )
                ; /* set */
           
            attrib date_key format=yymmdd8. length=5;
            stop;
        run;
    %end;

    %if 0 EQ %sysfunc(exist(mst_prep.party_transactions,view)) %then %do;
        data mst_prep.party_transactions(%fcf_get_ds_opts(lib_name=mst_prep, ds_name=party_transactions, output_ds=Y));
            if 0 then
                set
                  seg_kc.fsc_account_dim
                  (keep=
                    account_number
                    account_type_desc
                    currency_based_account_ind
                  )
                  
                  seg_kc.fsc_cash_flow_fact
                  (keep=
                    currency_amount
                    transaction_key
                  )
                  
                  seg_kc.fsc_country_dim
                  (keep=
                    country_code_3
                  )
                  
                  seg_kc.fsc_currency_dim
                  (keep=
                    currency_code
                  )
                  
                  seg_kc.fsc_party_dim
                  (keep=
                    annual_income_amount
                    customer_since_date
                    last_cash_trans_rpt_date
                    last_susp_actv_rpt_date
                    party_number
                    politically_exposed_person_ind
                    risk_classification
                  )
                  
                  seg_kc.fsc_transaction_status_dim
                  (keep=
                    status_desc
                  )
                  
                  seg_kc.fsc_transaction_type_dim
                  (keep=
                    mechanism_desc
                    primary_medium_desc
                    secondary_medium_desc
                    transaction_cdi_code
                  )
                ; /* set */
           
            attrib date_key format=yymmdd8. length=5;
            stop;
        run;
    %end;
    
    %if 0 EQ %sysfunc(exist(mst_prep.associate_transactions,view)) %then %do;
        data mst_prep.associate_transactions(%fcf_get_ds_opts(lib_name=mst_prep, ds_name=associate_transactions, output_ds=Y));
            if 0 then
              set
                seg_kc.fsc_account_dim
                (keep=
                  account_number
                  account_type_desc
                  currency_based_account_ind
                )
                
                seg_kc.fsc_associate_dim
                (keep=
                  associate_number
                )
                
                seg_kc.fsc_cash_flow_fact
                (keep=
                  currency_amount
                  transaction_key
                )
                
                seg_kc.fsc_country_dim
                (keep=
                  country_code_3
                )
                
                seg_kc.fsc_currency_dim
                (keep=
                  currency_code
                )
                
                seg_kc.fsc_party_dim
                (keep=
                  annual_income_amount
                  customer_since_date
                  last_cash_trans_rpt_date
                  last_susp_actv_rpt_date
                  party_number
                  politically_exposed_person_ind
                  risk_classification
                )
                
                seg_kc.fsc_transaction_status_dim
                (keep=
                  status_desc
                )
                
                seg_kc.fsc_transaction_type_dim
                (keep=
                  mechanism_desc
                  primary_medium_desc
                  secondary_medium_desc
                  transaction_cdi_code
                )
              ; /* set */
              
            attrib date_key format=yymmdd8. length=5;
            stop;
        run;
    %end;

    %if 0 EQ %sysfunc(exist(mst_prep.account_profile)) %then %do;        
        data mst_prep.account_profile(%fcf_get_ds_opts(lib_name=mst_prep, ds_name=account_profile, output_ds=Y));
            if 0 then
              set 
                seg_kc.fsc_account_dim
                (keep=
                  account_number
                  account_type_desc
                )
                
                seg_kc.fsc_account_profile_fact
                (keep=
                  avg_account_value_amount
                  cust_initiated_trans_count
                  max_account_value_amount
                  min_account_value_amount
                  month_key
                  total_credits_amount
                  total_debits_amount
                  total_wire_credits_amount
                  total_wire_debits_amount
                  wires_count
                )
              ; /* set */
        stop;
        run;
    %end;

    %if 0 EQ %sysfunc(exist(mst_prep.cash_flow_fact_history)) %then %do;
        data mst_prep.cash_flow_fact_history(%fcf_get_ds_opts(lib_name=mst_prep, ds_name=cash_flow_fact_history, output_ds=Y));
            if 0 then
              set
                seg_kc.fsc_account_dim
                (keep=
                  account_number
                )
              
                seg_kc.fsc_cash_flow_fact
                (keep=
                  currency_amount
                  date_key
                )
                
                seg_kc.fsc_transaction_type_dim
                (keep=
                  mechanism_desc
                  primary_medium_desc
                  transaction_cdi_code
                )
              ; /* set */
             
            attrib days_open length=8;
            stop;
        run;
    %end;
    
    %if 0 EQ %sysfunc(exist(mst_prep.closed_loans)) %then %do;
        data mst_prep.closed_loans(%fcf_get_ds_opts(lib_name=mst_prep, ds_name=closed_loans, output_ds=Y));
            if 0 then
              set
                seg_kc.fsc_account_dim
                (keep=
                  account_number
                  original_loan_amount
                  product_name
                  product_type_name
                )
                
                seg_kc.fsc_party_dim
                (keep=
                  party_number
                )
                
                seg_kc.fsc_party_account_bridge
                (keep=
                  role_desc
                )
              ; /* set */
              
              attrib account_close_date length=8;
              attrib account_open_date  length=8;
              attrib maturity_date      length=8;
            stop;
        run;
    %end;

    %if 0 EQ %sysfunc(exist(mst_prep.defaulted_loans)) %then %do;
        data mst_prep.defaulted_loans(%fcf_get_ds_opts(lib_name=mst_prep, ds_name=defaulted_loans, output_ds=Y));
            if 0 then
              set
                seg_kc.fsc_account_dim
                (keep=
                  account_number
                  account_type_desc
                  collateral_type_code
                  original_loan_amount
                  product_name
                  product_type_name
                )
              ; /* set */
              
              attrib account_open_date  length=8;
            stop;
        run;
    %end;

    %if 0 EQ %sysfunc(exist(mst_prep.dormant_account_transactions)) %then %do;
        data mst_prep.dormant_account_transactions(%fcf_get_ds_opts(lib_name=mst_prep, ds_name=dormant_account_transactions, output_ds=Y));
            if 0 then
              set
                seg_kc.fsc_account_dim
                (keep=
                  account_number
                )
              
                seg_kc.fsc_cash_flow_fact
                (keep=
                  currency_amount
                  transaction_key
                )
              ; /* set */
              
              attrib date_key format=yymmdd8. length=8;
              attrib dorm_days length=8;
            stop;
        run;
    %end;

    %if %sysfunc(exist(seg_kc.fsc_account_state_vector_view, view)) and
        0 EQ %sysfunc(exist(mst_prep.fsc_account_state_vector_view)) %then %do;
        
        /* this data set does not exist for some SQLServer installations */
        data mst_prep.fsc_account_state_vector_view(%fcf_get_ds_opts(lib_name=mst_prep, ds_name=fsc_account_state_vector_view, output_ds=Y));
            if 0 then
              set 
                seg_kc.fsc_account_state_vector_view
                (keep=
                  account_number
                  account_type_desc
                  date_key
                  debits_total
                  debits_total_5
                  debits_total_10
                  debits_total_30
                  credits_total
                  credits_total_5
                  credits_total_10
                  credits_total_30
                  atm_debits_total
                  atm_debits_total_5
                  atm_debits_total_10
                  atm_debits_total_30
                  atm_credits_total
                  atm_credits_total_5
                  atm_credits_total_10
                  atm_credits_total_30
                  atm_d_trans_count
                  atm_d_trans_count_5
                  atm_d_trans_count_10
                  atm_d_trans_count_30
                  atm_c_trans_count
                  atm_c_trans_count_5
                  atm_c_trans_count_10
                  atm_c_trans_count_30
                  debit_trans_count
                  debit_trans_count_5
                  debit_trans_count_10
                  debit_trans_count_30
                  credit_trans_count
                  credit_trans_count_5
                  credit_trans_count_10
                  credit_trans_count_30
                  debit_loc_count
                  debit_loc_count_5
                  debit_loc_count_10
                  debit_loc_count_30
                  credit_loc_count
                  credit_loc_count_5
                  credit_loc_count_10
                  credit_loc_count_30
                  atm_d_loc_count
                  atm_d_loc_count_5
                  atm_d_loc_count_10
                  atm_d_loc_count_30
                  atm_c_loc_count
                  atm_c_loc_count_5
                  atm_c_loc_count_10
                  atm_c_loc_count_30
                  wire_credit_total
                  wire_credit_total_5
                  wire_credit_total_10
                  wire_credit_total_30
                  wire_credit_trans_count
                  wire_credit_trans_count_5
                  wire_credit_trans_count_10
                  wire_credit_trans_count_30
                  wire_debits_total
                  wire_debits_total_5
                  wire_debits_total_10
                  wire_debits_total_30
                  wire_debit_trans_count
                  wire_debit_trans_count_5
                  wire_debit_trans_count_10
                  wire_debit_trans_count_30
                  d_i_wire_credits_total
                  d_i_wire_credits_total_5
                  d_i_wire_credits_total_10
                  d_i_wire_credits_total_30
                  d_i_wire_credit_trans_count
                  d_i_wire_credit_trans_count_5
                  d_i_wire_credit_trans_count_10
                  d_i_wire_credit_trans_count_30
                  d_i_wire_debits_total
                  d_i_wire_debits_total_5
                  d_i_wire_debits_total_10
                  d_i_wire_debits_total_30
                  d_i_wire_debit_trans_count
                  d_i_wire_debit_trans_count_5
                  d_i_wire_debit_trans_count_10
                  d_i_wire_debit_trans_count_30
                  balance_inquiry_count
                  balance_inquiry_count_5
                  balance_inquiry_count_10
                  balance_inquiry_count_30
                  exceeded_daily_limit_count
                  exceeded_daily_limit_count_5
                  exceeded_daily_limit_count_10
                  exceeded_daily_limit_count_30
                  insufficient_funds_count
                  insufficient_funds_count_5
                  insufficient_funds_count_10
                  insufficient_funds_count_30
                )
              ; /* set */
            stop;
        run;
    %end;

    %if 0 EQ %sysfunc(exist(mst_prep.ins_account_transactions,view)) %then %do;
        data mst_prep.ins_account_transactions(%fcf_get_ds_opts(lib_name=mst_prep, ds_name=ins_account_transactions, output_ds=Y));
            if 0 then
              set
                seg_kc.fsc_account_dim
                (keep=
                  account_number
                  account_open_date
                  account_type_desc
                )
                
                seg_kc.fsc_cash_flow_fact
                (keep=
                  currency_amount
                  transaction_key
                )
                
                seg_kc.fsc_transaction_type_dim
                (keep=
                  primary_medium_desc
                  secondary_medium_desc
                  transaction_cdi_code
                )
              ; /* set */
              
            attrib date_key format=yymmdd8. length=8;
            stop;
        run;
    %end;

    %if 0 EQ %sysfunc(exist(mst_prep.ins_party_transactions,view)) %then %do;
        data mst_prep.ins_party_transactions(%fcf_get_ds_opts(lib_name=mst_prep, ds_name=ins_party_transactions, output_ds=Y));
            if 0 then
              set
                seg_kc.fsc_account_dim
                (keep=
                  account_number
                  account_type_desc
                )
                
                seg_kc.fsc_cash_flow_fact
                (keep=
                  currency_amount
                  third_party_ind
                  transaction_key
                )
                
                seg_kc.fsc_party_dim
                (keep=
                  party_number
                )
                
                seg_kc.fsc_transaction_type_dim
                (keep=
                  mechanism_desc
                  primary_medium_desc
                  secondary_medium_desc
                  transaction_cdi_code
                )
              ; /* set */
              
            attrib date_key format=yymmdd8. length=8;
            stop;
        run;
    %end;

    %if 0 EQ %sysfunc(exist(mst_prep.ins_closing)) %then %do;
        data mst_prep.ins_closing(%fcf_get_ds_opts(lib_name=mst_prep, ds_name=ins_closing, output_ds=Y));
            if 0 then
              set
                seg_kc.fsc_account_dim
                (keep=
                  account_number
                  account_type_desc
                  account_open_date
                )
                
                seg_kc.fsc_cash_flow_fact
                (keep=
                  currency_amount
                  third_party_ind
                  transaction_key
                )
                
                seg_kc.fsc_transaction_type_dim
                (keep=
                  mechanism_desc
                  primary_medium_desc
                  secondary_medium_desc
                  transaction_cdi_code
                )
              ; /* set */
              
            attrib date_key format=yymmdd8. length=8;
            stop;
        run;
    %end;

    %if 0 EQ %sysfunc(exist(mst_prep.party_list)) %then %do;
        data mst_prep.party_list(%fcf_get_ds_opts(lib_name=mst_prep, ds_name=party_list, output_ds=Y));
            if 0 then
              set
                seg_kc.fsk_list
                (keep=
                  list_name
                )
                
                seg_kc.fsk_list_element
                (keep=list_element_value
                 rename=(list_element_value=party_number)
                )
              ; /* set */
            stop;
        run;
    %end;          

    %if 0 EQ %sysfunc(exist(mst_prep.party_phone)) %then %do;
        data mst_prep.party_phone(%fcf_get_ds_opts(lib_name=mst_prep, ds_name=party_phone, output_ds=Y));
            if 0 then
              set seg_kc.fsc_party_dim
              (keep=
                party_number
                phone_number_1
                street_state_code
              );
              
            stop;
        run;
    %end;

    %if 0 EQ %sysfunc(exist(mst_prep.party_profile)) %then %do;
        data mst_prep.party_profile(%fcf_get_ds_opts(lib_name=mst_prep, ds_name=party_profile, output_ds=Y));
            if 0 then
              set seg_kc.fsc_party_profile_fact
              (keep=
                aggregate_assets_amount
                party_number
                total_wire_credits_amount
                total_wire_debits_amount
              );
            stop;
        run;
    %end;

    %if 0 EQ %sysfunc(exist(mst_prep.party_taxid)) %then %do;
        data mst_prep.party_taxid(%fcf_get_ds_opts(lib_name=mst_prep, ds_name=party_taxid, output_ds=Y));
            if 0 then
              set seg_kc.fsc_party_dim
              (keep=
                party_number
                party_tax_id
                street_state_code
              );
            stop;
        run;
    %end;
    
    %if 0 EQ %sysfunc(exist(mst_prep.unrelated_transfers)) %then %do;
        data mst_prep.unrelated_transfers(%fcf_get_ds_opts(lib_name=mst_prep, ds_name=unrelated_transfers, output_ds=Y));
            if 0 then
              set
                seg_kc.fsc_account_dim
                (keep=
                    account_type_desc
                )
                
                seg_kc.fsc_cash_flow_fact
                (keep=
                  currency_amount
                  transaction_key
                )
                
                seg_kc.fsc_party_dim
                (keep=
                  party_number
                )
                
                seg_kc.fsc_transaction_type_dim
                (keep=
                  transaction_cdi_code
                )
              ; /* set */
              
              attrib date_key format=yymmdd8. length=8;
            stop;
        run;
    %end;
    
    %if 0 EQ %sysfunc(exist(mst_prep.cb_remitter,view)) %then %do;
        data mst_prep.cb_remitter(%fcf_get_ds_opts(lib_name=mst_prep, ds_name=cb_remitter, output_ds=Y));
            if 0 then
              set 
                seg_kc.fsc_cash_flow_fact
                (keep= 
                  beneficiary_ext_party_key
                  remitter_ext_party_key
                  account_key 
                  currency_amount
                  date_key
                  transaction_key
                )
                
                seg_kc.fsc_transaction_status_dim
                (keep=
                status_desc
                )
                
                seg_kc.fsc_transaction_type_dim 
                (keep=primary_medium_desc
                )
                
                seg_kc.fsc_ext_party_account_dim
                (keep=
                external_party_number
                rename=(external_party_number=beneficiary_party_number)
                );
                length remitter_party_number primary_party_number alert_party_number $400.;
                remitter_party_number=beneficiary_party_number;
                primary_party_number=beneficiary_party_number;
                alert_party_number=beneficiary_party_number;
               /* set */
            stop;
        run;
    %end;
  
    %if 0 EQ %sysfunc(exist(mst_prep.cb_beneficiary,view)) %then %do;
        data mst_prep.cb_beneficiary(%fcf_get_ds_opts(lib_name=mst_prep, ds_name=cb_beneficiary, output_ds=Y));
            if 0 then
              set 
                seg_kc.fsc_cash_flow_fact
                (keep= 
                  beneficiary_ext_party_key
                  remitter_ext_party_key
                  account_key 
                  currency_amount
                  date_key
                  transaction_key
                )
                
                seg_kc.fsc_transaction_status_dim
                (keep=
                status_desc
                )
                
                seg_kc.fsc_transaction_type_dim 
                (keep=primary_medium_desc
                )
                
                seg_kc.fsc_ext_party_account_dim
                (keep=
                external_party_number
                rename=(external_party_number=beneficiary_party_number)
                );
                length remitter_party_number primary_party_number alert_party_number $400.;
                remitter_party_number=beneficiary_party_number;
                primary_party_number=beneficiary_party_number;
                alert_party_number=beneficiary_party_number;
               /* set */
            stop;
        run;
    %end;
    
     %if 0 EQ %sysfunc(exist(mst_prep.cb_party,view)) %then %do;
        data mst_prep.cb_party(%fcf_get_ds_opts(lib_name=mst_prep, ds_name=cb_party, output_ds=Y));
            if 0 then
              set 
                seg_kc.fsc_cash_flow_fact
                (keep= 
                  beneficiary_ext_party_key
                  remitter_ext_party_key
                  account_key 
                  currency_amount
                  date_key
                  transaction_key
                )
                
                seg_kc.fsc_transaction_status_dim
                (keep=
                status_desc
                )
                
                seg_kc.fsc_transaction_type_dim 
                (keep=primary_medium_desc
                )
                
                seg_kc.fsc_ext_party_account_dim
                (keep=
                external_party_number
                rename=(external_party_number=beneficiary_party_number)
                );
                length remitter_party_number primary_party_number alert_party_number $400.;
                remitter_party_number=beneficiary_party_number;
                primary_party_number=beneficiary_party_number;
                alert_party_number=beneficiary_party_number;
               /* set */
            stop;
        run;
    %end;

    %if 0 EQ %sysfunc(exist(mst_prep.ctr_pty_transactions)) %then %do;
        data mst_prep.ctr_pty_transactions;
            if 0 then
              set 
                seg_kc.fsc_cash_flow_fact
                (keep= 
                  currency_amount
                  date_key
                  transaction_key
                  beneficiary_ext_party_key
                  executing_party_key
                  executing_ext_party_key
                )
                
                seg_kc.fsc_transaction_status_dim
                (keep=
                status_desc
                )
                
                seg_kc.fsc_transaction_type_dim 
                (keep=
                    transaction_cdi_code
                    primary_medium_desc
                    secondary_medium_desc
                    mechanism_desc
                )
                
                seg_kc.fsc_party_dim
                (keep=
                    party_number
                    party_key
                )
                
                seg_kc.fsc_account_dim
                (keep=
                    account_number
                    account_type_desc
                    currency_based_account_ind
                );
            stop;
        run;
    %end;
    
    %if 0 EQ %sysfunc(exist(mst_prep.ctr_hh_transactions)) %then %do;
        data mst_prep.ctr_hh_transactions;
           if 0 then
              set 
                seg_kc.fsc_cash_flow_fact
                (keep= 
                  currency_amount
                  date_key
                  transaction_key
                  beneficiary_ext_party_key
                  executing_party_key
                  executing_ext_party_key
                )
                
                seg_kc.fsc_transaction_status_dim
                (keep=
                status_desc
                )
                
                seg_kc.fsc_transaction_type_dim 
                (keep=
                    transaction_cdi_code
                    primary_medium_desc
                    secondary_medium_desc
                    mechanism_desc
                )
                
                seg_kc.fsc_household_dim
                (keep=
                    household_number
                )
                
                seg_kc.fsc_account_dim
                (keep=
                    account_number
                    account_type_desc
                    currency_based_account_ind
                );
            stop;
        run;
    %end;

    %if 0 EQ %sysfunc(exist(mst_prep.ctr_executing_pty_trans)) %then %do;
        data mst_prep.ctr_executing_pty_trans;
           if 0 then
              set 
                seg_kc.fsc_cash_flow_fact
                (keep= 
                  currency_amount
                  date_key
                  transaction_key
                  beneficiary_ext_party_key
                  executing_party_key
                  executing_ext_party_key
                )
                
                seg_kc.fsc_transaction_status_dim
                (keep=
                status_desc
                )
                
                seg_kc.fsc_transaction_type_dim 
                (keep=
                    transaction_cdi_code
                    primary_medium_desc
                    secondary_medium_desc
                    mechanism_desc
                )
                
                seg_kc.fsc_party_dim
                (keep=
                    party_number
                    party_key
                )
                
                seg_kc.fsc_account_dim
                (keep=
                    account_number
                    account_type_desc
                    currency_based_account_ind
                );
                
                length external_ext_party_key $ 80.;

            stop;
        run;
    %end;

    %if 0 EQ %sysfunc(exist(mst_prep.ctr_executing_ext_pty_trans)) %then %do;
        data mst_prep.ctr_executing_ext_pty_trans;
           if 0 then
              set 
                seg_kc.fsc_cash_flow_fact
                (keep= 
                  currency_amount
                  date_key
                  transaction_key
                  beneficiary_ext_party_key
                  executing_party_key
                  executing_ext_party_key
                )
                
                seg_kc.fsc_transaction_status_dim
                (keep=
                status_desc
                )

                 seg_kc.fsc_transaction_dim
                (keep=
                transaction_description
                )

                seg_kc.fsc_transaction_type_dim 
                (keep=
                    transaction_cdi_code
                    primary_medium_desc
                    secondary_medium_desc
                    mechanism_desc
                )
                
                seg_kc.fsc_ext_party_account_dim
                (keep=
                    external_party_number
                )
                
                seg_kc.fsc_account_dim
                (keep=
                    account_number
                    account_type_desc
                    currency_based_account_ind
                );
            stop;
        run;
    %end;
    
%mend fcf_prep_create_empty_data_sets;
