/* MAINDOC
+------------------------------------------------------------------------------+
| NAME:    fcf_sa_update_locale_data.sas
| PRODUCT: SAS Compliance Solutions
| SYSTEM:  Windows, Unix
| DESC:    update scenarios and headers with localized values for
|               scenario short description and long description
|               scenario parameter description
|               header description
+------------------------------------------------------------------------------+
MAINDOCEND */

/*-------------------------------------------------------------------
 * Copyright (c) 2018 by SAS Institute Inc., Cary, NC 27513 USA
 *  ---All Rights Reserved.
 *-------------------------------------------------------------------*/


%macro fcf_sa_update_locale_data();
    %let fcf_config_locale_opt = %sysfunc(sasmsg(sashelp.fcflocale, &fcf_config_locale, N));
    options locale=&fcf_config_locale_opt;

    /* update localization data, first parse the key and get the values using current server locale */
    data work.fcfsa;
        set sashelp.fcfsa;
        where locale="&fcf_config_locale_opt";
        length type $32 name $32 parm_name $32 VALUE $255 ;
        keep type name parm_name value ;
        type=kscan(key,1,'.');
        name=kscan(key,2,'.');
        parm_name=kscan(key,3,'.');
        VALUE=sasmsg("sashelp.fcfsa", key, 'NOQUOTE');
    run;

    proc sql;
        update seg_kc.fsk_header h
        set HEADER_DESCRIPTION =  COALESCE((select VALUE from work.fcfsa f
                                       where  f.type = "HDRDESC"
                                          and f.name = UPCASE(h.HEADER_NAME)
                                       ),  h.HEADER_DESCRIPTION )
        where HEADER_ID > 0 and LOGICAL_DELETE_IND = "N" or HEADER_ID = -1
        ;
    quit;

    proc sql;
        update seg_kc.FSK_SCENARIO s
        set SCENARIO_DESCRIPTION =  COALESCE((select VALUE from work.fcfsa f
                                       where  f.type = "SCRDESC"
                                          and f.name = UPCASE(s.SCENARIO_NAME)
                                       ), s.SCENARIO_DESCRIPTION)
        where SCENARIO_ID > 0 and LOGICAL_DELETE_IND = "N" and CURRENT_IND="Y" or SCENARIO_ID = -1
        ;
    quit;

    proc sql;
        update seg_kc.FSK_SCENARIO s
        set SCENARIO_SHORT_DESCRIPTION =  COALESCE((select VALUE from work.fcfsa f
                                       where  f.type = "SCRSDESC"
                                          and f.name = UPCASE(s.SCENARIO_NAME)
                                       ), s.SCENARIO_SHORT_DESCRIPTION)
        where SCENARIO_ID > 0 and LOGICAL_DELETE_IND = "N" and CURRENT_IND="Y"  or SCENARIO_ID = -1
        ;
    quit;

    proc sql;
        update seg_kc.FSK_SCENARIO_PARAMETER s
        set PARM_DESC =  COALESCE((select f.VALUE from work.fcfsa f
                                       inner join seg_kc.FSK_SCENARIO s1
                                       on     f.name = UPCASE(s1.SCENARIO_NAME)
                                          and s1.LOGICAL_DELETE_IND = "N"
                                          and s1.CURRENT_IND="Y"
                                          and s.SCENARIO_ID = s1.SCENARIO_ID
                                          and f.type = "SCRPDESC"
                                          and f.parm_name = UPCASE(s.PARM_NAME)
                                       ), s.PARM_DESC)

        ;
    quit;
%mend  fcf_sa_update_locale_data;

