/*==============================================================================
| NAME:    fcf_wl_dwjn_trans_remove
| PRODUCT: SAS Compliance Solutions
| SYSTEM:  UNIX/WINDOWS
================================================================================

WATCH LIST PROVIDER - Dow Jones
WATCH LIST NAME     - Watchlist (transportation)
WATCH LIST CODE     - DWJN
WEB LINK            - http://fis.dowjones.com/products/watchlist.html

MODULE TYPE         - REMOVE
MODULE PURPOSE      - Logically delete records with action type of 'DEL'.

MODULE NOTES
------------
None
==============================================================================*/

/*-------------------------------------------------------------------
 * Copyright (c) 2012-2016 by SAS Institute Inc., Cary, NC 27513 USA
 *  ---All Rights Reserved.
 *-------------------------------------------------------------------*/

%macro fcf_wl_dwjn_trans_remove;

  /*********************************************************************
   * DESCRIPTION:
   * Logically delete records that have an action of 'DEL' in the
   * ACTION field of the input data.  These records are split out to
   * the 'delete' data set during the transformation step.
   *
   * INPUTS(S):
   * stg_wtch.wl_dwjn_trans_delete
   *
   * OUTPUT(S):
   * seg_kc.fsc_transport_watch_list_dim
   *********************************************************************/
  %fcf_get_observation_count(table=stg_wtch.wl_dwjn_trans_delete);

  %if %eval(&fcf_obs_count) gt 0 %then %do;

     proc sql;
       update seg_kc.fsc_transport_watch_list_dim
          set change_end_date=dhms(input(put(&runasofdate,8.),yymmdd8.),00,00,00),
              change_current_ind = 'N'
        where upcase(watch_list_name) = 'DWJN' and
              upcase(change_current_ind) = 'Y' and
              transport_watch_list_number in
                   (select transport_watch_list_number
                      from stg_wtch.wl_dwjn_trans_delete(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dwjn_trans_delete)));
     quit;

  %end;
  %else %do;
    %put NOTE: FCF: No records to be removed for watch list.;
  %end;

%mend fcf_wl_dwjn_trans_remove;
