/*==============================================================================
| NAME:    fcf_wl_dwjn_transport
| PRODUCT: SAS Compliance Solutions
| SYSTEM:  UNIX/WINDOWS
================================================================================

WATCH LIST PROVIDER - Dow Jones
WATCH LIST NAME     - Watchlist
WATCH LIST CODE     - DWJN
WEB LINK            - http://fis.dowjones.com/products/watchlist.html

MODULE TYPE         - TRANSPORT
MODULE PURPOSE      - Transport data in preparation for data load.

MODULE NOTES
------------
None

==============================================================================*/

/*-------------------------------------------------------------------
 * Copyright (c) 2015-2016 by SAS Institute Inc., Cary, NC 27513 USA
 *  ---All Rights Reserved.
 *-------------------------------------------------------------------*/

%macro fcf_wl_dwjn_transport;

  /*------------
   * Set module
   *------------*/
  %local _fcfmodule_;
  %let _fcfmodule_=fcf_WL_DWJN_TRANSPORT;

  /*---------------------
   * Call pre macro stub
   *---------------------*/
  %fcf_execute_macro(pre&_fcfmodule_);

  /*------------------------------------------
   * Set error code to 0 and message to blank
   *------------------------------------------*/
  %let trans_rc = 0;
  %let _fcfmsg_=;

  /*------------------------------------------
   * get column names for watch_list_dim
   *------------------------------------------*/
  %fcf_get_column_names(table=seg_kc.fsc_entity_watch_list_dim);


  /****************************************************************************/
  /* STEP 1                                                                   */
  /*                                                                          */
  /* DESCRIPTION:                                                             */
  /* Process wl_dwjn_extract                                                  */
  /*                                                                          */
  /* NOTES:                                                                   */
  /*                                                                          */
  /* INPUTS(S);                                                               */
  /* stg_wtch.wl_dwjn_extract                                                 */
  /*                                                                          */
  /* OUTPUT(S):                                                               */
  /* stg_wtch.wl_dwjn_transport_01 (primary entity records)                   */
  /* stg_wtch.wl_dwjn_transport_02 (programs)                                 */
  /* stg_wtch.wl_dwjn_transport_03 (entity name)                              */
  /* stg_wtch.wl_dwjn_transport_04 (entity address)                           */
  /* stg_wtch.wl_dwjn_transport_05 ( entity_model_type/entity_flag)           */
  /* stg_wtch.wl_dwjn_transport_06 (entity_owner_operator)                    */
  /* stg_wtch.wl_dwjn_trans_delete (record deletes)                           */
  /* stg_err.wl_dwjn_trans_errors_01     (data errors                         */
  /****************************************************************************/
  data 
   stg_wtch.wl_dwjn_transport_01
  (%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dwjn_transport_01, output_ds=Y)
   keep=
      transport_watch_list_number
      watch_list_name
      identification_id
      identification_type_desc
      create_date
      update_date
      exclude_ind
   ) 

   stg_wtch.wl_dwjn_transport_02(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dwjn_transport_02, output_ds=Y)
                                 keep=
      transport_watch_list_number
      sanctions_list_reference
   )


   stg_wtch.wl_dwjn_transport_03(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dwjn_transport_03, output_ds=Y)
                                 keep=
      transport_watch_list_number
      type_desc
      entity_name
   )

   stg_wtch.wl_dwjn_transport_04(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dwjn_transport_04, output_ds=Y)
                                 keep=
      transport_watch_list_number
      address_line
      address_city
      address_country
   )

   stg_wtch.wl_dwjn_transport_05(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dwjn_transport_05, output_ds=Y)
                                 keep=
      transport_watch_list_number
      entity_model_type
	  entity_flag
   )

   stg_wtch.wl_dwjn_transport_06(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dwjn_transport_06, output_ds=Y)
                                 keep=
      transport_watch_list_number
	  entity_owner_operator
   )

   stg_wtch.wl_dwjn_trans_delete(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dwjn_trans_delete, output_ds=Y)
                                 keep=
      transport_watch_list_number
   )

   stg_err.wl_dwjn_trans_errors_01(%fcf_get_ds_opts(lib_name=stg_err, ds_name=wl_dwjn_trans_errors_01, output_ds=Y) 
                                   keep=
      transport_watch_list_number
      watch_list_name
      error_file
      error_record_number
      error_field
      error_value
      error_message
      error_datetime
   );

   length
      person_entity_id_lag 8
      action_lag $ 3
      type_desc_lag $ 20
      description_3_lag $20
   ;

   retain
      person_entity_id_lag
      action_lag
      type_desc_lag
      description_3_lag
	  addition_date_lag
	  last_reviewed_date_lag
   ;
   retain error_flag 0;

   attrib
   /* ERROR FIELDS */
      error_file          length=$200
                          informat=$200.
                          format=$200.
                          label='Error File'

      error_record_number length=8
                          informat=best32.
                          format=best32.
                          label='Error Record Number'

      error_field         length=$32
                          informat=$32.
                          format=$32.
                          label='Error Field'

      error_value         length=$1000
                          informat=$1000.
                          format=$1000.
                          label='Error Value'

      error_message       length=$200
                          informat=$200.
                          format=$200.
                          label='Error Message'

      error_datetime      length=8
                          informat=nldatm.
                          format=nldatm.
                          label='Error Datetime'
   ;

   /* FSC_TRANSPORT_WATCH_LIST_DIM */
   /* Sets variable attribs to match variables in DBMS */
   if 1 eq 0 then
      set seg_kc.FSC_TRANSPORT_WATCH_LIST_DIM;

   set stg_wtch.wl_dwjn_extract(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dwjn_extract)
                                keep=
      person_entity_id
      action
      firstname
	  description_2
	  description_3
      sanctions_list_reference
      address_line
      address_city
      address_country
	  vessel_type
	  vessel_owner
	  vessel_flag
      country
      identification_type
      identification_number
      addition_date
      last_reviewed_date
   ) end=eof;

  
   /* TRANSPORT_WATCH_LIST_NUMBER */
   if not missing(person_entity_id) then do;
      person_entity_id_lag=person_entity_id;
      description_3_lag=description_3;
	  addition_date_lag=addition_date;
	  last_reviewed_date_lag=last_reviewed_date;
   end;
   else if missing(person_entity_id) then do;
      person_entity_id=person_entity_id_lag;
      description_3=description_3_lag;
	  addition_date=addition_date_lag;
	  last_reviewed_date=last_reviewed_date_lag;
   end;

   /* Filter out Ships and Aircrafts */
   if upcase(description_3) eq "SHIP"
     or upcase(description_3) eq "AIRCRAFT";

   transport_watch_list_number=kstrip(put(person_entity_id,best32.));
   entity_name=firstname;

   if not missing(action) then
      action_lag=action;
   else if missing(action) then
      action=action_lag;

   if upcase(action) eq 'DEL' then
      output stg_wtch.wl_dwjn_trans_delete;

   else if upcase(action) in ('ADD','CHG') then do;

      /* WATCH_LIST_NAME */
      watch_list_name='DWJN';

      /* CATEGORY_DESC */
      if upcase(description_2) eq 'TERROR' then
         category_desc='TERRORISM';
      else
         category_desc=upcase(compbl(kstrip(description_2)));

      /* TYPE_DESC */
      if upcase(compbl(kstrip(description_3))) eq 'SHIP' then type_desc='VESSEL';
	  else type_desc=upcase(compbl(kstrip(description_3)));

      /* IDENTIFICATION_ID */
      identification_id=kstrip(identification_number);

      /* IDENTIFICATION_TYPE_DESC */
      identification_type_desc=upcase(compbl(kstrip(identification_type)));
      if kindex(identification_type_desc,'(IMO)') then identification_type_desc='IMO';

	  /* MODEL_TYPE, OWNER_OPERATOR, AND FLAG */
      if upcase(type_desc) eq "VESSEL" then do;
	      entity_model_type=upcase(compbl(kstrip(vessel_type)));
	      entity_owner_operator=upcase(compbl(kstrip(vessel_owner)));
	      entity_flag=upcase(compbl(kstrip(vessel_flag)));
		  if not missing(entity_model_type) or not missing(entity_flag) then output STG_WTCH.wl_dwjn_transport_05;
		  if not missing(entity_owner_operator) then output STG_WTCH.wl_dwjn_transport_06;
	  end;
	  else if upcase(type_desc) eq "AIRCRAFT" then do;
	        profile_notes=substr(profile_notes,kindex(profile_notes,":")+1);
	        num_notes=countc(profile_notes,';') + 1;

            /* Iterate thru profile_notes field */
            /* Output a record for each instance of a valid entry */
            do i=1 to num_notes;
                 notes_text=upcase(kscan(profile_notes,i,';'));

				 /* IDENTIFICATION_ID
                    IDENTIFICATION_TYPE_DESC=AIRCRAFT CONSTRUCTION NUMBER */
	             if indexw(notes_text,'MSN') then do;
                     identification_type_desc='MSN';
                     identification_id=kcompress(substr(notes_text,kindex(notes_text,")")+2));
                     output STG_WTCH.wl_dwjn_transport_01;
                  end;  /* end:  identification_id / identification_type_desc='MSN' */

                 /* IDENTIFICATION_ID
                    IDENTIFICATION_TYPE_DESC=AIRCRAFT CONSTRUCTION NUMBER */
                 else if indexw(profile_notes,'AIRCRAFT CONSTRUCTION NUMBER') then do;
                     identification_type_desc='AIRCRAFT CONSTRUCTION NUMBER';
                     identification_id=kcompress(substr(profile_notes,kindex(profile_notes,")")+2));
                     output STG_WTCH.wl_dwjn_transport_01;
                 end; /* end: identification_id / identification_type_desc='AIRCRAFT CONSTRUCTION NUMBER' */

                 /* ENTITY_MODEL_TYPE */
                 else if indexw(profile_notes,'AIRCRAFT MODEL') then do;
                     entity_model_type=kcompress(tranwrd(profile_notes,'AIRCRAFT MODEL',''));
                     if not missing(entity_model_type) then output STG_WTCH.wl_dwjn_transport_05;
                 end; /* end: entity_model_type */
      
                 /* ENTITY_OWNER_OPERATOR */
                 else if indexw(profile_notes,'AIRCRAFT OPERATOR') then do;
                     entity_owner_operator=kcompress(tranwrd(profile_notes,'AIRCRAFT OPERATOR',''));
                     if not missing(entity_owner_operator) then output STG_WTCH.wl_dwjn_transport_06;
                 end; /* end: identification_id / identification_type_desc='COMMERCIAL REGISTRY NUMBER' */
		  end; /* do */
      end; /* aircraft */
	  else do;  /* ERROR: Unknown description_3 - cannot determine type_desc */
         transport_watch_list_number=kstrip(put(person_entity_id,best32.));
         watch_list_name='DWJN';
         error_file="&dwjn_file";
         error_record_number=_N_;
         error_field='DESCRIPTION_3';
         error_value=kstrip(description_3);
         error_message='ERROR: Unknown DESCRIPTION_3.';
         error_datetime=datetime();

         putlog 'ERROR: FCF: Cannot determine type based on DESCRIPTION_3. '
                transport_watch_list_number= description_3=;
                
         error_flag=1;
         output stg_err.wl_dwjn_trans_errors_01;
      end;


      /* CREATE_DATE */
      if not missing(addition_date) then do;
         create_date=input(addition_date,??anydtdte32.);
         if not missing(create_date) then
            create_date=dhms(create_date,00,00,00);
      end;
      if not missing(last_reviewed_date) then do;
          update_date=input(last_reviewed_date,??anydtdte32.);
          if not missing(update_date) then
             update_date=dhms(update_date,00,00,00);
      end;

      /* EXCLUDE_IND */
      exclude_ind='N';

      
      /* SET LAG VALUES */
      if not missing(type_desc) then
         type_desc_lag=type_desc;
      else if missing(type_desc) then
         type_desc=type_desc_lag;


      
      /* ERROR: Unknown description_1 - cannot determine type_desc */
      if missing(type_desc) and not missing(description_1) then do;

         transport_watch_list_number=kstrip(put(person_entity_id,best32.));
         watch_list_name='DWJN';
         error_file="&dwjn_file";
         error_record_number=_N_;
         error_field='DESCRIPTION_1';
         error_value=kstrip(description_1);
         error_message='ERROR: Unknown DESCRIPTION_1.';
         error_datetime=datetime();

         putlog 'ERROR: FCF: Cannot determine type based on DESCRIPTION_1. '
                transport_watch_list_number= description_1=;
                
         error_flag=1;
         output stg_err.wl_dwjn_trans_errors_01;
      end;

	  if not missing(entity_name) then output stg_wtch.wl_dwjn_transport_03;
      output
         stg_wtch.wl_dwjn_transport_01
         stg_wtch.wl_dwjn_transport_02
         stg_wtch.wl_dwjn_transport_04
      ;

   end;

   if (eof) and (error_flag) then do;
      putlog ' ';
      putlog 'WARNING: FCF: Invalid values were encountered processing the watch list data';
      putlog 'WARNING: FCF: Data values were written to the STG_ERR.WL_DWJN_TRANS_ERRORS table.';
   end;
    
   /* Set all columns in if set 1=0 column to missing */
   call missing(&col_name_list);
  run;

  /****************************************************************************/
  /* STEP 2                                                                   */
  /*                                                                          */
  /*  Remove Duplicate Records                                                */
  /*                                                                          */ 
  /* INPUTS(S);                                                               */
  /* stg_wtch.wl_dwjn_transport_01                                            */
  /* stg_wtch.wl_dwjn_transport_02                                            */
  /* stg_wtch.wl_dwjn_transport_05                                            */
  /*                                                                          */
  /* OUTPUT(S):                                                               */
  /* stg_wtch.wl_dwjn_transport_07                                            */
  /****************************************************************************/
    proc sort data=stg_wtch.wl_dwjn_transport_01(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dwjn_transport_01))
            out=stg_wtch.wl_dwjn_transport_01(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dwjn_transport_01, output_ds=Y))
            nodupkey;
    by transport_watch_list_number identification_id identification_type_desc;
   run;

   proc sort data=stg_wtch.wl_dwjn_transport_02(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dwjn_transport_02)
                                                where=(sanctions_list_reference ne ''))
            out=stg_wtch.wl_dwjn_transport_02(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dwjn_transport_02, output_ds=Y))
            nodupkey;
    by transport_watch_list_number sanctions_list_reference;
   run;

   proc sort data=stg_wtch.wl_dwjn_transport_05(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dwjn_transport_05))
            out=stg_wtch.wl_dwjn_transport_05(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dwjn_transport_05, output_ds=Y))
            nodupkey;
    by transport_watch_list_number entity_model_type entity_flag;
   run;

   /****************************************************************************/
  /* STEP 3                                                                   */
  /*                                                                          */
  /* Populate Programs with sanctions_reference_list                          */
  /*                                                                          */ 
  /* INPUTS(S);                                                               */
  /* stg_wtch.wl_dwjn_transport_02                                            */
  /*                                                                          */
  /* OUTPUT(S):                                                               */
  /* stg_wtch.wl_dwjn_transport_07                                            */
  /****************************************************************************/
  data stg_wtch.wl_dwjn_transport_07(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dwjn_transport_07, output_ds=Y)
                                     keep=transport_watch_list_number programs);

   /* FSC_TRANSPORT_WATCH_LIST_DIM */
   /* Sets variable attribs to match variables in DBMS */
   if 1 eq 0 then
      set seg_kc.FSC_TRANSPORT_WATCH_LIST_DIM;

   set stg_wtch.wl_dwjn_transport_02(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dwjn_transport_02));
   by transport_watch_list_number sanctions_list_reference;

   retain programs;
  
   sanctions_list_reference=upcase(sanctions_list_reference);

  
    if not missing(sanctions_list_reference) and  first.transport_watch_list_number then 
	     programs=compbl(kstrip(sanctions_list_reference));
	else programs=kstrip(programs) || ';' || compbl(kstrip(sanctions_list_reference));
	
   /* if this is the last record for an entity, determine the text to be stored */
   if last.transport_watch_list_number then output;

  run;
  


  /****************************************************************************/
  /* STEP 4                                                                   */
  /*                                                                          */
  /* DESCRIPTION:                                                             */
  /* Process address, city_name, state_name, and country_name                 */
  /*                                                                          */
  /* NOTES:                                                                   */
  /*                                                                          */
  /* INPUTS(S);                                                               */
  /* stg_wtch.wl_dwjn_transport_04                                            */
  /*                                                                          */
  /* OUTPUT(S):                                                               */
  /* stg_wtch.wl_dwjn_transport_08                                            */
  /*                                                                          */
  /****************************************************************************/
  data stg_wtch.wl_dwjn_transport_08(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dwjn_transport_08, output_ds=Y)
                                     keep=
   transport_watch_list_number
   address
   city_name
   state_name
   country_name
   );

    /* FSC_TRANSPORT_WATCH_LIST_DIM */
    /* Sets variable attribs to match variables in DBMS */
    if 1 eq 0 then
      set seg_kc.FSC_TRANSPORT_WATCH_LIST_DIM;

    set stg_wtch.wl_dwjn_transport_04(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dwjn_transport_04));

    if upcase(address_country) eq 'NOT KNOWN' then
      address_country='';

    if missing(address_line) and
       missing(address_city) and
       missing(address_country) then
      delete;

    address=upcase(compbl(kstrip(address_line)));
	address=kstrip(tranwrd(address, "LINKED TO:",""));
    city_name=upcase(compbl(kstrip(address_city)));
    country_name=upcase(compbl(kstrip(address_country)));
    state_name='';
   
    /* Attempt to parse state/province name from city_name */
    pos = findc(city_name, ',', 'b');
    if pos > 0 then do;
       state_name=substr(city_name,pos+1);
       city_name=substr(city_name,1,pos-1);
    end;

    
    if not missing(address) then
      output stg_wtch.wl_dwjn_transport_08;

  run;

  proc sort data=stg_wtch.wl_dwjn_transport_08(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dwjn_transport_08))
            out=stg_wtch.wl_dwjn_transport_08(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dwjn_transport_08, output_ds=Y))
            nodupkey;
    by transport_watch_list_number
       address
       city_name
       ;
   run;


  /****************************************************************************/
  /* STEP 5                                                                   */
  /*                                                                          */
  /* DESCRIPTION:                                                             */
  /*                                                                          */
  /* Generate all data permutations for each distinct primary entity          */
  /*                                                                          */
  /* NOTES:                                                                   */
  /*                                                                          */
  /*                                                                          */
  /* INPUTS(S);                                                               */
  /*                                                                          */
  /* stg_wtch.wl_dwjn_transport_01                                            */                                      
  /* stg_wtch.wl_dwjn_transport_03                                            */
  /* stg_wtch.wl_dwjn_transport_05                                            */
  /* stg_wtch.wl_dwjn_transport_06                                            */
  /* stg_wtch.wl_dwjn_transport_07                                            */
  /*                                                                          */
  /* OUTPUT(S):                                                               */
  /*                                                                          */
  /* set stg_wtch.wl_dwjn_transport_09                                        */
  /* set stg_wtch.wl_dwjn_transport_10                                        */
  /* set stg_wtch.wl_dwjn_transport_11                                        */
  /* set stg_wtch.wl_dwjn_transport_12                                        */
  /* set stg_wtch.wl_dwjn_transport    (final transform)                      */
  /****************************************************************************/
  proc sql noprint;

   create table stg_wtch.wl_dwjn_transport_09 %fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dwjn_transport_09, output_ds=Y, add_parens=Y)  as
      select a.*,
             b.programs
        from stg_wtch.wl_dwjn_transport_01(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dwjn_transport_01)) as a full join
             stg_wtch.wl_dwjn_transport_07(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dwjn_transport_07)) as b
             on a.transport_watch_list_number=b.transport_watch_list_number;

   
   create table stg_wtch.wl_dwjn_transport_10 %fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dwjn_transport_10, output_ds=Y, add_parens=Y)  as
      select a.*,
	         b.type_desc,
             b.entity_name
        from stg_wtch.wl_dwjn_transport_09(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dwjn_transport_09)) as a full join
             stg_wtch.wl_dwjn_transport_03(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dwjn_transport_03)) as b
             on a.transport_watch_list_number=b.transport_watch_list_number;

    
   create table stg_wtch.wl_dwjn_transport_11 %fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dwjn_transport_11, output_ds=Y, add_parens=Y)  as
      select a.*,
	         b.entity_model_type,
             b.entity_flag
        from stg_wtch.wl_dwjn_transport_10(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dwjn_transport_10)) as a full join
             stg_wtch.wl_dwjn_transport_05(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dwjn_transport_05)) as b
             on a.transport_watch_list_number=b.transport_watch_list_number;
    
   create table stg_wtch.wl_dwjn_transport_12 %fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dwjn_transport_12, output_ds=Y, add_parens=Y)  as
      select a.*,
	         b.entity_owner_operator
        from stg_wtch.wl_dwjn_transport_11(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dwjn_transport_11)) as a full join
             stg_wtch.wl_dwjn_transport_06(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dwjn_transport_06)) as b
             on a.transport_watch_list_number=b.transport_watch_list_number;

   create table stg_wtch.wl_dwjn_transport_13 %fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dwjn_transport_13, output_ds=Y, add_parens=Y)  as
      select a.*,
             b.address,
             b.city_name,
             b.state_name,
             b.country_name
        from stg_wtch.wl_dwjn_transport_12(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dwjn_transport_12)) as a full join
             stg_wtch.wl_dwjn_transport_08(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dwjn_transport_08)) as b
             on a.transport_watch_list_number=b.transport_watch_list_number;

quit;

data stg_wtch.wl_dwjn_transport(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dwjn_transport, output_ds=Y));
/* Sets variable attribs to match variables in DBMS */
   if 1 eq 0 then
      set seg_kc.FSC_TRANSPORT_WATCH_LIST_DIM;
     set stg_wtch.wl_dwjn_transport_13(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dwjn_transport_13));
     if missing(country_name) and entity_flag ne "NOT KNOWN" then country_name=entity_flag;
run;

data  stg_wtch.POSTWL_DWJN_TRANSPORT(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=POSTWL_DWJN_TRANSPORT, output_ds=Y));
   set stg_wtch.wl_dwjn_transport(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dwjn_transport));

   /* Set the COUNTRY_CODE */
    if missing(country_name) then country_code="";
    else country_code=put(country_name, $country_code.);
run;

  /****************************************************************************/
  /* STEP 6                                                                   */
  /*                                                                          */
  /* DESCRIPTION:                                                             */
  /* Create final delete file                                                 */
  /*                                                                          */
  /* NOTES:                                                                   */
  /*                                                                          */
  /* INPUTS(S);                                                               */
  /* stg_wtch.wl_dwjn_trans_delete                                            */
  /*                                                                          */
  /* OUTPUT(S):                                                               */
  /* stg_wtch.wl_dwjn_trans_delete                                            */
  /****************************************************************************/
  proc sort data=stg_wtch.wl_dwjn_trans_delete(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dwjn_trans_delete))
            out=stg_wtch.wl_dwjn_trans_delete(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_dwjn_trans_delete, output_ds=Y))
            nodupkey;
    by transport_watch_list_number;
   run;

  /****************************************************************************/
  /* STEP 7                                                                   */
  /*                                                                          */
  /* DESCRIPTION:                                                             */
  /* Create final errors file                                                 */
  /*                                                                          */
  /* NOTES:                                                                   */
  /*                                                                          */
  /* INPUTS(S);                                                               */
  /* stg_err.wl_dwjn_trans_errors_01                                          */  
  /*                                                                          */
  /* OUTPUT(S):                                                               */
  /* stg_err.wl_dwjn_trans_errors                                             */
  /****************************************************************************/
  proc append base=stg_err.wl_dwjn_trans_errors(%fcf_get_ds_opts(lib_name=stg_err, ds_name=wl_dwjn_trans_errors, output_ds=Y))
              data=stg_err.wl_dwjn_trans_errors_01(%fcf_get_ds_opts(lib_name=stg_err, ds_name=wl_dwjn_trans_errors_01))
              force nowarn;
   run;

 
   proc sort data=stg_err.wl_dwjn_trans_errors(%fcf_get_ds_opts(lib_name=stg_err, ds_name=wl_dwjn_trans_errors))
            out=stg_err.wl_dwjn_trans_errors(%fcf_get_ds_opts(lib_name=stg_err, ds_name=wl_dwjn_trans_errors, output_ds=Y))
            nodupkey;
    by transport_watch_list_number
       error_value;
   run;


  %MACRO_END:

   %if &trans_rc eq 3 or &trans_rc ge 5 %then
      %fcf_execute_macro(fcf_error);
   %else %do;
      %fcf_execute_macro(post&_fcfmodule_);
      %fcf_execute_macro(fcf_success);
   %end;

%mend fcf_wl_dwjn_transport;
