/*==============================================================================
| NAME:    fcf_wl_hmt_extract
| PRODUCT: SAS Compliance Solutions
| SYSTEM:  UNIX/WINDOWS
================================================================================

WATCH LIST PROVIDER - HM Treasury
WATCH LIST NAME     - Consolidated List of Financial Sanctions Targets (Full List)
WATCH LIST CODE     - HMT
WEB LINK            - http://www.hm-treasury.gov.uk/fin_sanctions_index.htm

MODULE TYPE         - EXTRACT
MODULE PURPOSE      - Read extract file(s) and output to SAS data set(s).

MODULE NOTES
------------
None

==============================================================================*/

/*-------------------------------------------------------------------
 * Copyright (c) 2012-2016 by SAS Institute Inc., Cary, NC 27513 USA
 *  ---All Rights Reserved.
 *-------------------------------------------------------------------*/

%macro fcf_wl_hmt_extract;

  /*------------
   * Set module
   *------------*/
  %let _fcfmodule_=fcf_WL_HMT_EXTRACT;

  /*---------------------
   * Call pre macro stub
   *---------------------*/
  %fcf_execute_macro(pre&_fcfmodule_);

  /*------------------------------------------
   * Set error code to 0 and message to blank
   *------------------------------------------*/
  %let trans_rc = 0;
  %let _fcfmsg_=;

  /***************************************************************************/
  /* BEGIN: STG_WTCH.wl_hmt_extract_01                                       */
  /*                                                                         */
  /* DESCRIPTION: Obtain optimal field length values.                        */
  /***************************************************************************/
  filename in_wl "&hmt_file" encoding="latin1";

  data STG_WTCH.wl_hmt_extract_01(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_hmt_extract_01, output_ds=Y)
                                  keep=
      name_6_L
      name_1_L
      name_2_L
      name_3_L
      name_4_L
      name_5_L
      title_L
      dob_L
      town_of_birth_L
      country_of_birth_L
      nationality_L
      passport_details_L
      ni_number_L
      position_L
      address_1_L
      address_2_L
      address_3_L
      address_4_L
      address_5_L
      address_6_L
      post_zip_code_L
      country_L
      other_information_L
      group_type_L
      alias_type_L
      regime_L
      listed_on_L
      last_updated_L
      group_id_L
   );

      infile in_wl delimiter=',' dsd missover lrecl=32767 firstobs=3;

      attrib
         name_6            informat=$&textsize..
         name_1            informat=$&textsize..
         name_2            informat=$&textsize..
         name_3            informat=$&textsize..
         name_4            informat=$&textsize..
         name_5            informat=$&textsize..
         title             informat=$&textsize..
         dob               informat=$&textsize..
         town_of_birth     informat=$&textsize..
         country_of_birth  informat=$&textsize..
         nationality       informat=$&textsize..
         passport_details  informat=$&textsize..
         ni_number         informat=$&textsize..
         position          informat=$&textsize..
         address_1         informat=$&textsize..
         address_2         informat=$&textsize..
         address_3         informat=$&textsize..
         address_4         informat=$&textsize..
         address_5         informat=$&textsize..
         address_6         informat=$&textsize..
         post_zip_code     informat=$&textsize..
         country           informat=$&textsize..
         other_information informat=$&textsize..
         group_type        informat=$&textsize..
         alias_type        informat=$&textsize..
         regime            informat=$&textsize..
         listed_on         informat=$&textsize..
         last_updated      informat=$&textsize..
         group_id          informat=$&textsize..
      ;

      input
         name_6            $
         name_1            $
         name_2            $
         name_3            $
         name_4            $
         name_5            $
         title             $
         dob               $
         town_of_birth     $
         country_of_birth  $
         nationality       $
         passport_details  $
         ni_number         $
         position          $
         address_1         $
         address_2         $
         address_3         $
         address_4         $
         address_5         $
         address_6         $
         post_zip_code     $
         country           $
         other_information $
         group_type        $
         alias_type        $
         regime            $
         listed_on         $
         last_updated      $
         group_id          $
      ;

      name_6_L=length(name_6);
      name_1_L=length(name_1);
      name_2_L=length(name_2);
      name_3_L=length(name_3);
      name_4_L=length(name_4);
      name_5_L=length(name_5);
      title_L=length(title);
      dob_L=length(dob);
      town_of_birth_L=length(town_of_birth);
      country_of_birth_L=length(country_of_birth);
      nationality_L=length(nationality);
      passport_details_L=length(passport_details);
      ni_number_L=length(ni_number);
      position_L=length(position);
      address_1_L=length(address_1);
      address_2_L=length(address_2);
      address_3_L=length(address_3);
      address_4_L=length(address_4);
      address_5_L=length(address_5);
      address_6_L=length(address_6);
      post_zip_code_L=length(post_zip_code);
      country_L=length(country);
      other_information_L=length(other_information);
      group_type_L=length(group_type);
      alias_type_L=length(alias_type);
      regime_L=length(regime);
      listed_on_L=length(listed_on);
      last_updated_L=length(last_updated);
      group_id_L=length(group_id);

   run;

   proc sql noprint;
      select max(name_6_L),
             max(name_1_L),
             max(name_2_L),
             max(name_3_L),
             max(name_4_L),
             max(name_5_L),
             max(title_L),
             max(dob_L),
             max(town_of_birth_L),
             max(country_of_birth_L),
             max(nationality_L),
             max(passport_details_L),
             max(ni_number_L),
             max(position_L),
             max(address_1_L),
             max(address_2_L),
             max(address_3_L),
             max(address_4_L),
             max(address_5_L),
             max(address_6_L),
             max(post_zip_code_L),
             max(country_L),
             max(other_information_L),
             max(group_type_L),
             max(alias_type_L),
             max(regime_L),
             max(listed_on_L),
             max(last_updated_L),
             max(group_id_L)
      into   :L1,
             :L2,
             :L3,
             :L4,
             :L5,
             :L6,
             :L7,
             :L8,
             :L9,
             :L10,
             :L11,
             :L12,
             :L13,
             :L14,
             :L15,
             :L16,
             :L17,
             :L18,
             :L19,
             :L20,
             :L21,
             :L22,
             :L23,
             :L24,
             :L25,
             :L26,
             :L27,
             :L28,
             :L29
         from STG_WTCH.wl_hmt_extract_01(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_hmt_extract_01));
   quit;
   
   /* Make sure all columns have positive lengths, default of 200 */
   %macro fcf_check_length;
      %do i = 1 %to 29;
         %if &&L&i eq 0 %then
            %let L&i=200;
            /* DEBUG */
            /*
            %put L&i: &&L&i;
            */
      %end;
   %mend fcf_check_length;
   %fcf_check_length;
   
   /***************************************************************************/
   /* END: STG_WTCH.wl_hmt_extract_01                                         */
   /***************************************************************************/

   /***************************************************************************/
   /* BEGIN: STG_WTCH.wl_ofac_extract                                         */
   /*                                                                         */
   /* DESCRIPTION: Input the Bank of England's Consolidated List of Financial */
   /* Sanctions Targets (Full List) - csv delimited.                          */
   /***************************************************************************/
   data STG_WTCH.wl_hmt_extract(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_hmt_extract, output_ds=Y));

      infile in_wl delimiter=',' dsd missover lrecl=32767 firstobs=3 end=eof;

   attrib
      name_6            length=$&L1
                        informat=$&L1..
                        format=$&L1..
                        label='Last Name of Individual/Full Name of Entity'

      name_1            length=$&L2
                        informat=$&L2..
                        format=$&L2..
                        label='First Name'

      name_2            length=$&L3
                        informat=$&L3..
                        format=$&L3..
                        label='Second Name'

      name_3            length=$&L4
                        informat=$&L4..
                        format=$&L4..
                        label='Third Name'

      name_4            length=$&L5
                        informat=$&L5..
                        format=$&L5..
                        label='Fourth Name'

      name_5            length=$&L6
                        informat=$&L6..
                        format=$&L6..
                        label='Fifth Name'

      title             length=$&L7
                        informat=$&L7..
                        format=$&L7..
                        label='Title'

      dob               length=$&L8
                        informat=$&L8..
                        format=$&L8..
                        label='Date of Birth'

      town_of_birth     length=$&L9
                        informat=$&L9..
                        format=$&L9..
                        label='Town of Birth'

      country_of_birth  length=$&L10
                        informat=$&L10..
                        format=$&L10..
                        label='Country of Birth'

      nationality       length=$&L11
                        informat=$&L11..
                        format=$&L11..
                        label='Citizenship and/or Nationality'

      passport_details  length=$&L12
                        informat=$&L12..
                        format=$&L12..
                        label='Passport Numbers'

      ni_number         length=$&L13
                        informat=$&L13..
                        format=$&L13..
                        label='National ID Numbers'

      position          length=$&L14
                        informat=$&L14..
                        format=$&L14..
                        label='Official Title/Position'

      address_1         length=$&L15
                        informat=$&L15..
                        format=$&L15..
                        label='Address - First Line'

      address_2         length=$&L16
                        informat=$&L16..
                        format=$&L16..
                        label='Address - Second Line'

      address_3         length=$&L17
                        informat=$&L17..
                        format=$&L17..
                        label='Address - Third Line'

      address_4         length=$&L18
                        informat=$&L18..
                        format=$&L18..
                        label='Address - Fourth Line'

      address_5         length=$&L19
                        informat=$&L19..
                        format=$&L19..
                        label='Address - Fifth Line - Town'

      address_6         length=$&L20
                        informat=$&L20..
                        format=$&L20..
                        label='Address - Sixth Line - Town/State/Region'

      post_zip_code     length=$&L21
                        informat=$&L21..
                        format=$&L21..
                        label='Postal ID Codes'

      country           length=$&L22
                        informat=$&L22..
                        format=$&L22..
                        label='Country'

      other_information length=$&L23
                        informat=$&L23..
                        format=$&L23..
                        label='Other Information'

      group_type        length=$&L24
                        informat=$&L24..
                        format=$&L24..
                        label='Group Type'

      alias_type        length=$&L25
                        informat=$&L25..
                        format=$&L25..
                        label='Alias Type'

      regime            length=$&L26
                        informat=$&L26..
                        format=$&L26..
                        label='Regime'

      listed_on         length=$&L27
                        informat=$&L27..
                        format=$&L27..
                        label='Date Listed'

      last_updated      length=$&L28
                        informat=$&L28..
                        format=$&L28..
                        label='Date of Last Update'

      group_id          length=$&L29
                        informat=$&L29..
                        format=$&L29..
                        label='Group ID'
   ;

   input
      name_6            $
      name_1            $
      name_2            $
      name_3            $
      name_4            $
      name_5            $
      title             $
      dob               $
      town_of_birth     $
      country_of_birth  $
      nationality       $
      passport_details  $
      ni_number         $
      position          $
      address_1         $
      address_2         $
      address_3         $
      address_4         $
      address_5         $
      address_6         $
      post_zip_code     $
      country           $
      other_information $
      group_type        $
      alias_type        $
      regime            $
      listed_on         $
      last_updated      $
      group_id          $
   ;

      if upcase("&allow_invalid") eq "N" then
         if _error_ ne 0 then do;
            call symputx('trans_rc', 999999);
            stop;
         end;

      if eof then
         call symputx('num_recs', _N_ );

   run;
   /***************************************************************************/
   /* END: STG_WTCH.wl_hmt_extract                                            */
   /***************************************************************************/

   %if &trans_rc eq 3 or &trans_rc ge 5 %then
      %fcf_execute_macro(fcf_error);
   %else %do;
      %fcf_execute_macro(post&_fcfmodule_);
      %fcf_execute_macro(fcf_success);
   %end;

%mend fcf_wl_hmt_extract;
