/*==============================================================================
| NAME:    fcf_wl_hmt_transform
| PRODUCT: SAS Compliance Solutions
| SYSTEM:  UNIX/WINDOWS
================================================================================

WATCH LIST PROVIDER - HM Treasury
WATCH LIST NAME     - Consolidated list of persons, groups and entities subject (Full List)
WATCH LIST CODE     - HMT
WEB LINK            - http://www.hm-treasury.gov.uk/fin_sanctions_index.htm

MODULE TYPE         - TRANSFORM
MODULE PURPOSE      - Transform data in prepartion for data load.

MODULE NOTES
------------
None

==============================================================================*/

/*-------------------------------------------------------------------
 * Copyright (c) 2012-2016 by SAS Institute Inc., Cary, NC 27513 USA
 *  ---All Rights Reserved.
 *-------------------------------------------------------------------*/

%macro fcf_wl_hmt_transform;

  /*------------
   * Set module
   *------------*/
  %local _fcfmodule_;
  %let _fcfmodule_=fcf_WL_HMT_TRANSFORM;

  /*---------------------
   * Call pre macro stub
   *---------------------*/
  %fcf_execute_macro(pre&_fcfmodule_);

  /*------------------------------------------
   * Set error code to 0 and message to blank
   *------------------------------------------*/
  %let trans_rc=0;
  %let _fcfmsg_=;


/******************************************************************************/
/* BEGIN: STG_WTCH.wl_hmt_transform                                           */
/*        STG_ERR.wl_hmt_errors                                               */
/*                                                                            */
/* DESCRIPTION: Output table 'STG_WTCH.wl_hmt_transform' contains all final   */
/*              data transformations.                                         */
/******************************************************************************/
data

   STG_WTCH.wl_hmt_transform_01(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_hmt_transform_01, output_ds=Y)
                                keep=
      entity_watch_list_key
      entity_watch_list_number
      watch_list_name
      category_desc
      type_desc
      programs
      tax_id
      tax_id_type_code
      identification_id
      identification_type_desc
      date_of_birth
      year_of_birth
	  place_of_birth
      deceased_ind
      first_name
      last_name
      middle_name
      entity_name
      match_code_individual
      match_code_organization
      entity_title
      occupation_desc
      address
      city_name
      state_name
      postal_code
      country_code
      country_name
      full_address
      match_code_full_address
      citizenship_country_code
      citizenship_country_name
      match_code_citizenship
      nationality_country_code
      nationality_country_name
      match_code_nationality
      org_country_of_business_code
      org_country_of_business_name
      match_code_org_country
      politically_exposed_person_ind
      create_date
      update_date
      exclude_ind
      change_begin_date
      change_end_date
      change_current_ind
   )

   STG_WTCH.wl_hmt_transform_02(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_hmt_transform_02, output_ds=Y)
                                keep=
      entity_watch_list_number
	  entry_num
      town_of_birth
   )

    STG_WTCH.wl_hmt_transform_03(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_hmt_transform_03, output_ds=Y)
                                 keep=
      entity_watch_list_number
      entry_num
      country_of_birth
   )

    STG_WTCH.wl_hmt_transform_04(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_hmt_transform_04, output_ds=Y)
                                 keep=
      entity_watch_list_number
      nationality
   )

   STG_ERR.wl_hmt_errors(%fcf_get_ds_opts(lib_name=stg_err, ds_name=wl_hmt_errors, output_ds=Y)
                         keep=
      entity_watch_list_number
      watch_list_name
      error_file
      error_record_number
      error_field
      error_value
      error_message
      error_datetime
   );

   retain error_flag 0;

   attrib

   /* ERROR FIELDS */
      error_file          length=$200
                          informat=$200.
                          format=$200.
                          label='Error File'

      error_record_number length=8
                          informat=best32.
                          format=best32.
                          label='Error Record Number'

      error_field         length=$32
                          informat=$32.
                          format=$32.
                          label='Error Field'

      error_value         length=$1000
                          informat=$1000.
                          format=$1000.
                          label='Error Value'

      error_message       length=$200
                          informat=$200.
                          format=$200.
                          label='Error Message'

      error_datetime      length=8
                          informat=nldatm.
                          format=nldatm.
                          label='Error Datetime'
   ;

   /* variables for parsing place of birth strings */
   length town_of_birth_ $ 255;
   length country_of_birth_ $ 255;
   length nationality_ $ 255;
   length string $ 255;
   array entry_count[8] entry_count1 - entry_count8;
   array entry_text[8] $255 entry_text1 - entry_text8;

   patternId=prxparse("s/\d\)/|/");

   /* FSC_ENTITY_WATCH_LIST_DIM */
   /* Sets variable attribs to match variables in DBMS */
   if 1 eq 0 then
      set seg_kc.FSC_ENTITY_WATCH_LIST_DIM;

   set STG_WTCH.wl_hmt_extract(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_hmt_extract)) end=eof;

/******************************************************************************/
/* NOTE:                                                                      */
/*                                                                            */
/* The place of birth, country of birth, and nationality have multiple        */
/* entries in one row.  These strings must be parsed.  The values are         */
/* separated by either numbers or letters like (1) or (a)                     */
/******************************************************************************/

/******************************************************************************/
/* NOTE:                                                                      */
/*                                                                            */
/* The following fields are set to null as this watch list extract does not   */
/* currently include this data.                                               */
/******************************************************************************/
   deceased_ind='';
   state_name='';
   org_country_of_business_name='';
   politically_exposed_person_ind='';

/******************************************************************************/
/* NOTE:                                                                      */
/*                                                                            */
/* The following fields are set to null due to the complexity of required     */
/* transformations. This does not preclude users from writing                 */
/* transformation code which could populate these fields.                     */
/******************************************************************************/
   tax_id='';                   /* NI_NUMBER */
   tax_id_type_code='';         /* NI_NUMBER */
   identification_id='';        /* PASSPORT_DETAILS / NI_NUMBER */
   identification_type_desc=''; /* PASSPORT_DETAILS / NI_NUMBER */

   /* ENTITY_WATCH_LIST_NUMBER */
   entity_watch_list_number=kstrip(group_id);
   if missing(entity_watch_list_number) then do;

      watch_list_name='HMT';
      error_file="&hmt_file";
      error_record_number=_N_;
      error_field='GROUP_ID';
      error_value=kstrip(group_id);
      error_message='WARNING: Invalid entity_watch_list_number.';
      error_datetime=datetime();
      error_flag=1;

      putlog 'WARNING: FCF: Invalid entity watch list number. ' entity_name=;
      output STG_ERR.wl_hmt_errors;
   end;

   /* Valid entity_watch_list_number */
   else do;
   
      /* WATCH_LIST_NAME */
      watch_list_name='HMT';

      /* PROGRAMS */
      programs=upcase(compbl(kstrip(regime)));

      /* CATEGORY_DESC */
	  category_desc='';
      if programs eq 'TERRORIST FINANCING' then
         category_desc='TERRORISM';

      /* ENTITY_TITLE */
      entity_title=compbl(kstrip(title));

      /* OCCUPATION_DESC */
      occupation_desc=compbl(kstrip(position));

      /* ADDRESS */
      address=upcase(compbl(catx(' ',address_1,address_2,address_3,address_4)));

      /* CITY_NAME */
      city_name=upcase(compbl(catx(' ',address_5,address_6)));

      /* POSTAL_CODE */
      postal_code=kstrip(post_zip_code);

      /* COUNTRY_NAME */
      country_name=upcase(compbl(country));

      /* FULL_ADDRESS */
      full_address=catx(';',address,city_name,postal_code,country_name);

      /* CREATE_DATE */
      create_date=dhms(input(listed_on,ddmmyy10.),00,00,00);

      /* UPDATE_DATE */
      update_date=dhms(input(last_updated,?? ddmmyy10.),00,00,00);

      /* EXCLUDE_IND */
      exclude_ind='N';

      /* TYPE_DESC */
      if upcase(group_type) eq 'INDIVIDUAL' then
         type_desc='INDIVIDUAL';

      else if upcase(group_type) eq 'ENTITY' then
         type_desc='ORGANIZATION';

      /* ERROR: Unknown GROUP_TYPE */
      else if upcase(group_type) not in('ENTITY','INDIVIDUAL') then do;

         entity_watch_list_number=kstrip(group_id);
         watch_list_name='HMT';
         error_file="&hmt_file";
         error_record_number=_N_;
         error_field='GROUP_TYPE';
         error_value=kstrip(group_type);
         error_message='ERROR: Unknown GROUP_TYPE.';
         error_datetime=datetime();
         error_flag=1;

         putlog 'WARNING: FCF: Unknown GROUP_TYPE. ' entity_watch_list_number= group_type=;
         output STG_ERR.wl_hmt_errors;
      end;

      /* type_desc=INDIVIDUAL */
      if type_desc eq 'INDIVIDUAL' then do;

         /* DATE_OF_BIRTH
            YEAR_OF_BIRTH */

         /* Valid date format DD/MM/YYYY                                  */
         /* DOB values formatted as 00/00/YYYY indicate missing day/month */

         date_of_birth=.;
         year_of_birth=.;
        
         /* Non-missing dob */
         if not missing(dob) then do;
            /* DOB formatted 00/00/YYYY or 00/MM/YYYY */
            /* Set date_of_birth to missing and obtain year_of_birth */
            if index(dob,'00') then do;
               date_of_birth=.;
               year_of_birth=input(kscan(dob,-1,'/'),best32.);
            end;
            /* DOB formatted DD/MM/YYYY */
            /* Obtain date_of_birth and year_of_birth */
            else if not index(dob,'00/00') then do;

               date_of_birth=input(dob,??ddmmyy10.);

               if not missing(date_of_birth) then
                  date_of_birth=dhms(date_of_birth,00,00,00);

               if not missing(date_of_birth) then
                  year_of_birth=year(datepart(date_of_birth));

               /* WARNING: Invalid date of birth */
               else if missing(date_of_birth) then do;
                  year_of_birth=.;

                  entity_watch_list_number=kstrip(group_id);
                  watch_list_name='HMT';
                  error_file="&hmt_file";
                  error_record_number=_N_;
                  error_field='DOB';
                  error_value=kstrip(dob);
                  error_message='WARNING: Invalid date of birth. ';
                  error_datetime=datetime();
                  error_flag=1;

                  putlog 'WARNING: FCF: Invalid date of birth. ' entity_watch_list_number= dob=;
                  output STG_ERR.wl_hmt_errors;

               end; /* end: invalid dob */
            end; /* end: dob not formatted '00/00/YY' */
         end; /* end: non-missing dob */

         /* FIRST_NAME */
         first_name=upcase(compbl(name_1));

         /* LAST_NAME */
         last_name=upcase(compbl(name_6));

         /* MIDDLE_NAME */
         middle_name=upcase(compbl(catx(' ',name_2,name_3,name_4,name_5)));

         /* ENTITY_NAME */
         entity_name=catx(' ',first_name,middle_name,last_name);

          /* Output the data determined so far for the individual.  */
		  /* This will be merged later with the place_of_birth and  */
		  /* the nationality                                        */
		 output STG_WTCH.wl_hmt_transform_01;

		
/******************************************************************************/
/* NOTE:                                                                      */
/*                                                                            */
/* The place of birth, country of birth, and nationality have multiple        */
/* entries in one row.  These strings must be parsed.  The values are         */
/* separated by either numbers or letters like (1) or (a)                     */
/******************************************************************************/

/* parse town of birth and keep max count for use in parsing country */
if not missing(town_of_birth) then do;
   entity_watch_list_number=kstrip(group_id);
   town_of_birth=kstrip(town_of_birth);
   if substr(town_of_birth,length(town_of_birth)) eq ')' then do;
      end_town=find(town_of_birth,'(',-length(town_of_birth)) - 1;
      if end_town lt 0 then end_town=length(town_of_birth) -1;
      town_of_birth=substr(town_of_birth,1,end_town);
   end;
   town_of_birth=tranwrd(town_of_birth,'(a)','1)');
   town_of_birth=tranwrd(town_of_birth,'(b)','2)');
   town_of_birth=tranwrd(town_of_birth,'(c)','3)');
   town_of_birth=tranwrd(town_of_birth,'(d)','4)');
   town_of_birth=tranwrd(town_of_birth,'(1)','1)');
   town_of_birth=tranwrd(town_of_birth,'(2)','2)');
   town_of_birth=tranwrd(town_of_birth,'(3)','3)');
   town_of_birth=tranwrd(town_of_birth,'(4)','4)');
   town_of_birth=tranwrd(town_of_birth,'(5)','5)');
   town_of_birth=tranwrd(town_of_birth,'(6)','6)');
   town_of_birth=tranwrd(town_of_birth,'(7)','7)');
   town_of_birth=tranwrd(town_of_birth,'(8)','8)');
   position=prxmatch(patternID,town_of_birth);
   num=1;
   if position eq 0 then do;
      entry_count[1]=1;
      entry_text[1]=town_of_birth;
   end;
   else do;
      i=0;
      max_vals=0;
      string=town_of_birth;
      do while (position ne 0);
	      i+1;
	      entry_count[i]=substr(string,position,1);
	      string=substr(string,position+2);
	      position=prxmatch(patternID,string);
      end;
    
	  call prxchange(patternId,-1,town_of_birth,town_of_birth_);
      if find(town_of_birth_,'|',1) then town_of_birth_=substr(town_of_birth_,2);
      if kindex(town_of_birth_,'|') then do;
	     num=countc(town_of_birth_,'|')+1;
	     max_vals=entry_count[num];
   	     do i = 1 to num;
		     entry_text[i]=compbl(strip(scan(town_of_birth_,i,'|')));
	     end;
       end; 
   end; /* else do */

   max_count=num;
   do i=1 to num;
	   town_of_birth=entry_text[i];
	   if town_of_birth='-' then town_of_birth='';
	   do j = i to entry_count[i];
	       entry_num=j;
		   output STG_WTCH.wl_hmt_transform_02;
       end;
   end;
end; /* if not missing(town_of_birth) */

/* parse country of birth.                                      */
/* if number of countries is 1 and number of towns >1           */
/* then replicate the countries until the same number as towns  */              
if not missing(country_of_birth) then do;
   entity_watch_list_number=kstrip(group_id);
   if substr(country_of_birth,length(country_of_birth)) eq ')' then
      country_of_birth=substr(country_of_birth,1,find(country_of_birth,'(',-length(country_of_birth))-1);
   country_of_birth=tranwrd(country_of_birth,'(a)','1)');
   country_of_birth=tranwrd(country_of_birth,'(b)','2)');
   country_of_birth=tranwrd(country_of_birth,'(c)','3)');
   country_of_birth=tranwrd(country_of_birth,'(d)','4)');
   country_of_birth=tranwrd(country_of_birth,'(1)','1)');
   country_of_birth=tranwrd(country_of_birth,'(2)','2)');
   country_of_birth=tranwrd(country_of_birth,'(3)','3)');
   country_of_birth=tranwrd(country_of_birth,'(4)','4)');
   country_of_birth=tranwrd(country_of_birth,'(5)','5)');
   country_of_birth=tranwrd(country_of_birth,'(6)','6)');
   country_of_birth=tranwrd(country_of_birth,'(7)','7)');
   country_of_birth=tranwrd(country_of_birth,'(8)','8)');
   position=prxmatch(patternID,country_of_birth);
   num=max(1,max_count);
   if position eq 0 then do;
      do i = 1 to num;
         entry_count[i]=i;
         entry_text[i]=country_of_birth;
      end;
   end;
   else do;
      i=0;
      max_vals=0;
      string=country_of_birth;
      do while (position ne 0);
	      i+1;
	      entry_count[i]=substr(string,position,1);
	      string=substr(string,position+2);
	      position=prxmatch(patternID,string);
       end;
    
	   call prxchange(patternId,-1,country_of_birth,country_of_birth_);
       if find(country_of_birth_,'|',1) then country_of_birth_=substr(country_of_birth_,2);
       if index(country_of_birth_,'|') then do;
	      num=countc(country_of_birth_,'|')+1;
	      max_vals=entry_count[num];
   	      do i = 1 to num;
		      entry_text[i]=compbl(strip(scan(country_of_birth_,i,'|')));
	      end;
        end; 
   end;
   
   do i=1 to num;
      if upcase(entry_text[1])='TO' and num>1 then
         entry_text[1]=entry_text[2];
	  country_of_birth=entry_text[i];
	  if country_of_birth='-' then country_of_birth='';
	  do j = i to entry_count[i];
	      entry_num=j;
		  output STG_WTCH.wl_hmt_transform_03;
      end;
   end;
end; /* if not missing(country_of_birth) */

/* parse nationality */
if not missing(nationality) then do;
   entity_watch_list_number=kstrip(group_id);
   if substr(nationality,length(nationality)) eq ')' then
      nationality=substr(nationality,1,find(nationality,'(',-length(nationality))-1);
   nationality=tranwrd(nationality,'(a)','1)');
   nationality=tranwrd(nationality,'(b)','2)');
   nationality=tranwrd(nationality,'(c)','3)');
   nationality=tranwrd(nationality,'(d)','4)');
   nationality=tranwrd(nationality,'(1)','1)');
   nationality=tranwrd(nationality,'(2)','2)');
   nationality=tranwrd(nationality,'(3)','3)');
   nationality=tranwrd(nationality,'(4)','4)');
   nationality=tranwrd(nationality,'(5)','5)');
   nationality=tranwrd(nationality,'(6)','6)');
   nationality=tranwrd(nationality,'(7)','7)');
   nationality=tranwrd(nationality,'(8)','8)');
   position=prxmatch(patternID,nationality);
   num=1;
   if position eq 0 then do;
      entry_count[1]=1;
      entry_text[1]=nationality;
   end;
   else do;
      i=0;
      max_vals=0;
      string=nationality;
      do while (position ne 0);
	      i+1;
	      entry_count[i]=substr(string,position,1);
	      string=substr(string,position+2);
	      position=prxmatch(patternID,string);
      end;
    
	  call prxchange(patternId,-1,nationality,nationality_);
      if find(nationality_,'|',1) then nationality_=substr(nationality_,2);
      if index(nationality_,'|') then do;
	     num=countc(nationality_,'|')+1;
	     max_vals=entry_count[num];
   	     do i = 1 to num;
		     entry_text[i]=compbl(strip(scan(nationality_,i,'|')));
	     end;
       end; 
   end; /* else do */

   max_count=num;
   do i=1 to num;
	   nationality=entry_text[i];
	   if nationality='-' then nationality='';
	   do j = i to entry_count[i];
	       entry_num=j;
		   output STG_WTCH.wl_hmt_transform_04;
       end;
   end;
end; /* if not missing(nationality) */
    

      end; /* end: type_desc=INDIVIDUAL */

      /* type_desc=ORGANIZATION */
      else if type_desc eq 'ORGANIZATION' then do;

   /******************************************************************************/
   /* NOTE:                                                                      */
   /*                                                                            */
   /* The following fields are not applicable where type_desc='ORGANIZATION'.    */
   /* These fields are therefore set to null.                                    */
   /******************************************************************************/
         date_of_birth=.;
         year_of_birth=.;
         place_of_birth='';
         first_name='';
         last_name='';
         entity_title='';
         occupation_desc='';

         /* NAME */
         entity_name=upcase(compbl(kstrip(name_6)));

         output STG_WTCH.wl_hmt_transform_01;

      end;
      
   end;  /* End of valid entity_watch_list_number */

   if (eof) and (error_flag) then do;
      putlog ' ';
      putlog 'WARNING: FCF: Invalid values were encountered processing the watch list data';
      putlog 'WARNING: FCF: Data values were written to the STG_ERR.WL_HMT_ERRORS table.';
   end;


run;
/******************************************************************************/
/* END: STG_WTCH.wl_hmt_transform                                             */
/*        STG_ERR.wl_hmt_errors                                               */
/******************************************************************************/

   %if &trans_rc eq 3 or &trans_rc ge 5 %then
      %fcf_execute_macro(fcf_error);
   %else %do;
      %fcf_execute_macro(post&_fcfmodule_);
      %fcf_execute_macro(fcf_success);
   %end;


 proc sort data=STG_WTCH.wl_hmt_transform_01(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_hmt_transform_01));
    by entity_watch_list_number;
 run;
   
 proc sort data=STG_WTCH.wl_hmt_transform_02(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_hmt_transform_02)) nodupkey;
    by entity_watch_list_number entry_num town_of_birth;
 run;

 proc sort data=STG_WTCH.wl_hmt_transform_03(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_hmt_transform_03)) nodupkey;
    by entity_watch_list_number entry_num country_of_birth;
 run;
 
 proc sort data=STG_WTCH.wl_hmt_transform_04(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_hmt_transform_04)) nodupkey;
    by entity_watch_list_number nationality;
 run;


data STG_WTCH.wl_hmt_transform_05 (%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_hmt_transform_05, output_ds=Y) keep=entity_watch_list_number place_of_birth);
    merge STG_WTCH.wl_hmt_transform_02(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_hmt_transform_02))
          STG_WTCH.wl_hmt_transform_03(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_hmt_transform_03));
	by entity_watch_list_number entry_num;
	if not missing (town_of_birth) then 
        if not missing(country_of_birth) then 
           place_of_birth=compbl(strip(town_of_birth))||", "||compbl(strip(country_of_birth));
		else place_of_birth=compbl(strip(town_of_birth));
	else place_of_birth=compbl(strip(country_of_birth));
run;


data STG_WTCH.wl_hmt_transform(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_hmt_transform, output_ds=Y));
 merge STG_WTCH.wl_hmt_transform_01(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_hmt_transform_01))
       STG_WTCH.wl_hmt_transform_04(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_hmt_transform_04))
       STG_WTCH.wl_hmt_transform_05(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_hmt_transform_05));
 by entity_watch_list_number;
/******************************************************************************/
   /* NOTE:                                                                      */
   /*                                                                            */
   /* The NATIONALITY field contains the individuals citizenship and/or          */
   /* nationality.                                                               */
   /******************************************************************************/

         /* CITIZENSHIP_COUNTRY_NAME */
         citizenship_country_name=upcase(compbl(kstrip(nationality)));

         /* NATIONALITY_COUNTRY_NAME */
         nationality_country_name=upcase(compbl(kstrip(nationality)));
drop nationality;
run;

%mend fcf_wl_hmt_transform;

