/*==============================================================================
| NAME:    fcf_wl_nbci_extract
| PRODUCT: SAS Compliance Solutions
| SYSTEM:  UNIX/WINDOWS
================================================================================

WATCH LIST PROVIDER - National Bureau of Criminal Intelligence, New Zealand Police
WATCH LIST NAME     - Designated Terrorist Entities
WATCH LIST CODE     - NBCI
WEB LINK            - http://www.police.govt.nz/service/counterterrorism/designated-terrorists.html

MODULE TYPE         - EXTRACT
MODULE PURPOSE      - Read extract file(s) and output to SAS data set(s).

MODULE NOTES
------------
None

==============================================================================*/

/*-------------------------------------------------------------------
 * Copyright (c) 2012-2016 by SAS Institute Inc., Cary, NC 27513 USA
 *  ---All Rights Reserved.
 *-------------------------------------------------------------------*/

%macro fcf_wl_nbci_extract(engine=xls);


  /*------------
   * Set module
   *------------*/
  %let _fcfmodule_=fcf_WL_NBCI_EXTRACT;

  /*---------------------
   * Call pre macro stub
   *---------------------*/
  %fcf_execute_macro(pre&_fcfmodule_);

  /*------------------------------------------
   * Set error code to 0 and message to blank
   *------------------------------------------*/
  %let trans_rc=0;
  %let _fcfmsg_=;

  %let engine=%upcase(&engine);

   /****************************************************************************
    BEGIN: STG_WTCH.wl_nbci_ind_extract

    DESCRIPTION:

    Import Indviduals Excel worksheet
   ****************************************************************************/

   %put NOTE: FCF: Using &engine engine to import watch list data.;
   %if &engine eq XLS %then %do;
      proc import datafile="&nbci_file"
                  out=stg_wtch.wl_nbci_ind_extract(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_nbci_ind_extract, output_ds=Y))
                  dbms=xls
                  replace;
                  sheet="Individuals";
                  textsize=10000;
      run;
   %end;
   %else %if &engine eq EXCEL %then %do;
      filename file "&nbci_file";
      proc import datafile=file
                  out=stg_wtch.wl_nbci_ind_extract(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_nbci_ind_extract, output_ds=Y))
                  dbms=excel
                  replace;
                  sheet="Individuals$";
                  getnames=yes;
                  mixed=yes;
                  scantext=yes;
                  usedate=no;
                  scantime=no;
                  textsize=32767;
      run;
   %end;
   %else %if &engine eq EXCELCS %then %do;
      proc import datafile="&nbci_file"
                  out=stg_wtch.wl_nbci_ind_extract(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_nbci_ind_extract, output_ds=Y))
                  dbms=excelcs
                  replace;
                  sheet="Individuals$";
                  scantext=yes;
                  usedate=no;
                  scantime=no;
                  textsize=10000;
      run;
   %end;
   %else %do;
      %let _fcfmsg_=ERROR: FCF: Engine &engine is not supported.  Supported values are: EXCEL, EXCELCS and XLS;
      %fcf_put_error;
      %goto MACRO_END;
   %end;

   %fcf_rcset(&syserr);
   %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
      %let _fcfmsg_=ERROR: FCF: Cannot create STG_WTCH.WL_NBCI_IND_EXTRACT.;
      %fcf_put_error;
      %goto MACRO_END;
   %end;
   /****************************************************************************
    END: STG_WTCH.wl_nbci_ind_extract
   ****************************************************************************/

   /****************************************************************************
    BEGIN: STG_WTCH.wl_nbci_org_extract

    DESCRIPTION:

    Import Organisations Excel worksheet
   ****************************************************************************/

   %if &engine eq XLS %then %do;
      proc import datafile="&nbci_file"
                  out=stg_wtch.wl_nbci_org_extract(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_nbci_org_extract, output_ds=Y))
                  dbms=xls
                  replace;
                  sheet="Organisations";
                  textsize=10000;
      run;
   %end;
   %else %if &engine eq EXCEL %then %do;
      proc import datafile=file
                  out=stg_wtch.wl_nbci_org_extract(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_nbci_org_extract, output_ds=Y))
                  dbms=excel
                  replace;
                  sheet="Organisations$";
                  getnames=yes;
                  mixed=yes;
                  scantext=yes;
                  usedate=no;
                  scantime=no;
                  textsize=32767;
      run;
   %end;
   %else %if &engine eq EXCELCS %then %do;
      proc import datafile="&nbci_file"
                  out=stg_wtch.wl_nbci_org_extract(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_nbci_org_extract, output_ds=Y))
                  dbms=excelcs
                  replace;
                  sheet="Organisations$";
                  scantext=yes;
                  usedate=no;
                  scantime=no;
                  textsize=10000;
      run;
   %end;

   %fcf_rcset(&syserr);
   %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
      %let _fcfmsg_=ERROR: FCF: Cannot create STG_WTCH.WL_NBCI_ORG_EXTRACT.;
      %fcf_put_error;
      %goto MACRO_END;
   %end;

   /*******************************************************************************
    END: STG_WTCH.wl_nbci_org_extract
   *******************************************************************************/

  %MACRO_END:

   %if &trans_rc eq 3 or &trans_rc ge 5 %then
      %fcf_execute_macro(fcf_error);
   %else %do;
      %fcf_execute_macro(post&_fcfmodule_);
      %fcf_execute_macro(fcf_success);
   %end;

%mend fcf_wl_nbci_extract;
