/*==============================================================================
| NAME:    fcf_wl_uncs_transform
| PRODUCT: SAS Compliance Solutions
| SYSTEM:  UNIX/WINDOWS
================================================================================

WATCH LIST PROVIDER - United Nations Security Council
WATCH LIST NAME     - The Consolidated List
WATCH LIST CODE     - UNSC
WEB LINK            - http://www.un.org/sc/committees/1267/consolist.shtml

MODULE TYPE         - TRANSFORM
MODULE PURPOSE      - Transform data in prepartion for data load.

MODULE NOTES
------------
None

==============================================================================*/

/*-------------------------------------------------------------------
 * Copyright (c) 2012-2016 by SAS Institute Inc., Cary, NC 27513 USA
 *  ---All Rights Reserved.
 *-------------------------------------------------------------------*/

%macro fcf_wl_unsc_transform;

  /*------------
   * Set module
   *------------*/
  %local _fcfmodule_;
  %let _fcfmodule_=fcf_WL_UNSC_TRANSFORM;

  /*---------------------
   * Call pre macro stub
   *---------------------*/
  %fcf_execute_macro(pre&_fcfmodule_);

  /*------------------------------------------
   * Set error code to 0 and message to blank
   *------------------------------------------*/
  %let trans_rc = 0;
  %let _fcfmsg_=;


/******************************************************************************/
/* BEGIN: PROCESS INDIVIDUALS                                                 */
/******************************************************************************/


/******************************************************************************/
/* STEP 1                                                                     */
/*                                                                            */
/* DESCRIPTION:                                                               */
/*                                                                            */
/* Process stg_wtch.wl_unsc_extract_i                                         */
/*                                                                            */
/* NOTES:                                                                     */
/*                                                                            */
/*                                                                            */
/*                                                                            */
/*                                                                            */
/* INPUTS(S);                                                                 */
/*                                                                            */
/* stg_wtch.wl_unsc_extract_i                                                 */
/*                                                                            */
/*                                                                            */
/* OUTPUT(S):                                                                 */
/*                                                                            */
/* stg_wtch.wl_unsc_transform_01 - (dataid, entity_name)                      */
/* stg_wtch.wl_unsc_transform_02 - (dataid, type_desc, programs, create_date) */
/* stg_wtch.wl_unsc_transform_03 - (dataid, nationality)                      */
/*                                                                            */
/******************************************************************************/
data stg_wtch.wl_unsc_transform_01(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_01, output_ds=Y)
                                   keep=dataid
                                        entity_name);

attrib
entity_name length=$200 informat=$200. format=$200.
;

   set stg_wtch.wl_unsc_extract_i(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_extract_i));

   /* ENTITY_NAME */
   entity_name=upcase(compbl(catx(' ',first_name,
                                      second_name,
                                      third_name,
                                      fourth_name)));

   if not missing(entity_name) then
      output;

run;

proc sort data=stg_wtch.wl_unsc_transform_01(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_01))
          out=stg_wtch.wl_unsc_transform_01(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_01, output_ds=Y))
          nodupkey;
by dataid
   entity_name;
run;

data stg_wtch.wl_unsc_transform_02(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_02, output_ds=Y)
                                   keep=dataid
                                        type_desc
                                        programs
                                        create_date);

attrib
type_desc   length=$20    informat=$20.         format=$20.
programs    length=$250   informat=$250.        format=$250.
create_date length=8      informat=datetime20.  format=datetime20.
;

   set stg_wtch.wl_unsc_extract_i(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_extract_i));

   /* TYPE_DESC */
   type_desc='INDIVIDUAL';

   /* PROGRAMS */
   programs='UN - ' || upcase(kstrip(un_list_type));

   /* CREATE_DATE */
   create_date=dhms(input(listed_on,??anydtdte32.),00,00,00);

run;

proc sort data=stg_wtch.wl_unsc_transform_02(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_02))
          out=stg_wtch.wl_unsc_transform_02(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_02, output_ds=Y))
          nodupkey;
by dataid
   type_desc
   programs
   create_date;
run;

data stg_wtch.wl_unsc_transform_03(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_03, output_ds=Y)
                                   keep=dataid
                                        nationality);

   set stg_wtch.wl_unsc_extract_i(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_extract_i) rename=(nationality2=nationality));

   if not missing(nationality) then
      output;

run;

proc sort data=stg_wtch.wl_unsc_transform_03(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_03))
          out=stg_wtch.wl_unsc_transform_03(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_03, output_ds=Y))
          nodupkey;
by dataid
   nationality;
run;

/******************************************************************************/
/* STEP 2                                                                     */
/*                                                                            */
/* DESCRIPTION:                                                               */
/*                                                                            */
/* Process stg_wtch.wl_unsc_extract_i_address                                 */
/*                                                                            */
/* NOTES:                                                                     */
/*                                                                            */
/*                                                                            */
/*                                                                            */
/*                                                                            */
/* INPUTS(S);                                                                 */
/*                                                                            */
/* stg_wtch.wl_unsc_extract_i_address                                         */
/*                                                                            */
/*                                                                            */
/* OUTPUT(S):                                                                 */
/*                                                                            */
/* stg_wtch.wl_unsc_transform_04 -                                            */
/* (dataid, address, city_name, state_name, country_name, full_address)       */
/*                                                                            */
/******************************************************************************/
data stg_wtch.wl_unsc_transform_04(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_04, output_ds=Y)
                                   keep=dataid
                                        address
                                        city_name
                                        state_name
                                        postal_code
                                        country_name
                                        full_address);

attrib
address      length=$300   informat=$300. format=$300.
city_name    length=$50    informat=$50.  format=$50.
state_name   length=$50    informat=$50.  format=$50.
postal_code  length=$30    informat=$30.  format=$30.
country_name length=$100   informat=$100. format=$100.
full_address length=$500   informat=$500. format=$500.
;

   set stg_wtch.wl_unsc_extract_i_address(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_extract_i_address));

   /* ADDRESS */
   address=upcase(compbl(kstrip(street)));

   /* CITY_NAME */
   city_name=upcase(compbl(kstrip(city)));

   /* STATE_NAME */
   state_name=upcase(compbl(kstrip(state_province)));

   /* POSTAL_CODE */
   postal_code='';

   /* COUNTRY_NAME */
   country_name=upcase(compbl(kstrip(country)));

   /* FULL_ADDRESS */
   full_address=catx(';', address, city_name, state_name, country_name);

   if not missing(full_address) then
      output;

run;

proc sort data=stg_wtch.wl_unsc_transform_04(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_04))
          out=stg_wtch.wl_unsc_transform_04(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_04, output_ds=Y))
          nodupkey;
by dataid
   full_address;
run;

/******************************************************************************/
/* STEP 3                                                                     */
/*                                                                            */
/* DESCRIPTION:                                                               */
/*                                                                            */
/* Process stg_wtch.wl_unsc_extract_i_alias                                   */
/*                                                                            */
/* NOTES:                                                                     */
/*                                                                            */
/*                                                                            */
/*                                                                            */
/*                                                                            */
/* INPUTS(S);                                                                 */
/*                                                                            */
/* stg_wtch.wl_unsc_extract_i_alias                                           */
/*                                                                            */
/*                                                                            */
/* OUTPUT(S):                                                                 */
/*                                                                            */
/* stg_wtch.wl_unsc_transform_05 - (dataid, entity_name)                      */
/* stg_wtch.wl_unsc_transform_06 - (dataid, date)                             */
/* stg_wtch.wl_unsc_transform_07 - (dataid, place_of_birth)                   */
/*                                                                            */
/******************************************************************************/
data stg_wtch.wl_unsc_transform_05(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_05, output_ds=Y)
                                   keep=dataid
                                        entity_name);

attrib
entity_name length=$200 informat=$200. format=$200.
;

   set stg_wtch.wl_unsc_extract_i_alias(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_extract_i_alias));

   entity_name=upcase(compbl(kstrip(alias_name)));

   if not missing(entity_name) then
      output;

run;

proc append base=stg_wtch.wl_unsc_transform_05(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_05, output_ds=Y))
            data=stg_wtch.wl_unsc_transform_01(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_01))
            force nowarn;
run;

proc sort data=stg_wtch.wl_unsc_transform_05(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_05))
          out=stg_wtch.wl_unsc_transform_05(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_05, output_ds=Y))
          nodupkey;
by dataid
   entity_name;
run;

data stg_wtch.wl_unsc_transform_06(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_06, output_ds=Y)
                                   keep=dataid
                                        date);

   set stg_wtch.wl_unsc_extract_i_alias(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_extract_i_alias) rename=(date_of_birth=date));

   if not missing(date) then
      output;

run;

proc sort data=stg_wtch.wl_unsc_transform_06(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_06))
          out=stg_wtch.wl_unsc_transform_06(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_06, output_ds=Y))
          nodupkey;
by dataid
   date;
run;


data stg_wtch.wl_unsc_transform_07(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_07, output_ds=Y)
                                   keep=dataid
                                        place_of_birth);

   set stg_wtch.wl_unsc_extract_i_alias(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_extract_i_alias));

attrib
place_of_birth length=$100 informat=$100. format=$100.
;

   place_of_birth=upcase(compbl(kstrip(catx(';', city_of_birth,
                                           country_of_birth))));

   if not missing(place_of_birth) then
      output;

run;

proc sort data=stg_wtch.wl_unsc_transform_07(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_07))
          out=stg_wtch.wl_unsc_transform_07(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_07, output_ds=Y))
          nodupkey;
by dataid
   place_of_birth;
run;


/******************************************************************************/
/* STEP 4                                                                     */
/*                                                                            */
/* DESCRIPTION:                                                               */
/*                                                                            */
/* Process stg_wtch.wl_unsc_extract_i_date_of_birth                           */
/*                                                                            */
/* NOTES:                                                                     */
/*                                                                            */
/*                                                                            */
/*                                                                            */
/*                                                                            */
/* INPUTS(S);                                                                 */
/*                                                                            */
/* stg_wtch.wl_unsc_extract_i_date_of_birth                                   */
/* stg_wtch.wl_unsc_transform_06                                              */
/*                                                                            */
/* OUTPUT(S):                                                                 */
/*                                                                            */
/* stg_wtch.wl_unsc_transform_08 - (dataid, date_of_birth, year_of_birth      */
/* stg_err.wl_unsc_errors        - (invalid date_of_birth)                    */
/*                                                                            */
/******************************************************************************/
proc append base=stg_wtch.wl_unsc_transform_08(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_08, output_ds=Y))
            data=stg_wtch.wl_unsc_extract_i_date_of_birth(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_extract_i_date_of_birth))
            force nowarn;
run;


proc append base=stg_wtch.wl_unsc_transform_08(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_08, output_ds=Y))
            data=stg_wtch.wl_unsc_transform_06(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_06))
            force nowarn;
run;


data
   stg_wtch.wl_unsc_transform_08(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_08, output_ds=Y)
                                 keep=
      dataid
      date_of_birth
      year_of_birth
)
   stg_err.wl_unsc_errors(%fcf_get_ds_opts(lib_name=stg_err, ds_name=wl_unsc_errors, output_ds=Y)
                          keep=
      entity_watch_list_number
      watch_list_name
      error_file
      error_record_number
      error_field
      error_value
      error_message
      error_datetime
);


attrib
entity_watch_list_number length=$35 informat=$35.        format=$35.
watch_list_name          length=$4  informat=$4.         format=$4.
date_of_birth            length=8   informat=datetime20. format=datetime20.
year_of_birth            length=8   informat=best32.     format=best32.

/* ERROR FIELDS */
   error_file          length=$200
                       informat=$200.
                       format=$200.
                       label='Error File'

   error_record_number length=8
                       informat=best32.
                       format=best32.
                       label='Error Record Number'

   error_field         length=$32
                       informat=$32.
                       format=$32.
                       label='Error Field'

   error_value         length=$1000
                       informat=$1000.
                       format=$1000.
                       label='Error Value'

   error_message       length=$200
                       informat=$200.
                       format=$200.
                       label='Error Message'

   error_datetime      length=8
                       informat=nldatm.
                       format=nldatm.
                       label='Error Datetime'
;

   set stg_wtch.wl_unsc_transform_08(%fcf_get_ds_opts(lib_name=stg_err, ds_name=wl_unsc_transform_08));

   if not missing(date) then do;
      date_of_birth=input(date,??anydtdte32.);
      if not missing(date_of_birth) then do;
         date_of_birth=dhms(date_of_birth,00,00,00);
         year_of_birth=year(datepart(date_of_birth));
         output stg_wtch.wl_unsc_transform_08;
      end;
      else if missing(date_of_birth) then do;
         entity_watch_list_number=kstrip(put(dataid,best32.));
         watch_list_name='UNSC';
         error_file="&unsc_file";
         error_record_number=_N_;
         error_field='DATE';
         error_value=kstrip(date);
         error_message='WARNING: Invalid date of birth.';
         error_datetime=datetime();

         putlog 'WARNING: FCF: Invalid date of birth.';
         putlog 'NOTE:    FCF: Data value written to STG_ERR.WL_UNSC_ERRORS table.';

         output stg_err.wl_unsc_errors;
      end;
   end;
   if not missing(year) then do;
      date_of_birth=.;
      year_of_birth=year;
      output stg_wtch.wl_unsc_transform_08;
   end;
   if not missing(from_year) and
      not missing(to_year) then do;

      do i=from_year to to_year;
         date_of_birth=.;
         year_of_birth=i;
         output stg_wtch.wl_unsc_transform_08;
      end;
   end;

run;

proc sort data=stg_wtch.wl_unsc_transform_08(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_08))
          out= stg_wtch.wl_unsc_transform_08(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_08, output_ds=Y))
          nodupkey;
by dataid
   date_of_birth
   year_of_birth;
run;

/******************************************************************************/
/* STEP 5                                                                     */
/*                                                                            */
/* DESCRIPTION:                                                               */
/*                                                                            */
/* Process stg_wtch.wl_unsc_extract_i_document                                */
/*                                                                            */
/* NOTES:                                                                     */
/*                                                                            */
/*                                                                            */
/*                                                                            */
/*                                                                            */
/* INPUTS(S);                                                                 */
/*                                                                            */
/* stg_wtch.wl_unsc_extract_i_document                                        */
/*                                                                            */
/* OUTPUT(S):                                                                 */
/*                                                                            */
/* stg_wtch.wl_unsc_transform_09 -                                            */
/* (dataid, identification_id, identification_type_desc)                      */
/*                                                                            */
/******************************************************************************/
data stg_wtch.wl_unsc_transform_09(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_09, output_ds=Y)
                                   keep=dataid
                                        identification_id
                                        identification_type_desc);

attrib
identification_id        length=$35 informat=$35. format=$35.
identification_type_desc length=$35 informat=$35. format=$35.
;

   set stg_wtch.wl_unsc_extract_i_document(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_extract_i_document));

   /* IDENTIFICATION_ID */
   identification_id=upcase(number);
   identification_id=tranwrd(identification_id,'PASSPORT','');
   identification_id=tranwrd(identification_id,'NUMBER','');
   identification_id=tranwrd(identification_id,'IDENTITY','');
   identification_id=tranwrd(identification_id,'CARD','');
   identification_id=tranwrd(identification_id,'ISSUED','');

   identification_id=compbl(kstrip(identification_id));

   /* IDENTIFICATION_TYPE_DESC */
   if upcase(type_of_document) eq 'PASSPORT' then
      identification_type_desc='PASSPORT';
   else if upcase(type_of_document) eq 'NATIONAL IDENTIFICATION NUMBER' then
      identification_type_desc='GOVERNMENT ID';

   if not missing(identification_id) and
      not missing(identification_type_desc) then
      output;

run;

proc sort data=stg_wtch.wl_unsc_transform_09(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_09))
          out= stg_wtch.wl_unsc_transform_09(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_09, output_ds=Y))
          nodupkey;
by dataid
   identification_id
   identification_type_desc;
run;

/******************************************************************************/
/* STEP 6                                                                     */
/*                                                                            */
/* DESCRIPTION:                                                               */
/*                                                                            */
/* Process stg_wtch.wl_unsc_extract_i_nationality                             */
/*                                                                            */
/* NOTES:                                                                     */
/*                                                                            */
/*                                                                            */
/*                                                                            */
/*                                                                            */
/* INPUTS(S);                                                                 */
/*                                                                            */
/* stg_wtch.wl_unsc_extract_i_nationality                                     */
/* stg_wtch.wl_unsc_transform_03                                              */
/*                                                                            */
/* OUTPUT(S):                                                                 */
/*                                                                            */
/* stg_wtch.wl_unsc_transform_10 - (dataid, citizenship_country_name)         */
/*                                                                            */
/******************************************************************************/
proc append base=stg_wtch.wl_unsc_transform_10(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_10, output_ds=Y))
            data=stg_wtch.wl_unsc_extract_i_nationality(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_extract_i_nationality))
            force nowarn;
run;

proc append base=stg_wtch.wl_unsc_transform_10(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_10, output_ds=Y))
            data=stg_wtch.wl_unsc_transform_03(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_03))
            force nowarn;
run;

data stg_wtch.wl_unsc_transform_10(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_10, output_ds=Y)
                                   keep=dataid
                                        citizenship_country_name);

attrib
citizenship_country_name length=$100 informat=$100. format=$100.
;

   set stg_wtch.wl_unsc_transform_10(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_10));

   /* CITIZENSHIP_COUNTRY_NAME */
   citizenship_country_name=upcase(compbl(kstrip(nationality)));

run;

proc sort data=stg_wtch.wl_unsc_transform_10(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_10))
          out= stg_wtch.wl_unsc_transform_10(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_10, output_ds=Y))
          nodupkey;
by dataid
   citizenship_country_name;
run;

/******************************************************************************/
/* STEP 7                                                                     */
/*                                                                            */
/* DESCRIPTION:                                                               */
/*                                                                            */
/* Process stg_wtch.wl_unsc_extract_i_designation                             */
/*                                                                            */
/* NOTES:                                                                     */
/*                                                                            */
/*                                                                            */
/*                                                                            */
/*                                                                            */
/* INPUTS(S);                                                                 */
/*                                                                            */
/* stg_wtch.wl_unsc_extract_i_designation                                     */
/*                                                                            */
/* OUTPUT(S):                                                                 */
/*                                                                            */
/* stg_wtch.wl_unsc_transform_09 - (dataid, occupation_desc)                  */
/*                                                                            */
/******************************************************************************/
data stg_wtch.wl_unsc_transform_11(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_11, output_ds=Y)
                                   keep=dataid
                                        occupation_desc);

attrib
occupation_desc length=$200 informat=$200. format=$200.
;

   set stg_wtch.wl_unsc_extract_i_designation(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_extract_i_designation));

   /* OCCUPATION_DESC */
   occupation_desc=compbl(kstrip(designation));

run;

proc sort data=stg_wtch.wl_unsc_transform_11(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_11))
          out= stg_wtch.wl_unsc_transform_11(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_11, output_ds=Y))
          nodupkey;
by dataid
   occupation_desc;
run;


/******************************************************************************/
/* STEP 8                                                                     */
/*                                                                            */
/* DESCRIPTION:                                                               */
/*                                                                            */
/* Process stg_wtch.wl_unsc_extract_i_title                                   */
/*                                                                            */
/* NOTES:                                                                     */
/*                                                                            */
/*                                                                            */
/*                                                                            */
/*                                                                            */
/* INPUTS(S);                                                                 */
/*                                                                            */
/* stg_wtch.wl_unsc_extract_i_title                                           */
/*                                                                            */
/* OUTPUT(S):                                                                 */
/*                                                                            */
/* stg_wtch.wl_unsc_transform_09 - (dataid, entity_title)                     */
/*                                                                            */
/******************************************************************************/
data stg_wtch.wl_unsc_transform_12(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_12, output_ds=Y)
                                   keep=dataid
                                        entity_title);

attrib
entity_title length=$200 informat=$200. format=$200.
;

   set stg_wtch.wl_unsc_extract_i_title(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_extract_i_title));

   /* ENTITY_TITLE */
   entity_title=upcase(compbl(kstrip(title)));

run;

proc sort data=stg_wtch.wl_unsc_transform_12(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_12))
          out= stg_wtch.wl_unsc_transform_12(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_12, output_ds=Y))
          nodupkey;
by dataid
   entity_title;
run;

/******************************************************************************/
/* STEP 9                                                                     */
/*                                                                            */
/* DESCRIPTION:                                                               */
/*                                                                            */
/* Process stg_wtch.wl_unsc_extract_i_updated                                 */
/*                                                                            */
/* NOTES:                                                                     */
/*                                                                            */
/*                                                                            */
/*                                                                            */
/*                                                                            */
/* INPUTS(S);                                                                 */
/*                                                                            */
/* stg_wtch.wl_unsc_extract_i_updated                                         */
/*                                                                            */
/* OUTPUT(S):                                                                 */
/*                                                                            */
/* stg_wtch.wl_unsc_transform_09 - (dataid, update_date)                      */
/*                                                                            */
/******************************************************************************/
proc sort data=stg_wtch.wl_unsc_extract_i_updated(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_extract_i_updated))
          out=stg_wtch.wl_unsc_extract_i_updated(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_extract_i_updated, output_ds=Y));
by dataid
   last_day_updated;
run;


data stg_wtch.wl_unsc_transform_13(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_13, output_ds=Y)
                                   keep=dataid
                                        update_date);

   attrib update_date length=8 informat=datetime20. format=datetime20.;

   set stg_wtch.wl_unsc_extract_i_updated(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_extract_i_updated));
   by dataid
      last_day_updated;

   /* UPDATE_DATE */
   if last.dataid then do;
      update_date=dhms(input(last_day_updated,??anydtdte32.),00,00,00);
      output;
   end;

run;

proc sort data=stg_wtch.wl_unsc_transform_13(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_13))
          out=stg_wtch.wl_unsc_transform_13(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_13, output_ds=Y))
          nodupkey;
by dataid
   update_date;
run;

/******************************************************************************/
/* STEP 10                                                                    */
/*                                                                            */
/* DESCRIPTION:                                                               */
/*                                                                            */
/* Process stg_wtch.wl_unsc_extract_i_place_of_birth                          */
/*                                                                            */
/* NOTES:                                                                     */
/*                                                                            */
/*                                                                            */
/*                                                                            */
/*                                                                            */
/* INPUTS(S);                                                                 */
/*                                                                            */
/* stg_wtch.wl_unsc_extract_i_place_of_birth                                  */
/*                                                                            */
/* OUTPUT(S):                                                                 */
/*                                                                            */
/* stg_wtch.wl_unsc_transform_14 - (dataid, place_of_birth)                   */
/*                                                                            */
/******************************************************************************/
data stg_wtch.wl_unsc_transform_14(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_14, output_ds=Y)
                                   keep=dataid
                                        place_of_birth);

attrib
place_of_birth length=$100 informat=$100. format=$100.
;

   set stg_wtch.wl_unsc_extract_i_place_of_birth(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_extract_i_place_of_birth));

   /* PLACE_OF_BIRTH */
   place_of_birth=upcase(compbl(kstrip(catx(';', city,
                                           state_province, country))));

   if not missing(place_of_birth) then
      output;

run;

proc append base=stg_wtch.wl_unsc_transform_14(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_14, output_ds=Y))
            data=stg_wtch.wl_unsc_transform_07(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_07))
            force nowarn;
run;

proc sort data=stg_wtch.wl_unsc_transform_14(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_14))
          out=stg_wtch.wl_unsc_transform_14(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_14, output_ds=Y))
          nodupkey;
by dataid
   place_of_birth;
run;


/******************************************************************************/
/* STEP 11                                                                    */
/*                                                                            */
/* DESCRIPTION:                                                               */
/*                                                                            */
/* Create distinct indvidual records for each combination of entity_name,     */
/* address, birth date, identification_id, citizenship, title and place of    */
/* birth.                                                                     */
/*                                                                            */
/* NOTES:                                                                     */
/*                                                                            */
/* INPUTS(S);                                                                 */
/*                                                                            */
/* stg_wtch.wl_unsc_transform_02                                              */
/* stg_wtch.wl_unsc_transform_04                                              */
/* stg_wtch.wl_unsc_transform_05                                              */
/* stg_wtch.wl_unsc_transform_08                                              */
/* stg_wtch.wl_unsc_transform_09                                              */
/* stg_wtch.wl_unsc_transform_10                                              */
/* stg_wtch.wl_unsc_transform_11                                              */
/* stg_wtch.wl_unsc_transform_12                                              */
/* stg_wtch.wl_unsc_transform_13                                              */
/* stg_wtch.wl_unsc_transform_14                                              */
/*                                                                            */
/* OUTPUT(S):                                                                 */
/*                                                                            */
/* stg_wtch.wl_unsc_transform_16                                              */
/* (data_id, type_desc, programs, create_date, entity_name)                   */
/*                                                                            */
/* stg_wtch.wl_unsc_transform_16                                              */
/* (dataid, type_desc, programs, create_date, entity_name, address, city_name,*/
/*  state_name, postal_code, country_name, full_address)                      */
/*                                                                            */
/* stg_wtch.wl_unsc_transform_17                                              */
/* (dataid, type_desc, programs, create_date, entity_name, address, city_name,*/
/*  state_name, postal_code, country_name, full_address, date_of_birth,       */
/*  year_of_birth)                                                            */
/*                                                                            */
/* stg_wtch.wl_unsc_transform_18                                              */
/* (dataid, type_desc, programs, create_date, entity_name, address, city_name,*/
/*  state_name, postal_code, country_name, full_address, date_of_birth,       */
/*  year_of_birth, identification_type_desc, identification_id)               */
/*                                                                            */
/* stg_wtch.wl_unsc_transform_19                                              */
/* (dataid, type_desc, programs, create_date, entity_name, address, city_name,*/
/*  state_name, postal_code, country_name, full_address, date_of_birth,       */
/*  year_of_birth, identification_type_desc, identification_id,               */
/*  citizenship_country_name)                                                 */
/*                                                                            */
/* stg_wtch.wl_unsc_transform_20                                              */
/* (dataid, type_desc, programs, create_date, entity_name, address, city_name,*/
/*  state_name, postal_code, country_name, full_address, date_of_birth,       */
/*  year_of_birth, identification_type_desc, identification_id,               */
/*  citizenship_country_name, occupation_desc)                                */
/*                                                                            */
/* stg_wtch.wl_unsc_transform_21                                              */
/* (dataid, type_desc, programs, create_date, entity_name, address, city_name,*/
/*  state_name, postal_code, country_name, full_address, date_of_birth,       */
/*  year_of_birth, identification_type_desc, identification_id,               */
/*  citizenship_country_name, occupation_desc, entity_title)                  */
/*                                                                            */
/* stg_wtch.wl_unsc_transform_22                                              */
/* (dataid, type_desc, programs, create_date, entity_name, address, city_name,*/
/*  state_name, postal_code, country_name, full_address, date_of_birth,       */
/*  year_of_birth, identification_type_desc, identification_id,               */
/*  citizenship_country_name, occupation_desc, entity_title, update_date)     */
/*                                                                            */
/* stg_wtch.wl_unsc_transform_23                                              */
/* (dataid, type_desc, programs, create_date, entity_name, address, city_name,*/
/*  state_name, postal_code, country_name, full_address, date_of_birth,       */
/*  year_of_birth, identification_type_desc, identification_id,               */
/*  citizenship_country_name, occupation_desc, entity_title, update_date,     */
/*  place_of_birth)                                                           */
/*                                                                            */
/******************************************************************************/
proc sql noprint;

  create table stg_wtch.wl_unsc_transform_15 %fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_15, output_ds=Y, add_parens=Y)  as
      select a.*,
             b.entity_name
      from stg_wtch.wl_unsc_transform_02(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_02)) as a full join
           stg_wtch.wl_unsc_transform_05(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_05)) as b
      on a.dataid=b.dataid;

  create table stg_wtch.wl_unsc_transform_16 %fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_16, output_ds=Y, add_parens=Y)  as
      select a.*,
             b.address,
             b.city_name,
             b.state_name,
             b.postal_code,
             b.country_name,
             b.full_address
      from stg_wtch.wl_unsc_transform_15(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_15)) as a full join
           stg_wtch.wl_unsc_transform_04(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_04)) as b
      on a.dataid=b.dataid;

  create table stg_wtch.wl_unsc_transform_17 %fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_17, output_ds=Y, add_parens=Y)  as
      select a.*,
             b.date_of_birth,
             b.year_of_birth
      from stg_wtch.wl_unsc_transform_16(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_16)) as a full join
           stg_wtch.wl_unsc_transform_08(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_08)) as b
      on a.dataid=b.dataid;

  create table stg_wtch.wl_unsc_transform_18 %fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_18, output_ds=Y, add_parens=Y)  as
      select a.*,
             b.identification_id,
             b.identification_type_desc
      from stg_wtch.wl_unsc_transform_17(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_17)) as a full join
           stg_wtch.wl_unsc_transform_09(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_09)) as b
      on a.dataid=b.dataid;

  create table stg_wtch.wl_unsc_transform_19 %fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_19, output_ds=Y, add_parens=Y)  as
      select a.*,
             b.citizenship_country_name
      from stg_wtch.wl_unsc_transform_18(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_18)) as a full join
           stg_wtch.wl_unsc_transform_10(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_10)) as b
      on a.dataid=b.dataid;

  create table stg_wtch.wl_unsc_transform_20 %fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_20, output_ds=Y, add_parens=Y)  as
      select a.*,
             b.occupation_desc
      from stg_wtch.wl_unsc_transform_19(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_19)) as a full join
           stg_wtch.wl_unsc_transform_11(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_11)) as b
      on a.dataid=b.dataid;

  create table stg_wtch.wl_unsc_transform_21 %fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_21, output_ds=Y, add_parens=Y)  as
      select a.*,
             b.entity_title
      from stg_wtch.wl_unsc_transform_20(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_20)) as a full join
           stg_wtch.wl_unsc_transform_12(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_12)) as b
      on a.dataid=b.dataid;

  create table stg_wtch.wl_unsc_transform_22 %fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_22, output_ds=Y, add_parens=Y)  as
      select a.*,
             b.update_date
      from stg_wtch.wl_unsc_transform_21(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_21)) as a full join
           stg_wtch.wl_unsc_transform_13(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_13)) as b
      on a.dataid=b.dataid;

  create table stg_wtch.wl_unsc_transform_23 %fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_23, output_ds=Y, add_parens=Y)  as
      select a.*,
             b.place_of_birth
      from stg_wtch.wl_unsc_transform_22(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_22)) as a full join
           stg_wtch.wl_unsc_transform_14(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_14)) as b
      on a.dataid=b.dataid
      order by dataid;

quit;


/******************************************************************************/
/* END: PROCESS INDIVIDUALS                                                   */
/******************************************************************************/


/******************************************************************************/
/* BEGIN: PROCESS ORGANIZATIONS                                               */
/******************************************************************************/

/******************************************************************************/
/* STEP 12                                                                    */
/*                                                                            */
/* DESCRIPTION:                                                               */
/*                                                                            */
/* Process stg_wtch.wl_unsc_extract_e                                         */
/*                                                                            */
/* NOTES:                                                                     */
/*                                                                            */
/*                                                                            */
/* INPUTS(S);                                                                 */
/*                                                                            */
/* stg_wtch.wl_unsc_extract_e                                                 */
/*                                                                            */
/*                                                                            */
/* OUTPUT(S):                                                                 */
/*                                                                            */
/* stg_wtch.wl_unsc_transform_24 - (dataid, entity_name)                      */
/* stg_wtch.wl_unsc_transform_25 - (dataid, type_desc, programs, create_date) */
/*                                                                            */
/******************************************************************************/

data stg_wtch.wl_unsc_transform_24(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_24, output_ds=Y)
                                   keep=dataid
                                        entity_name);

attrib
entity_name length=$200 informat=$200. format=$200.
;

   set stg_wtch.wl_unsc_extract_e(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_extract_e));

   /* ENTITY_NAME */
   entity_name=upcase(compbl(kstrip(first_name)));

   if not missing(entity_name) then
      output;

run;

proc sort data=stg_wtch.wl_unsc_transform_24(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_24))
          out=stg_wtch.wl_unsc_transform_24(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_24, output_ds=Y))
          nodupkey;
by dataid
   entity_name;
run;

data stg_wtch.wl_unsc_transform_25(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_25, output_ds=Y)
                                   keep=dataid
                                        type_desc
                                        programs
                                        create_date);

attrib
type_desc   length=$20    informat=$20.         format=$20.
programs    length=$250   informat=$250.        format=$250.
create_date length=8      informat=datetime20.  format=datetime20.
;

   set stg_wtch.wl_unsc_extract_e(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_extract_e));

   /* TYPE_DESC */
   type_desc='ORGANIZATION';

   /* PROGRAMS */
   programs='UN - ' || upcase(kstrip(un_list_type));

   /* CREATE_DATE */
   create_date=dhms(input(listed_on,??anydtdte32.),00,00,00);

run;

proc sort data=stg_wtch.wl_unsc_transform_25(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_25))
          out=stg_wtch.wl_unsc_transform_25(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_25, output_ds=Y))
          nodupkey;
by dataid
   type_desc
   programs
   create_date;
run;

/******************************************************************************/
/* STEP 13                                                                    */
/*                                                                            */
/* DESCRIPTION:                                                               */
/*                                                                            */
/* Process stg_wtch.wl_unsc_extract_e_address                                 */
/*                                                                            */
/* NOTES:                                                                     */
/*                                                                            */
/*                                                                            */
/* INPUTS(S);                                                                 */
/*                                                                            */
/* stg_wtch.wl_unsc_extract_e_address                                         */
/*                                                                            */
/*                                                                            */
/* OUTPUT(S):                                                                 */
/*                                                                            */
/* stg_wtch.wl_unsc_transform_26 -                                            */
/* (dataid, address, city_name, state_name, postal_code, country_name,        */
/*  full_address)                                                             */
/*                                                                            */
/******************************************************************************/
data stg_wtch.wl_unsc_transform_26(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_26, output_ds=Y)
                                   keep=dataid
                                        address
                                        city_name
                                        state_name
                                        postal_code
                                        country_name
                                        full_address);

attrib
address      length=$300   informat=$300. format=$300.
city_name    length=$50    informat=$50.  format=$50.
state_name   length=$50    informat=$50.  format=$50.
postal_code  length=$30    informat=$30.  format=$30.
country_name length=$100   informat=$100. format=$100.
full_address length=$500   informat=$500. format=$500.
;

   set stg_wtch.wl_unsc_extract_e_address(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_extract_e_address));

   address=upcase(compbl(kstrip(street)));
   city_name=upcase(compbl(kstrip(city)));
   state_name=upcase(compbl(kstrip(state_province)));
   postal_code=upcase(compbl(kstrip(zip_code)));
   country_name=upcase(compbl(kstrip(country)));

   full_address=catx(';', address, city_name, state_name,
                     postal_code, country_name);

   if not missing(full_address) then
      output;

run;

proc sort data=stg_wtch.wl_unsc_transform_26(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_26))
          out=stg_wtch.wl_unsc_transform_26(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_26, output_ds=Y))
          nodupkey;
by dataid
   full_address;
run;

/******************************************************************************/
/* STEP 14                                                                    */
/*                                                                            */
/* DESCRIPTION:                                                               */
/*                                                                            */
/* Pre-process stg_wtch.wl_unsc_extract_e_alias                               */
/*                                                                            */
/* NOTES:                                                                     */
/*                                                                            */
/*                                                                            */
/* INPUTS(S);                                                                 */
/*                                                                            */
/* stg_wtch.wl_unsc_extract_e_alias                                           */
/*                                                                            */
/*                                                                            */
/* OUTPUT(S):                                                                 */
/*                                                                            */
/* stg_wtch.wl_unsc_transform_27 - (dataid, entity_name)                      */
/*                                                                            */
/******************************************************************************/
data stg_wtch.wl_unsc_transform_27(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_27, output_ds=Y)
                                   keep=dataid
                                        entity_name);

attrib
entity_name length=$200 informat=$200. format=$200.
;

   set stg_wtch.wl_unsc_extract_e_alias(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_extract_e_alias));

   entity_name=upcase(compbl(kstrip(alias_name)));

   if not missing(entity_name) then
      output;

run;

proc append base=stg_wtch.wl_unsc_transform_27(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_27, output_ds=Y))
            data=stg_wtch.wl_unsc_transform_24(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_24))
            force nowarn;
run;

proc sort data=stg_wtch.wl_unsc_transform_27(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_27))
          out=stg_wtch.wl_unsc_transform_27(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_27, output_ds=Y))
          nodupkey;
by dataid
   entity_name;
run;

/******************************************************************************/
/* STEP 15                                                                    */
/*                                                                            */
/* DESCRIPTION:                                                               */
/*                                                                            */
/* Process stg_wtch.wl_unsc_extract_e_updated                                 */
/*                                                                            */
/* NOTES:                                                                     */
/*                                                                            */
/*                                                                            */
/* INPUTS(S);                                                                 */
/*                                                                            */
/* stg_wtch.wl_unsc_extract_e_updated                                         */
/*                                                                            */
/* OUTPUT(S):                                                                 */
/*                                                                            */
/* stg_wtch.wl_unsc_transform_28 - (dataid, update_date)                      */
/*                                                                            */
/******************************************************************************/
proc sort data=stg_wtch.wl_unsc_extract_e_updated(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_extract_e_updated))
          out=stg_wtch.wl_unsc_extract_e_updated(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_extract_e_updated, output_ds=Y));
by dataid
   last_day_updated;
run;

data stg_wtch.wl_unsc_transform_28(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_28, output_ds=Y)
                                   keep=dataid
                                        update_date);

attrib
update_date length=8 informat=datetime20. format=datetime20.
;

   set stg_wtch.wl_unsc_extract_e_updated(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_extract_e_updated));
   by dataid
      last_day_updated;

   if last.dataid then do;
      update_date=dhms(input(last_day_updated,??anydtdte32.),00,00,00);
      output;
   end;

run;

proc sort data=stg_wtch.wl_unsc_transform_28(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_28))
          out=stg_wtch.wl_unsc_transform_28(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_28, output_ds=Y))
          nodupkey;
by dataid
   update_date;
run;

/******************************************************************************/
/* STEP 16                                                                    */
/*                                                                            */
/* DESCRIPTION:                                                               */
/*                                                                            */
/* Create distinct organization records for each combination of entity_name   */
/*                                                                            */
/* NOTES:                                                                     */
/*                                                                            */
/*                                                                            */
/* INPUTS(S);                                                                 */
/*                                                                            */
/* stg_wtch.wl_unsc_transform_25                                              */
/* stg_wtch.wl_unsc_transform_26                                              */
/* stg_wtch.wl_unsc_transform_27                                              */
/* stg_wtch.wl_unsc_transform_28                                              */
/*                                                                            */
/*                                                                            */
/* OUTPUT(S):                                                                 */
/*                                                                            */
/* stg_wtch.wl_unsc_transform_29                                              */
/* (dataid, type_desc, programs, create_date, entity_name)                    */
/*                                                                            */
/* stg_wtch.wl_unsc_transform_29                                              */
/* (dataid, type_desc, programs, create_date, entity_name, address,           */
/*  city_name, state_name, postal_code, country_name, full_address)           */
/*                                                                            */
/* stg_wtch.wl_unsc_transform_29                                              */
/* (dataid, type_desc, programs, create_date, entity_name, address,           */
/*  city_name, state_name, postal_code, country_name, full_address,           */
/*  update_date)                                                              */
/*                                                                            */
/******************************************************************************/
proc sql noprint;

  create table stg_wtch.wl_unsc_transform_29 %fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_29, output_ds=Y, add_parens=Y)  as
      select a.*,
             b.entity_name
      from stg_wtch.wl_unsc_transform_25(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_25)) as a full join
           stg_wtch.wl_unsc_transform_27(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_27)) as b
      on a.dataid=b.dataid;

  create table stg_wtch.wl_unsc_transform_30 %fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_30, output_ds=Y, add_parens=Y)  as
      select a.*,
             b.address,
             b.city_name,
             b.state_name,
             b.postal_code,
             b.country_name,
             b.full_address
      from stg_wtch.wl_unsc_transform_29(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_29)) as a full join
           stg_wtch.wl_unsc_transform_26(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_26)) as b
      on a.dataid=b.dataid;

  create table stg_wtch.wl_unsc_transform_31 %fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_31, output_ds=Y, add_parens=Y)  as
      select a.*,
             b.update_date
      from stg_wtch.wl_unsc_transform_30(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_30)) as a full join
           stg_wtch.wl_unsc_transform_28(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_28)) as b
      on a.dataid=b.dataid
      order by dataid;

quit;

/******************************************************************************/
/* END: PROCESS ORGANIZATIONS                                                 */
/******************************************************************************/

/******************************************************************************/
/* STEP 17                                                                    */
/*                                                                            */
/* DESCRIPTION:                                                               */
/*                                                                            */
/* Append individual and organizations records and output final transform     */
/*                                                                            */
/* NOTES:                                                                     */
/*                                                                            */
/* INPUTS(S);                                                                 */
/*                                                                            */
/* stg_wtch.wl_unsc_transform_23                                              */
/* stg_wtch.wl_unsc_transform_31                                              */
/* stg_wtch.wl_unsc_transform_32                                              */
/*                                                                            */
/* OUTPUT(S):                                                                 */
/*                                                                            */
/* stg_wtch.wl_unsc_transform                                                 */
/******************************************************************************/
proc append base=stg_wtch.wl_unsc_transform_32(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_32, output_ds=Y))
            data=stg_wtch.wl_unsc_transform_23(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_23))
            force nowarn;
run;

proc append base=stg_wtch.wl_unsc_transform_32(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_32, output_ds=Y))
            data=stg_wtch.wl_unsc_transform_31(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_31))
            force nowarn;
run;


data stg_wtch.wl_unsc_transform(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform, output_ds=Y)
                                keep=
   entity_watch_list_number
   watch_list_name
   category_desc
   type_desc
   programs
   identification_id
   identification_type_desc
   date_of_birth
   year_of_birth
   place_of_birth
   entity_name
   entity_title
   occupation_desc
   address
   city_name
   state_name
   postal_code
   country_name
   full_address
   citizenship_country_name
   create_date
   update_date
   exclude_ind
);

attrib
entity_watch_list_number length=$35    informat=$35.         format=$35.
watch_list_name          length=$4     informat=$4.          format=$4.
category_desc            length=$50    informat=$50.         format=$50.
type_desc                length=$20    informat=$20.         format=$20.
programs                 length=$250   informat=$250.        format=$250.
identification_id        length=$35    informat=$35.         format=$35.
identification_type_desc length=$35    informat=$35.         format=$35.
date_of_birth            length=8      informat=datetime20.  format=datetime20.
year_of_birth            length=8      informat=best32.      format=best32.
place_of_birth           length=$100   informat=$100.        format=$100.
entity_name              length=$200   informat=$200.        format=$200.
entity_title             length=$200   informat=$200.        format=$200.
occupation_desc          length=$200   informat=$200.        format=$200.
address                  length=$300   informat=$300.        format=$300.
city_name                length=$50    informat=$50.         format=$50.
state_name               length=$50    informat=$50.         format=$50.
postal_code              length=$30    informat=$30.         format=$30.
country_name             length=$100   informat=$100.        format=$100.
full_address             length=$500   informat=$500.        format=$500.
citizenship_country_name length=$100   informat=$100.        format=$100.
create_date              length=8      informat=datetime20.  format=datetime20.
update_date              length=8      informat=datetime20.  format=datetime20.
exclude_ind              length=$1     informat=$1.          format=$1.
;

   set stg_wtch.wl_unsc_transform_32(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform_32));

   /* ENTITY_WATCH_LIST_NUMBER */
   entity_watch_list_number=kstrip(put(dataid,best32.));

   /* WATCH_LIST_NAME */
   watch_list_name='UNSC';

   /* CATEGORY_DESC */
   category_desc='';

   /* EXCLUDE_IND */
   exclude_ind='N';

run;

  proc sort data=stg_wtch.wl_unsc_transform(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform))
             out=stg_wtch.wl_unsc_transform(%fcf_get_ds_opts(lib_name=stg_wtch, ds_name=wl_unsc_transform, output_ds=Y));
    by entity_watch_list_number;
   run;

  %if &trans_rc eq 3 or &trans_rc ge 5 %then
     %fcf_execute_macro(fcf_error);
  %else %do;
     %fcf_execute_macro(post&_fcfmodule_);
     %fcf_execute_macro(fcf_success);
  %end;

%mend fcf_wl_unsc_transform;

