/* MAINDOC
+------------------------------------------------------------------------------+
| NAME:    rc_efile_db_updt.sas
| PRODUCT: SAS Regulatory Console
| SYSTEM:  Windows, Unix
| DESC:    This macro update the SEG_KC and RC_DATA data tables after efiles are 
|          successfully generated.    
+-----------------------------------------------------------------------------------------+
| USAGE:   form_config_key = form key
|          form_type_code  = form type (e.g. SAR, CTR)
|          efile_indsn    =  input table with efile info
|          efile_report_indsn = input table with report keys of each e-file 
|          newYN          = Y if the efiles are new
+------------------------------------------------------------------------------------------+
MAINDOCEND */

%macro rc_efile_db_updt(form_config_key=,
                        form_type_code=,
                        efile_indsn=rc_efile, 
                        efile_report_indsn=rc_efile_report,
                        newYN=);
 
  
    %let newYN=%upcase(&newYN);
    %let trans_rc=0;
    %let _fcfmsg_=;

    
         %let existYN=N;
         proc sql noprint;
         select 'Y' into :existYN
         from seg_kc.fsk_rc_efile
         where efile_key in (select distinct efile_key 
                             from &efile_indsn(%fcf_get_ds_opts(ds_name=&efile_indsn)))
         ;
         quit;
         %fcf_rcset(&sqlrc);
         %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
             %goto MACRO_END;
         %end;   
    

    %if &existYN=Y %then 
    %do;
        %if &newYN=Y %then
        %do;
             %let _fcfmsg_=Error: RC: Same efile key found in SEG_KC.FSK_RC_EFILE. Run the job again. ;
             %fcf_put_error;
             %fcf_rcset(3);
             %goto MACRO_END;
        %end;
        %else 
        %do;
            proc sql noprint;
            
                delete from seg_kc.fsk_rc_efile_report
                         where efile_key=(select distinct efile_key 
                                          from &efile_report_indsn(%fcf_get_ds_opts(ds_name=&efile_report_indsn))
                                         );
            %fcf_rcset(&sqlrc);
            %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
                             %goto MACRO_END;
                %end;            
                 
                 delete from seg_kc.fsk_rc_efile
                 where efile_key=(select distinct efile_key 
                                  from &efile_indsn(%fcf_get_ds_opts(ds_name=&efile_indsn))
                                  );
                %fcf_rcset(&sqlrc);
                %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
                     %goto MACRO_END;
                %end;            
 
               
 
             quit;

        %end;  
    %end;

    proc append base=seg_kc.fsk_rc_efile  (dbforce=yes) data=&efile_indsn(%fcf_get_ds_opts(ds_name=&efile_indsn)) force nowarn ;
    run;
  
    %fcf_rcset(&syserr);
    %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
       %goto MACRO_END;
    %end;  

    proc append base=seg_kc.fsk_rc_efile_report (dbforce=yes) 
                data=&efile_report_indsn(%fcf_get_ds_opts(ds_name=&efile_report_indsn)) force nowarn ;
    run;

    %fcf_rcset(&syserr);
   
         
    %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
       proc sql;
                 delete from seg_kc.fsk_rc_efile
                 where efile_key=(select distinct efile_key 
                                  from &efile_indsn(%fcf_get_ds_opts(ds_name=&efile_indsn))
                                  );
       quit;
       %let _fcfmsg_=Error: RC: Cannot insert rc_efile_report records. Removed the new efile records from SEG_KC.FSK_RC_EFILE. Run the job again. ;
             %fcf_put_error;
       %goto MACRO_END;
    %end;  
   
  
   
    
    proc sql;
         update seg_kc.fsk_rc_report
         set report_ready_code='G',
             report_Status_code='G'
         where report_key in (select report_key from &efile_report_indsn(%fcf_get_ds_opts(ds_name=&efile_report_indsn)));
    quit; 
     %fcf_rcset(&sqlrc);
       %if &trans_rc eq 3 or &trans_rc ge 5 %then 
       %do;
           proc sql;
                 delete from seg_kc.fsk_rc_efile
                 where efile_key=(select distinct efile_key 
                                  from &efile_indsn(%fcf_get_ds_opts(ds_name=&efile_indsn))
                                  );
                 delete from seg_kc.fsk_rc_efile_report
                 where efile_key=(select distinct efile_key 
                             from &efile_report_indsn(%fcf_get_ds_opts(ds_name=&efile_report_indsn))
                             );
            quit;
            %let _fcfmsg_=Error: RC: Cannot insert rc_efile_report records. Removed the new efile records from SEG_KC.FSK_RC_EFILE. Run the job again. ;
            %fcf_put_error;
            %goto MACRO_END;
       %end; 


   
   %if (&form_type_code.=SAR) or (&form_type_code.=CTR) or (&form_type_code.=DOEP) %then
   %do;

        proc sql noprint;
             select distinct  form_efile_record_id into :record_id_1 -  
                 from rc_cfg.form_efile_record_config(%fcf_get_ds_opts(lib_name=rc_cfg, ds_name=form_efile_record_config))
                 where form_config_key=&form_config_key
                 order by form_efile_record_id
                  ;
                   %let record_cnt=&sqlobs;
        quit;
        %fcf_rcset(&sqlrc);

        %if &trans_rc eq 3 or &trans_rc ge 5 %then 
        %do; 
           %goto MACRO_END;
        %end;


        %do irecord =1 %to &record_cnt;
           
             %let dsn=&form_type_code._&&&record_id_&irecord;
             

              proc sql; 
                delete from rc_db.&dsn(%fcf_get_ds_opts(lib_name=rc_db, ds_name=&dsn))
                where efile_key in (select efile_key from &efile_indsn(%fcf_get_ds_opts(ds_name=&efile_indsn)))
                ;
              
              quit;   

              %fcf_rcset(&sqlrc);
               %if &trans_rc eq 3 or &trans_rc ge 5 %then 
               %do; 
                   %goto MACRO_END;
               %end;
                 
               %if %sysfunc(exist(&dsn)) %then 
               %do;
                   proc append base=rc_db.&dsn(%fcf_get_ds_opts(lib_name=rc_db, ds_name=&dsn, output_ds=Y))
                               data=&dsn force nowarn;
                   run;
               %end;

               %fcf_rcset(&syserr);
               %if &trans_rc eq 3 or &trans_rc ge 5 %then 
               %do; 
                   %goto MACRO_END;
               %end;
                     
        %end;

    %end;



%MACRO_END:
  
    quit;
    %if &trans_rc eq 3 or &trans_rc ge 5 %then 
       %fcf_execute_macro(fcf_error);
    %else 
       %fcf_execute_macro(fcf_success);
    

%mend;
