/* MAINDOC
+------------------------------------------------------------------------------+
| NAME:    rc_efile_fincen_data_x.sas
| PRODUCT: SAS Regulatory Console
| SYSTEM:  Windows, Unix
| DESC:    Program to extract report data and transform it to
|          node name and value pairs in sas table.
|          The data will be used in rc_efle_fincen_generate_x 
|          to create xmls.
|          Multiple e-file keys may be generated if the number
|          of 'ready to submit' reports are more than the maximum
|          allowed size defined in SEG_KC.FSK_RC_FORM_CONFIG
|          This program is called by rc_efile_fincen_driver.
|Output tables: 
|          rc_report_node_more_x - data fields with names, values and tyes
|          seq_report - reports with new or existing e-file key
|          transmitter - current transmitter info
|          filer - current filing institution info
|          report_branch - branch node with only entity_number, one for each
|                          branch in a report
|          branch_list - list of branches that will be included in e-file with detailed branch information

+------------------------------------------------------------------------------+
| PARAMETERS: 
|          form_config_key = form key
|          form_type_code = form type code (defined in FSK_RC_FORM_CONFIG)
|          report_list = report key list of reports to be processed 
|                        The keys are separated by ' ' 
|          efile_key = efile key, specified only if e-file record 
|                      exists in FSK_RC_EFILE. This is for
|                      regenerating e-file. 
+------------------------------------------------------------------------------+
MAINDOCEND */

/*-------------------------------------------------------------------
 * Copyright (c) 2018 by SAS Institute Inc., Cary, NC 27513 USA
 *  ---All Rights Reserved.
 *-------------------------------------------------------------------*/

 
%macro rc_efile_fincen_data_x(
                            form_config_key=,
                            form_type_code=,
                            report_list=,
                            efile_key=                            
                           );
 
    %let trans_rc=0;
    %let _fcfmsg_=;

    /*----------------------------------------------------------------------
     * Assign e-file key to reports
     * out_dsn is the output table containing the efile_key and report_key
     * This step is needed because multiple e-files may be created if
     * the number of reports is bigger than the max allowed count.
     *----------------------------------------------------------------------*/
 
     %rc_efile_assign_efile_key(report_list=%superq(report_list),
                                form_config_key=&form_config_key,
                                form_type_code=&form_type_code,
                                efile_key=&efile_key,
                                out_dsn=seq_report
                         );

     %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
        %goto MACRO_END;
     %end;
    

    /*---------------------------------------------
     * extract report data with node names and values 
     * including the node types and e-file key
     *---------------------------------------------*/
    %rc_efile_fincen_detail_x(report_list=%superq(report_list),
                              form_config_key=&form_config_key,
                              form_type_code=&form_type_code,
                              efile_key=&efile_key,
                              out_dsn=rc_report_node_more_x,
                              seq_dsn=seq_report
                           );

     %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
        %goto MACRO_END;
     %end;

   
 
    /*---------------------------------------------------------
     * Extract location data (transmitter, filer, branches 
     *---------------------------------------------------------*/
     
    %rc_efile_fincen_sum_x(form_config_key=&form_config_key,
                           form_type_code=&form_type_code,
                           in_dsn=rc_report_node_more_x,
                           efile_key=&efile_key,
                           seq_dsn=seq_report
                           );

     %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
        %goto MACRO_END;
     %end;
    
                                 

%MACRO_END:
  

    %if &trans_rc eq 3 or &trans_rc ge 5 %then 
       %fcf_execute_macro(fcf_error);
    %else 
       %fcf_execute_macro(fcf_success);
    

%mend;
 
