/* MAINDOC
+------------------------------------------------------------------------------+
| NAME:    rc_efile_fincen_detail_x.sas
| PRODUCT: SAS Regulatory Console
| SYSTEM:  Windows, Unix
| DESC:    Extract report data for xml format e-filing (detail record level)
|          
+------------------------------------------------------------------------------+
| USAGE:   form_config_key = form key
|          form_type_code  = form type code (defined in FSK_RC_FORM_CONFIG)
|          report_list     = report key list of reports to be processed 
|                            Keys are separated by ' ' 
+------------------------------------------------------------------------------+
MAINDOCEND */

/*-------------------------------------------------------------------
 * Copyright (c) 2018 by SAS Institute Inc., Cary, NC 27513 USA
 *  ---All Rights Reserved.
 *-------------------------------------------------------------------*/

  

%macro rc_efile_fincen_detail_x(
                              form_config_key=, 
                              form_type_code=,
                              report_list=,
                              skipGetNodeYN=,
                              efile_key=,
                              out_dsn=rc_report_node_more_x,
                              seq_dsn=
                             );                                        

 
   
    %let trans_rc=0;
    %let _fcfmsg_=;
    
    %if %upcase(&skipGetNodeYN) ne Y or %sysfunc(exist(rc_report_node))=0 %then
    %do;
     
       %rc_rest_get_node(report_list=&report_list);
        
       %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
           %goto MACRO_END;
       %end;
       
    %end;
    
    /* create null efile key if no efile has been created */
    %if %str(&efile_key) = %str() %then %let efile_key=0;
  
    proc sql noprint; 
        create table &out_dsn %fcf_get_ds_opts(ds_name=&out_dsn, output_ds=Y, add_parens=Y) as
        select distinct &efile_key as efile_key,
               a.node_name length=32,  
               a.node_value, 
               a.report_key,
               a.entity_key,
               a.entity_level_code length=32,
               b.source_entity_level_code,
               a.node_path length=128,  
               b.form_efile_record_id,
               d.source_field_type
        from rc_report_node as a,
             rc_cfg.form_efile_record_config(%fcf_get_ds_opts(lib_name=rc_cfg, ds_name=form_efile_record_config)) as b,
             seg_kc.fsk_rc_form_code_mapping as c,
             rc_cfg.form_efile_field_config(%fcf_get_ds_opts(lib_name=rc_cfg, ds_name=form_efile_field_config)) as d 
        where  b.source_table_name='RC_REPORT_NODE'       
           and b.form_config_key=&form_config_key
           and c.form_config_key=&form_config_key
           and d.form_config_key=&form_config_key
           and a.node_name ne 'id'
           and a.node_value ne 'false'
           and a.entity_level_code=c.input_code
           and c.format_name=b.source_entity_level_code
           and a.group_key_name=b.source_group_name 
           and b.form_efile_record_id=d.form_efile_record_id
           and ((a.node_name=d.source_field_name and source_field_type ne 'ARRYCAT') or
                (substr(a.node_name,1,length(node_name)-1)=d.source_field_name and source_field_type = 'ARRYCAT')
               ) 
        order by efile_key,  report_key, source_entity_level_code, entity_key, form_efile_record_id, node_path        
        ;

    %fcf_rcset(&sqlrc);
     %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
         %let _fcfmsg_=ERROR: RC: Failed to create &out_dsn;
         %fcf_put_error;
         %goto MACRO_END;
     %end;

       /* if efile_key is not assigned, get efile key from sequence table*/
    %if &efile_key = 0 %then
    %do;
         update &out_dsn(%fcf_get_ds_opts(ds_name=&out_dsn)) as node     
         set efile_key=(select efile_key
              from &seq_dsn(%fcf_get_ds_opts(ds_name=&seq_dsn)) as seq 
              where node.report_key = seq.report_key 
              );
         %fcf_rcset(&sqlrc);
         %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
         %let _fcfmsg_=ERROR: RC: Failed to assign efile_key to &out_dsn;
         %fcf_put_error;
         %goto MACRO_END;
     %end;
    %end;
        
quit;

  
%MACRO_END:
  

    %if &trans_rc eq 3 or &trans_rc ge 5 %then 
       %fcf_execute_macro(fcf_error);
    %else 
       %fcf_execute_macro(fcf_success);
    


%mend;
 
