/* MAINDOC
+------------------------------------------------------------------------------+
| NAME:    rc_efile_fincen_narrative.sas
| PRODUCT: SAS Regulatory Console
| SYSTEM:  Windows, Unix
| DESC:    This macro breaks up NARRATIVE_LONG_DESC in FSK_RC_REPORT into 
|          smaller string to create SAR_5A.
|          This macro is called by rc_efile_fincen_detail.
|          
+------------------------------------------------------------------------------+
| USAGE:    
|          form_type_code  = form type code (defined in FSK_RC_FORM_CONFIG)
|          report_list     = report key list of reports to be processed 
|                            Keys are separated by ' ' 
|          outsize         = maximum length of the string
|          outseqmax       = maximum number of strings
+------------------------------------------------------------------------------+
MAINDOCEND */

/*-------------------------------------------------------------------
 * Copyright (c) 2016 by SAS Institute Inc., Cary, NC 27513 USA
 *  ---All Rights Reserved.
 *-------------------------------------------------------------------*/

%macro rc_efile_fincen_narrative(
                                 form_type_code=, 
                                 report_list=,
                                 outsize=850, 
                                 outseqmax=20
                            );



    data &form_type_code._5A ; 
 
         if 0 then set rc_db.&form_type_code._5A(%fcf_get_ds_opts(lib_name=rc_db, ds_name=&form_type_code._5A));
         set seg_kc.fsk_rc_report (keep=report_key narrative_long_desc);
         where report_key in (&report_list) ;     
         /* remove non printable characters including carriage return */
         narrative_long_desc=compress(narrative_long_desc,,'kw');
         start=1;     
         entity_key=report_key;
         entity_level_code='REPORT';
         record_type='5A';
         entity_seq_number=99999;
          
         row_seq_number=0; 
/* 
         if narrative_long_desc='' then 
         do;
           sar_narrative_desc = substrn(narrative_long_desc,start,&outsize);     
            node_path='narrative['||strip(put(row_seq_number,best.))||']';
            output;
            start+&outsize; 
            row_seq_number+1;    
         end;
         else 
         */
         do until (substrn(narrative_long_desc,start,&outsize) = '' and row_seq_number <= &outseqmax); 
            sar_narrative_desc = substrn(narrative_long_desc,start,&outsize);     
            node_path='narrative['||strip(put(row_seq_number,best.))||']';
            output;
            start+&outsize; 
            row_seq_number+1;      
         end;
       
         drop start narrative_long_desc ;
            
   run;

   %fcf_rcset(&syserr);
             %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
                %goto MACRO_END;
              %end;

   proc sort data=&form_type_code._5A;
        by efile_key report_key row_seq_number;
   run;

   %fcf_rcset(&syserr);
   %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
       %goto MACRO_END;
   %end; 
 

%MACRO_END:
  

    %if &trans_rc eq 3 or &trans_rc ge 5 %then 
       %fcf_execute_macro(fcf_error);
    %else 
       %fcf_execute_macro(fcf_success);
    
 

%mend;  
 
