/* MAINDOC
+------------------------------------------------------------------------------+
| NAME:    rc_efile_fincen_zip_sar.sas
| PRODUCT: SAS Regulatory Console
| SYSTEM:  Windows, Unix
| DESC:    This macro create .zip of SAR attachments.
|          
+------------------------------------------------------------------------------+
| USAGE:   form_config_key = form key 
|          form_type_code  = form type code (defined in FSK_RC_FORM_CONFIG)
|
+------------------------------------------------------------------------------+
MAINDOCEND */

/*-------------------------------------------------------------------
 * Copyright (c) 2016 by SAS Institute Inc., Cary, NC 27513 USA
 *  ---All Rights Reserved.
 *-------------------------------------------------------------------*/
 
 
%macro rc_efile_fincen_zip_sar (efile_indsn=rc_efile,
                                form_type_code=,                                  
                                form_config_key=
                                );
                                          

  
 
  
    %let efile_file_prefix=;

    proc sql noprint;

      select trim(efile_file_prefix)                
           into :efile_file_prefix               
         from seg_kc.fsk_rc_form_config
         where form_config_key=&form_config_key
      ;
       %let efile_file_prefix=%trim(&efile_file_prefix);

     %if %nrbquote(&efile_file_prefix)=%nrbquote() %then %do;
         %let _fcfmsg_=Note: RC: efile prefix is not defined for &form_type_code form in SEG_KC.FSK_RC_FORM_CONFIG.;
         %fcf_put_error;
         %fcf_rcset(3);
         %goto MACRO_END;
    %end;

     %let attachment_cnt=0;
    /* get attachment file name */
     create table &form_type_code._attachment as
     select dat.efile_key,
            dat.report_key,
            dat.report_Seq_number,
            att.attachment_name,
            att.attachment_path
     from &form_type_code._3A as dat,
            seg_kc.fsk_rc_report as db,
            seg_kc.fsk_attachment as att
     where dat.report_key=db.report_key
           and dat.attachment_ind > 0 
           and dat.attachment_ind=att.attachment_id
     order by efile_key, report_seq_number
     ;
    %fcf_rcset(&sqlrc);
    %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
         %goto MACRO_END;
    %end;
    %let attachment_cnt=&sqlobs;
     %if &attachment_cnt=0 %then %goto MACRO_END;
    

     %let zip_cnt=0;
     select distinct put(efile_key,best.),
                     count(*)
            into :zip_efile_key_1 -, 
                 :zip_attach_cnt_1 -
     from &form_type_code._attachment
     group by efile_key;
    
     %fcf_rcset(&sqlrc);
     %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
         %goto MACRO_END;
     %end;
     %let zip_cnt=&sqlobs;
     %if &zip_cnt=0 %then %goto MACRO_END;

    quit;

    %let rc_rc=0;
    proc sql;
    %do izip=1 %to &zip_cnt;
        
        %rc_mkdir(pathname=%sysfunc(pathname(work))&slash&form_type_code._&&&zip_efile_key_&izip,rcvar=rc_rc,resetYN=Y);
        %if %str(&rc_rc) ne 1 %then %do;
             %let _fcfmsg_=ERROR: RC: work directories for creating zip file is not created.;
             %fcf_put_error;
             %fcf_rcset(3);
             %goto MACRO_END;
        %end;
        
    %end;
    quit;
 

    data _null_;
          set &form_type_code._attachment;   
          by efile_key; 
          
          length fname $ 64 ;
          length attachment_filepath tmp_filepath $ 1024;
          length msg $256;
          retain attachment_filepath "&rcdata_path&slash.attachments";
          retain tmp_filepath;
           if first.efile_key then
             tmp_filepath=pathname('WORK')||"&slash"||"%trim(&form_type_code)"||'_'||strip(put(efile_key,best.));
          fname=put(report_seq_number,z5.)||'_'||strip(attachment_name);
          link copy2work;
          return;

    COPY2WORK:
           
            rc=filename('src',strip(attachment_path));
            rc=filename('save',strip(attachment_filepath)||"&slash"||
               'efile'||strip(put(efile_key,best.))||'_'||strip(fname));
            rc=filename('target',strip(tmp_filepath)||"&slash"||strip(fname));
            copyrc=fcopy('src','target');
            msg=sysmsg();
            if copyrc ne 0 then put 'Cannot copy attachment to work. ' msg=;
            copyrc=fcopy('src','save');
            msg=sysmsg();
            if copyrc ne 0 then put 'Cannot copy attachment to regulatory console. ' msg=;
            rc=filename('src');
            rc=filename('save');
            rc=filename('target');
    return;
    run; 
    %fcf_rcset(&syserr);
    %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
        %goto MACRO_END;
   %end;
         

    %let rc_rc=0;
     
    %do izip=1 %to &zip_cnt;

        %let outpath=%trim(&rc_efile_path)&slash.%trim(&efile_file_prefix)&slash&form_type_code._&&&zip_efile_key_&izip;
        filename outzip "&outpath..zip";
        %put &outpath;
        %let zippath=%sysfunc(pathname(work))&slash%trim(&form_type_code)_&&&zip_efile_key_&izip;
        
        %rc_zip(zippath=%superq(zippath),outfref=outzip,rcvar=rc_rc);
        %if %str(&rc_rc) ne 1 %then %do;
             %let _fcfmsg_=ERROR: RC: "&outpath..zip" cannot be created.;
             %fcf_put_error;
             %fcf_rcset(3);
             %goto MACRO_END;
        %end;
        
        proc sql;
        update &efile_indsn(%fcf_get_ds_opts(ds_name=&efile_indsn))
        set output_zip_name="&form_type_code._&&&zip_efile_key_&izip...zip"
        where efile_key=&&&zip_efile_key_&izip
        ;
        quit;

        %fcf_rcset(&sqlrc);
         %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
             %goto MACRO_END;
         %end;
        
    %end;
 
  

%MACRO_END:
  

    %if &trans_rc eq 3 or &trans_rc ge 5 %then 
       %fcf_execute_macro(fcf_error);
    %else 
       %fcf_execute_macro(fcf_success);
    
  


 
%mend;
 
