/* MAINDOC
+------------------------------------------------------------------------------+
| NAME:    rc_efile_fincen_zip_sarx.sas
| PRODUCT: SAS Regulatory Console
| SYSTEM:  Windows, Unix
| DESC:    This macro create .zip of SARX attachments.
|          
+------------------------------------------------------------------------------+
| USAGE:   indsn = input dataset with with report keys and attachment ids
|          efile_key = efile key 
|          form_type_code  = form type code (defined in FSK_RC_FORM_CONFIG)
|          efile_file_prefix = efile_file_prefix (defined in FSK_RC_FORM_CONFIG)
|          zip_name_var=macro variable name to return the name of the output zip file
|
+------------------------------------------------------------------------------+
MAINDOCEND */

/*-------------------------------------------------------------------
 * Copyright (c) 2018 by SAS Institute Inc., Cary, NC 27513 USA
 *  ---All Rights Reserved.
 *-------------------------------------------------------------------*/
 
 
%macro rc_efile_fincen_zip_sarx (indsn=,
                                 efile_key=,
                                 form_type_code=,
                                 efile_file_prefix=%str(fincen-sarx-v1),
                                 zip_name_var=zip_name 
                                 );

    %let trans_rc=0;
    %let _fcfmsg_=;
   
    %if &zip_name_var= %then %let zip_name_var=zip_name;
    %let &zip_name_var=;
    %if &form_type_code= %then %let form_type_code=SARX;
    %if &efile_file_prefix= %then %let efile_file_prefix=fincen-sarx-v1;
    %if &indsn = %then %do;
        %let _fcfmsg_=ERROR: Parameter indsn is required.;
        %fcf_put_error;
        %fcf_rcset(5);
        %goto MACRO_END;
    %end;
    %if &efile_key = %then %do;
        %let _fcfmsg_=ERROR: Parameter efile_key is required.;
        %fcf_put_error;
        %fcf_rcset(5);
        %goto MACRO_END;
    %end;

            
    proc sql noprint;        
    
    %let attachment_cnt=0;
    /* get attachment name and path */
        create table _attachment as
        select dat.report_key,
               dat.attachment_id,
               dat.attachment_name as report_attachment_name,
               att.attachment_name,
               att.attachment_path
        from &indsn(%fcf_get_ds_opts(ds_name=&indsn)) as dat,
             seg_kc.fsk_attachment as att
        where dat.attachment_id > 0 
              and dat.attachment_id=att.attachment_id
        order by report_key
        ;
     
        %fcf_rcset(&sqlrc);
        %put trans_rc=&trans_rc;
        %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
            %goto MACRO_END;
        %end;

     
        %let attachment_cnt=&sqlobs;  
        %if &attachment_cnt=0 %then %goto MACRO_END;

        create table mismatch_attachment as
        select *
        from _attachment
        where report_attachment_name ne attachment_name
        ;

        %let mismatch_attachment_cnt=&sqlobs;
        %if &mismatch_attachment_cnt > 0 %then %do;
            %let _fcfmsg_=ERROR: attachment names in report table and attachment table do not match.;
            %fcf_put_error;
            %fcf_rcset(5);
            %goto MACRO_END;
        %end;
    quit;
   
    /* Make work directory for creating zip file */
    %let tmp_path=%sysfunc(pathname(work))&slash&form_type_code._%trim(&efile_key); 
    %let rc_rc=0;
    %rc_mkdir(pathname=&tmp_path,rcvar=rc_rc,resetYN=Y);
    %if %str(&rc_rc) ne 1 %then %do;
        %let _fcfmsg_=ERROR: RC: work directories for creating zip file is not created.;
        %fcf_put_error;
        %fcf_rcset(3);
        %goto MACRO_END;
    %end;
     

    data _null_;
        set _attachment;  
        length fname $ 64 ;
        length attachment_filepath tmp_filepath $ 1024;
        length msg $256;
        retain attachment_filepath "&rcdata_path&slash.attachments";
        retain tmp_filepath "&tmp_path";  
        fname=strip(put(report_key,best20.))||'_'||strip(attachment_name);
        link copy2work;
    return;

    COPY2WORK:          
        rc=filename('src',strip(attachment_path));
        rc=filename('save',strip(attachment_filepath)||"&slash"||
                    "efile&efile_key._"||strip(fname));
        rc=filename('target',strip(tmp_filepath)||"&slash"||strip(fname));
        copyrc=fcopy('src','target');
        msg=sysmsg();
        if copyrc ne 0 then put 'Cannot copy attachment to work. ' msg=;
        copyrc=fcopy('src','save');
        msg=sysmsg();
        if copyrc ne 0 then put 'Cannot copy attachment to regulatory console. ' msg=;
        rc=filename('src');
        rc=filename('save');
        rc=filename('target');
    return;
    run;
	
    %fcf_rcset(&syserr);
    %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
        %goto MACRO_END;
    %end;

    %let outpath=%trim(&rc_efile_path)&slash.%trim(&efile_file_prefix)&slash&form_type_code._&efile_key;
    filename outzip "&outpath..zip";
    %let zippath=%sysfunc(pathname(work))&slash%trim(&form_type_code)_&efile_key;
        
    %rc_zip(zippath=%superq(zippath),outfref=outzip,rcvar=rc_rc);
    %if %str(&rc_rc) ne 1 %then %do;
        %let _fcfmsg_=ERROR: RC: "&outpath..zip" cannot be created.;
        %fcf_put_error;
        %fcf_rcset(3);
        %goto MACRO_END;
    %end;
        
        
    %let &zip_name_var=&form_type_code._&efile_key..zip;
         
    %fcf_rcset(&sqlrc);
    %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
        %goto MACRO_END;
    %end;
 
%MACRO_END:
  
    %if &trans_rc eq 3 or &trans_rc ge 5 %then 
       %fcf_execute_macro(fcf_error);
    %else 
       %fcf_execute_macro(fcf_success);
   
%mend;
 
