/* MAINDOC
+------------------------------------------------------------------------------+
| NAME:    rc_efile_xml_seqnum 
| PRODUCT: SAS Regulatory Console
| SYSTEM:  Windows, Unix
| DESC:    assign sequence number to xml tags
| PARAMETERS:    exclude_dsn: name of table containing numbers that should        
|                        not be used for sequence number.                          
|                exclude_var: variable in exclude_dsn that contains the seq number
|                             that should be excluded                               
|                infname: file reference of input xml                             
|                outfname: file reference of output xml                           
|                linecntVar: name of macro variable to return total number of     
|                            in the xml.                                          
| NOTE:          replacing '.' in 'SeqNum="."' with unique seq number.            
|                although FinCEN CTRX user's guide requires the sequence number be
|                consecutive and starts with 1, the efile got accepted as long    
|                as the sequence numbers are unique.                              
|          
+------------------------------------------------------------------------------+
| USAGE:    
|          form_type_code  = form type code (defined in FSK_RC_FORM_CONFIG)
+------------------------------------------------------------------------------+
MAINDOCEND */

/*-------------------------------------------------------------------
 * Copyright (c) 2018 by SAS Institute Inc., Cary, NC 27513 USA
 *  ---All Rights Reserved.
 *-------------------------------------------------------------------*/


%macro rc_efile_xml_seqnum(exclude_dsn=,
                           exclude_var=, 
                           infname=, 
                           outfname=,
                           linecntVar=line_cnt);

%let trans_rc=0;
%let _fcfmsg_=;


%let factor=100000;
%let seq_offset=0;

%if %str(&exclude_dsn) ne %str() %then
%do; 
     proc sql noprint;
	     /* round up the maximum number to the nearest factor */
         select distinct strip(put(ceil(max(&exclude_var)/&factor)*&factor,best.)) 
                into :seq_offset
          from &exclude_dsn(%fcf_get_ds_opts(ds_name=&exclude_dsn))
          ;		  
    quit;
    %fcf_rcset(&sqlrc);                       
    %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
       %let _fcfmsg_=ERROR: RC: failed to get the maximum of &exclude_var in &exclude_dsn.;
       %fcf_put_error;
       %goto MACRO_END;
   %end;


%end;

	data _null_;
		 
		infile &infname end=eof ;
		file &outfname;
		input;	

		if index(_infile_,'SeqNum="."') then
		do;     
			seqNum=&seq_offset + _n_;
			_infile_=tranwrd(_infile_,'SeqNum="."','SeqNum="'||strip(put(seqNum,best.))||'"');
		end;
		put _infile_;
		if eof then call symput("&lineCntVar",strip(put(_n_,best.)));
	run;

 %fcf_rcset(&syserr);
                       
   %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
       %let _fcfmsg_=ERROR: RC: Unable to assign sequence number.;
       %fcf_put_error;
       %goto MACRO_END;
   %end;

%MACRO_END:
  

    %if &trans_rc eq 3 or &trans_rc ge 5 %then 
       %fcf_execute_macro(fcf_error);
    %else 
       %fcf_execute_macro(fcf_success);
    


%mend;


 
