/* MAINDOC
+------------------------------------------------------------------------------+
| NAME:    rc_refresh_entity_info
| PRODUCT: SAS Regulatory Console
| SYSTEM:  Windows, Unix
| DESC:    This macro loads the rc_cfg.fincen_* data into seg_kc.fsk_rc_report_entity_info
|          
+------------------------------------------------------------------------------+
| NOTE:    This macro is called by rc_tmplt(rc_fincen_config_update_3).
|          It should be executed after rc_cfg.FINCEN_* tables are updated.
|
+------------------------------------------------------------------------------+
MAINDOCEND */

/*-------------------------------------------------------------------
 * Copyright (c) 2017-2018 by SAS Institute Inc., Cary, NC 27513 USA
 *  ---All Rights Reserved.
 *-------------------------------------------------------------------*/

%macro rc_refresh_entity_info;

    %macro rc_load_sample_by_form (form_config_key=); 


    /* load transmitter data into json for UI display */
    %rc_efile_wrt_entity_info(indsn=rc_cfg.fincen_transmitter,
                  entity_type_name=FINCEN_TRANSMITTER_%trim(&form_config_key),
                  entity_level_code=TRANSMITTER,
                  entity_key_var=transmitter_key,                  
                  entity_description_var=transmitter_control_code,                                    
                  where_cl=%str(form_config_key=&form_config_key)
                  );



     /* load institution data into json for UI display */

     %rc_efile_wrt_entity_info(indsn=rc_cfg.fincen_institution,
                  entity_type_name=FINCEN_INSTITUTION_%trim(&form_config_key),
                  entity_level_code=INSTITUTION,
                  entity_key_var=institution_key,                     
                  entity_description_var=%nrbquote(cat(strip(institution_address),strip(institution_city_name))),                      
                  default_ind_var=default_ind,
                  where_cl=%str(form_config_key=&form_config_key)
                  );
    %mend;



    %rc_load_sample_by_form (form_config_key=301);
    %rc_load_sample_by_form (form_config_key=302);
    %rc_load_sample_by_form (form_config_key=303);
    %rc_load_sample_by_form (form_config_key=312);
    %rc_load_sample_by_form (form_config_key=311);



    /* load branch data into json for UI display */
    %rc_efile_wrt_entity_info(indsn=rc_cfg.fincen_branch,
                  entity_type_name=FINCEN_BRANCH,
                  entity_level_code=BRANCH,
                  entity_key_var=branch_key,                 
                  entity_description_var=%nrbquote(cat(strip(branch_address),strip(branch_city_name))),                   
                  parent_entity_number_var=parent_entity_number
                  );

%mend;
