/* MAINDOC
+------------------------------------------------------------------------------+
| NAME:    rc_resp_fincen_ctrx
| PRODUCT: SAS Regulatory Console
| SYSTEM:  Windows, Unix
| DESC:    Process CTRX response file. 
|          
+------------------------------------------------------------------------------+
| USAGE:    indsn_response_meta=name of response meta-data table               
|           response_type_code=type of response file 
|                       (xml for manual or xml.ACKED for SDTM)  
|           infref=file reference for the directory where CTR responses can  
|                  be found.                                                 
+------------------------------------------------------------------------------+
MAINDOCEND */

/*-------------------------------------------------------------------
 * Copyright (c) 2018 by SAS Institute Inc., Cary, NC 27513 USA
 *  ---All Rights Reserved.
 *-------------------------------------------------------------------*/


%macro rc_resp_fincen_ctrx(  indsn_response_meta=
                           , response_type_code=
                           , infref=   
                           , testYN=N 
                              );
 
 %let trans_rc=;
 %let _fcfmsg_=;

 

    /* read the CTRX response file */
    /* _1A, _3A,  _ctrx_error_codes are the expected output */
    %rc_resp_fincen_ctrx_read(infref=&infref);
    
    %if &trans_rc eq 3 or &trans_rc ge 5 %then %goto MACRO_END; 

     %rc_resp_fincen_get_efile(indsn_activity=Efilingactivityxml, 
                               indsn_response_meta=&indsn_response_meta);
    
    %if &trans_rc eq 3 or &trans_rc ge 5 %then %goto MACRO_END; 

     
  
    /* Add the response data to response tables in RC_DB */    
    %rc_resp_fincen_update(       indsn_response_meta=&indsn_response_meta
                                   , indsn_error_codes=_ctrx_error_codes
                                   , indsn_1A=_1A
                                   , indsn_3A=_3A
                                   , form_type_code=CTRX
                                   , testYN=&testYN
                                  );
    %if &trans_rc eq 3 or &trans_rc ge 5 %then %goto MACRO_END; 
    
 

%MACRO_END:    

  
    %if &trans_rc eq 3 or &trans_rc ge 5 %then 
      %fcf_execute_macro(fcf_error);
    %else %do;
      %fcf_execute_macro(fcf_success);
    %end;
   

%mend;
