﻿/* MAINDOC
+------------------------------------------------------------------------------+
| NAME:    rc_resp_fincen_get_efile
| PRODUCT: SAS Regulatory Console
| SYSTEM:  Windows, Unix
| DESC:    Get e-file key based on Process CTRX response file. 
|          
+------------------------------------------------------------------------------+
| PARAMETERS:
|          indsn_activity=name of activity table containing report keys in 
|          indsn_response_meta = name of response metadata table to get e-file key                                                
+------------------------------------------------------------------------------+
MAINDOCEND */

/*-------------------------------------------------------------------
 * Copyright (c) 2018 by SAS Institute Inc., Cary, NC 27513 USA
 *  ---All Rights Reserved.
 *-------------------------------------------------------------------*/


%macro rc_resp_fincen_get_efile ( indsn_activity=Efilingactivityxml, 
                                  indsn_response_meta=response_meta_one
                                );
 
 %let trans_rc=;
 %let _fcfmsg_=;

 %let efile_key=.;
 %let output_report_count=.;
 proc sql noprint;
       
      select upcase(response_file_ext),
             response_id 
             into :response_file_ext,
                  :response_id
      from response_meta_one
      ;
      /* 
         if it is response file from sdtm, use the response ID to
         locate the e-file
      */ 
      %if %str(&response_file_ext)=%str(ACKED) %then
      %do;
          select strip(put(efile_key, best.)),
                      strip(put(output_report_count, best.)) 
             into :efile_key, 
                  :output_report_count
             from seg_kc.fsk_rc_efile
             where direct_transfer_efile_name="&response_id"
          ;
      %end;
      /*
         if efile key is unknown, try finding it from fsk_rc_efile_report 
         based on activity sequence number which is report key
       */
      %if  %str(&efile_key)=%str(.) %then
      %do;
 
          select distinct strip(put(ef.efile_key, best.)),
                          strip(put(ef.output_report_count, best.)) 
                 into :efile_key, 
                      :output_report_count
          from &indsn_activity(%fcf_get_ds_opts(ds_name=&indsn_activity)) as act,
               seg_kc.fsk_rc_efile_report 
                         (where=(file_status_code ne 'RJ')) as erpt,
               seg_kc.fsk_rc_efile as ef
          where act.EFilingActivityXML_SeqNum=erpt.report_key 
                and erpt.efile_key=ef.efile_key             
          ;
      %end;
       
     %fcf_rcset(&sqlrc);
     %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
         %let _fcfmsg_=ERROR: RC: Cannot extract efile_key and output_report_count;
         %fcf_put_error;
         %goto MACRO_END;
     %end;

      
      update &indsn_response_meta(%fcf_get_ds_opts(ds_name=&indsn_response_meta))
      set efile_key=&efile_key,
          output_report_count=&output_report_count
      ;
      
     %fcf_rcset(&sqlrc);
     %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
         %let _fcfmsg_=ERROR: RC: Cannot update &indsn_response_meta;
         %fcf_put_error;
         %goto MACRO_END;
     %end;
 
%MACRO_END:    

    quit;
  
    %if &trans_rc eq 3 or &trans_rc ge 5 %then 
      %fcf_execute_macro(fcf_error);
    %else %do;
      %fcf_execute_macro(fcf_success);
    %end;
   

%mend;
