/* MAINDOC
+------------------------------------------------------------------------------+
| NAME:    rc_rest_get_node.sas
| PRODUCT: SAS Regulatory Console
| SYSTEM:  Windows, Unix
| DESC:    Constructs the AML rest url from information gathered from the 
|          AMLService url.  Fails if the mid-tier software component is not
|          found (usually this occurs only during deployment).
+------------------------------------------------------------------------------+
| USAGE:   %rc_rest_get_node
+------------------------------------------------------------------------------+
MAINDOCEND */

/*-------------------------------------------------------------------
 * Copyright (c) 2016 by SAS Institute Inc., Cary, NC 27513 USA
 *  ---All Rights Reserved.
 *-------------------------------------------------------------------*/
 
%macro rc_rest_get_node(report_list=);
 
    %let trans_rc=0;
    %let _fcfmsg_=;


    %if %nrbquote(&fcf_service_RegulatoryReports)=%nrbquote() %then
    %do;
         
          %let fcf_service_RegulatoryReports=;
          %fcf_get_rest_url(domainType=RegulatoryReports);

         %if %nrbquote(&fcf_service_RegulatoryReports)=%nrbquote() %then
         %do;
             %let _fcfmsg_=Error: RC: cannot retreive report service url.;
             %fcf_put_error;     
             %goto MACRO_END;
         %end;
    %end;
                                            
  

     %if %sysfunc(exist(rc_report_node)) %then 
     %do;
         proc sql noprint;
              drop table rc_report_node;
         quit;
         
        %fcf_rcset(&sqlrc);
        %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
             %let _fcfmsg_=Error: RC: cannot deleting existing RC_REPORT_NODE.;
             %fcf_put_error;     
             %goto MACRO_END;
        %end;
     %end;

    /* Extract report nodes from ui_json for each report and its associated entities */

    %let repport_key=;
    %let ireport=1;

    %do %while(%scan(&report_list,&ireport) ne );

        %let report_key=%scan(&report_list,&ireport);

        %let request_url=&fcf_service_RegulatoryReports/&report_key/nodes.xml?businessUnit=&segKCDBUser;

           filename srv_resp temp;
           /* call regulatorReport REST service */
            
           proc http url="&request_url"
                     out=srv_resp
                     method="get"
                     ct="application/x-www-form-urlencoded" 
                     HTTP_TOKENAUTH                       
               %if %str(&rc_webusername) ne %str() and
                   %str(&rc_webpassword) ne %str() %then
               %do;                             
                     webusername="&rc_webusername" webpassword="&rc_webpassword"  
               %end;    
                     
           ;

           run;
             
            %fcf_rcset(&syserr);
           
            %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
                 %let _fcfmsg_=Error: RC: cannot call report REST service.;
                 %fcf_put_error;     
                 %goto MACRO_END;
            %end;

            libname  srv_resp xml92  xmlmap="&fcf_xml_map_path/rc_report_node.map";
            proc copy in=srv_resp out=work;               
            run;
            
            %let error_msg=;
            proc sql noprint;
                 select distinct message into :error_msg 
                 from error
            ;
            quit;

            libname srv_resp clear;
            filename srv_resp clear;

            %if %nrbquote(&error_msg) ne %nrbquote() %then 
            %do;
 
                %fcf_rcset(5);                
                %let _fcfmsg_=Error: RC: error message "%trim(&error_msg)" found in service call.;
                %fcf_put_error;     
                %goto MACRO_END;
              
            %end;
        

      

       %if &ireport=1 %then 
       %do;
          data rc_report_node;
               set report_node (where=(node_value ne 'null' and node_value ne '' ));
          run;

          %fcf_rcset(&syserr);
          %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
             %let _fcfmsg_=Error: RC: cannot create report_node.;
             %fcf_put_error;     
             %goto MACRO_END;
          %end;
         
       
       %end;
       %else 
       %do;
           proc append base=rc_report_node data=report_node (where=(node_value ne 'null' and node_value ne '' )) force;
           run;
       %end;

        %fcf_rcset(&syserr);
        %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
             %let _fcfmsg_=Error: RC: cannot create report nodes for report &report_key;
             %fcf_put_error;     
             %goto MACRO_END;
        %end;
         %let ireport=%eval(&ireport+1);
        %end;
       

 %MACRO_END:
      

        %if &trans_rc eq 3 or &trans_rc ge 5 %then 
           %fcf_execute_macro(fcf_error);
        %else 
           %fcf_execute_macro(fcf_success);
              
 
 
%mend;
 
